# -*- coding: mbcs -*-
# Created by makepy.py version 0.5.01
# By python version 2.7.10 (default, May 23 2015, 09:40:32) [MSC v.1500 32 bit (Intel)]
# From type library 'SAPbobsCOM67.dll'
# On Thu Oct 06 16:26:20 2016
'SAP Business One DI API Version 2004'
makepy_version = '0.5.01'
python_version = 0x2070af0

import win32com.client.CLSIDToClass, pythoncom, pywintypes
import win32com.client.util
from pywintypes import IID
from win32com.client import Dispatch

# The following 3 lines may need tweaking for the particular server
# Candidates are pythoncom.Missing, .Empty and .ArgNotFound
defaultNamedOptArg=pythoncom.Empty
defaultNamedNotOptArg=pythoncom.Empty
defaultUnnamedArg=pythoncom.Empty

CLSID = IID('{57B30C66-6F53-4B32-9E9A-1C4CE6E28B62}')
MajorVersion = 6
MinorVersion = 7
LibraryFlags = 8
LCID = 0x0

class constants:
	bodt_CreditNote               =14         # from enum BoAPARDocumentTypes
	bodt_DeliveryNote             =15         # from enum BoAPARDocumentTypes
	bodt_Invoice                  =13         # from enum BoAPARDocumentTypes
	bodt_Order                    =17         # from enum BoAPARDocumentTypes
	bodt_PurchaseCreditNote       =19         # from enum BoAPARDocumentTypes
	bodt_PurchaseDeliveryNote     =20         # from enum BoAPARDocumentTypes
	bodt_PurchaseInvoice          =18         # from enum BoAPARDocumentTypes
	bodt_PurchaseOrder            =22         # from enum BoAPARDocumentTypes
	bodt_PurchaseReturn           =21         # from enum BoAPARDocumentTypes
	bodt_Quotation                =23         # from enum BoAPARDocumentTypes
	bodt_Return                   =16         # from enum BoAPARDocumentTypes
	at_Expenses                   =1          # from enum BoAccountTypes
	at_Other                      =2          # from enum BoAccountTypes
	at_Revenues                   =0          # from enum BoAccountTypes
	cn_Conversation               =0          # from enum BoActivities
	cn_Meeting                    =1          # from enum BoActivities
	cn_Note                       =4          # from enum BoActivities
	cn_Other                      =3          # from enum BoActivities
	cn_Task                       =2          # from enum BoActivities
	aedm_Equally                  =4          # from enum BoAdEpnsDistribMethods
	aedm_None                     =0          # from enum BoAdEpnsDistribMethods
	aedm_Quantity                 =1          # from enum BoAdEpnsDistribMethods
	aedm_RowTotal                 =5          # from enum BoAdEpnsDistribMethods
	aedm_Volume                   =2          # from enum BoAdEpnsDistribMethods
	aedm_Weight                   =3          # from enum BoAdEpnsDistribMethods
	aext_NoTax                    =1          # from enum BoAdEpnsTaxTypes
	aext_NormalTax                =0          # from enum BoAdEpnsTaxTypes
	aext_UseTax                   =2          # from enum BoAdEpnsTaxTypes
	bo_BillTo                     =1          # from enum BoAddressType
	bo_ShipTo                     =0          # from enum BoAddressType
	aed_Equally                   =4          # from enum BoAeDistMthd
	aed_LineTotal                 =5          # from enum BoAeDistMthd
	aed_None                      =0          # from enum BoAeDistMthd
	aed_Quantity                  =1          # from enum BoAeDistMthd
	aed_Volume                    =2          # from enum BoAeDistMthd
	aed_Weight                    =3          # from enum BoAeDistMthd
	bobt_Incoming                 =0          # from enum BoBOETypes
	bobt_Outgoing                 =1          # from enum BoBOETypes
	btfs_Deposited                =2          # from enum BoBOTFromStatus
	btfs_Generated                =1          # from enum BoBOTFromStatus
	btfs_Paid                     =3          # from enum BoBOTFromStatus
	btfs_Sent                     =0          # from enum BoBOTFromStatus
	btts_Canceled                 =0          # from enum BoBOTToStatus
	btts_Closed                   =5          # from enum BoBOTToStatus
	btts_Deposit                  =2          # from enum BoBOTToStatus
	btts_Failed                   =4          # from enum BoBOTToStatus
	btts_Generated                =1          # from enum BoBOTToStatus
	btts_Paid                     =3          # from enum BoBOTToStatus
	bld_PostingDate               =0          # from enum BoBaselineDate
	bld_SystemDate                =1          # from enum BoBaselineDate
	bld_TaxDate                   =2          # from enum BoBaselineDate
	boes_Cancelled                =4          # from enum BoBoeStatus
	boes_Closed                   =5          # from enum BoBoeStatus
	boes_Created                  =0          # from enum BoBoeStatus
	boes_Deposited                =2          # from enum BoBoeStatus
	boes_Failed                   =6          # from enum BoBoeStatus
	boes_Paid                     =3          # from enum BoBoeStatus
	boes_Sent                     =1          # from enum BoBoeStatus
	bpat_AssetsAccount            =2          # from enum BoBpAccountTypes
	bpat_AssetsPayable            =7          # from enum BoBpAccountTypes
	bpat_Discounted               =8          # from enum BoBpAccountTypes
	bpat_DownPayment              =1          # from enum BoBpAccountTypes
	bpat_General                  =0          # from enum BoBpAccountTypes
	bpat_OnCollection             =5          # from enum BoBpAccountTypes
	bpat_OpenDebts                =10         # from enum BoBpAccountTypes
	bpat_Payable                  =4          # from enum BoBpAccountTypes
	bpat_Presentation             =6          # from enum BoBpAccountTypes
	bpat_Receivable               =3          # from enum BoBpAccountTypes
	bpat_Unpaid                   =9          # from enum BoBpAccountTypes
	bpdt_DocNum                   =2          # from enum BoBpsDocTypes
	bpdt_ISR                      =1          # from enum BoBpsDocTypes
	bpdt_PaymentReference         =0          # from enum BoBpsDocTypes
	bbpgt_CustomerGroup           =0          # from enum BoBusinessPartnerGroupTypes
	bbpgt_VendorGroup             =1          # from enum BoBusinessPartnerGroupTypes
	cCompany                      =0          # from enum BoCardCompanyTypes
	cPrivate                      =1          # from enum BoCardCompanyTypes
	cCustomer                     =0          # from enum BoCardTypes
	cLid                          =2          # from enum BoCardTypes
	cSupplier                     =1          # from enum BoCardTypes
	bocpdbld_BaseSystemDate       =1          # from enum BoClosingDateProcedureBaseDateEnum
	bocpdbld_PostingDate          =0          # from enum BoClosingDateProcedureBaseDateEnum
	bocpddm_HalfMonth             =1          # from enum BoClosingDateProcedureDueMonthEnum
	bocpddm_MonthEnd              =0          # from enum BoClosingDateProcedureDueMonthEnum
	bocpddm_MonthStart            =2          # from enum BoClosingDateProcedureDueMonthEnum
	ct_Customer                   =0          # from enum BoContractTypes
	ct_ItemGroup                  =1          # from enum BoContractTypes
	ct_SerialNumber               =2          # from enum BoContractTypes
	ciis_ShouldBe                 =1          # from enum BoCorInvItemStatus
	ciis_Was                      =0          # from enum BoCorInvItemStatus
	cfp_Account                   =1          # from enum BoCpCardAcct
	cfp_Card                      =0          # from enum BoCpCardAcct
	bocs_BPCurrency               =2          # from enum BoCurrencySources
	bocs_LocalCurrency            =0          # from enum BoCurrencySources
	bocs_SystemCurrency           =1          # from enum BoCurrencySources
	dst_DB_2                      =2          # from enum BoDataServerTypes
	dst_MSSQL                     =1          # from enum BoDataServerTypes
	dst_SYBASE                    =3          # from enum BoDataServerTypes
	dpt_Collection                =0          # from enum BoDepositPostingTypes
	dpt_Discounted                =1          # from enum BoDepositPostingTypes
	dByDocuments                  =2          # from enum BoDocSummaryTypes
	dByItems                      =1          # from enum BoDocSummaryTypes
	dNoSummary                    =0          # from enum BoDocSummaryTypes
	dwh_Consignment               =3          # from enum BoDocWhsUpdateTypes
	dwh_CustomerOrders            =2          # from enum BoDocWhsUpdateTypes
	dwh_No                        =0          # from enum BoDocWhsUpdateTypes
	dwh_OrdersFromVendors         =1          # from enum BoDocWhsUpdateTypes
	dwh_Stock                     =4          # from enum BoDocWhsUpdateTypes
	dlps_NotPicked                =1          # from enum BoDocumentLinePickStatus
	dlps_PartiallyPicked          =3          # from enum BoDocumentLinePickStatus
	dlps_Picked                   =0          # from enum BoDocumentLinePickStatus
	dlps_ReleasedForPicking       =2          # from enum BoDocumentLinePickStatus
	bod_Bill                      =3          # from enum BoDocumentSubType
	bod_DebitMemo                 =2          # from enum BoDocumentSubType
	bod_ExemptBill                =4          # from enum BoDocumentSubType
	bod_ExportInvoice             =6          # from enum BoDocumentSubType
	bod_InvoiceExempt             =1          # from enum BoDocumentSubType
	bod_None                      =0          # from enum BoDocumentSubType
	bod_PurchaseDebitMemo         =5          # from enum BoDocumentSubType
	dDocument_Items               =0          # from enum BoDocumentTypes
	dDocument_Service             =1          # from enum BoDocumentTypes
	du_Days                       =2          # from enum BoDurations
	du_Hours                      =1          # from enum BoDurations
	du_Minuts                     =0          # from enum BoDurations
	cDelivery_sum                 =1          # from enum BoFatherCardTypes
	cPayments_sum                 =0          # from enum BoFatherCardTypes
	db_Alpha                      =0          # from enum BoFieldTypes
	db_Date                       =3          # from enum BoFieldTypes
	db_Float                      =4          # from enum BoFieldTypes
	db_Memo                       =1          # from enum BoFieldTypes
	db_Numeric                    =2          # from enum BoFieldTypes
	st_Address                    =63         # from enum BoFldSubTypes
	st_Image                      =73         # from enum BoFldSubTypes
	st_Link                       =66         # from enum BoFldSubTypes
	st_Measurement                =77         # from enum BoFldSubTypes
	st_None                       =0          # from enum BoFldSubTypes
	st_Percentage                 =37         # from enum BoFldSubTypes
	st_Phone                      =35         # from enum BoFldSubTypes
	st_Price                      =80         # from enum BoFldSubTypes
	st_Quantity                   =81         # from enum BoFldSubTypes
	st_Rate                       =82         # from enum BoFldSubTypes
	st_Sum                        =83         # from enum BoFldSubTypes
	st_Time                       =84         # from enum BoFldSubTypes
	glm_ItemClass                 =1          # from enum BoGLMethods
	glm_ItemLevel                 =2          # from enum BoGLMethods
	glm_WH                        =0          # from enum BoGLMethods
	gt_Female                     =0          # from enum BoGenderTypes
	gt_Male                       =1          # from enum BoGenderTypes
	bis_FIFO                      =2          # from enum BoInventorySystem
	bis_MovingAverage             =0          # from enum BoInventorySystem
	bis_Standard                  =1          # from enum BoInventorySystem
	im_Backflush                  =0          # from enum BoIssueMethod
	im_Manual                     =1          # from enum BoIssueMethod
	iAssemblyTree                 =1          # from enum BoItemTreeTypes
	iNotATree                     =0          # from enum BoItemTreeTypes
	iProductionTree               =3          # from enum BoItemTreeTypes
	iSalesTree                    =2          # from enum BoItemTreeTypes
	iTemplateTree                 =4          # from enum BoItemTreeTypes
	bomm_OnEveryTransaction       =0          # from enum BoManageMethod
	bomm_OnReleaseOnly            =1          # from enum BoManageMethod
	mt_FinishedGoods              =1          # from enum BoMaterialTypes
	mt_GoodsInProcess             =2          # from enum BoMaterialTypes
	mt_RawMaterial                =3          # from enum BoMaterialTypes
	mts_Divorced                  =2          # from enum BoMeritalStatuses
	mts_Married                   =1          # from enum BoMeritalStatuses
	mts_Single                    =0          # from enum BoMeritalStatuses
	mts_Widowed                   =3          # from enum BoMeritalStatuses
	mpt_Measure                   =5          # from enum BoMoneyPrecisionTypes
	mpt_Percent                   =4          # from enum BoMoneyPrecisionTypes
	mpt_Price                     =1          # from enum BoMoneyPrecisionTypes
	mpt_Quantity                  =3          # from enum BoMoneyPrecisionTypes
	mpt_Rate                      =2          # from enum BoMoneyPrecisionTypes
	mpt_Sum                       =0          # from enum BoMoneyPrecisionTypes
	mpt_Tax                       =6          # from enum BoMoneyPrecisionTypes
	pr_High                       =2          # from enum BoMsgPriorities
	pr_Low                        =0          # from enum BoMsgPriorities
	pr_Normal                     =1          # from enum BoMsgPriorities
	rt_ContactPerson              =11         # from enum BoMsgRcpTypes
	rt_InternalUser               =12         # from enum BoMsgRcpTypes
	rt_RandomUser                 =-1         # from enum BoMsgRcpTypes
	bopt_Electronic               =1          # from enum BoORCTPaymentTypeEnum
	bopt_Express                  =4          # from enum BoORCTPaymentTypeEnum
	bopt_None                     =0          # from enum BoORCTPaymentTypeEnum
	bopt_Post                     =2          # from enum BoORCTPaymentTypeEnum
	bopt_Telegraph                =3          # from enum BoORCTPaymentTypeEnum
	BoBridge                      =305        # from enum BoObjectTypes
	BoRecordset                   =300        # from enum BoObjectTypes
	oActivityLocations            =104        # from enum BoObjectTypes
	oActivityStatus               =217        # from enum BoObjectTypes
	oActivityTypes                =103        # from enum BoObjectTypes
	oAdditionalExpenses           =125        # from enum BoObjectTypes
	oAlternateCatNum              =73         # from enum BoObjectTypes
	oBPFiscalRegistryID           =278        # from enum BoObjectTypes
	oBankPages                    =42         # from enum BoObjectTypes
	oBillOfExchangeTransactions   =182        # from enum BoObjectTypes
	oBudget                       =77         # from enum BoObjectTypes
	oBudgetDistribution           =78         # from enum BoObjectTypes
	oBudgetScenarios              =91         # from enum BoObjectTypes
	oBusinessPartnerGroups        =10         # from enum BoObjectTypes
	oBusinessPartners             =2          # from enum BoObjectTypes
	oBusinessPlaces               =247        # from enum BoObjectTypes
	oChartOfAccounts              =1          # from enum BoObjectTypes
	oChecksforPayment             =57         # from enum BoObjectTypes
	oClosingDateProcedure         =261        # from enum BoObjectTypes
	oContacts                     =33         # from enum BoObjectTypes
	oContractTemplates            =170        # from enum BoObjectTypes
	oCorrectionInvoice            =165        # from enum BoObjectTypes
	oCorrectionInvoiceReversal    =166        # from enum BoObjectTypes
	oCorrectionPurchaseInvoice    =163        # from enum BoObjectTypes
	oCorrectionPurchaseInvoiceReversal=164        # from enum BoObjectTypes
	oCreditNotes                  =14         # from enum BoObjectTypes
	oCurrencyCodes                =37         # from enum BoObjectTypes
	oCustomerEquipmentCards       =176        # from enum BoObjectTypes
	oCustomsGroups                =56         # from enum BoObjectTypes
	oDeliveryNotes                =15         # from enum BoObjectTypes
	oDrafts                       =112        # from enum BoObjectTypes
	oDunningLetters               =151        # from enum BoObjectTypes
	oEmployeesInfo                =171        # from enum BoObjectTypes
	oIncomingPayments             =24         # from enum BoObjectTypes
	oIndustries                   =201        # from enum BoObjectTypes
	oInventoryGenEntry            =59         # from enum BoObjectTypes
	oInventoryGenExit             =60         # from enum BoObjectTypes
	oInvoices                     =13         # from enum BoObjectTypes
	oItemGroups                   =52         # from enum BoObjectTypes
	oItems                        =4          # from enum BoObjectTypes
	oJournalEntries               =30         # from enum BoObjectTypes
	oJournalVouchers              =28         # from enum BoObjectTypes
	oKnowledgeBaseSolutions       =189        # from enum BoObjectTypes
	oLocalEra                     =250        # from enum BoObjectTypes
	oManufacturers                =43         # from enum BoObjectTypes
	oMaterialRevaluation          =162        # from enum BoObjectTypes
	oMessages                     =81         # from enum BoObjectTypes
	oNotaFiscalCFOP               =258        # from enum BoObjectTypes
	oNotaFiscalCST                =259        # from enum BoObjectTypes
	oNotaFiscalUsage              =260        # from enum BoObjectTypes
	oOrders                       =17         # from enum BoObjectTypes
	oPackagesTypes                =205        # from enum BoObjectTypes
	oPaymentRunExport             =158        # from enum BoObjectTypes
	oPaymentTermsTypes            =40         # from enum BoObjectTypes
	oPaymentsDrafts               =140        # from enum BoObjectTypes
	oPriceLists                   =6          # from enum BoObjectTypes
	oProductTrees                 =66         # from enum BoObjectTypes
	oProductionOrders             =202        # from enum BoObjectTypes
	oPurchaseCreditNotes          =19         # from enum BoObjectTypes
	oPurchaseDeliveryNotes        =20         # from enum BoObjectTypes
	oPurchaseInvoices             =18         # from enum BoObjectTypes
	oPurchaseOrders               =22         # from enum BoObjectTypes
	oPurchaseReturns              =21         # from enum BoObjectTypes
	oPurchaseTaxInvoice           =281        # from enum BoObjectTypes
	oQueryCategories              =134        # from enum BoObjectTypes
	oQueue                        =194        # from enum BoObjectTypes
	oQuotations                   =23         # from enum BoObjectTypes
	oRelationships                =212        # from enum BoObjectTypes
	oReturns                      =16         # from enum BoObjectTypes
	oSalesForecast                =198        # from enum BoObjectTypes
	oSalesOpportunities           =97         # from enum BoObjectTypes
	oSalesTaxAuthorities          =126        # from enum BoObjectTypes
	oSalesTaxAuthoritiesTypes     =127        # from enum BoObjectTypes
	oSalesTaxCodes                =128        # from enum BoObjectTypes
	oSalesTaxInvoice              =280        # from enum BoObjectTypes
	oServiceCalls                 =191        # from enum BoObjectTypes
	oServiceContracts             =190        # from enum BoObjectTypes
	oShippingTypes                =49         # from enum BoObjectTypes
	oSpecialPrices                =7          # from enum BoObjectTypes
	oStockTakings                 =31         # from enum BoObjectTypes
	oStockTransfer                =67         # from enum BoObjectTypes
	oTeams                        =211        # from enum BoObjectTypes
	oTerritories                  =200        # from enum BoObjectTypes
	oUserFields                   =152        # from enum BoObjectTypes
	oUserKeys                     =193        # from enum BoObjectTypes
	oUserObjectsMD                =206        # from enum BoObjectTypes
	oUserPermissionTree           =214        # from enum BoObjectTypes
	oUserTables                   =153        # from enum BoObjectTypes
	oUsers                        =12         # from enum BoObjectTypes
	oVendorPayments               =46         # from enum BoObjectTypes
	oWarehouses                   =64         # from enum BoObjectTypes
	oWorkOrders                   =68         # from enum BoObjectTypes
	oip_BankTransfer              =4          # from enum BoOpenIncPayment
	oip_Cash                      =1          # from enum BoOpenIncPayment
	oip_Checks                    =2          # from enum BoOpenIncPayment
	oip_Credit                    =3          # from enum BoOpenIncPayment
	oip_No                        =0          # from enum BoOpenIncPayment
	bos_Close                     =1          # from enum BoOpexStatus
	bos_Open                      =0          # from enum BoOpexStatus
	pdt_HalfMonth                 =1          # from enum BoPayTermDueTypes
	pdt_MonthEnd                  =0          # from enum BoPayTermDueTypes
	pdt_MonthStart                =2          # from enum BoPayTermDueTypes
	pdt_None                      =3          # from enum BoPayTermDueTypes
	bopp_Priority_1               =0          # from enum BoPaymentPriorities
	bopp_Priority_2               =1          # from enum BoPaymentPriorities
	bopp_Priority_3               =2          # from enum BoPaymentPriorities
	bopp_Priority_4               =3          # from enum BoPaymentPriorities
	bopp_Priority_5               =4          # from enum BoPaymentPriorities
	bopp_Priority_6               =5          # from enum BoPaymentPriorities
	bopot_IncomingPayments        =0          # from enum BoPaymentsObjectType
	bopot_OutgoingPayments        =1          # from enum BoPaymentsObjectType
	boper_Full                    =1          # from enum BoPermission
	boper_None                    =3          # from enum BoPermission
	boper_ReadOnly                =2          # from enum BoPermission
	boper_Undefined               =6          # from enum BoPermission
	boper_Various                 =4          # from enum BoPermission
	bop_MRP                       =0          # from enum BoPlanningSystem
	bop_None                      =1          # from enum BoPlanningSystem
	boplgn_Group1                 =0          # from enum BoPriceListGroupNum
	boplgn_Group2                 =1          # from enum BoPriceListGroupNum
	boplgn_Group3                 =2          # from enum BoPriceListGroupNum
	boplgn_Group4                 =3          # from enum BoPriceListGroupNum
	bom_Buy                       =0          # from enum BoProcurementMethod
	bom_Make                      =1          # from enum BoProcurementMethod
	bps_ImportedByCompany         =2          # from enum BoProductSources
	bps_ImportedGoodsPurchasedFromDomVendor=3          # from enum BoProductSources
	bps_ProducedByCompany         =4          # from enum BoProductSources
	bps_PurchasedFromDomVendor    =1          # from enum BoProductSources
	bopooMRP                      =1          # from enum BoProductionOrderOriginEnum
	bopooManual                   =0          # from enum BoProductionOrderOriginEnum
	bopooSalesOrder               =2          # from enum BoProductionOrderOriginEnum
	boposCancelled                =3          # from enum BoProductionOrderStatusEnum
	boposClosed                   =2          # from enum BoProductionOrderStatusEnum
	boposPlanned                  =0          # from enum BoProductionOrderStatusEnum
	boposReleased                 =1          # from enum BoProductionOrderStatusEnum
	bopotDisassembly              =2          # from enum BoProductionOrderTypeEnum
	bopotSpecial                  =1          # from enum BoProductionOrderTypeEnum
	bopotStandard                 =0          # from enum BoProductionOrderTypeEnum
	bqc_Equal                     =0          # from enum BoQueryConditions
	bqc_Like                      =2          # from enum BoQueryConditions
	bqc_NotEqual                  =1          # from enum BoQueryConditions
	cr_Regular                    =0          # from enum BoRcptCredTypes
	cr_Telephone                  =1          # from enum BoRcptCredTypes
	it_AllTransactions            =-1         # from enum BoRcptInvTypes
	it_ChequesForPayment          =57         # from enum BoRcptInvTypes
	it_ClosingBalance             =-3         # from enum BoRcptInvTypes
	it_CorrectionInvoice          =132        # from enum BoRcptInvTypes
	it_CredItnote                 =14         # from enum BoRcptInvTypes
	it_DeferredDeposit            =76         # from enum BoRcptInvTypes
	it_Deposit                    =25         # from enum BoRcptInvTypes
	it_GeneralReceiptToStock      =59         # from enum BoRcptInvTypes
	it_GeneralReleaseFromStock    =60         # from enum BoRcptInvTypes
	it_Invoice                    =13         # from enum BoRcptInvTypes
	it_JournalEntry               =30         # from enum BoRcptInvTypes
	it_OpeningBalance             =-2         # from enum BoRcptInvTypes
	it_PaymentAdvice              =46         # from enum BoRcptInvTypes
	it_PurchaseCreditNote         =19         # from enum BoRcptInvTypes
	it_PurchaseDeliveryNote       =20         # from enum BoRcptInvTypes
	it_PurchaseInvoice            =18         # from enum BoRcptInvTypes
	it_PurchaseReturn             =21         # from enum BoRcptInvTypes
	it_Receipt                    =24         # from enum BoRcptInvTypes
	it_Return                     =16         # from enum BoRcptInvTypes
	it_StockReconciliations       =58         # from enum BoRcptInvTypes
	it_TaxInvoice                 =15         # from enum BoRcptInvTypes
	it_TransferBetweenWarehouses  =67         # from enum BoRcptInvTypes
	it_WorkInstructions           =68         # from enum BoRcptInvTypes
	rAccount                      =1          # from enum BoRcptTypes
	rCustomer                     =0          # from enum BoRcptTypes
	rSupplier                     =2          # from enum BoRcptTypes
	rcpt_In                       =0          # from enum BoRecCommParamTypes
	rcpt_Out                      =1          # from enum BoRecCommParamTypes
	reu_Days                      =0          # from enum BoRemindUnits
	reu_Month                     =2          # from enum BoRemindUnits
	reu_Weeks                     =1          # from enum BoRemindUnits
	rsu_Days                      =0          # from enum BoResolutionUnits
	rsu_Hours                     =1          # from enum BoResolutionUnits
	boru_Day                      =1          # from enum BoResponseUnit
	boru_Hour                     =0          # from enum BoResponseUnit
	borit_Leader                  =1          # from enum BoRoleInTeam
	borit_Member                  =0          # from enum BoRoleInTeam
	borm_NoRounding               =0          # from enum BoRoundingMethod
	borm_RoundToFullAmount        =2          # from enum BoRoundingMethod
	borm_RoundToFullDecAmount     =1          # from enum BoRoundingMethod
	borm_RoundToFullTensAmount    =3          # from enum BoRoundingMethod
	scu_Day                       =1          # from enum BoSalaryCostUnits
	scu_Hour                      =0          # from enum BoSalaryCostUnits
	scu_Month                     =3          # from enum BoSalaryCostUnits
	scu_Week                      =2          # from enum BoSalaryCostUnits
	scu_Year                      =4          # from enum BoSalaryCostUnits
	sns_Active                    =0          # from enum BoSerialNumberStatus
	sns_InLab                     =4          # from enum BoSerialNumberStatus
	sns_Loaned                    =3          # from enum BoSerialNumberStatus
	sns_Returned                  =1          # from enum BoSerialNumberStatus
	sns_Terminated                =2          # from enum BoSerialNumberStatus
	bst_Regular                   =0          # from enum BoServiceTypes
	bst_Warranty                  =1          # from enum BoServiceTypes
	sos_Days                      =2          # from enum BoSoClosedInTypes
	sos_Months                    =0          # from enum BoSoClosedInTypes
	sos_Weeks                     =1          # from enum BoSoClosedInTypes
	sos_Missed                    =1          # from enum BoSoOsStatus
	sos_Open                      =0          # from enum BoSoOsStatus
	sos_Sold                      =2          # from enum BoSoOsStatus
	so_Closed                     =1          # from enum BoSoStatus
	so_Open                       =0          # from enum BoSoStatus
	bost_Close                    =1          # from enum BoStatus
	bost_Open                     =0          # from enum BoStatus
	bos_TransferFromTechnician    =1          # from enum BoStckTrnDir
	bos_TransferToTechnician      =0          # from enum BoStckTrnDir
	ln_Chinese                    =15         # from enum BoSuppLangs
	ln_Czech_Cz                   =26         # from enum BoSuppLangs
	ln_Danish                     =11         # from enum BoSuppLangs
	ln_Dutch                      =16         # from enum BoSuppLangs
	ln_English                    =3          # from enum BoSuppLangs
	ln_English_Cy                 =21         # from enum BoSuppLangs
	ln_English_Gb                 =8          # from enum BoSuppLangs
	ln_English_Sg                 =6          # from enum BoSuppLangs
	ln_Finnish                    =17         # from enum BoSuppLangs
	ln_French                     =22         # from enum BoSuppLangs
	ln_German                     =9          # from enum BoSuppLangs
	ln_Greek                      =18         # from enum BoSuppLangs
	ln_Hebrew                     =1          # from enum BoSuppLangs
	ln_Hungarian                  =14         # from enum BoSuppLangs
	ln_Italian                    =13         # from enum BoSuppLangs
	ln_Japanese_Jp                =30         # from enum BoSuppLangs
	ln_Korean_Kr                  =28         # from enum BoSuppLangs
	ln_Norwegian                  =12         # from enum BoSuppLangs
	ln_Polish                     =5          # from enum BoSuppLangs
	ln_Portuguese                 =19         # from enum BoSuppLangs
	ln_Portuguese_Br              =29         # from enum BoSuppLangs
	ln_Russian                    =24         # from enum BoSuppLangs
	ln_Serbian                    =10         # from enum BoSuppLangs
	ln_Slovak_Sk                  =27         # from enum BoSuppLangs
	ln_Spanish                    =23         # from enum BoSuppLangs
	ln_Spanish_Ar                 =2          # from enum BoSuppLangs
	ln_Spanish_La                 =25         # from enum BoSuppLangs
	ln_Spanish_Pa                 =7          # from enum BoSuppLangs
	ln_Swedish                    =20         # from enum BoSuppLangs
	ln_TrdtnlChinese_Hk           =35         # from enum BoSuppLangs
	ln_Turkish_Tr                 =31         # from enum BoSuppLangs
	scp_High                      =2          # from enum BoSvcCallPriorities
	scp_Low                       =0          # from enum BoSvcCallPriorities
	scp_Medium                    =1          # from enum BoSvcCallPriorities
	scs_Approved                  =0          # from enum BoSvcContractStatus
	scs_Draft                     =2          # from enum BoSvcContractStatus
	scs_Frozen                    =1          # from enum BoSvcContractStatus
	scs_Terminated                =3          # from enum BoSvcContractStatus
	edt_CreditMemo                =14         # from enum BoSvcEpxDocTypes
	edt_Delivery                  =15         # from enum BoSvcEpxDocTypes
	edt_Invoice                   =13         # from enum BoSvcEpxDocTypes
	edt_Return                    =16         # from enum BoSvcEpxDocTypes
	edt_StockTransfer             =67         # from enum BoSvcEpxDocTypes
	sep_Inventory                 =0          # from enum BoSvcExpPartTypes
	sep_NonInventory              =1          # from enum BoSvcExpPartTypes
	botit_Invoice                 =0          # from enum BoTaxInvoiceTypes
	botit_JournalEntry            =2          # from enum BoTaxInvoiceTypes
	botit_Payment                 =1          # from enum BoTaxInvoiceTypes
	tt_No                         =1          # from enum BoTaxTypes
	tt_UseTax                     =2          # from enum BoTaxTypes
	tt_Yes                        =0          # from enum BoTaxTypes
	botrntComplete                =0          # from enum BoTransactionTypeEnum
	botrntReject                  =1          # from enum BoTransactionTypeEnum
	boud_Document                 =3          # from enum BoUDOObjType
	boud_MasterData               =1          # from enum BoUDOObjType
	bou_FullNone                  =1          # from enum BoUPTOptions
	bou_FullReadNone              =0          # from enum BoUPTOptions
	bott_Document                 =3          # from enum BoUTBTableType
	bott_DocumentLines            =4          # from enum BoUTBTableType
	bott_MasterData               =1          # from enum BoUTBTableType
	bott_MasterDataLines          =2          # from enum BoUTBTableType
	bott_NoObject                 =0          # from enum BoUTBTableType
	vEC                           =2          # from enum BoVatStatus
	vExempted                     =0          # from enum BoVatStatus
	vLiable                       =1          # from enum BoVatStatus
	wf_Commit                     =0          # from enum BoWfTransOpt
	wf_RollBack                   =1          # from enum BoWfTransOpt
	wk_ProductComplete            =2          # from enum BoWorkOrderStat
	wk_WorkInstruction            =1          # from enum BoWorkOrderStat
	wk_WorkOrder                  =0          # from enum BoWorkOrderStat
	xet_AllNodes                  =0          # from enum BoXmlExportTypes
	xet_ExportImportMode          =3          # from enum BoXmlExportTypes
	xet_NodesAsProperties         =2          # from enum BoXmlExportTypes
	xet_ValidNodesOnly            =1          # from enum BoXmlExportTypes
	tNO                           =0          # from enum BoYesNoEnum
	tYES                          =1          # from enum BoYesNoEnum
	itcMaterial                   =2          # from enum ItemClassEnum
	itcService                    =1          # from enum ItemClassEnum
	itItems                       =0          # from enum ItemTypeEnum
	itLabor                       =1          # from enum ItemTypeEnum
	itTravel                      =2          # from enum ItemTypeEnum

from win32com.client import DispatchBaseClass
class IActivityLocations(DispatchBaseClass):
	'IActivityLocations Interface'
	CLSID = IID('{0383EE76-4325-42FE-8164-91C2E8FDE242}')
	coclass_clsid = IID('{1FE6EEB5-6D21-4EE0-AC7C-8A2B181080C8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (1, 2, (3, 0), (), "Code", None),
		"Name": (2, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivityStatus(DispatchBaseClass):
	'IActivityStatus Interface'
	CLSID = IID('{E985FCDC-43E0-47C4-821D-7F60D4BC9009}')
	coclass_clsid = IID('{07B255E1-6AF8-4615-BAC4-D258D316BF1B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, ActivityID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),ActivityID
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(6, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"StatusDescription": (1, 2, (8, 0), (), "StatusDescription", None),
		"StatusId": (2, 2, (3, 0), (), "StatusId", None),
		"StatusName": (3, 2, (8, 0), (), "StatusName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"StatusDescription": ((1, LCID, 4, 0),()),
		"StatusName": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivityTypes(DispatchBaseClass):
	'IActivityTypes Interface'
	CLSID = IID('{0C60C86B-3CB9-4E78-80D0-1AACB3C1C6F0}')
	coclass_clsid = IID('{094BA05B-B730-4D86-8BCF-91F788C16057}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (1, 2, (3, 0), (), "Code", None),
		"Name": (2, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAdditionalExpenses(DispatchBaseClass):
	'IAdditionalExpenses Interface'
	CLSID = IID('{0FCFCE88-47F3-4F05-9803-3081D83C92DC}')
	coclass_clsid = IID('{F68150E3-371A-4D4F-990C-16CDFF1A04FA}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(22, LCID, 1, (8, 0), (),)

	def GetByKey(self, ExpnsCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),ExpnsCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(23, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"DistributionMethod": (17, 2, (3, 0), (), "DistributionMethod", None),
		"ExpensCode": (21, 2, (3, 0), (), "ExpensCode", None),
		"ExpenseAccount": (11, 2, (8, 0), (), "ExpenseAccount", None),
		"FixedAmountExpenses": (14, 2, (5, 0), (), "FixedAmountExpenses", None),
		"FixedAmountRevenues": (13, 2, (5, 0), (), "FixedAmountRevenues", None),
		"FreightOffsetAccount": (19, 2, (8, 0), (), "FreightOffsetAccount", None),
		"Includein1099": (18, 2, (3, 0), (), "Includein1099", None),
		"InputVATGroup": (16, 2, (8, 0), (), "InputVATGroup", None),
		"Name": (9, 2, (8, 0), (), "Name", None),
		"OutputVATGroup": (15, 2, (8, 0), (), "OutputVATGroup", None),
		"RevenuesAccount": (10, 2, (8, 0), (), "RevenuesAccount", None),
		"TaxLiable": (12, 2, (3, 0), (), "TaxLiable", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WTLiable": (20, 2, (8, 0), (), "WTLiable", None),
	}
	_prop_map_put_ = {
		"DistributionMethod": ((17, LCID, 4, 0),()),
		"ExpenseAccount": ((11, LCID, 4, 0),()),
		"FixedAmountExpenses": ((14, LCID, 4, 0),()),
		"FixedAmountRevenues": ((13, LCID, 4, 0),()),
		"FreightOffsetAccount": ((19, LCID, 4, 0),()),
		"Includein1099": ((18, LCID, 4, 0),()),
		"InputVATGroup": ((16, LCID, 4, 0),()),
		"Name": ((9, LCID, 4, 0),()),
		"OutputVATGroup": ((15, LCID, 4, 0),()),
		"RevenuesAccount": ((10, LCID, 4, 0),()),
		"TaxLiable": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAlternateCatNum(DispatchBaseClass):
	'IAlternateCatNum Interface'
	CLSID = IID('{0677DAD5-92DA-441E-A674-13DE601888FB}')
	coclass_clsid = IID('{BBC625E2-17DA-4434-83D6-56FE0401D9A6}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(12, LCID, 1, (8, 0), (),)

	def GetByKey(self, ItemCode=defaultNamedNotOptArg, CardCode=defaultNamedNotOptArg, Substitute=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (11, 0), ((8, 1), (8, 1), (8, 1)),ItemCode
			, CardCode, Substitute)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"CardCode": (7, 2, (8, 0), (), "CardCode", None),
		"ItemCode": (6, 2, (8, 0), (), "ItemCode", None),
		"Substitute": (8, 2, (8, 0), (), "Substitute", None),
	}
	_prop_map_put_ = {
		"CardCode": ((7, LCID, 4, 0),()),
		"ItemCode": ((6, LCID, 4, 0),()),
		"Substitute": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAttachment(DispatchBaseClass):
	'IAttachment Interface'
	CLSID = IID('{18B4A57B-206A-4CF7-B94B-7325AED96137}')
	coclass_clsid = IID('{054C0B23-FE27-46A4-990C-901A4906BEB5}')

	_prop_map_get_ = {
		"FileName": (1, 2, (8, 0), (), "FileName", None),
	}
	_prop_map_put_ = {
		"FileName": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAttachments(DispatchBaseClass):
	'IAttachments Interface'
	CLSID = IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')
	coclass_clsid = IID('{3C447394-4D07-46E5-8ADE-0E5973F97CF7}')

	def Add(self):
		'Add a new field.'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	# Result is of type IAttachment
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{18B4A57B-206A-4CF7-B94B-7325AED96137}')
		return ret

	def Refresh(self):
		'method Refresh'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{18B4A57B-206A-4CF7-B94B-7325AED96137}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{18B4A57B-206A-4CF7-B94B-7325AED96137}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPAccountReceivablePayble(DispatchBaseClass):
	'IBPAccountReceivablePayble Interface'
	CLSID = IID('{4162242D-4217-47FA-BDFF-5070B6D03F30}')
	coclass_clsid = IID('{2795C6A1-A943-411B-BE58-A062A0E4711A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (5, 2, (8, 0), (), "AccountCode", None),
		"AccountType": (6, 2, (3, 0), (), "AccountType", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
		"AccountCode": ((5, LCID, 4, 0),()),
		"AccountType": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPAddresses(DispatchBaseClass):
	'IBPAddresses Interface'
	CLSID = IID('{02F225DD-827F-4065-BC4A-14D5F4136D28}')
	coclass_clsid = IID('{1520690D-0D25-415A-B290-66DF277561FE}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AddressName": (4, 2, (8, 0), (), "AddressName", None),
		"AddressType": (16, 2, (3, 0), (), "AddressType", None),
		"Block": (6, 2, (8, 0), (), "Block", None),
		"BuildingFloorRoom": (15, 2, (8, 0), (), "BuildingFloorRoom", None),
		"City": (8, 2, (8, 0), (), "City", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"Country": (10, 2, (8, 0), (), "Country", None),
		"County": (9, 2, (8, 0), (), "County", None),
		"FederalTaxID": (12, 2, (8, 0), (), "FederalTaxID", None),
		"State": (11, 2, (8, 0), (), "State", None),
		"Street": (5, 2, (8, 0), (), "Street", None),
		"TaxCode": (13, 2, (8, 0), (), "TaxCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (14, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"ZipCode": (7, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AddressName": ((4, LCID, 4, 0),()),
		"AddressType": ((16, LCID, 4, 0),()),
		"Block": ((6, LCID, 4, 0),()),
		"BuildingFloorRoom": ((15, LCID, 4, 0),()),
		"City": ((8, LCID, 4, 0),()),
		"Country": ((10, LCID, 4, 0),()),
		"County": ((9, LCID, 4, 0),()),
		"FederalTaxID": ((12, LCID, 4, 0),()),
		"State": ((11, LCID, 4, 0),()),
		"Street": ((5, LCID, 4, 0),()),
		"TaxCode": ((13, LCID, 4, 0),()),
		"ZipCode": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPBankAccounts(DispatchBaseClass):
	'IBPBankAccounts Interface'
	CLSID = IID('{472B7A32-EB83-4D3A-9908-699D5C8DC33B}')
	coclass_clsid = IID('{0C9CE0A9-AA16-4C81-A474-9D960E735AA5}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(23, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(22, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountName": (26, 2, (8, 0), (), "AccountName", None),
		"AccountNo": (17, 2, (8, 0), (), "AccountNo", None),
		"BIK": (25, 2, (8, 0), (), "BIK", None),
		"BPCode": (3, 2, (8, 0), (), "BPCode", None),
		"BankCode": (16, 2, (8, 0), (), "BankCode", None),
		"Block": (10, 2, (8, 0), (), "Block", None),
		"Branch": (11, 2, (8, 0), (), "Branch", None),
		"BuildingFloorRoom": (20, 2, (8, 0), (), "BuildingFloorRoom", None),
		"City": (9, 2, (8, 0), (), "City", None),
		"ControlKey": (14, 2, (8, 0), (), "ControlKey", None),
		"CorrespondentAccount": (27, 2, (8, 0), (), "CorrespondentAccount", None),
		"Count": (21, 2, (3, 0), (), "Count", None),
		"Country": (12, 2, (8, 0), (), "Country", None),
		"County": (4, 2, (8, 0), (), "County", None),
		"Fax": (29, 2, (8, 0), (), "Fax", None),
		"IBAN": (7, 2, (8, 0), (), "IBAN", None),
		"InternalKey": (19, 2, (3, 0), (), "InternalKey", None),
		"LogInstance": (1, 2, (3, 0), (), "LogInstance", None),
		"Phone": (28, 2, (8, 0), (), "Phone", None),
		"State": (5, 2, (8, 0), (), "State", None),
		"Street": (13, 2, (8, 0), (), "Street", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (24, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserNo1": (18, 2, (8, 0), (), "UserNo1", None),
		"UserNo2": (6, 2, (8, 0), (), "UserNo2", None),
		"UserNo3": (15, 2, (8, 0), (), "UserNo3", None),
		"UserNo4": (2, 2, (8, 0), (), "UserNo4", None),
		"ZipCode": (8, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AccountName": ((26, LCID, 4, 0),()),
		"AccountNo": ((17, LCID, 4, 0),()),
		"BIK": ((25, LCID, 4, 0),()),
		"BPCode": ((3, LCID, 4, 0),()),
		"BankCode": ((16, LCID, 4, 0),()),
		"Block": ((10, LCID, 4, 0),()),
		"Branch": ((11, LCID, 4, 0),()),
		"BuildingFloorRoom": ((20, LCID, 4, 0),()),
		"City": ((9, LCID, 4, 0),()),
		"ControlKey": ((14, LCID, 4, 0),()),
		"CorrespondentAccount": ((27, LCID, 4, 0),()),
		"Country": ((12, LCID, 4, 0),()),
		"County": ((4, LCID, 4, 0),()),
		"Fax": ((29, LCID, 4, 0),()),
		"IBAN": ((7, LCID, 4, 0),()),
		"InternalKey": ((19, LCID, 4, 0),()),
		"LogInstance": ((1, LCID, 4, 0),()),
		"Phone": ((28, LCID, 4, 0),()),
		"State": ((5, LCID, 4, 0),()),
		"Street": ((13, LCID, 4, 0),()),
		"UserNo1": ((18, LCID, 4, 0),()),
		"UserNo2": ((6, LCID, 4, 0),()),
		"UserNo3": ((15, LCID, 4, 0),()),
		"UserNo4": ((2, LCID, 4, 0),()),
		"ZipCode": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(21, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPFiscalRegistryID(DispatchBaseClass):
	'IBPFiscalRegistryID Interface'
	CLSID = IID('{2C35D508-856B-43E0-A1A5-EC6BCA16E62A}')
	coclass_clsid = IID('{F2BCB557-408E-4D6C-B46D-7E5517D939B2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lGroupCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lGroupCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CNAECode": (11, 2, (8, 0), (), "CNAECode", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Numerator": (10, 2, (3, 0), (), "Numerator", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CNAECode": ((11, LCID, 4, 0),()),
		"Description": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBPFiscalTaxID(DispatchBaseClass):
	'IBPFiscalTaxID Interface'
	CLSID = IID('{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}')
	coclass_clsid = IID('{578B1918-60ED-440F-9729-7C59AEE459E8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Address": (10, 2, (8, 0), (), "Address", None),
		"CNAECode": (23, 2, (3, 0), (), "CNAECode", None),
		"Count": (4, 2, (3, 0), (), "Count", None),
		"TaxId0": (11, 2, (8, 0), (), "TaxId0", None),
		"TaxId1": (12, 2, (8, 0), (), "TaxId1", None),
		"TaxId10": (21, 2, (8, 0), (), "TaxId10", None),
		"TaxId11": (22, 2, (8, 0), (), "TaxId11", None),
		"TaxId2": (13, 2, (8, 0), (), "TaxId2", None),
		"TaxId3": (14, 2, (8, 0), (), "TaxId3", None),
		"TaxId4": (15, 2, (8, 0), (), "TaxId4", None),
		"TaxId5": (16, 2, (8, 0), (), "TaxId5", None),
		"TaxId6": (17, 2, (8, 0), (), "TaxId6", None),
		"TaxId7": (18, 2, (8, 0), (), "TaxId7", None),
		"TaxId8": (19, 2, (8, 0), (), "TaxId8", None),
		"TaxId9": (20, 2, (8, 0), (), "TaxId9", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Address": ((10, LCID, 4, 0),()),
		"CNAECode": ((23, LCID, 4, 0),()),
		"TaxId0": ((11, LCID, 4, 0),()),
		"TaxId1": ((12, LCID, 4, 0),()),
		"TaxId10": ((21, LCID, 4, 0),()),
		"TaxId11": ((22, LCID, 4, 0),()),
		"TaxId2": ((13, LCID, 4, 0),()),
		"TaxId3": ((14, LCID, 4, 0),()),
		"TaxId4": ((15, LCID, 4, 0),()),
		"TaxId5": ((16, LCID, 4, 0),()),
		"TaxId6": ((17, LCID, 4, 0),()),
		"TaxId7": ((18, LCID, 4, 0),()),
		"TaxId8": ((19, LCID, 4, 0),()),
		"TaxId9": ((20, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(4, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPPaymentDates(DispatchBaseClass):
	'IBPPaymentDates Interface'
	CLSID = IID('{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}')
	coclass_clsid = IID('{727B34C7-DD01-4B31-9213-F5B02C5E3276}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (3, 2, (3, 0), (), "Count", None),
		"PaymentDate": (1, 2, (8, 0), (), "PaymentDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (2, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"PaymentDate": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPPaymentMethods(DispatchBaseClass):
	'IBPPaymentMethods Interface'
	CLSID = IID('{7D947F60-6017-44AA-AEAC-9721FF263D5E}')
	coclass_clsid = IID('{9091A78F-FCC8-4399-88F3-53E1631F100F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (3, 2, (3, 0), (), "Count", None),
		"PaymentMethodCode": (1, 2, (8, 0), (), "PaymentMethodCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (2, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"PaymentMethodCode": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPWithholdingTax(DispatchBaseClass):
	'IBPWithholdingTax Interface'
	CLSID = IID('{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}')
	coclass_clsid = IID('{740243E4-B946-4D50-94D9-7F7E3EC04FE9}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (3, 2, (3, 0), (), "Count", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (2, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WTCode": (1, 2, (8, 0), (), "WTCode", None),
	}
	_prop_map_put_ = {
		"WTCode": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBankPages(DispatchBaseClass):
	'IBankPages Interface'
	CLSID = IID('{5BB202A1-E560-4E34-ACB3-2ECA52FFB274}')
	coclass_clsid = IID('{842BE793-D5A4-4C52-B7C1-99E189D39B8D}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(27, LCID, 1, (8, 0), (),)

	def GetByKey(self, AccountCode=defaultNamedNotOptArg, Sequence=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((8, 1), (3, 1)),AccountCode
			, Sequence)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(28, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AccountCode": (6, 2, (8, 0), (), "AccountCode", None),
		"AccountName": (8, 2, (8, 0), (), "AccountName", None),
		"BankMatch": (14, 2, (3, 0), (), "BankMatch", None),
		"CardCode": (18, 2, (8, 0), (), "CardCode", None),
		"CardName": (19, 2, (8, 0), (), "CardName", None),
		"CreditAmount": (13, 2, (5, 0), (), "CreditAmount", None),
		"DataSource": (15, 2, (8, 0), (), "DataSource", None),
		"DebitAmount": (12, 2, (5, 0), (), "DebitAmount", None),
		"DocNumberType": (24, 2, (3, 0), (), "DocNumberType", None),
		"DueDate": (10, 2, (7, 0), (), "DueDate", None),
		"ExternalCode": (17, 2, (8, 0), (), "ExternalCode", None),
		"InvoiceNumber": (21, 2, (3, 0), (), "InvoiceNumber", None),
		"InvoiceNumberEx": (26, 2, (8, 0), (), "InvoiceNumberEx", None),
		"Memo": (11, 2, (8, 0), (), "Memo", None),
		"PaymentCreated": (22, 2, (3, 0), (), "PaymentCreated", None),
		"PaymentReference": (25, 2, (8, 0), (), "PaymentReference", None),
		"Reference": (9, 2, (8, 0), (), "Reference", None),
		"Sequence": (7, 2, (3, 0), (), "Sequence", None),
		"StatementNumber": (20, 2, (3, 0), (), "StatementNumber", None),
		"UserSignature": (16, 2, (3, 0), (), "UserSignature", None),
		"VisualOrder": (23, 2, (3, 0), (), "VisualOrder", None),
	}
	_prop_map_put_ = {
		"AccountCode": ((6, LCID, 4, 0),()),
		"CardCode": ((18, LCID, 4, 0),()),
		"CardName": ((19, LCID, 4, 0),()),
		"CreditAmount": ((13, LCID, 4, 0),()),
		"DebitAmount": ((12, LCID, 4, 0),()),
		"DocNumberType": ((24, LCID, 4, 0),()),
		"DueDate": ((10, LCID, 4, 0),()),
		"ExternalCode": ((17, LCID, 4, 0),()),
		"InvoiceNumber": ((21, LCID, 4, 0),()),
		"InvoiceNumberEx": ((26, LCID, 4, 0),()),
		"Memo": ((11, LCID, 4, 0),()),
		"PaymentCreated": ((22, LCID, 4, 0),()),
		"PaymentReference": ((25, LCID, 4, 0),()),
		"Reference": ((9, LCID, 4, 0),()),
		"StatementNumber": ((20, LCID, 4, 0),()),
		"VisualOrder": ((23, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBatchNumbers(DispatchBaseClass):
	'IBatchNumbers Interface'
	CLSID = IID('{1FEF5698-93E1-4167-AEA0-4BB151792623}')
	coclass_clsid = IID('{41172218-C619-4E35-9D03-59EAF1E0F300}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AddmisionDate": (10, 2, (7, 0), (), "AddmisionDate", None),
		"BaseLineNumber": (15, 2, (3, 0), (), "BaseLineNumber", None),
		"BatchNumber": (5, 2, (8, 0), (), "BatchNumber", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"ExpiryDate": (8, 2, (7, 0), (), "ExpiryDate", None),
		"InternalSerialNumber": (7, 2, (8, 0), (), "InternalSerialNumber", None),
		"Location": (11, 2, (8, 0), (), "Location", None),
		"ManufacturerSerialNumber": (6, 2, (8, 0), (), "ManufacturerSerialNumber", None),
		"ManufacturingDate": (9, 2, (7, 0), (), "ManufacturingDate", None),
		"Notes": (12, 2, (8, 0), (), "Notes", None),
		"Quantity": (14, 2, (5, 0), (), "Quantity", None),
	}
	_prop_map_put_ = {
		"AddmisionDate": ((10, LCID, 4, 0),()),
		"BaseLineNumber": ((15, LCID, 4, 0),()),
		"BatchNumber": ((5, LCID, 4, 0),()),
		"ExpiryDate": ((8, LCID, 4, 0),()),
		"InternalSerialNumber": ((7, LCID, 4, 0),()),
		"Location": ((11, LCID, 4, 0),()),
		"ManufacturerSerialNumber": ((6, LCID, 4, 0),()),
		"ManufacturingDate": ((9, LCID, 4, 0),()),
		"Notes": ((12, LCID, 4, 0),()),
		"Quantity": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBillOfExchange(DispatchBaseClass):
	'IBillOfExchange Interface'
	CLSID = IID('{741AA803-AB33-4FD7-B664-63116291D6CE}')
	coclass_clsid = IID('{EA7AF142-F7C4-4E1A-BA6A-B5DBFCB71C3C}')

	_prop_map_get_ = {
		"BPBankAct": (22, 2, (8, 0), (), "BPBankAct", None),
		"BPBankCode": (21, 2, (8, 0), (), "BPBankCode", None),
		"BPBankCountry": (23, 2, (8, 0), (), "BPBankCountry", None),
		"BillOfExchangeDueDate": (12, 2, (7, 0), (), "BillOfExchangeDueDate", None),
		"BillOfExchangeNo": (10, 2, (8, 0), (), "BillOfExchangeNo", None),
		"ControlKey": (24, 2, (8, 0), (), "ControlKey", None),
		"Details": (13, 2, (8, 0), (), "Details", None),
		"PaymentEngineStatus1": (25, 2, (8, 0), (), "PaymentEngineStatus1", None),
		"PaymentEngineStatus2": (26, 2, (8, 0), (), "PaymentEngineStatus2", None),
		"PaymentEngineStatus3": (27, 2, (8, 0), (), "PaymentEngineStatus3", None),
		"PaymentMethodCode": (20, 2, (8, 0), (), "PaymentMethodCode", None),
		"ReferenceNo": (14, 2, (8, 0), (), "ReferenceNo", None),
		"Remarks": (19, 2, (8, 0), (), "Remarks", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (28, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BPBankAct": ((22, LCID, 4, 0),()),
		"BPBankCode": ((21, LCID, 4, 0),()),
		"BPBankCountry": ((23, LCID, 4, 0),()),
		"BillOfExchangeDueDate": ((12, LCID, 4, 0),()),
		"BillOfExchangeNo": ((10, LCID, 4, 0),()),
		"Details": ((13, LCID, 4, 0),()),
		"PaymentEngineStatus1": ((25, LCID, 4, 0),()),
		"PaymentEngineStatus2": ((26, LCID, 4, 0),()),
		"PaymentEngineStatus3": ((27, LCID, 4, 0),()),
		"PaymentMethodCode": ((20, LCID, 4, 0),()),
		"ReferenceNo": ((14, LCID, 4, 0),()),
		"Remarks": ((19, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBillOfExchangeTrans_BankPages(DispatchBaseClass):
	'IBillOfExchangeTrans_BankPages Interface'
	CLSID = IID('{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}')
	coclass_clsid = IID('{C057A0F5-A755-4C5E-A410-D4C4D1379487}')

	_prop_map_get_ = {
		"AccountCode": (4, 2, (8, 0), (), "AccountCode", None),
		"Sequence": (5, 2, (3, 0), (), "Sequence", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AccountCode": ((4, LCID, 4, 0),()),
		"Sequence": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBillOfExchangeTrans_Deposits(DispatchBaseClass):
	'IBillOfExchangeTrans_Deposits Interface'
	CLSID = IID('{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}')
	coclass_clsid = IID('{94DA073B-4599-4BC9-A22B-87D912159247}')

	_prop_map_get_ = {
		"BankAccount": (4, 2, (8, 0), (), "BankAccount", None),
		"BankBranch": (6, 2, (8, 0), (), "BankBranch", None),
		"BankCountry": (3, 2, (8, 0), (), "BankCountry", None),
		"BankDepositAccount": (5, 2, (8, 0), (), "BankDepositAccount", None),
		"DepositNorm": (1, 2, (8, 0), (), "DepositNorm", None),
		"PostingType": (2, 2, (3, 0), (), "PostingType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (7, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BankAccount": ((4, LCID, 4, 0),()),
		"BankBranch": ((6, LCID, 4, 0),()),
		"BankCountry": ((3, LCID, 4, 0),()),
		"BankDepositAccount": ((5, LCID, 4, 0),()),
		"DepositNorm": ((1, LCID, 4, 0),()),
		"PostingType": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBillOfExchangeTransaction(DispatchBaseClass):
	'IBillOfExchangeTransaction Interface'
	CLSID = IID('{DB038EC5-97EC-4D04-8E6A-AF01A5C05900}')
	coclass_clsid = IID('{CFAA1E6C-53D8-4C8E-A7DE-78ABE1601F30}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(19, LCID, 1, (8, 0), (),)

	def GetByKey(self, InternalKey=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),InternalKey
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		"BOETransactionkey": (18, 2, (3, 0), (), "BOETransactionkey", None),
		# Method 'BankPages' returns object of type 'IBillOfExchangeTrans_BankPages'
		"BankPages": (16, 2, (9, 0), (), "BankPages", '{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}'),
		# Method 'Deposits' returns object of type 'IBillOfExchangeTrans_Deposits'
		"Deposits": (15, 2, (9, 0), (), "Deposits", '{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}'),
		"IsBoeReconciled": (10, 2, (3, 0), (), "IsBoeReconciled", None),
		# Method 'Lines' returns object of type 'IBillOfExchangeTransaction_Lines'
		"Lines": (14, 2, (9, 0), (), "Lines", '{2DBFED56-4DB4-455A-9C22-E2C01C052D39}'),
		"PostingDate": (12, 2, (7, 0), (), "PostingDate", None),
		"StatusFrom": (6, 2, (3, 0), (), "StatusFrom", None),
		"StatusTo": (7, 2, (3, 0), (), "StatusTo", None),
		"TaxDate": (13, 2, (7, 0), (), "TaxDate", None),
		"TransactionDate": (8, 2, (7, 0), (), "TransactionDate", None),
		"TransactionNumber": (11, 2, (3, 0), (), "TransactionNumber", None),
		"TransactionTime": (9, 2, (7, 0), (), "TransactionTime", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (17, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"IsBoeReconciled": ((10, LCID, 4, 0),()),
		"PostingDate": ((12, LCID, 4, 0),()),
		"StatusFrom": ((6, LCID, 4, 0),()),
		"StatusTo": ((7, LCID, 4, 0),()),
		"TaxDate": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBillOfExchangeTransaction_Lines(DispatchBaseClass):
	'IBillOfExchangeTransaction_Lines Interface'
	CLSID = IID('{2DBFED56-4DB4-455A-9C22-E2C01C052D39}')
	coclass_clsid = IID('{A8A658F8-0A8A-4CEF-B5F4-481C3D4652FA}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BillOfExchangeDueDate": (7, 2, (7, 0), (), "BillOfExchangeDueDate", None),
		"BillOfExchangeNo": (5, 2, (3, 0), (), "BillOfExchangeNo", None),
		"BillOfExchangeType": (6, 2, (3, 0), (), "BillOfExchangeType", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BillOfExchangeNo": ((5, LCID, 4, 0),()),
		"BillOfExchangeType": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBudget(DispatchBaseClass):
	'IBudget Interface'
	CLSID = IID('{C1F83FBE-3A3F-4A81-8B0B-B5485DC6ADF9}')
	coclass_clsid = IID('{11067A79-5484-43A2-945C-7408CDCF01E6}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(33, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((3, 1),),Key
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(34, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AccountCode": (27, 2, (8, 0), (), "AccountCode", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (31, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BudgetBalanceCreditLoc": (25, 2, (5, 0), (), "BudgetBalanceCreditLoc", None),
		"BudgetBalanceCreditSys": (24, 2, (5, 0), (), "BudgetBalanceCreditSys", None),
		"BudgetBalanceDebitLoc": (20, 2, (5, 0), (), "BudgetBalanceDebitLoc", None),
		"BudgetBalanceDebitSys": (19, 2, (5, 0), (), "BudgetBalanceDebitSys", None),
		"BudgetScenario": (32, 2, (3, 0), (), "BudgetScenario", None),
		"DivisionCode": (26, 2, (3, 0), (), "DivisionCode", None),
		"FutureAnnualExpensesCreditLoc": (8, 2, (5, 0), (), "FutureAnnualExpensesCreditLoc", None),
		"FutureAnnualExpensesCreditSys": (7, 2, (5, 0), (), "FutureAnnualExpensesCreditSys", None),
		"FutureAnnualExpensesDebitLoc": (10, 2, (5, 0), (), "FutureAnnualExpensesDebitLoc", None),
		"FutureAnnualExpensesDebitSys": (9, 2, (5, 0), (), "FutureAnnualExpensesDebitSys", None),
		"FutureAnnualRevenuesCredit": (11, 2, (5, 0), (), "FutureAnnualRevenuesCredit", None),
		"FutureAnnualRevenuesDebit": (12, 2, (5, 0), (), "FutureAnnualRevenuesDebit", None),
		"FutureRevenuesDebitLoc": (14, 2, (5, 0), (), "FutureRevenuesDebitLoc", None),
		"FutureRevenuesDebitSys": (13, 2, (5, 0), (), "FutureRevenuesDebitSys", None),
		# Method 'Lines' returns object of type 'IBudget_Lines'
		"Lines": (29, 2, (9, 0), (), "Lines", '{D2BAB599-C7C6-4301-B925-B6BB51092A79}'),
		"Numerator": (28, 2, (3, 0), (), "Numerator", None),
		"ParentAccPercent": (15, 2, (5, 0), (), "ParentAccPercent", None),
		"ParentAccountKey": (17, 2, (8, 0), (), "ParentAccountKey", None),
		"StartofFiscalYear": (16, 2, (7, 0), (), "StartofFiscalYear", None),
		"TotalAnnualBudgetCreditLoc": (23, 2, (5, 0), (), "TotalAnnualBudgetCreditLoc", None),
		"TotalAnnualBudgetCreditSys": (22, 2, (5, 0), (), "TotalAnnualBudgetCreditSys", None),
		"TotalAnnualBudgetDebitLoc": (21, 2, (5, 0), (), "TotalAnnualBudgetDebitLoc", None),
		"TotalAnnualBudgetDebitSys": (18, 2, (5, 0), (), "TotalAnnualBudgetDebitSys", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (30, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AccountCode": ((27, LCID, 4, 0),()),
		"BudgetScenario": ((32, LCID, 4, 0),()),
		"DivisionCode": ((26, LCID, 4, 0),()),
		"ParentAccPercent": ((15, LCID, 4, 0),()),
		"ParentAccountKey": ((17, LCID, 4, 0),()),
		"TotalAnnualBudgetCreditLoc": ((23, LCID, 4, 0),()),
		"TotalAnnualBudgetCreditSys": ((22, LCID, 4, 0),()),
		"TotalAnnualBudgetDebitLoc": ((21, LCID, 4, 0),()),
		"TotalAnnualBudgetDebitSys": ((18, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBudgetDistribution(DispatchBaseClass):
	'IBudgetDistribution Interface'
	CLSID = IID('{0CFCFE82-D222-486A-9E49-0FBE58FDD534}')
	coclass_clsid = IID('{16F466DA-6A22-46AE-A5B2-5934A0194D7A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(23, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(24, LCID, 1, (8, 0), (),)

	def GetByKey(self, lBgdCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (11, 0), ((3, 1),),lBgdCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(25, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(20, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"April": (6, 2, (5, 0), (), "April", None),
		"August": (2, 2, (5, 0), (), "August", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (22, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BudgetAmount": (13, 2, (5, 0), (), "BudgetAmount", None),
		"December": (9, 2, (5, 0), (), "December", None),
		"Description": (14, 2, (8, 0), (), "Description", None),
		"DivisionCode": (15, 2, (3, 0), (), "DivisionCode", None),
		"February": (8, 2, (5, 0), (), "February", None),
		"January": (12, 2, (5, 0), (), "January", None),
		"July": (3, 2, (5, 0), (), "July", None),
		"June": (4, 2, (5, 0), (), "June", None),
		"March": (7, 2, (5, 0), (), "March", None),
		"May": (5, 2, (5, 0), (), "May", None),
		"November": (10, 2, (5, 0), (), "November", None),
		"October": (11, 2, (5, 0), (), "October", None),
		"September": (1, 2, (5, 0), (), "September", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (21, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"April": ((6, LCID, 4, 0),()),
		"August": ((2, LCID, 4, 0),()),
		"BudgetAmount": ((13, LCID, 4, 0),()),
		"December": ((9, LCID, 4, 0),()),
		"Description": ((14, LCID, 4, 0),()),
		"February": ((8, LCID, 4, 0),()),
		"January": ((12, LCID, 4, 0),()),
		"July": ((3, LCID, 4, 0),()),
		"June": ((4, LCID, 4, 0),()),
		"March": ((7, LCID, 4, 0),()),
		"May": ((5, LCID, 4, 0),()),
		"November": ((10, LCID, 4, 0),()),
		"October": ((11, LCID, 4, 0),()),
		"September": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBudgetScenarios(DispatchBaseClass):
	'IBudgetScenarios Interface'
	CLSID = IID('{5D48514C-4B40-4C2A-9FC9-8CC2518B0F8E}')
	coclass_clsid = IID('{8DCD076F-BF30-45C6-822A-B23FDA1B37F5}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(15, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((3, 1),),lAbsID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(16, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(10, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"BasicBudget": (4, 2, (3, 0), (), "BasicBudget", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (12, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"InitialRatioPercentage": (2, 2, (5, 0), (), "InitialRatioPercentage", None),
		"Name": (1, 2, (8, 0), (), "Name", None),
		"Numerator": (5, 2, (3, 0), (), "Numerator", None),
		"RoundingMethod": (14, 2, (3, 0), (), "RoundingMethod", None),
		"StartofFiscalYear": (3, 2, (7, 0), (), "StartofFiscalYear", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (11, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BasicBudget": ((4, LCID, 4, 0),()),
		"InitialRatioPercentage": ((2, LCID, 4, 0),()),
		"Name": ((1, LCID, 4, 0),()),
		"RoundingMethod": ((14, LCID, 4, 0),()),
		"StartofFiscalYear": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBudget_Lines(DispatchBaseClass):
	'IBudget_Lines Interface'
	CLSID = IID('{D2BAB599-C7C6-4301-B925-B6BB51092A79}')
	coclass_clsid = IID('{F105494C-B48F-4E8A-B6E7-C1947194E835}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(25, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(24, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (21, 2, (8, 0), (), "AccountCode", None),
		"BalSysTotCredit": (18, 2, (5, 0), (), "BalSysTotCredit", None),
		"BalSysTotDebit": (13, 2, (5, 0), (), "BalSysTotDebit", None),
		"BalTotCredit": (19, 2, (5, 0), (), "BalTotCredit", None),
		"BalTotDebit": (14, 2, (5, 0), (), "BalTotDebit", None),
		"BudgetKey": (20, 2, (3, 0), (), "BudgetKey", None),
		"BudgetSysTotCredit": (16, 2, (5, 0), (), "BudgetSysTotCredit", None),
		"BudgetSysTotDebit": (12, 2, (5, 0), (), "BudgetSysTotDebit", None),
		"BudgetTotCredit": (15, 2, (5, 0), (), "BudgetTotCredit", None),
		"BudgetTotDebit": (17, 2, (5, 0), (), "BudgetTotDebit", None),
		"Count": (23, 2, (3, 0), (), "Count", None),
		"FutExpenCredit": (7, 2, (5, 0), (), "FutExpenCredit", None),
		"FutExpenDebit": (5, 2, (5, 0), (), "FutExpenDebit", None),
		"FutExpenSysCredit": (6, 2, (5, 0), (), "FutExpenSysCredit", None),
		"FutExpenSysDebit": (4, 2, (5, 0), (), "FutExpenSysDebit", None),
		"FutIncomesCredit": (11, 2, (5, 0), (), "FutIncomesCredit", None),
		"FutIncomesSysCredit": (9, 2, (5, 0), (), "FutIncomesSysCredit", None),
		"FutIncomesSysDebit": (10, 2, (5, 0), (), "FutIncomesSysDebit", None),
		"FutureIncomeDeb": (26, 2, (5, 0), (), "FutureIncomeDeb", None),
		"PrecentOfAnnualBudgetAmount": (1, 2, (5, 0), (), "PrecentOfAnnualBudgetAmount", None),
		"RowDetails": (2, 2, (8, 0), (), "RowDetails", None),
		"RowNumber": (3, 2, (3, 0), (), "RowNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (22, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BudgetSysTotCredit": ((16, LCID, 4, 0),()),
		"BudgetSysTotDebit": ((12, LCID, 4, 0),()),
		"BudgetTotCredit": ((15, LCID, 4, 0),()),
		"BudgetTotDebit": ((17, LCID, 4, 0),()),
		"RowDetails": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(23, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBusinessPartnerGroups(DispatchBaseClass):
	'IBusinessPartnerGroups Interface'
	CLSID = IID('{9147FC50-6FF2-40EC-B59B-2F9302B4A31D}')
	coclass_clsid = IID('{A3C87BAE-49A3-4A53-A50B-D20716733709}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lGroupCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lGroupCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"Type": (12, 2, (3, 0), (), "Type", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((11, LCID, 4, 0),()),
		"Type": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBusinessPartners(DispatchBaseClass):
	'IBusinessPartners Interface'
	CLSID = IID('{9DF321C2-6A1D-446B-AE8A-F7C33987D792}')
	coclass_clsid = IID('{4A1DF035-9612-4CCC-B9B8-C58511D0D705}')

	def Add(self):
		'Use this function to add the card to the system.'
		return self._oleobj_.InvokeTypes(50, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(75, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(76, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(145, LCID, 1, (8, 0), (),)

	def GetByKey(self, CardCode=defaultNamedNotOptArg):
		"Get a card object by it's key (string value)."
		return self._oleobj_.InvokeTypes(57, LCID, 1, (11, 0), ((8, 0),),CardCode
			)

	# The method Properties is actually a property, but must be used as a method to correctly pass the arguments
	def Properties(self, GroupNum=defaultNamedNotOptArg):
		'You use card characteristics for cross-sections and an additional sort of the customer and supplier cards.'
		return self._oleobj_.InvokeTypes(52, LCID, 2, (3, 0), ((3, 0),),GroupNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(74, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(146, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save the objects data in xml format.'
		return self._ApplyTypes_(59, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	# The method SetProperties is actually a property, but must be used as a method to correctly pass the arguments
	def SetProperties(self, GroupNum=defaultNamedNotOptArg, arg1=defaultUnnamedArg):
		'You use card characteristics for cross-sections and an additional sort of the customer and supplier cards.'
		return self._oleobj_.InvokeTypes(52, LCID, 4, (24, 0), ((3, 0), (3, 1)),GroupNum
			, arg1)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(60, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'AccountRecivablePayables' returns object of type 'IBPAccountReceivablePayble'
		"AccountRecivablePayables": (119, 2, (9, 0), (), "AccountRecivablePayables", '{4162242D-4217-47FA-BDFF-5070B6D03F30}'),
		"AccrualCriteria": (127, 2, (3, 0), (), "AccrualCriteria", None),
		"AdditionalID": (46, 2, (8, 0), (), "AdditionalID", None),
		"Address": (7, 2, (8, 0), (), "Address", None),
		# Method 'Addresses' returns object of type 'IBPAddresses'
		"Addresses": (87, 2, (9, 0), (), "Addresses", '{02F225DD-827F-4065-BC4A-14D5F4136D28}'),
		"AvarageLate": (34, 2, (3, 0), (), "AvarageLate", None),
		# Method 'BPBankAccounts' returns object of type 'IBPBankAccounts'
		"BPBankAccounts": (142, 2, (9, 0), (), "BPBankAccounts", '{472B7A32-EB83-4D3A-9908-699D5C8DC33B}'),
		# Method 'BPPaymentDates' returns object of type 'IBPPaymentDates'
		"BPPaymentDates": (141, 2, (9, 0), (), "BPPaymentDates", '{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}'),
		# Method 'BPPaymentMethods' returns object of type 'IBPPaymentMethods'
		"BPPaymentMethods": (139, 2, (9, 0), (), "BPPaymentMethods", '{7D947F60-6017-44AA-AEAC-9721FF263D5E}'),
		# Method 'BPWithholdingTax' returns object of type 'IBPWithholdingTax'
		"BPWithholdingTax": (140, 2, (9, 0), (), "BPWithholdingTax", '{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}'),
		"BackOrder": (95, 2, (3, 0), (), "BackOrder", None),
		"BankChargesAllocationCode": (157, 2, (8, 0), (), "BankChargesAllocationCode", None),
		"BankCountry": (98, 2, (8, 0), (), "BankCountry", None),
		"BillToBuildingFloorRoom": (130, 2, (8, 0), (), "BillToBuildingFloorRoom", None),
		"BillToState": (89, 2, (8, 0), (), "BillToState", None),
		"BillofExchangeonCollection": (152, 2, (8, 0), (), "BillofExchangeonCollection", None),
		"BilltoDefault": (134, 2, (8, 0), (), "BilltoDefault", None),
		"Block": (88, 2, (8, 0), (), "Block", None),
		"BlockDunning": (97, 2, (3, 0), (), "BlockDunning", None),
		"Box1099": (93, 2, (8, 0), (), "Box1099", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (86, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (1, 2, (8, 0), (), "CardCode", None),
		"CardForeignName": (49, 2, (8, 0), (), "CardForeignName", None),
		"CardName": (4, 2, (8, 0), (), "CardName", None),
		"CardType": (3, 2, (3, 0), (), "CardType", None),
		"Cellular": (33, 2, (8, 0), (), "Cellular", None),
		"CertificateNumber": (124, 2, (8, 0), (), "CertificateNumber", None),
		"ChannelBP": (132, 2, (8, 0), (), "ChannelBP", None),
		"City": (35, 2, (8, 0), (), "City", None),
		"ClosingDateProcedureNumber": (150, 2, (3, 0), (), "ClosingDateProcedureNumber", None),
		"CollectionAuthorization": (105, 2, (3, 0), (), "CollectionAuthorization", None),
		"CommissionGroupCode": (28, 2, (3, 0), (), "CommissionGroupCode", None),
		"CommissionPercent": (27, 2, (5, 0), (), "CommissionPercent", None),
		"CompanyPrivate": (153, 2, (3, 0), (), "CompanyPrivate", None),
		# Method 'ContactEmployees' returns object of type 'IContactEmployees'
		"ContactEmployees": (64, 2, (9, 0), (), "ContactEmployees", '{52C8673B-CA79-4476-9F2E-28109AE17545}'),
		"ContactPerson": (14, 2, (8, 0), (), "ContactPerson", None),
		"Country": (37, 2, (8, 0), (), "Country", None),
		"County": (36, 2, (8, 0), (), "County", None),
		"CreditCardCode": (70, 2, (3, 0), (), "CreditCardCode", None),
		"CreditCardExpiration": (72, 2, (7, 0), (), "CreditCardExpiration", None),
		"CreditCardNum": (71, 2, (8, 0), (), "CreditCardNum", None),
		"CreditLimit": (17, 2, (5, 0), (), "CreditLimit", None),
		"Currency": (31, 2, (8, 0), (), "Currency", None),
		"CurrentAccountBalance": (61, 2, (5, 0), (), "CurrentAccountBalance", None),
		"CustomerBillofExchangDisc": (135, 2, (8, 0), (), "CustomerBillofExchangDisc", None),
		"CustomerBillofExchangPres": (138, 2, (8, 0), (), "CustomerBillofExchangPres", None),
		"DME": (106, 2, (3, 0), (), "DME", None),
		"DebitorAccount": (73, 2, (8, 0), (), "DebitorAccount", None),
		"DeductibleAtSource": (22, 2, (3, 0), (), "DeductibleAtSource", None),
		"DeductionOffice": (53, 2, (8, 0), (), "DeductionOffice", None),
		"DeductionPercent": (23, 2, (5, 0), (), "DeductionPercent", None),
		"DeductionValidUntil": (24, 2, (7, 0), (), "DeductionValidUntil", None),
		"DefaultAccount": (43, 2, (8, 0), (), "DefaultAccount", None),
		"DefaultBankCode": (45, 2, (8, 0), (), "DefaultBankCode", None),
		"DefaultBranch": (44, 2, (8, 0), (), "DefaultBranch", None),
		"DefaultTechnician": (133, 2, (3, 0), (), "DefaultTechnician", None),
		"DeferredTax": (129, 2, (3, 0), (), "DeferredTax", None),
		"DiscountPercent": (19, 2, (5, 0), (), "DiscountPercent", None),
		"DownPaymentClearAct": (131, 2, (8, 0), (), "DownPaymentClearAct", None),
		"DunningDate": (104, 2, (7, 0), (), "DunningDate", None),
		"DunningLevel": (103, 2, (3, 0), (), "DunningLevel", None),
		"DunningTerm": (147, 2, (8, 0), (), "DunningTerm", None),
		"EmailAddress": (41, 2, (8, 0), (), "EmailAddress", None),
		"Equalization": (122, 2, (3, 0), (), "Equalization", None),
		"ExemptNum": (90, 2, (8, 0), (), "ExemptNum", None),
		"ExemptionValidityDateFrom": (117, 2, (7, 0), (), "ExemptionValidityDateFrom", None),
		"ExemptionValidityDateTo": (118, 2, (7, 0), (), "ExemptionValidityDateTo", None),
		"ExpirationDate": (125, 2, (7, 0), (), "ExpirationDate", None),
		"ExportCode": (54, 2, (8, 0), (), "ExportCode", None),
		"FatherCard": (48, 2, (8, 0), (), "FatherCard", None),
		"FatherType": (51, 2, (3, 0), (), "FatherType", None),
		"Fax": (13, 2, (8, 0), (), "Fax", None),
		"FederalTaxID": (21, 2, (8, 0), (), "FederalTaxID", None),
		# Method 'FiscalTaxID' returns object of type 'IBPFiscalTaxID'
		"FiscalTaxID": (158, 2, (9, 0), (), "FiscalTaxID", '{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}'),
		"FormCode1099": (92, 2, (3, 0), (), "FormCode1099", None),
		"FreeText": (29, 2, (8, 0), (), "FreeText", None),
		"Frozen": (82, 2, (3, 0), (), "Frozen", None),
		"FrozenFrom": (83, 2, (7, 0), (), "FrozenFrom", None),
		"FrozenRemarks": (85, 2, (8, 0), (), "FrozenRemarks", None),
		"FrozenTo": (84, 2, (7, 0), (), "FrozenTo", None),
		"GroupCode": (5, 2, (3, 0), (), "GroupCode", None),
		"HouseBank": (99, 2, (8, 0), (), "HouseBank", None),
		"HouseBankAccount": (101, 2, (8, 0), (), "HouseBankAccount", None),
		"HouseBankBranch": (112, 2, (8, 0), (), "HouseBankBranch", None),
		"HouseBankCountry": (100, 2, (8, 0), (), "HouseBankCountry", None),
		"IBAN": (69, 2, (8, 0), (), "IBAN", None),
		"ISRBillerID": (109, 2, (8, 0), (), "ISRBillerID", None),
		"Indicator": (68, 2, (8, 0), (), "Indicator", None),
		"InstructionKey": (107, 2, (8, 0), (), "InstructionKey", None),
		"IntrestRatePercent": (26, 2, (5, 0), (), "IntrestRatePercent", None),
		"LanguageCode": (154, 2, (3, 0), (), "LanguageCode", None),
		"LastMultiReconciliationNum": (121, 2, (3, 0), (), "LastMultiReconciliationNum", None),
		"LinkedBusinessPartner": (120, 2, (8, 0), (), "LinkedBusinessPartner", None),
		"MailAddress": (9, 2, (8, 0), (), "MailAddress", None),
		"MailCity": (38, 2, (8, 0), (), "MailCity", None),
		"MailCountry": (40, 2, (8, 0), (), "MailCountry", None),
		"MailCounty": (39, 2, (8, 0), (), "MailCounty", None),
		"MailZipCode": (10, 2, (8, 0), (), "MailZipCode", None),
		"MaxAmountOfExemption": (116, 2, (5, 0), (), "MaxAmountOfExemption", None),
		"MaxCommitment": (18, 2, (5, 0), (), "MaxCommitment", None),
		"MinIntrest": (55, 2, (5, 0), (), "MinIntrest", None),
		"NationalInsuranceNum": (126, 2, (8, 0), (), "NationalInsuranceNum", None),
		"Notes": (15, 2, (8, 0), (), "Notes", None),
		"OpenDeliveryNotesBalance": (62, 2, (5, 0), (), "OpenDeliveryNotesBalance", None),
		"OpenOpportunities": (77, 2, (3, 0), (), "OpenOpportunities", None),
		"OpenOrdersBalance": (63, 2, (5, 0), (), "OpenOrdersBalance", None),
		"OtherReceivablePayable": (149, 2, (8, 0), (), "OtherReceivablePayable", None),
		"OwnerIDNumber": (113, 2, (8, 0), (), "OwnerIDNumber", None),
		"Pager": (47, 2, (8, 0), (), "Pager", None),
		"PartialDelivery": (96, 2, (3, 0), (), "PartialDelivery", None),
		"Password": (67, 2, (8, 0), (), "Password", None),
		"PayTermsGrpCode": (16, 2, (3, 0), (), "PayTermsGrpCode", None),
		"PaymentBlock": (110, 2, (3, 0), (), "PaymentBlock", None),
		"PaymentBlockDescription": (114, 2, (3, 0), (), "PaymentBlockDescription", None),
		"PeymentMethodCode": (94, 2, (8, 0), (), "PeymentMethodCode", None),
		"Phone1": (11, 2, (8, 0), (), "Phone1", None),
		"Phone2": (12, 2, (8, 0), (), "Phone2", None),
		"Picture": (42, 2, (8, 0), (), "Picture", None),
		"PriceListNum": (25, 2, (3, 0), (), "PriceListNum", None),
		"Priority": (91, 2, (3, 0), (), "Priority", None),
		"Profession": (151, 2, (8, 0), (), "Profession", None),
		"ProjectCode": (143, 2, (8, 0), (), "ProjectCode", None),
		"RateDiffAccount": (32, 2, (8, 0), (), "RateDiffAccount", None),
		"ReferenceDetails": (111, 2, (8, 0), (), "ReferenceDetails", None),
		"SalesPersonCode": (30, 2, (3, 0), (), "SalesPersonCode", None),
		"ShipToBuildingFloorRoom": (137, 2, (8, 0), (), "ShipToBuildingFloorRoom", None),
		"ShipToDefault": (102, 2, (8, 0), (), "ShipToDefault", None),
		"ShippingType": (66, 2, (3, 0), (), "ShippingType", None),
		"SinglePayment": (108, 2, (3, 0), (), "SinglePayment", None),
		"SubjectToWithholdingTax": (123, 2, (3, 0), (), "SubjectToWithholdingTax", None),
		"TaxExemptionLetterNum": (115, 2, (8, 0), (), "TaxExemptionLetterNum", None),
		"Territory": (136, 2, (3, 0), (), "Territory", None),
		"UnpaidBillofExchange": (155, 2, (8, 0), (), "UnpaidBillofExchange", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (58, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"Valid": (78, 2, (3, 0), (), "Valid", None),
		"ValidFrom": (79, 2, (7, 0), (), "ValidFrom", None),
		"ValidRemarks": (81, 2, (8, 0), (), "ValidRemarks", None),
		"ValidTo": (80, 2, (7, 0), (), "ValidTo", None),
		"VatGroup": (65, 2, (8, 0), (), "VatGroup", None),
		"VatGroupLatinAmerica": (144, 2, (8, 0), (), "VatGroupLatinAmerica", None),
		"VatLiable": (20, 2, (3, 0), (), "VatLiable", None),
		"WTCode": (128, 2, (8, 0), (), "WTCode", None),
		"Website": (148, 2, (8, 0), (), "Website", None),
		"WithholdingTaxDeductionGroup": (156, 2, (3, 0), (), "WithholdingTaxDeductionGroup", None),
		"ZipCode": (8, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AccrualCriteria": ((127, LCID, 4, 0),()),
		"AdditionalID": ((46, LCID, 4, 0),()),
		"Address": ((7, LCID, 4, 0),()),
		"AvarageLate": ((34, LCID, 4, 0),()),
		"BackOrder": ((95, LCID, 4, 0),()),
		"BankChargesAllocationCode": ((157, LCID, 4, 0),()),
		"BankCountry": ((98, LCID, 4, 0),()),
		"BillToBuildingFloorRoom": ((130, LCID, 4, 0),()),
		"BillToState": ((89, LCID, 4, 0),()),
		"BillofExchangeonCollection": ((152, LCID, 4, 0),()),
		"BilltoDefault": ((134, LCID, 4, 0),()),
		"Block": ((88, LCID, 4, 0),()),
		"BlockDunning": ((97, LCID, 4, 0),()),
		"Box1099": ((93, LCID, 4, 0),()),
		"CardCode": ((1, LCID, 4, 0),()),
		"CardForeignName": ((49, LCID, 4, 0),()),
		"CardName": ((4, LCID, 4, 0),()),
		"CardType": ((3, LCID, 4, 0),()),
		"Cellular": ((33, LCID, 4, 0),()),
		"CertificateNumber": ((124, LCID, 4, 0),()),
		"ChannelBP": ((132, LCID, 4, 0),()),
		"City": ((35, LCID, 4, 0),()),
		"ClosingDateProcedureNumber": ((150, LCID, 4, 0),()),
		"CollectionAuthorization": ((105, LCID, 4, 0),()),
		"CommissionGroupCode": ((28, LCID, 4, 0),()),
		"CommissionPercent": ((27, LCID, 4, 0),()),
		"CompanyPrivate": ((153, LCID, 4, 0),()),
		"ContactPerson": ((14, LCID, 4, 0),()),
		"Country": ((37, LCID, 4, 0),()),
		"County": ((36, LCID, 4, 0),()),
		"CreditCardCode": ((70, LCID, 4, 0),()),
		"CreditCardExpiration": ((72, LCID, 4, 0),()),
		"CreditCardNum": ((71, LCID, 4, 0),()),
		"CreditLimit": ((17, LCID, 4, 0),()),
		"Currency": ((31, LCID, 4, 0),()),
		"CustomerBillofExchangDisc": ((135, LCID, 4, 0),()),
		"CustomerBillofExchangPres": ((138, LCID, 4, 0),()),
		"DME": ((106, LCID, 4, 0),()),
		"DebitorAccount": ((73, LCID, 4, 0),()),
		"DeductibleAtSource": ((22, LCID, 4, 0),()),
		"DeductionOffice": ((53, LCID, 4, 0),()),
		"DeductionPercent": ((23, LCID, 4, 0),()),
		"DeductionValidUntil": ((24, LCID, 4, 0),()),
		"DefaultAccount": ((43, LCID, 4, 0),()),
		"DefaultBankCode": ((45, LCID, 4, 0),()),
		"DefaultBranch": ((44, LCID, 4, 0),()),
		"DefaultTechnician": ((133, LCID, 4, 0),()),
		"DeferredTax": ((129, LCID, 4, 0),()),
		"DiscountPercent": ((19, LCID, 4, 0),()),
		"DownPaymentClearAct": ((131, LCID, 4, 0),()),
		"DunningTerm": ((147, LCID, 4, 0),()),
		"EmailAddress": ((41, LCID, 4, 0),()),
		"Equalization": ((122, LCID, 4, 0),()),
		"ExemptNum": ((90, LCID, 4, 0),()),
		"ExpirationDate": ((125, LCID, 4, 0),()),
		"ExportCode": ((54, LCID, 4, 0),()),
		"FatherCard": ((48, LCID, 4, 0),()),
		"FatherType": ((51, LCID, 4, 0),()),
		"Fax": ((13, LCID, 4, 0),()),
		"FederalTaxID": ((21, LCID, 4, 0),()),
		"FormCode1099": ((92, LCID, 4, 0),()),
		"FreeText": ((29, LCID, 4, 0),()),
		"Frozen": ((82, LCID, 4, 0),()),
		"FrozenFrom": ((83, LCID, 4, 0),()),
		"FrozenRemarks": ((85, LCID, 4, 0),()),
		"FrozenTo": ((84, LCID, 4, 0),()),
		"GroupCode": ((5, LCID, 4, 0),()),
		"HouseBank": ((99, LCID, 4, 0),()),
		"HouseBankAccount": ((101, LCID, 4, 0),()),
		"HouseBankBranch": ((112, LCID, 4, 0),()),
		"HouseBankCountry": ((100, LCID, 4, 0),()),
		"IBAN": ((69, LCID, 4, 0),()),
		"ISRBillerID": ((109, LCID, 4, 0),()),
		"Indicator": ((68, LCID, 4, 0),()),
		"InstructionKey": ((107, LCID, 4, 0),()),
		"IntrestRatePercent": ((26, LCID, 4, 0),()),
		"LanguageCode": ((154, LCID, 4, 0),()),
		"LastMultiReconciliationNum": ((121, LCID, 4, 0),()),
		"LinkedBusinessPartner": ((120, LCID, 4, 0),()),
		"MailAddress": ((9, LCID, 4, 0),()),
		"MailCity": ((38, LCID, 4, 0),()),
		"MailCountry": ((40, LCID, 4, 0),()),
		"MailCounty": ((39, LCID, 4, 0),()),
		"MailZipCode": ((10, LCID, 4, 0),()),
		"MaxAmountOfExemption": ((116, LCID, 4, 0),()),
		"MaxCommitment": ((18, LCID, 4, 0),()),
		"MinIntrest": ((55, LCID, 4, 0),()),
		"NationalInsuranceNum": ((126, LCID, 4, 0),()),
		"Notes": ((15, LCID, 4, 0),()),
		"OwnerIDNumber": ((113, LCID, 4, 0),()),
		"Pager": ((47, LCID, 4, 0),()),
		"PartialDelivery": ((96, LCID, 4, 0),()),
		"Password": ((67, LCID, 4, 0),()),
		"PayTermsGrpCode": ((16, LCID, 4, 0),()),
		"PaymentBlock": ((110, LCID, 4, 0),()),
		"PaymentBlockDescription": ((114, LCID, 4, 0),()),
		"PeymentMethodCode": ((94, LCID, 4, 0),()),
		"Phone1": ((11, LCID, 4, 0),()),
		"Phone2": ((12, LCID, 4, 0),()),
		"Picture": ((42, LCID, 4, 0),()),
		"PriceListNum": ((25, LCID, 4, 0),()),
		"Priority": ((91, LCID, 4, 0),()),
		"Profession": ((151, LCID, 4, 0),()),
		"ProjectCode": ((143, LCID, 4, 0),()),
		"RateDiffAccount": ((32, LCID, 4, 0),()),
		"ReferenceDetails": ((111, LCID, 4, 0),()),
		"SalesPersonCode": ((30, LCID, 4, 0),()),
		"ShipToBuildingFloorRoom": ((137, LCID, 4, 0),()),
		"ShipToDefault": ((102, LCID, 4, 0),()),
		"ShippingType": ((66, LCID, 4, 0),()),
		"SinglePayment": ((108, LCID, 4, 0),()),
		"SubjectToWithholdingTax": ((123, LCID, 4, 0),()),
		"Territory": ((136, LCID, 4, 0),()),
		"UnpaidBillofExchange": ((155, LCID, 4, 0),()),
		"Valid": ((78, LCID, 4, 0),()),
		"ValidFrom": ((79, LCID, 4, 0),()),
		"ValidRemarks": ((81, LCID, 4, 0),()),
		"ValidTo": ((80, LCID, 4, 0),()),
		"VatGroup": ((65, LCID, 4, 0),()),
		"VatGroupLatinAmerica": ((144, LCID, 4, 0),()),
		"VatLiable": ((20, LCID, 4, 0),()),
		"WTCode": ((128, LCID, 4, 0),()),
		"Website": ((148, LCID, 4, 0),()),
		"WithholdingTaxDeductionGroup": ((156, LCID, 4, 0),()),
		"ZipCode": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBusinessPlaces(DispatchBaseClass):
	'IBusinessPlaces Interface'
	CLSID = IID('{6C92660E-0507-4C90-8DDB-1C5B61AB41AA}')
	coclass_clsid = IID('{ADDFFAB7-1BA1-4C06-8229-D3CE76605700}')

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lBplId=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lBplId
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	_prop_map_get_ = {
		"Address": (14, 2, (8, 0), (), "Address", None),
		"Addressforeign": (15, 2, (8, 0), (), "Addressforeign", None),
		"BPLID": (7, 2, (3, 0), (), "BPLID", None),
		"BPLName": (8, 2, (8, 0), (), "BPLName", None),
		"BPLNameForeign": (9, 2, (8, 0), (), "BPLNameForeign", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Business": (13, 2, (8, 0), (), "Business", None),
		"Disabled": (18, 2, (3, 0), (), "Disabled", None),
		"Industry": (12, 2, (8, 0), (), "Industry", None),
		"MainBPL": (16, 2, (3, 0), (), "MainBPL", None),
		"RepName": (11, 2, (8, 0), (), "RepName", None),
		"TaxOfficeNo": (17, 2, (8, 0), (), "TaxOfficeNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATRegNum": (10, 2, (8, 0), (), "VATRegNum", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChartOfAccounts(DispatchBaseClass):
	'IChartOfAccounts Interface'
	CLSID = IID('{2CF2E472-CA6D-4D8E-8B80-046D28E75C40}')
	coclass_clsid = IID('{85EBDF2E-252D-4489-9E2F-FE17C36ACE86}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(41, LCID, 1, (8, 0), (),)

	def GetByKey(self, AccountCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (11, 0), ((8, 0),),AccountCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(42, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AccountLevel": (15, 2, (3, 0), (), "AccountLevel", None),
		"AccountType": (25, 2, (3, 0), (), "AccountType", None),
		"AcctCurrency": (26, 2, (8, 0), (), "AcctCurrency", None),
		"ActiveAccount": (13, 2, (3, 0), (), "ActiveAccount", None),
		"AllowChangeVatGroup": (43, 2, (3, 0), (), "AllowChangeVatGroup", None),
		"Balance": (9, 2, (5, 0), (), "Balance", None),
		"Balance_FrgnCurr": (29, 2, (5, 0), (), "Balance_FrgnCurr", None),
		"Balance_syscurr": (28, 2, (5, 0), (), "Balance_syscurr", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (6, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BudgetAccount": (11, 2, (3, 0), (), "BudgetAccount", None),
		"CashAccount": (10, 2, (3, 0), (), "CashAccount", None),
		"Code": (7, 2, (8, 0), (), "Code", None),
		"DataExportCode": (16, 2, (8, 0), (), "DataExportCode", None),
		"DefaultVatGroup": (44, 2, (8, 0), (), "DefaultVatGroup", None),
		"Details": (34, 2, (8, 0), (), "Details", None),
		"ExternalCode": (18, 2, (8, 0), (), "ExternalCode", None),
		"ExternalReconNo": (23, 2, (3, 0), (), "ExternalReconNo", None),
		"FatherAccountKey": (17, 2, (8, 0), (), "FatherAccountKey", None),
		"ForeignName": (33, 2, (8, 0), (), "ForeignName", None),
		"FormatCode": (39, 2, (8, 0), (), "FormatCode", None),
		"InternalReconNo": (24, 2, (3, 0), (), "InternalReconNo", None),
		"LiableForAdvances": (32, 2, (3, 0), (), "LiableForAdvances", None),
		"LockManualTransaction": (38, 2, (3, 0), (), "LockManualTransaction", None),
		"Name": (8, 2, (8, 0), (), "Name", None),
		"PrimaryAccount": (14, 2, (3, 0), (), "PrimaryAccount", None),
		"ProjectCode": (35, 2, (8, 0), (), "ProjectCode", None),
		"Protected": (30, 2, (3, 0), (), "Protected", None),
		"RateConversion": (20, 2, (3, 0), (), "RateConversion", None),
		"ReconciledAccount": (31, 2, (3, 0), (), "ReconciledAccount", None),
		"RevaluationCoordinated": (36, 2, (3, 0), (), "RevaluationCoordinated", None),
		"TaxExemptAccount": (22, 2, (3, 0), (), "TaxExemptAccount", None),
		"TaxLiableAccount": (21, 2, (3, 0), (), "TaxLiableAccount", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (40, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AccountType": ((25, LCID, 4, 0),()),
		"AcctCurrency": ((26, LCID, 4, 0),()),
		"ActiveAccount": ((13, LCID, 4, 0),()),
		"AllowChangeVatGroup": ((43, LCID, 4, 0),()),
		"BudgetAccount": ((11, LCID, 4, 0),()),
		"CashAccount": ((10, LCID, 4, 0),()),
		"Code": ((7, LCID, 4, 0),()),
		"DataExportCode": ((16, LCID, 4, 0),()),
		"DefaultVatGroup": ((44, LCID, 4, 0),()),
		"Details": ((34, LCID, 4, 0),()),
		"ExternalCode": ((18, LCID, 4, 0),()),
		"FatherAccountKey": ((17, LCID, 4, 0),()),
		"ForeignName": ((33, LCID, 4, 0),()),
		"FormatCode": ((39, LCID, 4, 0),()),
		"LiableForAdvances": ((32, LCID, 4, 0),()),
		"LockManualTransaction": ((38, LCID, 4, 0),()),
		"Name": ((8, LCID, 4, 0),()),
		"ProjectCode": ((35, LCID, 4, 0),()),
		"Protected": ((30, LCID, 4, 0),()),
		"RateConversion": ((20, LCID, 4, 0),()),
		"ReconciledAccount": ((31, LCID, 4, 0),()),
		"RevaluationCoordinated": ((36, LCID, 4, 0),()),
		"TaxExemptAccount": ((22, LCID, 4, 0),()),
		"TaxLiableAccount": ((21, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChecksforPayment(DispatchBaseClass):
	'IChecksforPayment Interface'
	CLSID = IID('{5E6A92D1-9BAB-4BB4-A379-2428006247C3}')
	coclass_clsid = IID('{31341DF9-0A1F-4B75-BBAB-50B96478E579}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(44, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(46, LCID, 1, (8, 0), (),)

	def GetByKey(self, CheckKey=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),CheckKey
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(47, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AccountNumber": (17, 2, (8, 0), (), "AccountNumber", None),
		"Address": (33, 2, (8, 0), (), "Address", None),
		"AddressName": (45, 2, (8, 0), (), "AddressName", None),
		"BankCode": (11, 2, (8, 0), (), "BankCode", None),
		"BankName": (13, 2, (8, 0), (), "BankName", None),
		"Branch": (12, 2, (8, 0), (), "Branch", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Canceled": (26, 2, (3, 0), (), "Canceled", None),
		"CardOrAccount": (27, 2, (3, 0), (), "CardOrAccount", None),
		"CheckAmount": (22, 2, (5, 0), (), "CheckAmount", None),
		"CheckCurrency": (25, 2, (8, 0), (), "CheckCurrency", None),
		"CheckDate": (14, 2, (7, 0), (), "CheckDate", None),
		"CheckKey": (9, 2, (3, 0), (), "CheckKey", None),
		"CheckNumber": (10, 2, (3, 0), (), "CheckNumber", None),
		"CountryCode": (41, 2, (8, 0), (), "CountryCode", None),
		"CreateJournalEntry": (34, 2, (3, 0), (), "CreateJournalEntry", None),
		"CreationDate": (36, 2, (7, 0), (), "CreationDate", None),
		"CustomerAccountCode": (31, 2, (8, 0), (), "CustomerAccountCode", None),
		"DeductionRefundAmount": (39, 2, (5, 0), (), "DeductionRefundAmount", None),
		"Details": (18, 2, (8, 0), (), "Details", None),
		"JournalEntryReference": (19, 2, (8, 0), (), "JournalEntryReference", None),
		# Method 'Lines' returns object of type 'IChecksforPaymentLines'
		"Lines": (43, 2, (9, 0), (), "Lines", '{A6DB2CDA-3A42-4A70-918C-53595D6091C9}'),
		"PaymentDate": (20, 2, (7, 0), (), "PaymentDate", None),
		"PaymentNo": (21, 2, (3, 0), (), "PaymentNo", None),
		"Printed": (28, 2, (3, 0), (), "Printed", None),
		"PrintedBy": (40, 2, (3, 0), (), "PrintedBy", None),
		"Signature": (30, 2, (8, 0), (), "Signature", None),
		"TaxDate": (38, 2, (7, 0), (), "TaxDate", None),
		"TaxTotal": (37, 2, (5, 0), (), "TaxTotal", None),
		"TotalinWords": (42, 2, (8, 0), (), "TotalinWords", None),
		"TransactionNumber": (32, 2, (3, 0), (), "TransactionNumber", None),
		"Transferable": (23, 2, (3, 0), (), "Transferable", None),
		"UpdateDate": (35, 2, (7, 0), (), "UpdateDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VendorCode": (24, 2, (8, 0), (), "VendorCode", None),
		"VendorName": (29, 2, (8, 0), (), "VendorName", None),
	}
	_prop_map_put_ = {
		"AccountNumber": ((17, LCID, 4, 0),()),
		"Address": ((33, LCID, 4, 0),()),
		"AddressName": ((45, LCID, 4, 0),()),
		"BankCode": ((11, LCID, 4, 0),()),
		"Branch": ((12, LCID, 4, 0),()),
		"CardOrAccount": ((27, LCID, 4, 0),()),
		"CheckDate": ((14, LCID, 4, 0),()),
		"CheckNumber": ((10, LCID, 4, 0),()),
		"CountryCode": ((41, LCID, 4, 0),()),
		"CreateJournalEntry": ((34, LCID, 4, 0),()),
		"CustomerAccountCode": ((31, LCID, 4, 0),()),
		"DeductionRefundAmount": ((39, LCID, 4, 0),()),
		"Details": ((18, LCID, 4, 0),()),
		"JournalEntryReference": ((19, LCID, 4, 0),()),
		"PaymentDate": ((20, LCID, 4, 0),()),
		"Signature": ((30, LCID, 4, 0),()),
		"TotalinWords": ((42, LCID, 4, 0),()),
		"Transferable": ((23, LCID, 4, 0),()),
		"VendorCode": ((24, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChecksforPaymentLines(DispatchBaseClass):
	'IChecksforPaymentLines Interface'
	CLSID = IID('{A6DB2CDA-3A42-4A70-918C-53595D6091C9}')
	coclass_clsid = IID('{36360587-E2A6-4BF4-BFED-92F2CEDDF03D}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"CreditedAccount": (12, 2, (8, 0), (), "CreditedAccount", None),
		"LineTotal": (13, 2, (5, 0), (), "LineTotal", None),
		"RowCurrency": (8, 2, (8, 0), (), "RowCurrency", None),
		"RowDetails": (6, 2, (8, 0), (), "RowDetails", None),
		"RowNumber": (5, 2, (3, 0), (), "RowNumber", None),
		"RowTotal": (7, 2, (5, 0), (), "RowTotal", None),
		"TaxDefinition": (10, 2, (8, 0), (), "TaxDefinition", None),
		"TaxPercent": (11, 2, (5, 0), (), "TaxPercent", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CreditedAccount": ((12, LCID, 4, 0),()),
		"RowCurrency": ((8, LCID, 4, 0),()),
		"RowDetails": ((6, LCID, 4, 0),()),
		"RowTotal": ((7, LCID, 4, 0),()),
		"TaxDefinition": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IClosingDateProcedure(DispatchBaseClass):
	'IClosingDateProcedure Interface'
	CLSID = IID('{910FEA90-B652-4099-9817-3AA0CF635963}')
	coclass_clsid = IID('{B50BD947-38AC-4ACE-97F4-8EA9ECD9AB77}')

	def GetByKey(self, ClosingDateNum=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((3, 0),),ClosingDateNum
			)

	_prop_map_get_ = {
		"BaselineDate": (4, 2, (3, 0), (), "BaselineDate", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (8, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ClosingDateCode": (3, 2, (8, 0), (), "ClosingDateCode", None),
		"ClosingDateNum": (2, 2, (3, 0), (), "ClosingDateNum", None),
		"DueMonth": (5, 2, (3, 0), (), "DueMonth", None),
		"ExtraDay": (7, 2, (3, 0), (), "ExtraDay", None),
		"ExtraMonth": (6, 2, (3, 0), (), "ExtraMonth", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICommand(DispatchBaseClass):
	'ICommand Interface'
	CLSID = IID('{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}')
	coclass_clsid = IID('{15BD344C-48ED-4A6A-8A31-AFBD7A2ED57B}')

	def Execute(self):
		'method Execute'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	_prop_map_get_ = {
		"Name": (1, 2, (8, 0), (), "Name", None),
		# Method 'Parameters' returns object of type 'ICommandParams'
		"Parameters": (2, 2, (9, 0), (), "Parameters", '{93CF87D1-95CB-459C-A906-729819461CA1}'),
	}
	_prop_map_put_ = {
		"Name": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICommandParam(DispatchBaseClass):
	'ICommandParam Interface'
	CLSID = IID('{8CA91808-D098-4416-8368-E426484BA8DB}')
	coclass_clsid = IID('{13CC4089-F2FA-4B28-9BD9-75F6DC0E44B3}')

	_prop_map_get_ = {
		"Direction": (4, 2, (3, 0), (), "Direction", None),
		"Name": (1, 2, (8, 0), (), "Name", None),
		"Type": (3, 2, (3, 0), (), "Type", None),
		"Value": (2, 2, (12, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Value": ((2, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(2, 2, (12, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICommandParams(DispatchBaseClass):
	'ICommandParams Interface'
	CLSID = IID('{93CF87D1-95CB-459C-A906-729819461CA1}')
	coclass_clsid = IID('{9C536750-5FC9-45DF-AF6E-62DB9ACCAEA8}')

	# Result is of type ICommandParam
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{8CA91808-D098-4416-8368-E426484BA8DB}')
		return ret

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{8CA91808-D098-4416-8368-E426484BA8DB}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{8CA91808-D098-4416-8368-E426484BA8DB}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICompany(DispatchBaseClass):
	'ICompany Interface'
	CLSID = IID('{3BA8DAED-5B33-4CE4-A4B8-B4308D86E524}')
	coclass_clsid = IID('{A355004F-AAB4-41D3-BDE0-7EAED1ED5FFF}')

	def Connect(self):
		'Use this function for establishing connection to the database.'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Disconnect(self):
		'Use this function to dissconnect from the server'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (24, 0), (),)

	def EndTransaction(self, endType=defaultNamedNotOptArg):
		'method EndTransaction'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (24, 0), ((3, 0),),endType
			)

	def GetBusinessObject(self, Object=defaultNamedNotOptArg):
		'Get a new initialized business object.'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((3, 0),),Object
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBusinessObject', None)
		return ret

	def GetBusinessObjectFromXML(self, FileName=defaultNamedNotOptArg, Index=defaultNamedNotOptArg):
		'Get a saved business object.'
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), ((8, 1), (3, 1)),FileName
			, Index)
		if ret is not None:
			ret = Dispatch(ret, u'GetBusinessObjectFromXML', None)
		return ret

	def GetBusinessObjectXmlSchema(self, Object=defaultNamedNotOptArg):
		'method GetBusinessObjectXmlSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(29, LCID, 1, (8, 0), ((3, 1),),Object
			)

	# Result is of type IRecordset
	def GetCompanyList(self):
		'method GetCompanyList'
		ret = self._oleobj_.InvokeTypes(24, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCompanyList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	def GetContextCookie(self):
		'method GetContextCookie'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(34, LCID, 1, (8, 0), (),)

	def GetLastError(self, errCode=pythoncom.Missing, errMsg=pythoncom.Missing):
		'Use this function for establishing connection to the database.'
		return self._ApplyTypes_(19, 1, (24, 0), ((16387, 2), (16392, 2)), u'GetLastError', None,errCode
			, errMsg)

	def GetLastErrorCode(self):
		'method GetLastErrorCode'
		return self._oleobj_.InvokeTypes(40, LCID, 1, (3, 0), (),)

	def GetLastErrorDescription(self):
		'method GetLastErrorDescription'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(39, LCID, 1, (8, 0), (),)

	def GetNewObjectCode(self, ObjectCode=pythoncom.Missing):
		'method GetNewObjectCode'
		return self._ApplyTypes_(22, 1, (24, 0), ((16392, 2),), u'GetNewObjectCode', None,ObjectCode
			)

	def GetNewObjectKey(self):
		'method GetNewObjectKey'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(41, LCID, 1, (8, 0), (),)

	def GetXMLelementCount(self, FileName=defaultNamedNotOptArg):
		'method GetXMLelementCount'
		return self._oleobj_.InvokeTypes(26, LCID, 1, (3, 0), ((8, 1),),FileName
			)

	def GetXMLobjectType(self, FileName=defaultNamedNotOptArg, Index=defaultNamedNotOptArg):
		'method GetXMLobjectType'
		return self._oleobj_.InvokeTypes(25, LCID, 1, (3, 0), ((8, 1), (3, 1)),FileName
			, Index)

	def IsDTCTransactionObjectSet(self):
		'IsDTCTransactionObjectSet'
		return self._oleobj_.InvokeTypes(45, LCID, 1, (11, 0), (),)

	def SetSboLoginContext(self, conStr=defaultNamedNotOptArg):
		'method SetSboLoginContext'
		return self._oleobj_.InvokeTypes(35, LCID, 1, (3, 0), ((8, 1),),conStr
			)

	def StartTransaction(self):
		'method StartTransaction'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), (),)

	_prop_map_get_ = {
		"AddonIdentifier": (37, 2, (8, 0), (), "AddonIdentifier", None),
		"AttachMentPath": (13, 2, (8, 0), (), "AttachMentPath", None),
		"BitMapPath": (8, 2, (8, 0), (), "BitMapPath", None),
		"CompanyDB": (4, 2, (8, 0), (), "CompanyDB", None),
		"CompanyName": (6, 2, (8, 0), (), "CompanyName", None),
		"Connected": (12, 2, (11, 0), (), "Connected", None),
		"DTCTransactionObject": (44, 2, (13, 0), (), "DTCTransactionObject", None),
		"DbPassword": (33, 2, (8, 0), (), "DbPassword", None),
		"DbServerType": (36, 2, (3, 0), (), "DbServerType", None),
		"DbUserName": (32, 2, (8, 0), (), "DbUserName", None),
		"ExcelDocsPath": (9, 2, (8, 0), (), "ExcelDocsPath", None),
		"InTransaction": (31, 2, (11, 0), (), "InTransaction", None),
		"LicenseServer": (38, 2, (8, 0), (), "LicenseServer", None),
		"MinimalSupportedVersion": (43, 2, (3, 0), (), "MinimalSupportedVersion", None),
		"Password": (11, 2, (8, 0), (), "Password", None),
		"Server": (2, 2, (8, 0), (), "Server", None),
		"UseTrusted": (23, 2, (11, 0), (), "UseTrusted", None),
		"UserName": (10, 2, (8, 0), (), "UserName", None),
		"UserSignature": (5, 2, (3, 0), (), "UserSignature", None),
		# Method 'UserTables' returns object of type 'IUserTables'
		"UserTables": (27, 2, (9, 0), (), "UserTables", '{625162C1-3894-460F-94EC-72D6AFEA34D2}'),
		"Version": (42, 2, (3, 0), (), "Version", None),
		"WordDocsPath": (7, 2, (8, 0), (), "WordDocsPath", None),
		"XMLAsString": (28, 2, (11, 0), (), "XMLAsString", None),
		"XmlExportType": (30, 2, (3, 0), (), "XmlExportType", None),
		"language": (18, 2, (3, 0), (), "language", None),
	}
	_prop_map_put_ = {
		"AddonIdentifier": ((37, LCID, 4, 0),()),
		"CompanyDB": ((4, LCID, 4, 0),()),
		"DTCTransactionObject": ((44, LCID, 4, 0),()),
		"DbPassword": ((33, LCID, 4, 0),()),
		"DbServerType": ((36, LCID, 4, 0),()),
		"DbUserName": ((32, LCID, 4, 0),()),
		"LicenseServer": ((38, LCID, 4, 0),()),
		"Password": ((11, LCID, 4, 0),()),
		"Server": ((2, LCID, 4, 0),()),
		"UseTrusted": ((23, LCID, 4, 0),()),
		"UserName": ((10, LCID, 4, 0),()),
		"XMLAsString": ((28, LCID, 4, 0),()),
		"XmlExportType": ((30, LCID, 4, 0),()),
		"language": ((18, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IContactEmployees(DispatchBaseClass):
	'IContactEmployees Interface'
	CLSID = IID('{52C8673B-CA79-4476-9F2E-28109AE17545}')
	coclass_clsid = IID('{22DCA799-2F7B-4B31-ABB6-74F3C07CB367}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Address": (3, 2, (8, 0), (), "Address", None),
		"CardCode": (23, 2, (8, 0), (), "CardCode", None),
		"Count": (13, 2, (3, 0), (), "Count", None),
		"DateOfBirth": (20, 2, (7, 0), (), "DateOfBirth", None),
		"E_Mail": (8, 2, (8, 0), (), "E_Mail", None),
		"Fax": (7, 2, (8, 0), (), "Fax", None),
		"Gender": (21, 2, (3, 0), (), "Gender", None),
		"InternalCode": (18, 2, (3, 0), (), "InternalCode", None),
		"MobilePhone": (6, 2, (8, 0), (), "MobilePhone", None),
		"Name": (16, 2, (8, 0), (), "Name", None),
		"Pager": (9, 2, (8, 0), (), "Pager", None),
		"Password": (12, 2, (8, 0), (), "Password", None),
		"Phone1": (4, 2, (8, 0), (), "Phone1", None),
		"Phone2": (5, 2, (8, 0), (), "Phone2", None),
		"PlaceOfBirth": (19, 2, (8, 0), (), "PlaceOfBirth", None),
		"Position": (2, 2, (8, 0), (), "Position", None),
		"Profession": (22, 2, (8, 0), (), "Profession", None),
		"Remarks1": (10, 2, (8, 0), (), "Remarks1", None),
		"Remarks2": (11, 2, (8, 0), (), "Remarks2", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (17, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Address": ((3, LCID, 4, 0),()),
		"DateOfBirth": ((20, LCID, 4, 0),()),
		"E_Mail": ((8, LCID, 4, 0),()),
		"Fax": ((7, LCID, 4, 0),()),
		"Gender": ((21, LCID, 4, 0),()),
		"MobilePhone": ((6, LCID, 4, 0),()),
		"Name": ((16, LCID, 4, 0),()),
		"Pager": ((9, LCID, 4, 0),()),
		"Password": ((12, LCID, 4, 0),()),
		"Phone1": ((4, LCID, 4, 0),()),
		"Phone2": ((5, LCID, 4, 0),()),
		"PlaceOfBirth": ((19, LCID, 4, 0),()),
		"Position": ((2, LCID, 4, 0),()),
		"Profession": ((22, LCID, 4, 0),()),
		"Remarks1": ((10, LCID, 4, 0),()),
		"Remarks2": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(13, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IContacts(DispatchBaseClass):
	'IContacts Interface'
	CLSID = IID('{96D7BBA9-27E7-4893-BC78-CC4313BE0DD1}')
	coclass_clsid = IID('{161C44B9-9DAC-4D31-AB92-EED776B8C745}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(52, LCID, 1, (8, 0), (),)

	def GetByKey(self, ContactCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((3, 0),),ContactCode
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(53, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(4, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Activity": (24, 2, (3, 0), (), "Activity", None),
		"ActivityType": (25, 2, (3, 0), (), "ActivityType", None),
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (19, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (20, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (5, 2, (8, 0), (), "CardCode", None),
		"City": (38, 2, (8, 0), (), "City", None),
		"CloseDate": (11, 2, (7, 0), (), "CloseDate", None),
		"Closed": (10, 2, (3, 0), (), "Closed", None),
		"ContactCode": (21, 2, (3, 0), (), "ContactCode", None),
		"ContactDate": (7, 2, (7, 0), (), "ContactDate", None),
		"ContactPersonCode": (32, 2, (3, 0), (), "ContactPersonCode", None),
		"ContactTime": (8, 2, (7, 0), (), "ContactTime", None),
		"Country": (47, 2, (8, 0), (), "Country", None),
		"Details": (23, 2, (8, 0), (), "Details", None),
		"DocEntry": (18, 2, (8, 0), (), "DocEntry", None),
		"DocNum": (17, 2, (8, 0), (), "DocNum", None),
		"DocType": (16, 2, (3, 0), (), "DocType", None),
		"DocTypeEx": (51, 2, (8, 0), (), "DocTypeEx", None),
		"Duration": (29, 2, (5, 0), (), "Duration", None),
		"DurationType": (30, 2, (3, 0), (), "DurationType", None),
		"EndDuedate": (50, 2, (7, 0), (), "EndDuedate", None),
		"EndTime": (28, 2, (7, 0), (), "EndTime", None),
		"Fax": (14, 2, (8, 0), (), "Fax", None),
		"HandledBy": (33, 2, (3, 0), (), "HandledBy", None),
		"Inactiveflag": (44, 2, (3, 0), (), "Inactiveflag", None),
		"Location": (26, 2, (3, 0), (), "Location", None),
		"Notes": (6, 2, (8, 0), (), "Notes", None),
		"ParentobjectId": (41, 2, (3, 0), (), "ParentobjectId", None),
		"Parentobjecttype": (42, 2, (8, 0), (), "Parentobjecttype", None),
		"Personalflag": (39, 2, (3, 0), (), "Personalflag", None),
		"Phone": (13, 2, (8, 0), (), "Phone", None),
		"PreviousActivity": (46, 2, (3, 0), (), "PreviousActivity", None),
		"Priority": (22, 2, (3, 0), (), "Priority", None),
		"Recontact": (9, 2, (7, 0), (), "Recontact", None),
		"Reminder": (35, 2, (3, 0), (), "Reminder", None),
		"ReminderPeriod": (36, 2, (5, 0), (), "ReminderPeriod", None),
		"ReminderType": (37, 2, (3, 0), (), "ReminderType", None),
		"Room": (43, 2, (8, 0), (), "Room", None),
		"SalesEmployee": (31, 2, (3, 0), (), "SalesEmployee", None),
		"StartTime": (27, 2, (7, 0), (), "StartTime", None),
		"State": (45, 2, (8, 0), (), "State", None),
		"Status": (48, 2, (3, 0), (), "Status", None),
		"Street": (40, 2, (8, 0), (), "Street", None),
		"Subject": (15, 2, (8, 0), (), "Subject", None),
		"Tentativeflag": (49, 2, (3, 0), (), "Tentativeflag", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (34, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Activity": ((24, LCID, 4, 0),()),
		"ActivityType": ((25, LCID, 4, 0),()),
		"CardCode": ((5, LCID, 4, 0),()),
		"City": ((38, LCID, 4, 0),()),
		"CloseDate": ((11, LCID, 4, 0),()),
		"Closed": ((10, LCID, 4, 0),()),
		"ContactDate": ((7, LCID, 4, 0),()),
		"ContactPersonCode": ((32, LCID, 4, 0),()),
		"ContactTime": ((8, LCID, 4, 0),()),
		"Country": ((47, LCID, 4, 0),()),
		"Details": ((23, LCID, 4, 0),()),
		"DocEntry": ((18, LCID, 4, 0),()),
		"DocType": ((16, LCID, 4, 0),()),
		"DocTypeEx": ((51, LCID, 4, 0),()),
		"Duration": ((29, LCID, 4, 0),()),
		"DurationType": ((30, LCID, 4, 0),()),
		"EndDuedate": ((50, LCID, 4, 0),()),
		"EndTime": ((28, LCID, 4, 0),()),
		"Fax": ((14, LCID, 4, 0),()),
		"HandledBy": ((33, LCID, 4, 0),()),
		"Inactiveflag": ((44, LCID, 4, 0),()),
		"Location": ((26, LCID, 4, 0),()),
		"Notes": ((6, LCID, 4, 0),()),
		"Personalflag": ((39, LCID, 4, 0),()),
		"Phone": ((13, LCID, 4, 0),()),
		"PreviousActivity": ((46, LCID, 4, 0),()),
		"Priority": ((22, LCID, 4, 0),()),
		"Recontact": ((9, LCID, 4, 0),()),
		"Reminder": ((35, LCID, 4, 0),()),
		"ReminderPeriod": ((36, LCID, 4, 0),()),
		"ReminderType": ((37, LCID, 4, 0),()),
		"Room": ((43, LCID, 4, 0),()),
		"SalesEmployee": ((31, LCID, 4, 0),()),
		"StartTime": ((27, LCID, 4, 0),()),
		"State": ((45, LCID, 4, 0),()),
		"Status": ((48, LCID, 4, 0),()),
		"Street": ((40, LCID, 4, 0),()),
		"Subject": ((15, LCID, 4, 0),()),
		"Tentativeflag": ((49, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IContractTemplates(DispatchBaseClass):
	'IContractTemplates Interface'
	CLSID = IID('{9EB0E81A-9442-4C9A-B096-93C6134E684D}')
	coclass_clsid = IID('{835F6104-3A36-4122-8AE8-C4E1D7B15453}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(46, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(50, LCID, 1, (8, 0), (),)

	def GetByKey(self, TemplateName=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((8, 1),),TemplateName
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(51, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (41, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (45, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ContractType": (16, 2, (3, 0), (), "ContractType", None),
		"Description": (14, 2, (8, 0), (), "Description", None),
		"DurationOfCoverage": (11, 2, (3, 0), (), "DurationOfCoverage", None),
		"FridayEnabled": (21, 2, (3, 0), (), "FridayEnabled", None),
		"FridayEnd": (33, 2, (7, 0), (), "FridayEnd", None),
		"FridayStart": (32, 2, (7, 0), (), "FridayStart", None),
		"IncludeHolidays": (47, 2, (3, 0), (), "IncludeHolidays", None),
		"IncludeLabor": (39, 2, (3, 0), (), "IncludeLabor", None),
		"IncludeParts": (38, 2, (3, 0), (), "IncludeParts", None),
		"IncludeTravel": (40, 2, (3, 0), (), "IncludeTravel", None),
		"MondayEnabled": (17, 2, (3, 0), (), "MondayEnabled", None),
		"MondayEnd": (25, 2, (7, 0), (), "MondayEnd", None),
		"MondayStart": (24, 2, (7, 0), (), "MondayStart", None),
		"Remarks": (43, 2, (8, 0), (), "Remarks", None),
		"RemindBeforeRenewal": (9, 2, (3, 0), (), "RemindBeforeRenewal", None),
		"RemindUnit": (10, 2, (3, 0), (), "RemindUnit", None),
		"ResolutionTime": (49, 2, (3, 0), (), "ResolutionTime", None),
		"ResolutionUnit": (13, 2, (3, 0), (), "ResolutionUnit", None),
		"ResponseUnit": (48, 2, (3, 0), (), "ResponseUnit", None),
		"ResponseValue": (12, 2, (3, 0), (), "ResponseValue", None),
		"SaturdayEnabled": (22, 2, (3, 0), (), "SaturdayEnabled", None),
		"SaturdayEnd": (35, 2, (7, 0), (), "SaturdayEnd", None),
		"SaturdayStart": (34, 2, (7, 0), (), "SaturdayStart", None),
		"SundayEnabled": (23, 2, (3, 0), (), "SundayEnabled", None),
		"SundayEnd": (37, 2, (7, 0), (), "SundayEnd", None),
		"SundayStart": (36, 2, (7, 0), (), "SundayStart", None),
		"TemplateIsDeleted": (7, 2, (3, 0), (), "TemplateIsDeleted", None),
		"TemplateIsRenewal": (8, 2, (3, 0), (), "TemplateIsRenewal", None),
		"TemplateName": (6, 2, (8, 0), (), "TemplateName", None),
		"ThursdayEnabled": (20, 2, (3, 0), (), "ThursdayEnabled", None),
		"ThursdayEnd": (31, 2, (7, 0), (), "ThursdayEnd", None),
		"ThursdayStart": (30, 2, (7, 0), (), "ThursdayStart", None),
		"TuesdayEnabled": (18, 2, (3, 0), (), "TuesdayEnabled", None),
		"TuesdayEnd": (27, 2, (7, 0), (), "TuesdayEnd", None),
		"TuesdayStart": (26, 2, (7, 0), (), "TuesdayStart", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (44, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WednesdayEnabled": (19, 2, (3, 0), (), "WednesdayEnabled", None),
		"WednesdayEnd": (29, 2, (7, 0), (), "WednesdayEnd", None),
		"WednesdayStart": (28, 2, (7, 0), (), "WednesdayStart", None),
	}
	_prop_map_put_ = {
		"ContractType": ((16, LCID, 4, 0),()),
		"Description": ((14, LCID, 4, 0),()),
		"DurationOfCoverage": ((11, LCID, 4, 0),()),
		"FridayEnabled": ((21, LCID, 4, 0),()),
		"FridayEnd": ((33, LCID, 4, 0),()),
		"FridayStart": ((32, LCID, 4, 0),()),
		"IncludeHolidays": ((47, LCID, 4, 0),()),
		"IncludeLabor": ((39, LCID, 4, 0),()),
		"IncludeParts": ((38, LCID, 4, 0),()),
		"IncludeTravel": ((40, LCID, 4, 0),()),
		"MondayEnabled": ((17, LCID, 4, 0),()),
		"MondayEnd": ((25, LCID, 4, 0),()),
		"MondayStart": ((24, LCID, 4, 0),()),
		"Remarks": ((43, LCID, 4, 0),()),
		"RemindBeforeRenewal": ((9, LCID, 4, 0),()),
		"RemindUnit": ((10, LCID, 4, 0),()),
		"ResolutionTime": ((49, LCID, 4, 0),()),
		"ResolutionUnit": ((13, LCID, 4, 0),()),
		"ResponseUnit": ((48, LCID, 4, 0),()),
		"ResponseValue": ((12, LCID, 4, 0),()),
		"SaturdayEnabled": ((22, LCID, 4, 0),()),
		"SaturdayEnd": ((35, LCID, 4, 0),()),
		"SaturdayStart": ((34, LCID, 4, 0),()),
		"SundayEnabled": ((23, LCID, 4, 0),()),
		"SundayEnd": ((37, LCID, 4, 0),()),
		"SundayStart": ((36, LCID, 4, 0),()),
		"TemplateIsDeleted": ((7, LCID, 4, 0),()),
		"TemplateIsRenewal": ((8, LCID, 4, 0),()),
		"TemplateName": ((6, LCID, 4, 0),()),
		"ThursdayEnabled": ((20, LCID, 4, 0),()),
		"ThursdayEnd": ((31, LCID, 4, 0),()),
		"ThursdayStart": ((30, LCID, 4, 0),()),
		"TuesdayEnabled": ((18, LCID, 4, 0),()),
		"TuesdayEnd": ((27, LCID, 4, 0),()),
		"TuesdayStart": ((26, LCID, 4, 0),()),
		"WednesdayEnabled": ((19, LCID, 4, 0),()),
		"WednesdayEnd": ((29, LCID, 4, 0),()),
		"WednesdayStart": ((28, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICurrencies(DispatchBaseClass):
	'ICurrencies Interface'
	CLSID = IID('{596CFFFE-E95F-472D-8243-37094A850DCF}')
	coclass_clsid = IID('{12788346-93BB-4D1C-8649-A3266A413D3F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(9, LCID, 1, (8, 0), (),)

	def GetByKey(self, Currency=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (11, 0), ((8, 0),),Currency
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (11, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (6, 2, (8, 0), (), "Code", None),
		"DocumentsCode": (8, 2, (8, 0), (), "DocumentsCode", None),
		"Name": (7, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (12, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Code": ((6, LCID, 4, 0),()),
		"DocumentsCode": ((8, LCID, 4, 0),()),
		"Name": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICustomerEquipmentCards(DispatchBaseClass):
	'ICustomerEquipmentCards Interface'
	CLSID = IID('{D8BCB8BC-6DD1-4D3A-ABBF-FA7A18396B2C}')
	coclass_clsid = IID('{6EF2D0B5-8580-41AD-B879-42738445BE03}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(47, LCID, 1, (8, 0), (),)

	def GetByKey(self, EquipmentCardNum=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),EquipmentCardNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(48, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (39, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		"Block": (29, 2, (8, 0), (), "Block", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BuildingFloorRoom": (49, 2, (8, 0), (), "BuildingFloorRoom", None),
		"City": (31, 2, (8, 0), (), "City", None),
		"ContactEmployeeCode": (12, 2, (3, 0), (), "ContactEmployeeCode", None),
		"ContactPhone": (27, 2, (8, 0), (), "ContactPhone", None),
		"CountryCode": (33, 2, (8, 0), (), "CountryCode", None),
		"County": (32, 2, (8, 0), (), "County", None),
		"CustomerCode": (10, 2, (8, 0), (), "CustomerCode", None),
		"CustomerName": (11, 2, (8, 0), (), "CustomerName", None),
		"DefaultTechnician": (44, 2, (3, 0), (), "DefaultTechnician", None),
		"Defaultterritory": (46, 2, (3, 0), (), "Defaultterritory", None),
		"DeliveryCode": (40, 2, (3, 0), (), "DeliveryCode", None),
		"DeliveryDate": (26, 2, (7, 0), (), "DeliveryDate", None),
		"DeliveryNumber": (41, 2, (3, 0), (), "DeliveryNumber", None),
		"DirectCustomerCode": (13, 2, (8, 0), (), "DirectCustomerCode", None),
		"DirectCustomerName": (14, 2, (8, 0), (), "DirectCustomerName", None),
		"EquipmentCardNum": (9, 2, (3, 0), (), "EquipmentCardNum", None),
		"InstallLocation": (35, 2, (8, 0), (), "InstallLocation", None),
		"InternalSerialNum": (16, 2, (8, 0), (), "InternalSerialNum", None),
		"InvoiceCode": (24, 2, (3, 0), (), "InvoiceCode", None),
		"InvoiceNumber": (25, 2, (3, 0), (), "InvoiceNumber", None),
		"ItemCode": (22, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (23, 2, (8, 0), (), "ItemDescription", None),
		"ManufacturerSerialNum": (15, 2, (8, 0), (), "ManufacturerSerialNum", None),
		"ReplaceSN": (43, 2, (3, 0), (), "ReplaceSN", None),
		"ReplacedBySN": (45, 2, (3, 0), (), "ReplacedBySN", None),
		"StateCode": (34, 2, (8, 0), (), "StateCode", None),
		"StatusOfSerialNumber": (42, 2, (3, 0), (), "StatusOfSerialNumber", None),
		"Street": (28, 2, (8, 0), (), "Street", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"ZipCode": (30, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"Block": ((29, LCID, 4, 0),()),
		"BuildingFloorRoom": ((49, LCID, 4, 0),()),
		"City": ((31, LCID, 4, 0),()),
		"ContactEmployeeCode": ((12, LCID, 4, 0),()),
		"CountryCode": ((33, LCID, 4, 0),()),
		"County": ((32, LCID, 4, 0),()),
		"CustomerCode": ((10, LCID, 4, 0),()),
		"CustomerName": ((11, LCID, 4, 0),()),
		"DefaultTechnician": ((44, LCID, 4, 0),()),
		"Defaultterritory": ((46, LCID, 4, 0),()),
		"DeliveryCode": ((40, LCID, 4, 0),()),
		"DirectCustomerCode": ((13, LCID, 4, 0),()),
		"DirectCustomerName": ((14, LCID, 4, 0),()),
		"InstallLocation": ((35, LCID, 4, 0),()),
		"InternalSerialNum": ((16, LCID, 4, 0),()),
		"InvoiceCode": ((24, LCID, 4, 0),()),
		"ItemCode": ((22, LCID, 4, 0),()),
		"ItemDescription": ((23, LCID, 4, 0),()),
		"ManufacturerSerialNum": ((15, LCID, 4, 0),()),
		"ReplaceSN": ((43, LCID, 4, 0),()),
		"ReplacedBySN": ((45, LCID, 4, 0),()),
		"StateCode": ((34, LCID, 4, 0),()),
		"StatusOfSerialNumber": ((42, LCID, 4, 0),()),
		"Street": ((28, LCID, 4, 0),()),
		"ZipCode": ((30, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICustomsGroups(DispatchBaseClass):
	'ICustomsGroups Interface'
	CLSID = IID('{842F5C3F-67A6-42B4-8181-98EFB9520A5F}')
	coclass_clsid = IID('{C7224CA0-BA56-4141-84AA-9E45D75208EF}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lGroupCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lGroupCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Customs": (13, 2, (5, 0), (), "Customs", None),
		"Locked": (17, 2, (3, 0), (), "Locked", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"Number": (12, 2, (8, 0), (), "Number", None),
		"Other": (15, 2, (5, 0), (), "Other", None),
		"Purchase": (14, 2, (5, 0), (), "Purchase", None),
		"Total": (16, 2, (5, 0), (), "Total", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Customs": ((13, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"Number": ((12, LCID, 4, 0),()),
		"Other": ((15, LCID, 4, 0),()),
		"Purchase": ((14, LCID, 4, 0),()),
		"Total": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDataBrowser(DispatchBaseClass):
	'IDataBrowser Interface'
	CLSID = IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')
	coclass_clsid = IID('{0D5D4022-6FCC-49A4-AB69-7F4304B47EC9}')

	def MoveFirst(self):
		'method MoveFirst'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def MoveLast(self):
		'method MoveLast'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), (),)

	def MoveNext(self):
		'method MoveNext'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def MovePrevious(self):
		'method MovePrevious'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def ReadXml(self, XmlFileStr=defaultNamedNotOptArg, Index=defaultNamedNotOptArg):
		'method ReadXml'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1), (3, 1)),XmlFileStr
			, Index)

	def Refresh(self):
		'method Refresh'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (24, 0), (),)

	_prop_map_get_ = {
		"BoF": (7, 2, (11, 0), (), "BoF", None),
		"EoF": (8, 2, (11, 0), (), "EoF", None),
		"RecordCount": (2, 2, (3, 0), (), "RecordCount", None),
	}
	_prop_map_put_ = {
		"Recordset": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDocument_Lines(DispatchBaseClass):
	'IDocument_Lines Interface'
	CLSID = IID('{248B28DD-1281-4C6C-9780-22D19BA13D1F}')
	coclass_clsid = IID('{E9B749CA-045B-4BDD-A5BD-143458EBA752}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(120, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(48, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (18, 2, (8, 0), (), "AccountCode", None),
		"Address": (54, 2, (8, 0), (), "Address", None),
		"AppliedTax": (74, 2, (5, 0), (), "AppliedTax", None),
		"AppliedTaxFC": (75, 2, (5, 0), (), "AppliedTaxFC", None),
		"AppliedTaxSC": (76, 2, (5, 0), (), "AppliedTaxSC", None),
		"BackOrder": (62, 2, (3, 0), (), "BackOrder", None),
		"BarCode": (23, 2, (8, 0), (), "BarCode", None),
		"BaseEntry": (42, 2, (3, 0), (), "BaseEntry", None),
		"BaseLine": (43, 2, (3, 0), (), "BaseLine", None),
		"BaseOpenQuantity": (122, 2, (5, 0), (), "BaseOpenQuantity", None),
		"BaseType": (41, 2, (3, 0), (), "BaseType", None),
		# Method 'BatchNumbers' returns object of type 'IBatchNumbers'
		"BatchNumbers": (69, 2, (9, 0), (), "BatchNumbers", '{1FEF5698-93E1-4167-AEA0-4BB151792623}'),
		"CFOPCode": (99, 2, (8, 0), (), "CFOPCode", None),
		"CSTCode": (100, 2, (8, 0), (), "CSTCode", None),
		"CommisionPercent": (16, 2, (5, 0), (), "CommisionPercent", None),
		"ConsumerSalesForecast": (97, 2, (3, 0), (), "ConsumerSalesForecast", None),
		"CorrInvAmountToDiffAcct": (73, 2, (5, 0), (), "CorrInvAmountToDiffAcct", None),
		"CorrInvAmountToStock": (72, 2, (5, 0), (), "CorrInvAmountToStock", None),
		"CorrectionInvoiceItem": (71, 2, (3, 0), (), "CorrectionInvoiceItem", None),
		"CostingCode": (21, 2, (8, 0), (), "CostingCode", None),
		"Count": (47, 2, (3, 0), (), "Count", None),
		"CountryOrg": (95, 2, (8, 0), (), "CountryOrg", None),
		"Currency": (9, 2, (8, 0), (), "Currency", None),
		"DeferredTax": (88, 2, (3, 0), (), "DeferredTax", None),
		"DiscountPercent": (11, 2, (5, 0), (), "DiscountPercent", None),
		"DistributeExpense": (107, 2, (3, 0), (), "DistributeExpense", None),
		"EqualizationTaxPercent": (78, 2, (5, 0), (), "EqualizationTaxPercent", None),
		"ExciseAmount": (92, 2, (5, 0), (), "ExciseAmount", None),
		# Method 'Expenses' returns object of type 'IDocument_LinesAdditionalExpenses'
		"Expenses": (70, 2, (9, 0), (), "Expenses", '{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}'),
		"Factor1": (37, 2, (5, 0), (), "Factor1", None),
		"Factor2": (38, 2, (5, 0), (), "Factor2", None),
		"Factor3": (39, 2, (5, 0), (), "Factor3", None),
		"Factor4": (40, 2, (5, 0), (), "Factor4", None),
		"FreeText": (63, 2, (8, 0), (), "FreeText", None),
		"Height1": (25, 2, (5, 0), (), "Height1", None),
		"Height2": (27, 2, (5, 0), (), "Height2", None),
		"Height2Unit": (28, 2, (3, 0), (), "Height2Unit", None),
		"Hight1Unit": (26, 2, (3, 0), (), "Hight1Unit", None),
		"ItemCode": (3, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (4, 2, (8, 0), (), "ItemDescription", None),
		"LastBuyDistributeSum": (114, 2, (5, 0), (), "LastBuyDistributeSum", None),
		"LastBuyDistributeSumFc": (112, 2, (5, 0), (), "LastBuyDistributeSumFc", None),
		"LastBuyDistributeSumSc": (113, 2, (5, 0), (), "LastBuyDistributeSumSc", None),
		"LastBuyInmPrice": (111, 2, (5, 0), (), "LastBuyInmPrice", None),
		"Lengh1": (29, 2, (5, 0), (), "Lengh1", None),
		"Lengh1Unit": (30, 2, (3, 0), (), "Lengh1Unit", None),
		"Lengh2": (31, 2, (5, 0), (), "Lengh2", None),
		"Lengh2Unit": (32, 2, (3, 0), (), "Lengh2Unit", None),
		"LineNum": (2, 2, (3, 0), (), "LineNum", None),
		"LineStatus": (124, 2, (3, 0), (), "LineStatus", None),
		"LineTotal": (84, 2, (5, 0), (), "LineTotal", None),
		"MeasureUnit": (90, 2, (8, 0), (), "MeasureUnit", None),
		"NetTaxAmount": (81, 2, (5, 0), (), "NetTaxAmount", None),
		"NetTaxAmountFC": (82, 2, (5, 0), (), "NetTaxAmountFC", None),
		"NetTaxAmountSC": (83, 2, (5, 0), (), "NetTaxAmountSC", None),
		"OriginalItem": (61, 2, (8, 0), (), "OriginalItem", None),
		"POTargetEntry": (66, 2, (8, 0), (), "POTargetEntry", None),
		"POTargetNum": (65, 2, (3, 0), (), "POTargetNum", None),
		"POTargetRowNum": (67, 2, (8, 0), (), "POTargetRowNum", None),
		"PackageQuantity": (125, 2, (5, 0), (), "PackageQuantity", None),
		"PickListIdNumber": (60, 2, (3, 0), (), "PickListIdNumber", None),
		"PickQuantity": (59, 2, (5, 0), (), "PickQuantity", None),
		"PickStatus": (58, 2, (3, 0), (), "PickStatus", None),
		"PickStatusEx": (119, 2, (3, 0), (), "PickStatusEx", None),
		"Price": (7, 2, (5, 0), (), "Price", None),
		"PriceAfterVAT": (8, 2, (5, 0), (), "PriceAfterVAT", None),
		"ProjectCode": (22, 2, (8, 0), (), "ProjectCode", None),
		"Quantity": (5, 2, (5, 0), (), "Quantity", None),
		"Rate": (10, 2, (5, 0), (), "Rate", None),
		"RowTotalFC": (109, 2, (5, 0), (), "RowTotalFC", None),
		"RowTotalSC": (110, 2, (5, 0), (), "RowTotalSC", None),
		"SWW": (96, 2, (8, 0), (), "SWW", None),
		"SalesPersonCode": (15, 2, (3, 0), (), "SalesPersonCode", None),
		"SerialNum": (13, 2, (8, 0), (), "SerialNum", None),
		# Method 'SerialNumbers' returns object of type 'ISerialNumbers'
		"SerialNumbers": (68, 2, (9, 0), (), "SerialNumbers", '{93E5E52B-181E-46B8-96CB-1C066AC04DCA}'),
		"ShipDate": (6, 2, (7, 0), (), "ShipDate", None),
		"ShipToCode": (108, 2, (8, 0), (), "ShipToCode", None),
		"ShippingMethod": (64, 2, (3, 0), (), "ShippingMethod", None),
		"StockDistributesum": (117, 2, (5, 0), (), "StockDistributesum", None),
		"StockDistributesumForeign": (115, 2, (5, 0), (), "StockDistributesumForeign", None),
		"StockDistributesumSystem": (116, 2, (5, 0), (), "StockDistributesumSystem", None),
		"StockInmPrice": (118, 2, (5, 0), (), "StockInmPrice", None),
		"SupplierCatNum": (20, 2, (8, 0), (), "SupplierCatNum", None),
		"TaxBeforeDPM": (103, 2, (5, 0), (), "TaxBeforeDPM", None),
		"TaxBeforeDPMFC": (104, 2, (5, 0), (), "TaxBeforeDPMFC", None),
		"TaxBeforeDPMSC": (105, 2, (5, 0), (), "TaxBeforeDPMSC", None),
		"TaxCode": (55, 2, (8, 0), (), "TaxCode", None),
		"TaxLiable": (57, 2, (3, 0), (), "TaxLiable", None),
		"TaxOnly": (102, 2, (3, 0), (), "TaxOnly", None),
		"TaxPerUnit": (93, 2, (5, 0), (), "TaxPerUnit", None),
		"TaxPercentagePerRow": (86, 2, (5, 0), (), "TaxPercentagePerRow", None),
		"TaxTotal": (87, 2, (5, 0), (), "TaxTotal", None),
		"TaxType": (56, 2, (3, 0), (), "TaxType", None),
		"Text": (126, 2, (8, 0), (), "Text", None),
		"TotalEqualizationTax": (89, 2, (5, 0), (), "TotalEqualizationTax", None),
		"TotalEqualizationTaxFC": (79, 2, (5, 0), (), "TotalEqualizationTaxFC", None),
		"TotalEqualizationTaxSC": (80, 2, (5, 0), (), "TotalEqualizationTaxSC", None),
		"TotalInclTax": (94, 2, (5, 0), (), "TotalInclTax", None),
		"TransactionType": (106, 2, (3, 0), (), "TransactionType", None),
		"TreeType": (17, 2, (3, 0), (), "TreeType", None),
		"UnitPrice": (123, 2, (5, 0), (), "UnitPrice", None),
		"UnitsOfMeasurment": (91, 2, (5, 0), (), "UnitsOfMeasurment", None),
		"Usage": (101, 2, (8, 0), (), "Usage", None),
		"UseBaseUnits": (19, 2, (3, 0), (), "UseBaseUnits", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (49, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatGroup": (24, 2, (8, 0), (), "VatGroup", None),
		"VendorNum": (12, 2, (8, 0), (), "VendorNum", None),
		"VisualOrder": (121, 2, (3, 0), (), "VisualOrder", None),
		"Volume": (45, 2, (5, 0), (), "Volume", None),
		"VolumeUnit": (46, 2, (3, 0), (), "VolumeUnit", None),
		"WTLiable": (77, 2, (3, 0), (), "WTLiable", None),
		"WarehouseCode": (14, 2, (8, 0), (), "WarehouseCode", None),
		"Weight1": (33, 2, (5, 0), (), "Weight1", None),
		"Weight1Unit": (34, 2, (3, 0), (), "Weight1Unit", None),
		"Weight2": (35, 2, (5, 0), (), "Weight2", None),
		"Weight2Unit": (36, 2, (3, 0), (), "Weight2Unit", None),
		"Width1": (50, 2, (5, 0), (), "Width1", None),
		"Width1Unit": (51, 2, (3, 0), (), "Width1Unit", None),
		"Width2": (52, 2, (5, 0), (), "Width2", None),
		"Width2Unit": (53, 2, (3, 0), (), "Width2Unit", None),
		# Method 'WithholdingTaxLines' returns object of type 'IWithholdingTaxLines'
		"WithholdingTaxLines": (98, 2, (9, 0), (), "WithholdingTaxLines", '{458A15A5-B980-4543-A289-F6477A36EB24}'),
	}
	_prop_map_put_ = {
		"AccountCode": ((18, LCID, 4, 0),()),
		"Address": ((54, LCID, 4, 0),()),
		"BackOrder": ((62, LCID, 4, 0),()),
		"BarCode": ((23, LCID, 4, 0),()),
		"BaseEntry": ((42, LCID, 4, 0),()),
		"BaseLine": ((43, LCID, 4, 0),()),
		"BaseType": ((41, LCID, 4, 0),()),
		"CFOPCode": ((99, LCID, 4, 0),()),
		"CSTCode": ((100, LCID, 4, 0),()),
		"CommisionPercent": ((16, LCID, 4, 0),()),
		"ConsumerSalesForecast": ((97, LCID, 4, 0),()),
		"CorrInvAmountToDiffAcct": ((73, LCID, 4, 0),()),
		"CorrInvAmountToStock": ((72, LCID, 4, 0),()),
		"CorrectionInvoiceItem": ((71, LCID, 4, 0),()),
		"CostingCode": ((21, LCID, 4, 0),()),
		"CountryOrg": ((95, LCID, 4, 0),()),
		"Currency": ((9, LCID, 4, 0),()),
		"DeferredTax": ((88, LCID, 4, 0),()),
		"DiscountPercent": ((11, LCID, 4, 0),()),
		"DistributeExpense": ((107, LCID, 4, 0),()),
		"ExciseAmount": ((92, LCID, 4, 0),()),
		"Factor1": ((37, LCID, 4, 0),()),
		"Factor2": ((38, LCID, 4, 0),()),
		"Factor3": ((39, LCID, 4, 0),()),
		"Factor4": ((40, LCID, 4, 0),()),
		"FreeText": ((63, LCID, 4, 0),()),
		"Height1": ((25, LCID, 4, 0),()),
		"Height2": ((27, LCID, 4, 0),()),
		"Height2Unit": ((28, LCID, 4, 0),()),
		"Hight1Unit": ((26, LCID, 4, 0),()),
		"ItemCode": ((3, LCID, 4, 0),()),
		"ItemDescription": ((4, LCID, 4, 0),()),
		"Lengh1": ((29, LCID, 4, 0),()),
		"Lengh1Unit": ((30, LCID, 4, 0),()),
		"Lengh2": ((31, LCID, 4, 0),()),
		"Lengh2Unit": ((32, LCID, 4, 0),()),
		"LineStatus": ((124, LCID, 4, 0),()),
		"LineTotal": ((84, LCID, 4, 0),()),
		"Price": ((7, LCID, 4, 0),()),
		"PriceAfterVAT": ((8, LCID, 4, 0),()),
		"ProjectCode": ((22, LCID, 4, 0),()),
		"Quantity": ((5, LCID, 4, 0),()),
		"Rate": ((10, LCID, 4, 0),()),
		"RowTotalFC": ((109, LCID, 4, 0),()),
		"SWW": ((96, LCID, 4, 0),()),
		"SalesPersonCode": ((15, LCID, 4, 0),()),
		"SerialNum": ((13, LCID, 4, 0),()),
		"ShipDate": ((6, LCID, 4, 0),()),
		"ShipToCode": ((108, LCID, 4, 0),()),
		"ShippingMethod": ((64, LCID, 4, 0),()),
		"SupplierCatNum": ((20, LCID, 4, 0),()),
		"TaxCode": ((55, LCID, 4, 0),()),
		"TaxLiable": ((57, LCID, 4, 0),()),
		"TaxOnly": ((102, LCID, 4, 0),()),
		"TaxPercentagePerRow": ((86, LCID, 4, 0),()),
		"TaxType": ((56, LCID, 4, 0),()),
		"TransactionType": ((106, LCID, 4, 0),()),
		"UnitPrice": ((123, LCID, 4, 0),()),
		"Usage": ((101, LCID, 4, 0),()),
		"UseBaseUnits": ((19, LCID, 4, 0),()),
		"VatGroup": ((24, LCID, 4, 0),()),
		"VendorNum": ((12, LCID, 4, 0),()),
		"Volume": ((45, LCID, 4, 0),()),
		"VolumeUnit": ((46, LCID, 4, 0),()),
		"WTLiable": ((77, LCID, 4, 0),()),
		"WarehouseCode": ((14, LCID, 4, 0),()),
		"Weight1": ((33, LCID, 4, 0),()),
		"Weight1Unit": ((34, LCID, 4, 0),()),
		"Weight2": ((35, LCID, 4, 0),()),
		"Weight2Unit": ((36, LCID, 4, 0),()),
		"Width1": ((50, LCID, 4, 0),()),
		"Width1Unit": ((51, LCID, 4, 0),()),
		"Width2": ((52, LCID, 4, 0),()),
		"Width2Unit": ((53, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(47, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDocument_LinesAdditionalExpenses(DispatchBaseClass):
	'IDocument_LinesAdditionalExpenses Interface'
	CLSID = IID('{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}')
	coclass_clsid = IID('{7F3611B7-822C-41C3-82DB-2D8909B59C7A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(102, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(101, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AquisitionTax": (19, 2, (3, 0), (), "AquisitionTax", None),
		"BaseGroup": (105, 2, (3, 0), (), "BaseGroup", None),
		"Count": (100, 2, (3, 0), (), "Count", None),
		"DeductibleTaxSum": (16, 2, (5, 0), (), "DeductibleTaxSum", None),
		"DeductibleTaxSumFC": (17, 2, (5, 0), (), "DeductibleTaxSumFC", None),
		"DeductibleTaxSumSys": (18, 2, (5, 0), (), "DeductibleTaxSumSys", None),
		"EqualizationTaxFC": (27, 2, (5, 0), (), "EqualizationTaxFC", None),
		"EqualizationTaxPercent": (25, 2, (5, 0), (), "EqualizationTaxPercent", None),
		"EqualizationTaxSum": (26, 2, (5, 0), (), "EqualizationTaxSum", None),
		"EqualizationTaxSys": (28, 2, (5, 0), (), "EqualizationTaxSys", None),
		"ExpenseCode": (3, 2, (3, 0), (), "ExpenseCode", None),
		"GroupCode": (2, 2, (3, 0), (), "GroupCode", None),
		"LineNumber": (1, 2, (3, 0), (), "LineNumber", None),
		"LineTotal": (4, 2, (5, 0), (), "LineTotal", None),
		"LineTotalFC": (5, 2, (5, 0), (), "LineTotalFC", None),
		"LineTotalSys": (6, 2, (5, 0), (), "LineTotalSys", None),
		"PaidToDate": (7, 2, (5, 0), (), "PaidToDate", None),
		"PaidToDateFC": (8, 2, (5, 0), (), "PaidToDateFC", None),
		"PaidToDateSys": (9, 2, (5, 0), (), "PaidToDateSys", None),
		"TaxCode": (106, 2, (8, 0), (), "TaxCode", None),
		"TaxLiable": (10, 2, (3, 0), (), "TaxLiable", None),
		"TaxPaid": (22, 2, (5, 0), (), "TaxPaid", None),
		"TaxPaidFC": (23, 2, (5, 0), (), "TaxPaidFC", None),
		"TaxPaidSys": (24, 2, (5, 0), (), "TaxPaidSys", None),
		"TaxPercent": (12, 2, (5, 0), (), "TaxPercent", None),
		"TaxSum": (13, 2, (5, 0), (), "TaxSum", None),
		"TaxSumFC": (14, 2, (5, 0), (), "TaxSumFC", None),
		"TaxSumSys": (15, 2, (5, 0), (), "TaxSumSys", None),
		"TaxTotalSum": (29, 2, (5, 0), (), "TaxTotalSum", None),
		"TaxTotalSumFC": (30, 2, (5, 0), (), "TaxTotalSumFC", None),
		"TaxTotalSumSys": (31, 2, (5, 0), (), "TaxTotalSumSys", None),
		"TaxType": (21, 2, (3, 0), (), "TaxType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (104, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatGroup": (11, 2, (8, 0), (), "VatGroup", None),
		"WTLiable": (103, 2, (3, 0), (), "WTLiable", None),
	}
	_prop_map_put_ = {
		"BaseGroup": ((105, LCID, 4, 0),()),
		"ExpenseCode": ((3, LCID, 4, 0),()),
		"GroupCode": ((2, LCID, 4, 0),()),
		"LineNumber": ((1, LCID, 4, 0),()),
		"LineTotal": ((4, LCID, 4, 0),()),
		"TaxCode": ((106, LCID, 4, 0),()),
		"TaxType": ((21, LCID, 4, 0),()),
		"VatGroup": ((11, LCID, 4, 0),()),
		"WTLiable": ((103, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(100, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDocuments(DispatchBaseClass):
	'IDocuments Interface'
	CLSID = IID('{A6DA575B-E105-4585-9F4B-50CC4044EEDD}')
	coclass_clsid = IID('{4AFE074D-4F31-4E7B-87DF-64D55098DA5E}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(44, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(45, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(137, LCID, 1, (8, 0), (),)

	def GetByKey(self, AbsEntry=defaultNamedNotOptArg):
		'Get by key'
		return self._oleobj_.InvokeTypes(35, LCID, 1, (11, 0), ((3, 0),),AbsEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(46, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(138, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save object as XML document'
		return self._ApplyTypes_(38, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(39, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Address": (11, 2, (8, 0), (), "Address", None),
		"Address2": (125, 2, (8, 0), (), "Address2", None),
		"AgentCode": (97, 2, (8, 0), (), "AgentCode", None),
		"ApplyTaxOnFirstInstallment": (103, 2, (3, 0), (), "ApplyTaxOnFirstInstallment", None),
		"BPChannelCode": (121, 2, (8, 0), (), "BPChannelCode", None),
		"BPChannelContact": (122, 2, (3, 0), (), "BPChannelContact", None),
		"BPL_IDAssignedToInvoice": (139, 2, (3, 0), (), "BPL_IDAssignedToInvoice", None),
		"BaseAmount": (114, 2, (5, 0), (), "BaseAmount", None),
		"BaseAmountFC": (111, 2, (5, 0), (), "BaseAmountFC", None),
		"BaseAmountSC": (110, 2, (5, 0), (), "BaseAmountSC", None),
		"BillOfExchangeReserved": (96, 2, (3, 0), (), "BillOfExchangeReserved", None),
		"BlockDunning": (67, 2, (3, 0), (), "BlockDunning", None),
		"Box1099": (63, 2, (8, 0), (), "Box1099", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (48, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CancelDate": (66, 2, (7, 0), (), "CancelDate", None),
		"CardCode": (9, 2, (8, 0), (), "CardCode", None),
		"CardName": (10, 2, (8, 0), (), "CardName", None),
		"CentralBankIndicator": (75, 2, (8, 0), (), "CentralBankIndicator", None),
		"ClosingDate": (140, 2, (7, 0), (), "ClosingDate", None),
		"Comments": (18, 2, (8, 0), (), "Comments", None),
		"Confirmed": (25, 2, (3, 0), (), "Confirmed", None),
		"ContactPersonCode": (28, 2, (3, 0), (), "ContactPersonCode", None),
		"CreationDate": (52, 2, (7, 0), (), "CreationDate", None),
		"DeferredTax": (92, 2, (3, 0), (), "DeferredTax", None),
		"DiscountPercent": (49, 2, (5, 0), (), "DiscountPercent", None),
		"DocCurrency": (13, 2, (8, 0), (), "DocCurrency", None),
		"DocDate": (7, 2, (7, 0), (), "DocDate", None),
		"DocDueDate": (8, 2, (7, 0), (), "DocDueDate", None),
		"DocEntry": (51, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (3, 2, (3, 0), (), "DocNum", None),
		"DocObjectCode": (40, 2, (3, 0), (), "DocObjectCode", None),
		"DocObjectCodeEx": (124, 2, (8, 0), (), "DocObjectCodeEx", None),
		"DocRate": (14, 2, (5, 0), (), "DocRate", None),
		"DocTime": (21, 2, (7, 0), (), "DocTime", None),
		"DocTotal": (15, 2, (5, 0), (), "DocTotal", None),
		"DocTotalFc": (60, 2, (5, 0), (), "DocTotalFc", None),
		"DocTotalSys": (61, 2, (5, 0), (), "DocTotalSys", None),
		"DocType": (4, 2, (3, 0), (), "DocType", None),
		"DocumentStatus": (126, 2, (3, 0), (), "DocumentStatus", None),
		"DocumentSubType": (120, 2, (3, 0), (), "DocumentSubType", None),
		"DocumentsOwner": (130, 2, (3, 0), (), "DocumentsOwner", None),
		"DownPayment": (147, 2, (5, 0), (), "DownPayment", None),
		"ExemptionValidityDateFrom": (80, 2, (7, 0), (), "ExemptionValidityDateFrom", None),
		"ExemptionValidityDateTo": (81, 2, (7, 0), (), "ExemptionValidityDateTo", None),
		# Method 'Expenses' returns object of type 'IDocumentsAdditionalExpenses'
		"Expenses": (83, 2, (9, 0), (), "Expenses", '{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}'),
		"ExternalCorrectedDocNum": (89, 2, (8, 0), (), "ExternalCorrectedDocNum", None),
		"FederalTaxID": (43, 2, (8, 0), (), "FederalTaxID", None),
		"FinancialPeriod": (54, 2, (3, 0), (), "FinancialPeriod", None),
		"FolioNumber": (119, 2, (3, 0), (), "FolioNumber", None),
		"FolioPrefixString": (131, 2, (8, 0), (), "FolioPrefixString", None),
		"Form1099": (62, 2, (3, 0), (), "Form1099", None),
		"HandWritten": (5, 2, (3, 0), (), "HandWritten", None),
		"ImportFileNum": (26, 2, (3, 0), (), "ImportFileNum", None),
		"Indicator": (42, 2, (8, 0), (), "Indicator", None),
		"InternalCorrectedDocNum": (90, 2, (3, 0), (), "InternalCorrectedDocNum", None),
		"IsPayToBank": (132, 2, (3, 0), (), "IsPayToBank", None),
		"JournalMemo": (19, 2, (8, 0), (), "JournalMemo", None),
		"LanguageCode": (149, 2, (3, 0), (), "LanguageCode", None),
		# Method 'Lines' returns object of type 'IDocument_Lines'
		"Lines": (2, 2, (9, 0), (), "Lines", '{248B28DD-1281-4C6C-9780-22D19BA13D1F}'),
		"ManualNumber": (117, 2, (8, 0), (), "ManualNumber", None),
		"MaximumCashDiscount": (76, 2, (3, 0), (), "MaximumCashDiscount", None),
		"NetProcedure": (59, 2, (3, 0), (), "NetProcedure", None),
		"NextCorrectingDocument": (91, 2, (3, 0), (), "NextCorrectingDocument", None),
		"NumAtCard": (12, 2, (8, 0), (), "NumAtCard", None),
		"NumberOfInstallments": (102, 2, (3, 0), (), "NumberOfInstallments", None),
		"PartialSupply": (32, 2, (3, 0), (), "PartialSupply", None),
		"PayToBankAccountNo": (135, 2, (8, 0), (), "PayToBankAccountNo", None),
		"PayToBankBranch": (136, 2, (8, 0), (), "PayToBankBranch", None),
		"PayToBankCode": (134, 2, (8, 0), (), "PayToBankCode", None),
		"PayToBankCountry": (133, 2, (8, 0), (), "PayToBankCountry", None),
		"PayToCode": (129, 2, (8, 0), (), "PayToCode", None),
		"PaymentBlock": (73, 2, (3, 0), (), "PaymentBlock", None),
		"PaymentBlockEntry": (74, 2, (3, 0), (), "PaymentBlockEntry", None),
		"PaymentGroupCode": (20, 2, (3, 0), (), "PaymentGroupCode", None),
		"PaymentMethod": (72, 2, (8, 0), (), "PaymentMethod", None),
		"PaymentReference": (50, 2, (8, 0), (), "PaymentReference", None),
		"PeriodIndicator": (127, 2, (8, 0), (), "PeriodIndicator", None),
		"Pick": (71, 2, (3, 0), (), "Pick", None),
		"PickRemark": (151, 2, (8, 0), (), "PickRemark", None),
		"PickStatus": (70, 2, (3, 0), (), "PickStatus", None),
		"Printed": (6, 2, (3, 0), (), "Printed", None),
		"Project": (78, 2, (8, 0), (), "Project", None),
		"Reference1": (16, 2, (8, 0), (), "Reference1", None),
		"Reference2": (17, 2, (8, 0), (), "Reference2", None),
		"RequriedDate": (65, 2, (7, 0), (), "RequriedDate", None),
		"Reserve": (77, 2, (3, 0), (), "Reserve", None),
		"ReserveInvoice": (148, 2, (3, 0), (), "ReserveInvoice", None),
		"RevisionPo": (64, 2, (3, 0), (), "RevisionPo", None),
		"Rounding": (84, 2, (3, 0), (), "Rounding", None),
		"SalesPersonCode": (22, 2, (3, 0), (), "SalesPersonCode", None),
		"Segment": (69, 2, (3, 0), (), "Segment", None),
		"SequenceCode": (142, 2, (3, 0), (), "SequenceCode", None),
		"SequenceModel": (145, 2, (8, 0), (), "SequenceModel", None),
		"SequenceSerial": (141, 2, (3, 0), (), "SequenceSerial", None),
		"Series": (30, 2, (3, 0), (), "Series", None),
		"SeriesString": (143, 2, (8, 0), (), "SeriesString", None),
		"ShipToCode": (41, 2, (8, 0), (), "ShipToCode", None),
		"ShowSCN": (29, 2, (3, 0), (), "ShowSCN", None),
		"SubSeriesString": (144, 2, (8, 0), (), "SubSeriesString", None),
		"Submitted": (68, 2, (3, 0), (), "Submitted", None),
		"SummeryType": (27, 2, (3, 0), (), "SummeryType", None),
		"TaxDate": (31, 2, (7, 0), (), "TaxDate", None),
		"TaxExemptionLetterNum": (93, 2, (8, 0), (), "TaxExemptionLetterNum", None),
		# Method 'TaxExtension' returns object of type 'ITaxExtension'
		"TaxExtension": (146, 2, (9, 0), (), "TaxExtension", '{8CC29ECE-02C3-4C7B-851B-5533D2C83627}'),
		"TotalDiscount": (153, 2, (5, 0), (), "TotalDiscount", None),
		"TotalEqualizationTax": (99, 2, (5, 0), (), "TotalEqualizationTax", None),
		"TotalEqualizationTaxFC": (100, 2, (5, 0), (), "TotalEqualizationTaxFC", None),
		"TotalEqualizationTaxSC": (101, 2, (5, 0), (), "TotalEqualizationTaxSC", None),
		"TrackingNumber": (150, 2, (8, 0), (), "TrackingNumber", None),
		"TransNum": (55, 2, (3, 0), (), "TransNum", None),
		"TransportationCode": (23, 2, (3, 0), (), "TransportationCode", None),
		"UpdateDate": (53, 2, (7, 0), (), "UpdateDate", None),
		"UseCorrectionVATGroup": (152, 2, (3, 0), (), "UseCorrectionVATGroup", None),
		"UseShpdGoodsAct": (118, 2, (3, 0), (), "UseShpdGoodsAct", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (37, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatDate": (116, 2, (7, 0), (), "VatDate", None),
		"VatPercent": (154, 2, (5, 0), (), "VatPercent", None),
		"VatSum": (56, 2, (5, 0), (), "VatSum", None),
		"VatSumFc": (58, 2, (5, 0), (), "VatSumFc", None),
		"VatSumSys": (57, 2, (5, 0), (), "VatSumSys", None),
		"WTAmount": (115, 2, (5, 0), (), "WTAmount", None),
		"WTAmountFC": (112, 2, (5, 0), (), "WTAmountFC", None),
		"WTAmountSC": (113, 2, (5, 0), (), "WTAmountSC", None),
		"WTApplied": (94, 2, (5, 0), (), "WTApplied", None),
		"WTAppliedFC": (95, 2, (5, 0), (), "WTAppliedFC", None),
		"WTAppliedSC": (98, 2, (5, 0), (), "WTAppliedSC", None),
		"WTExemptedAmount": (107, 2, (5, 0), (), "WTExemptedAmount", None),
		"WTExemptedAmountFC": (109, 2, (5, 0), (), "WTExemptedAmountFC", None),
		"WTExemptedAmountSC": (108, 2, (5, 0), (), "WTExemptedAmountSC", None),
		"WTNonSubjectAmount": (104, 2, (5, 0), (), "WTNonSubjectAmount", None),
		"WTNonSubjectAmountFC": (106, 2, (5, 0), (), "WTNonSubjectAmountFC", None),
		"WTNonSubjectAmountSC": (105, 2, (5, 0), (), "WTNonSubjectAmountSC", None),
		"WareHouseUpdateType": (82, 2, (3, 0), (), "WareHouseUpdateType", None),
		# Method 'WithholdingTaxData' returns object of type 'IWithholdingTaxData'
		"WithholdingTaxData": (123, 2, (9, 0), (), "WithholdingTaxData", '{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}'),
	}
	_prop_map_put_ = {
		"Address": ((11, LCID, 4, 0),()),
		"Address2": ((125, LCID, 4, 0),()),
		"AgentCode": ((97, LCID, 4, 0),()),
		"ApplyTaxOnFirstInstallment": ((103, LCID, 4, 0),()),
		"BPChannelCode": ((121, LCID, 4, 0),()),
		"BPChannelContact": ((122, LCID, 4, 0),()),
		"BPL_IDAssignedToInvoice": ((139, LCID, 4, 0),()),
		"BlockDunning": ((67, LCID, 4, 0),()),
		"Box1099": ((63, LCID, 4, 0),()),
		"CancelDate": ((66, LCID, 4, 0),()),
		"CardCode": ((9, LCID, 4, 0),()),
		"CardName": ((10, LCID, 4, 0),()),
		"CentralBankIndicator": ((75, LCID, 4, 0),()),
		"ClosingDate": ((140, LCID, 4, 0),()),
		"Comments": ((18, LCID, 4, 0),()),
		"Confirmed": ((25, LCID, 4, 0),()),
		"ContactPersonCode": ((28, LCID, 4, 0),()),
		"DeferredTax": ((92, LCID, 4, 0),()),
		"DiscountPercent": ((49, LCID, 4, 0),()),
		"DocCurrency": ((13, LCID, 4, 0),()),
		"DocDate": ((7, LCID, 4, 0),()),
		"DocDueDate": ((8, LCID, 4, 0),()),
		"DocNum": ((3, LCID, 4, 0),()),
		"DocObjectCode": ((40, LCID, 4, 0),()),
		"DocObjectCodeEx": ((124, LCID, 4, 0),()),
		"DocRate": ((14, LCID, 4, 0),()),
		"DocTime": ((21, LCID, 4, 0),()),
		"DocTotal": ((15, LCID, 4, 0),()),
		"DocType": ((4, LCID, 4, 0),()),
		"DocumentSubType": ((120, LCID, 4, 0),()),
		"DocumentsOwner": ((130, LCID, 4, 0),()),
		"DownPayment": ((147, LCID, 4, 0),()),
		"ExemptionValidityDateFrom": ((80, LCID, 4, 0),()),
		"ExemptionValidityDateTo": ((81, LCID, 4, 0),()),
		"ExternalCorrectedDocNum": ((89, LCID, 4, 0),()),
		"FederalTaxID": ((43, LCID, 4, 0),()),
		"FolioNumber": ((119, LCID, 4, 0),()),
		"FolioPrefixString": ((131, LCID, 4, 0),()),
		"Form1099": ((62, LCID, 4, 0),()),
		"HandWritten": ((5, LCID, 4, 0),()),
		"ImportFileNum": ((26, LCID, 4, 0),()),
		"Indicator": ((42, LCID, 4, 0),()),
		"InternalCorrectedDocNum": ((90, LCID, 4, 0),()),
		"IsPayToBank": ((132, LCID, 4, 0),()),
		"JournalMemo": ((19, LCID, 4, 0),()),
		"LanguageCode": ((149, LCID, 4, 0),()),
		"ManualNumber": ((117, LCID, 4, 0),()),
		"MaximumCashDiscount": ((76, LCID, 4, 0),()),
		"NumAtCard": ((12, LCID, 4, 0),()),
		"NumberOfInstallments": ((102, LCID, 4, 0),()),
		"PartialSupply": ((32, LCID, 4, 0),()),
		"PayToBankAccountNo": ((135, LCID, 4, 0),()),
		"PayToBankBranch": ((136, LCID, 4, 0),()),
		"PayToBankCode": ((134, LCID, 4, 0),()),
		"PayToBankCountry": ((133, LCID, 4, 0),()),
		"PayToCode": ((129, LCID, 4, 0),()),
		"PaymentBlock": ((73, LCID, 4, 0),()),
		"PaymentBlockEntry": ((74, LCID, 4, 0),()),
		"PaymentGroupCode": ((20, LCID, 4, 0),()),
		"PaymentMethod": ((72, LCID, 4, 0),()),
		"PaymentReference": ((50, LCID, 4, 0),()),
		"Pick": ((71, LCID, 4, 0),()),
		"PickRemark": ((151, LCID, 4, 0),()),
		"Project": ((78, LCID, 4, 0),()),
		"Reference1": ((16, LCID, 4, 0),()),
		"Reference2": ((17, LCID, 4, 0),()),
		"RequriedDate": ((65, LCID, 4, 0),()),
		"RevisionPo": ((64, LCID, 4, 0),()),
		"Rounding": ((84, LCID, 4, 0),()),
		"SalesPersonCode": ((22, LCID, 4, 0),()),
		"SequenceCode": ((142, LCID, 4, 0),()),
		"SequenceModel": ((145, LCID, 4, 0),()),
		"SequenceSerial": ((141, LCID, 4, 0),()),
		"Series": ((30, LCID, 4, 0),()),
		"SeriesString": ((143, LCID, 4, 0),()),
		"ShipToCode": ((41, LCID, 4, 0),()),
		"ShowSCN": ((29, LCID, 4, 0),()),
		"SubSeriesString": ((144, LCID, 4, 0),()),
		"SummeryType": ((27, LCID, 4, 0),()),
		"TaxDate": ((31, LCID, 4, 0),()),
		"TaxExemptionLetterNum": ((93, LCID, 4, 0),()),
		"TrackingNumber": ((150, LCID, 4, 0),()),
		"TransportationCode": ((23, LCID, 4, 0),()),
		"UseCorrectionVATGroup": ((152, LCID, 4, 0),()),
		"UseShpdGoodsAct": ((118, LCID, 4, 0),()),
		"VatDate": ((116, LCID, 4, 0),()),
		"VatPercent": ((154, LCID, 4, 0),()),
		"WareHouseUpdateType": ((82, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDocumentsAdditionalExpenses(DispatchBaseClass):
	'IDocumentsAdditionalExpenses Interface'
	CLSID = IID('{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}')
	coclass_clsid = IID('{5E9FC07C-E9A5-465A-A532-F12DC65304D4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AquisitionTax": (22, 2, (3, 0), (), "AquisitionTax", None),
		"BaseDocEntry": (36, 2, (3, 0), (), "BaseDocEntry", None),
		"BaseDocLine": (37, 2, (3, 0), (), "BaseDocLine", None),
		"BaseDocType": (38, 2, (3, 0), (), "BaseDocType", None),
		"Count": (1, 2, (3, 0), (), "Count", None),
		"DeductibleTaxSum": (19, 2, (5, 0), (), "DeductibleTaxSum", None),
		"DeductibleTaxSumFC": (20, 2, (5, 0), (), "DeductibleTaxSumFC", None),
		"DeductibleTaxSumSys": (21, 2, (5, 0), (), "DeductibleTaxSumSys", None),
		"DistributionMethod": (12, 2, (3, 0), (), "DistributionMethod", None),
		"EqualizationTaxFC": (30, 2, (5, 0), (), "EqualizationTaxFC", None),
		"EqualizationTaxPercent": (28, 2, (5, 0), (), "EqualizationTaxPercent", None),
		"EqualizationTaxSum": (29, 2, (5, 0), (), "EqualizationTaxSum", None),
		"EqualizationTaxSys": (31, 2, (5, 0), (), "EqualizationTaxSys", None),
		"ExpenseCode": (4, 2, (3, 0), (), "ExpenseCode", None),
		"LineTotal": (5, 2, (5, 0), (), "LineTotal", None),
		"LineTotalFC": (6, 2, (5, 0), (), "LineTotalFC", None),
		"LineTotalSys": (7, 2, (5, 0), (), "LineTotalSys", None),
		"PaidToDate": (8, 2, (5, 0), (), "PaidToDate", None),
		"PaidToDateFC": (9, 2, (5, 0), (), "PaidToDateFC", None),
		"PaidToDateSys": (10, 2, (5, 0), (), "PaidToDateSys", None),
		"Remarks": (11, 2, (8, 0), (), "Remarks", None),
		"TaxCode": (23, 2, (8, 0), (), "TaxCode", None),
		"TaxLiable": (13, 2, (3, 0), (), "TaxLiable", None),
		"TaxPaid": (25, 2, (5, 0), (), "TaxPaid", None),
		"TaxPaidFC": (26, 2, (5, 0), (), "TaxPaidFC", None),
		"TaxPaidSys": (27, 2, (5, 0), (), "TaxPaidSys", None),
		"TaxPercent": (15, 2, (5, 0), (), "TaxPercent", None),
		"TaxSum": (16, 2, (5, 0), (), "TaxSum", None),
		"TaxSumFC": (17, 2, (5, 0), (), "TaxSumFC", None),
		"TaxSumSys": (18, 2, (5, 0), (), "TaxSumSys", None),
		"TaxTotalSum": (32, 2, (5, 0), (), "TaxTotalSum", None),
		"TaxTotalSumFC": (33, 2, (5, 0), (), "TaxTotalSumFC", None),
		"TaxTotalSumSys": (34, 2, (5, 0), (), "TaxTotalSumSys", None),
		"TaxType": (24, 2, (3, 0), (), "TaxType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (35, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatGroup": (14, 2, (8, 0), (), "VatGroup", None),
	}
	_prop_map_put_ = {
		"BaseDocEntry": ((36, LCID, 4, 0),()),
		"BaseDocLine": ((37, LCID, 4, 0),()),
		"BaseDocType": ((38, LCID, 4, 0),()),
		"DeductibleTaxSum": ((19, LCID, 4, 0),()),
		"DistributionMethod": ((12, LCID, 4, 0),()),
		"ExpenseCode": ((4, LCID, 4, 0),()),
		"LineTotal": ((5, LCID, 4, 0),()),
		"Remarks": ((11, LCID, 4, 0),()),
		"TaxCode": ((23, LCID, 4, 0),()),
		"VatGroup": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDunningLetters(DispatchBaseClass):
	'IDunningLetters Interface'
	CLSID = IID('{F8DE7AAE-13BF-46BD-A4B0-CD9535AAED63}')
	coclass_clsid = IID('{8C9A31B4-0BEA-4A72-8D4E-F4C00F683E6B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(19, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(13, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (17, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CalcInterest": (7, 2, (3, 0), (), "CalcInterest", None),
		"Effectiveafter": (4, 2, (8, 0), (), "Effectiveafter", None),
		"FeeCurrency": (1, 2, (8, 0), (), "FeeCurrency", None),
		"Feeperletter": (6, 2, (5, 0), (), "Feeperletter", None),
		"LetterFormat": (3, 2, (8, 0), (), "LetterFormat", None),
		"MinimumBalance": (8, 2, (5, 0), (), "MinimumBalance", None),
		"MinimumBalanceCurrency": (5, 2, (8, 0), (), "MinimumBalanceCurrency", None),
		"RowNumber": (2, 2, (3, 0), (), "RowNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (16, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CalcInterest": ((7, LCID, 4, 0),()),
		"Effectiveafter": ((4, LCID, 4, 0),()),
		"FeeCurrency": ((1, LCID, 4, 0),()),
		"Feeperletter": ((6, LCID, 4, 0),()),
		"LetterFormat": ((3, LCID, 4, 0),()),
		"MinimumBalance": ((8, LCID, 4, 0),()),
		"MinimumBalanceCurrency": ((5, LCID, 4, 0),()),
		"RowNumber": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeAbsenceInfo(DispatchBaseClass):
	'IEmployeeAbsenceInfo Interface'
	CLSID = IID('{CD47A725-AEA8-4224-93D3-F31848990C42}')
	coclass_clsid = IID('{A574B4DA-F87A-414B-AC49-ED8C6BF84B2C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ApprovedBy": (9, 2, (8, 0), (), "ApprovedBy", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"EmployeeID": (10, 2, (3, 0), (), "EmployeeID", None),
		"FromDate": (6, 2, (7, 0), (), "FromDate", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"Reason": (8, 2, (8, 0), (), "Reason", None),
		"ToDate": (7, 2, (7, 0), (), "ToDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ApprovedBy": ((9, LCID, 4, 0),()),
		"EmployeeID": ((10, LCID, 4, 0),()),
		"FromDate": ((6, LCID, 4, 0),()),
		"Reason": ((8, LCID, 4, 0),()),
		"ToDate": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeEducationInfo(DispatchBaseClass):
	'IEmployeeEducationInfo Interface'
	CLSID = IID('{A5EC07B2-5898-4104-8015-F876A386D231}')
	coclass_clsid = IID('{8D158412-BA39-4046-8326-2E22EE49F8C1}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Diploma": (11, 2, (8, 0), (), "Diploma", None),
		"EducationType": (8, 2, (3, 0), (), "EducationType", None),
		"EmployeeNo": (12, 2, (3, 0), (), "EmployeeNo", None),
		"FromDate": (6, 2, (7, 0), (), "FromDate", None),
		"Institute": (9, 2, (8, 0), (), "Institute", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"Major": (10, 2, (8, 0), (), "Major", None),
		"ToDate": (7, 2, (7, 0), (), "ToDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Diploma": ((11, LCID, 4, 0),()),
		"EducationType": ((8, LCID, 4, 0),()),
		"EmployeeNo": ((12, LCID, 4, 0),()),
		"FromDate": ((6, LCID, 4, 0),()),
		"Institute": ((9, LCID, 4, 0),()),
		"Major": ((10, LCID, 4, 0),()),
		"ToDate": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeePrevEmpoymentInfo(DispatchBaseClass):
	'IEmployeePrevEmpoymentInfo Interface'
	CLSID = IID('{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}')
	coclass_clsid = IID('{9E334DDA-DD14-48A7-8482-292392B27A13}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"EmployeeNo": (11, 2, (3, 0), (), "EmployeeNo", None),
		"Employer": (8, 2, (8, 0), (), "Employer", None),
		"FromDtae": (6, 2, (7, 0), (), "FromDtae", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"Position": (9, 2, (8, 0), (), "Position", None),
		"Remarks": (10, 2, (8, 0), (), "Remarks", None),
		"ToDate": (7, 2, (7, 0), (), "ToDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"EmployeeNo": ((11, LCID, 4, 0),()),
		"Employer": ((8, LCID, 4, 0),()),
		"FromDtae": ((6, LCID, 4, 0),()),
		"Position": ((9, LCID, 4, 0),()),
		"Remarks": ((10, LCID, 4, 0),()),
		"ToDate": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeReviewsInfo(DispatchBaseClass):
	'IEmployeeReviewsInfo Interface'
	CLSID = IID('{C4397D01-E44E-4B76-80AB-4B888EEA10DD}')
	coclass_clsid = IID('{3FF527E2-2FBB-4F74-BBF9-C0EDBF44E63C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Date": (6, 2, (7, 0), (), "Date", None),
		"EmployeeNo": (11, 2, (3, 0), (), "EmployeeNo", None),
		"Grade": (9, 2, (8, 0), (), "Grade", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"Manager": (8, 2, (3, 0), (), "Manager", None),
		"Remarks": (10, 2, (8, 0), (), "Remarks", None),
		"ReviewDescription": (7, 2, (8, 0), (), "ReviewDescription", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Date": ((6, LCID, 4, 0),()),
		"EmployeeNo": ((11, LCID, 4, 0),()),
		"Grade": ((9, LCID, 4, 0),()),
		"Manager": ((8, LCID, 4, 0),()),
		"Remarks": ((10, LCID, 4, 0),()),
		"ReviewDescription": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeRolesInfo(DispatchBaseClass):
	'IEmployeeRolesInfo Interface'
	CLSID = IID('{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}')
	coclass_clsid = IID('{E644A5ED-C97E-4EE8-8191-E20EBC9508AB}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"EmployeeID": (2, 2, (3, 0), (), "EmployeeID", None),
		"LineNum": (3, 2, (3, 0), (), "LineNum", None),
		"RoleID": (1, 2, (3, 0), (), "RoleID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"EmployeeID": ((2, LCID, 4, 0),()),
		"RoleID": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeesInfo(DispatchBaseClass):
	'IEmployeesInfo Interface'
	CLSID = IID('{B2CFCDE5-3753-4A47-9199-38D08718B3AE}')
	coclass_clsid = IID('{EB49B71E-C20E-4D6D-8ECD-A641B0BAAA35}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(72, LCID, 1, (8, 0), (),)

	def GetByKey(self, EmployeeID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),EmployeeID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(73, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'AbsenceInfo' returns object of type 'IEmployeeAbsenceInfo'
		"AbsenceInfo": (68, 2, (9, 0), (), "AbsenceInfo", '{CD47A725-AEA8-4224-93D3-F31848990C42}'),
		"ApplicationUserID": (26, 2, (3, 0), (), "ApplicationUserID", None),
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (64, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		"BankAccount": (46, 2, (8, 0), (), "BankAccount", None),
		"BankBranch": (44, 2, (8, 0), (), "BankBranch", None),
		"BankBranchNum": (45, 2, (8, 0), (), "BankBranchNum", None),
		"BankCode": (43, 2, (8, 0), (), "BankCode", None),
		"Branch": (17, 2, (3, 0), (), "Branch", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CitizenshipCountryCode": (59, 2, (8, 0), (), "CitizenshipCountryCode", None),
		"CountryOfBirth": (55, 2, (8, 0), (), "CountryOfBirth", None),
		"DateOfBirth": (54, 2, (7, 0), (), "DateOfBirth", None),
		"Department": (16, 2, (3, 0), (), "Department", None),
		# Method 'EducationInfo' returns object of type 'IEmployeeEducationInfo'
		"EducationInfo": (70, 2, (9, 0), (), "EducationInfo", '{A5EC07B2-5898-4104-8015-F876A386D231}'),
		"EmployeeCostUnit": (40, 2, (3, 0), (), "EmployeeCostUnit", None),
		"EmployeeCosts": (39, 2, (5, 0), (), "EmployeeCosts", None),
		"EmployeeCostsCurrency": (66, 2, (8, 0), (), "EmployeeCostsCurrency", None),
		"EmployeeID": (9, 2, (3, 0), (), "EmployeeID", None),
		# Method 'EmployeeRolesInfo' returns object of type 'IEmployeeRolesInfo'
		"EmployeeRolesInfo": (71, 2, (9, 0), (), "EmployeeRolesInfo", '{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}'),
		"EmployeeType": (15, 2, (3, 0), (), "EmployeeType", None),
		"Fax": (33, 2, (8, 0), (), "Fax", None),
		"FirstName": (11, 2, (8, 0), (), "FirstName", None),
		"Gender": (13, 2, (3, 0), (), "Gender", None),
		"HomeBlock": (48, 2, (8, 0), (), "HomeBlock", None),
		"HomeBuildingFloorRoom": (75, 2, (8, 0), (), "HomeBuildingFloorRoom", None),
		"HomeCity": (50, 2, (8, 0), (), "HomeCity", None),
		"HomeCountry": (52, 2, (8, 0), (), "HomeCountry", None),
		"HomeCounty": (51, 2, (8, 0), (), "HomeCounty", None),
		"HomePhone": (32, 2, (8, 0), (), "HomePhone", None),
		"HomeState": (53, 2, (8, 0), (), "HomeState", None),
		"HomeStreet": (47, 2, (8, 0), (), "HomeStreet", None),
		"HomeZipCode": (49, 2, (8, 0), (), "HomeZipCode", None),
		"IdNumber": (58, 2, (8, 0), (), "IdNumber", None),
		"JobTitle": (14, 2, (8, 0), (), "JobTitle", None),
		"LastName": (10, 2, (8, 0), (), "LastName", None),
		"Manager": (25, 2, (3, 0), (), "Manager", None),
		"MartialStatus": (56, 2, (3, 0), (), "MartialStatus", None),
		"MiddleName": (12, 2, (8, 0), (), "MiddleName", None),
		"MobilePhone": (30, 2, (8, 0), (), "MobilePhone", None),
		"NumOfChildren": (57, 2, (3, 0), (), "NumOfChildren", None),
		"OfficeExtension": (29, 2, (8, 0), (), "OfficeExtension", None),
		"OfficePhone": (28, 2, (8, 0), (), "OfficePhone", None),
		"Pager": (31, 2, (8, 0), (), "Pager", None),
		"PassportExpirationDate": (61, 2, (7, 0), (), "PassportExpirationDate", None),
		"PassportNumber": (60, 2, (8, 0), (), "PassportNumber", None),
		"Picture": (62, 2, (8, 0), (), "Picture", None),
		# Method 'PreviousEmpoymentInfo' returns object of type 'IEmployeePrevEmpoymentInfo'
		"PreviousEmpoymentInfo": (69, 2, (9, 0), (), "PreviousEmpoymentInfo", '{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}'),
		"Remarks": (63, 2, (8, 0), (), "Remarks", None),
		# Method 'ReviewsInfo' returns object of type 'IEmployeeReviewsInfo'
		"ReviewsInfo": (67, 2, (9, 0), (), "ReviewsInfo", '{C4397D01-E44E-4B76-80AB-4B888EEA10DD}'),
		"Salary": (37, 2, (5, 0), (), "Salary", None),
		"SalaryCurrency": (65, 2, (8, 0), (), "SalaryCurrency", None),
		"SalaryUnit": (38, 2, (3, 0), (), "SalaryUnit", None),
		"SalesPersonCode": (27, 2, (3, 0), (), "SalesPersonCode", None),
		"StartDate": (35, 2, (7, 0), (), "StartDate", None),
		"StatusCode": (36, 2, (3, 0), (), "StatusCode", None),
		"TerminationDate": (41, 2, (7, 0), (), "TerminationDate", None),
		"TreminationReason": (42, 2, (3, 0), (), "TreminationReason", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WorkBlock": (19, 2, (8, 0), (), "WorkBlock", None),
		"WorkBuildingFloorRoom": (74, 2, (8, 0), (), "WorkBuildingFloorRoom", None),
		"WorkCity": (21, 2, (8, 0), (), "WorkCity", None),
		"WorkCountryCode": (23, 2, (8, 0), (), "WorkCountryCode", None),
		"WorkCounty": (22, 2, (8, 0), (), "WorkCounty", None),
		"WorkStateCode": (24, 2, (8, 0), (), "WorkStateCode", None),
		"WorkStreet": (18, 2, (8, 0), (), "WorkStreet", None),
		"WorkZipCode": (20, 2, (8, 0), (), "WorkZipCode", None),
		"eMail": (34, 2, (8, 0), (), "eMail", None),
	}
	_prop_map_put_ = {
		"ApplicationUserID": ((26, LCID, 4, 0),()),
		"BankAccount": ((46, LCID, 4, 0),()),
		"BankBranch": ((44, LCID, 4, 0),()),
		"BankBranchNum": ((45, LCID, 4, 0),()),
		"BankCode": ((43, LCID, 4, 0),()),
		"Branch": ((17, LCID, 4, 0),()),
		"CitizenshipCountryCode": ((59, LCID, 4, 0),()),
		"CountryOfBirth": ((55, LCID, 4, 0),()),
		"DateOfBirth": ((54, LCID, 4, 0),()),
		"Department": ((16, LCID, 4, 0),()),
		"EmployeeCostUnit": ((40, LCID, 4, 0),()),
		"EmployeeCosts": ((39, LCID, 4, 0),()),
		"EmployeeCostsCurrency": ((66, LCID, 4, 0),()),
		"EmployeeType": ((15, LCID, 4, 0),()),
		"Fax": ((33, LCID, 4, 0),()),
		"FirstName": ((11, LCID, 4, 0),()),
		"Gender": ((13, LCID, 4, 0),()),
		"HomeBlock": ((48, LCID, 4, 0),()),
		"HomeBuildingFloorRoom": ((75, LCID, 4, 0),()),
		"HomeCity": ((50, LCID, 4, 0),()),
		"HomeCountry": ((52, LCID, 4, 0),()),
		"HomeCounty": ((51, LCID, 4, 0),()),
		"HomePhone": ((32, LCID, 4, 0),()),
		"HomeState": ((53, LCID, 4, 0),()),
		"HomeStreet": ((47, LCID, 4, 0),()),
		"HomeZipCode": ((49, LCID, 4, 0),()),
		"IdNumber": ((58, LCID, 4, 0),()),
		"JobTitle": ((14, LCID, 4, 0),()),
		"LastName": ((10, LCID, 4, 0),()),
		"Manager": ((25, LCID, 4, 0),()),
		"MartialStatus": ((56, LCID, 4, 0),()),
		"MiddleName": ((12, LCID, 4, 0),()),
		"MobilePhone": ((30, LCID, 4, 0),()),
		"NumOfChildren": ((57, LCID, 4, 0),()),
		"OfficeExtension": ((29, LCID, 4, 0),()),
		"OfficePhone": ((28, LCID, 4, 0),()),
		"Pager": ((31, LCID, 4, 0),()),
		"PassportExpirationDate": ((61, LCID, 4, 0),()),
		"PassportNumber": ((60, LCID, 4, 0),()),
		"Picture": ((62, LCID, 4, 0),()),
		"Remarks": ((63, LCID, 4, 0),()),
		"Salary": ((37, LCID, 4, 0),()),
		"SalaryCurrency": ((65, LCID, 4, 0),()),
		"SalaryUnit": ((38, LCID, 4, 0),()),
		"SalesPersonCode": ((27, LCID, 4, 0),()),
		"StartDate": ((35, LCID, 4, 0),()),
		"StatusCode": ((36, LCID, 4, 0),()),
		"TerminationDate": ((41, LCID, 4, 0),()),
		"TreminationReason": ((42, LCID, 4, 0),()),
		"WorkBlock": ((19, LCID, 4, 0),()),
		"WorkBuildingFloorRoom": ((74, LCID, 4, 0),()),
		"WorkCity": ((21, LCID, 4, 0),()),
		"WorkCountryCode": ((23, LCID, 4, 0),()),
		"WorkCounty": ((22, LCID, 4, 0),()),
		"WorkStateCode": ((24, LCID, 4, 0),()),
		"WorkStreet": ((18, LCID, 4, 0),()),
		"WorkZipCode": ((20, LCID, 4, 0),()),
		"eMail": ((34, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IField(DispatchBaseClass):
	'IField Interface'
	CLSID = IID('{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')
	coclass_clsid = IID('{0B6BCB38-6594-4EAB-88A8-5EEB856FF1EB}')

	_prop_map_get_ = {
		"DefaultValue": (13, 2, (8, 0), (), "DefaultValue", None),
		"Description": (5, 2, (8, 0), (), "Description", None),
		"LinkedTable": (12, 2, (8, 0), (), "LinkedTable", None),
		"Mandatory": (14, 2, (3, 0), (), "Mandatory", None),
		"Name": (1, 2, (8, 0), (), "Name", None),
		"Size": (3, 2, (3, 0), (), "Size", None),
		"SubType": (11, 2, (3, 0), (), "SubType", None),
		"Type": (2, 2, (3, 0), (), "Type", None),
		"ValidValue": (6, 2, (8, 0), (), "ValidValue", None),
		# Method 'ValidValues' returns object of type 'IValidValues'
		"ValidValues": (10, 2, (9, 0), (), "ValidValues", '{48B89C08-2AE9-435F-B7C4-D7219E938E46}'),
		"Value": (4, 2, (12, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"ValidValue": ((6, LCID, 4, 0),()),
		"Value": ((4, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(4, 2, (12, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFields(DispatchBaseClass):
	'IFields Interface'
	CLSID = IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')
	coclass_clsid = IID('{9D3B180E-A24C-48C9-A742-093663FF1878}')

	# Result is of type IField
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')
		return ret

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IIndustries(DispatchBaseClass):
	'IIndustries Interface'
	CLSID = IID('{68C60132-0DD3-4AD2-B4FF-DB358A6184BC}')
	coclass_clsid = IID('{4E6D1836-16F8-4D8F-9BF8-0271F4856450}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(11, LCID, 1, (8, 0), (),)

	def GetByKey(self, Code=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (11, 0), ((3, 1),),Code
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(8, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (10, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"IndustryCode": (3, 2, (3, 0), (), "IndustryCode", None),
		"IndustryDescription": (1, 2, (8, 0), (), "IndustryDescription", None),
		"IndustryName": (2, 2, (8, 0), (), "IndustryName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (9, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"IndustryDescription": ((1, LCID, 4, 0),()),
		"IndustryName": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IItemGroups(DispatchBaseClass):
	'IItemGroups Interface'
	CLSID = IID('{216974E8-B66D-4022-9AB1-97BAA96084A3}')
	coclass_clsid = IID('{5F2AE736-E6D3-4D3A-BCB5-F9EE3A45872A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(42, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(49, LCID, 1, (8, 0), (),)

	def GetByKey(self, GroupCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(45, LCID, 1, (11, 0), ((3, 1),),GroupCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(44, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(50, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(46, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(43, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Alert": (28, 2, (3, 0), (), "Alert", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (48, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CostAccount": (38, 2, (8, 0), (), "CostAccount", None),
		"CostInflationAccount": (15, 2, (8, 0), (), "CostInflationAccount", None),
		"CostInflationOffsetAccount": (21, 2, (8, 0), (), "CostInflationOffsetAccount", None),
		"CycleCode": (37, 2, (3, 0), (), "CycleCode", None),
		"DecreaseGLAccount": (23, 2, (8, 0), (), "DecreaseGLAccount", None),
		"DecreasingAccount": (32, 2, (8, 0), (), "DecreasingAccount", None),
		"EUExpensesAccount": (35, 2, (8, 0), (), "EUExpensesAccount", None),
		"EURevenuesAccount": (39, 2, (8, 0), (), "EURevenuesAccount", None),
		"ExchangeRateDifferencesAccount": (5, 2, (8, 0), (), "ExchangeRateDifferencesAccount", None),
		"ExemptRevenuesAccount": (31, 2, (8, 0), (), "ExemptRevenuesAccount", None),
		"ExpenseClearingAct": (54, 2, (8, 0), (), "ExpenseClearingAct", None),
		"ExpensesAccount": (16, 2, (8, 0), (), "ExpensesAccount", None),
		"ForeignExpensesAccount": (36, 2, (8, 0), (), "ForeignExpensesAccount", None),
		"ForeignRevenuesAccount": (27, 2, (8, 0), (), "ForeignRevenuesAccount", None),
		"GoodsClearingAccount": (25, 2, (8, 0), (), "GoodsClearingAccount", None),
		"GroupName": (41, 2, (8, 0), (), "GroupName", None),
		"IncreaseGLAccount": (26, 2, (8, 0), (), "IncreaseGLAccount", None),
		"IncreasingAccount": (6, 2, (8, 0), (), "IncreasingAccount", None),
		"InventoryAccount": (22, 2, (8, 0), (), "InventoryAccount", None),
		"InventorySystem": (10, 2, (3, 0), (), "InventorySystem", None),
		"LeadTime": (19, 2, (3, 0), (), "LeadTime", None),
		"MinimumOrderQuantity": (3, 2, (5, 0), (), "MinimumOrderQuantity", None),
		"Number": (24, 2, (3, 0), (), "Number", None),
		"OrderInterval": (4, 2, (3, 0), (), "OrderInterval", None),
		"OrderMultiple": (20, 2, (5, 0), (), "OrderMultiple", None),
		"PAReturnAccount": (40, 2, (8, 0), (), "PAReturnAccount", None),
		"PlanningSystem": (12, 2, (3, 0), (), "PlanningSystem", None),
		"PriceDifferencesAccount": (1, 2, (8, 0), (), "PriceDifferencesAccount", None),
		"ProcurementMethod": (8, 2, (3, 0), (), "ProcurementMethod", None),
		"PurchaseAccount": (13, 2, (8, 0), (), "PurchaseAccount", None),
		"PurchaseOffsetAccount": (9, 2, (8, 0), (), "PurchaseOffsetAccount", None),
		"ReturningAccount": (14, 2, (8, 0), (), "ReturningAccount", None),
		"RevenuesAccount": (17, 2, (8, 0), (), "RevenuesAccount", None),
		"ShippedGoodsAccount": (30, 2, (8, 0), (), "ShippedGoodsAccount", None),
		"StockInflationAdjustAccount": (2, 2, (8, 0), (), "StockInflationAdjustAccount", None),
		"StockInflationOffsetAccount": (7, 2, (8, 0), (), "StockInflationOffsetAccount", None),
		"TransfersAccount": (18, 2, (8, 0), (), "TransfersAccount", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (47, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATInRevenueAccount": (33, 2, (8, 0), (), "VATInRevenueAccount", None),
		"VarianceAccount": (34, 2, (8, 0), (), "VarianceAccount", None),
		"WIPMaterialAccount": (29, 2, (8, 0), (), "WIPMaterialAccount", None),
		"WIPMaterialVarianceAccount": (11, 2, (8, 0), (), "WIPMaterialVarianceAccount", None),
	}
	_prop_map_put_ = {
		"Alert": ((28, LCID, 4, 0),()),
		"CostAccount": ((38, LCID, 4, 0),()),
		"CostInflationAccount": ((15, LCID, 4, 0),()),
		"CostInflationOffsetAccount": ((21, LCID, 4, 0),()),
		"CycleCode": ((37, LCID, 4, 0),()),
		"DecreaseGLAccount": ((23, LCID, 4, 0),()),
		"DecreasingAccount": ((32, LCID, 4, 0),()),
		"EUExpensesAccount": ((35, LCID, 4, 0),()),
		"EURevenuesAccount": ((39, LCID, 4, 0),()),
		"ExchangeRateDifferencesAccount": ((5, LCID, 4, 0),()),
		"ExemptRevenuesAccount": ((31, LCID, 4, 0),()),
		"ExpenseClearingAct": ((54, LCID, 4, 0),()),
		"ExpensesAccount": ((16, LCID, 4, 0),()),
		"ForeignExpensesAccount": ((36, LCID, 4, 0),()),
		"ForeignRevenuesAccount": ((27, LCID, 4, 0),()),
		"GoodsClearingAccount": ((25, LCID, 4, 0),()),
		"GroupName": ((41, LCID, 4, 0),()),
		"IncreaseGLAccount": ((26, LCID, 4, 0),()),
		"IncreasingAccount": ((6, LCID, 4, 0),()),
		"InventoryAccount": ((22, LCID, 4, 0),()),
		"InventorySystem": ((10, LCID, 4, 0),()),
		"LeadTime": ((19, LCID, 4, 0),()),
		"MinimumOrderQuantity": ((3, LCID, 4, 0),()),
		"OrderInterval": ((4, LCID, 4, 0),()),
		"OrderMultiple": ((20, LCID, 4, 0),()),
		"PAReturnAccount": ((40, LCID, 4, 0),()),
		"PlanningSystem": ((12, LCID, 4, 0),()),
		"PriceDifferencesAccount": ((1, LCID, 4, 0),()),
		"ProcurementMethod": ((8, LCID, 4, 0),()),
		"PurchaseAccount": ((13, LCID, 4, 0),()),
		"PurchaseOffsetAccount": ((9, LCID, 4, 0),()),
		"ReturningAccount": ((14, LCID, 4, 0),()),
		"RevenuesAccount": ((17, LCID, 4, 0),()),
		"ShippedGoodsAccount": ((30, LCID, 4, 0),()),
		"StockInflationAdjustAccount": ((2, LCID, 4, 0),()),
		"StockInflationOffsetAccount": ((7, LCID, 4, 0),()),
		"TransfersAccount": ((18, LCID, 4, 0),()),
		"VATInRevenueAccount": ((33, LCID, 4, 0),()),
		"VarianceAccount": ((34, LCID, 4, 0),()),
		"WIPMaterialAccount": ((29, LCID, 4, 0),()),
		"WIPMaterialVarianceAccount": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IItemWarehouseInfo(DispatchBaseClass):
	'IItemWarehouseInfo Interface'
	CLSID = IID('{CDB52791-B0FC-4BE1-A712-06941AF91D52}')
	coclass_clsid = IID('{494EAB50-0ED0-4773-8BCF-9F769A80B6BC}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Committed": (26, 2, (5, 0), (), "Committed", None),
		"CostAccount": (9, 2, (8, 0), (), "CostAccount", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Counted": (30, 2, (5, 0), (), "Counted", None),
		"CountedQuantity": (28, 2, (5, 0), (), "CountedQuantity", None),
		"DecreasingAccount": (13, 2, (8, 0), (), "DecreasingAccount", None),
		"EUExpensesAccount": (18, 2, (8, 0), (), "EUExpensesAccount", None),
		"EURevenuesAccount": (17, 2, (8, 0), (), "EURevenuesAccount", None),
		"ExemptIncomeAcc": (21, 2, (8, 0), (), "ExemptIncomeAcc", None),
		"ExpenseClearingAct": (33, 2, (8, 0), (), "ExpenseClearingAct", None),
		"ExpensesAccount": (16, 2, (8, 0), (), "ExpensesAccount", None),
		"ForeignExpensAcc": (20, 2, (8, 0), (), "ForeignExpensAcc", None),
		"ForeignRevenueAcc": (19, 2, (8, 0), (), "ForeignRevenueAcc", None),
		"InStock": (25, 2, (5, 0), (), "InStock", None),
		"IncreasingAccount": (14, 2, (8, 0), (), "IncreasingAccount", None),
		"InventoryAccount": (8, 2, (8, 0), (), "InventoryAccount", None),
		"Locked": (7, 2, (3, 0), (), "Locked", None),
		"MaximalStock": (4, 2, (5, 0), (), "MaximalStock", None),
		"MinimalOrder": (5, 2, (5, 0), (), "MinimalOrder", None),
		"MinimalStock": (23, 2, (5, 0), (), "MinimalStock", None),
		"Ordered": (27, 2, (5, 0), (), "Ordered", None),
		"PriceDifferenceAcc": (22, 2, (8, 0), (), "PriceDifferenceAcc", None),
		"ReturningAccount": (15, 2, (8, 0), (), "ReturningAccount", None),
		"RevenuesAccount": (11, 2, (8, 0), (), "RevenuesAccount", None),
		"StandardAveragePrice": (6, 2, (5, 0), (), "StandardAveragePrice", None),
		"TransferAccount": (10, 2, (8, 0), (), "TransferAccount", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (31, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VarienceAccount": (12, 2, (8, 0), (), "VarienceAccount", None),
		"WarehouseCode": (24, 2, (8, 0), (), "WarehouseCode", None),
		"WasCounted": (29, 2, (3, 0), (), "WasCounted", None),
		"WipVarianceAccount": (32, 2, (8, 0), (), "WipVarianceAccount", None),
	}
	_prop_map_put_ = {
		"CostAccount": ((9, LCID, 4, 0),()),
		"DecreasingAccount": ((13, LCID, 4, 0),()),
		"EUExpensesAccount": ((18, LCID, 4, 0),()),
		"EURevenuesAccount": ((17, LCID, 4, 0),()),
		"ExemptIncomeAcc": ((21, LCID, 4, 0),()),
		"ExpenseClearingAct": ((33, LCID, 4, 0),()),
		"ExpensesAccount": ((16, LCID, 4, 0),()),
		"ForeignExpensAcc": ((20, LCID, 4, 0),()),
		"ForeignRevenueAcc": ((19, LCID, 4, 0),()),
		"IncreasingAccount": ((14, LCID, 4, 0),()),
		"InventoryAccount": ((8, LCID, 4, 0),()),
		"Locked": ((7, LCID, 4, 0),()),
		"MaximalStock": ((4, LCID, 4, 0),()),
		"MinimalOrder": ((5, LCID, 4, 0),()),
		"MinimalStock": ((23, LCID, 4, 0),()),
		"PriceDifferenceAcc": ((22, LCID, 4, 0),()),
		"ReturningAccount": ((15, LCID, 4, 0),()),
		"RevenuesAccount": ((11, LCID, 4, 0),()),
		"StandardAveragePrice": ((6, LCID, 4, 0),()),
		"TransferAccount": ((10, LCID, 4, 0),()),
		"VarienceAccount": ((12, LCID, 4, 0),()),
		"WarehouseCode": ((24, LCID, 4, 0),()),
		"WipVarianceAccount": ((32, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IItems(DispatchBaseClass):
	'IItems Interface'
	CLSID = IID('{1EFF6EB3-9368-4A68-B619-0B57A134F0CE}')
	coclass_clsid = IID('{210393EC-DEF3-4E55-965C-C2891393A73C}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(47, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(48, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(133, LCID, 1, (8, 0), (),)

	def GetByKey(self, ItemCode=defaultNamedNotOptArg):
		'Get by key'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((8, 0),),ItemCode
			)

	# The method Properties is actually a property, but must be used as a method to correctly pass the arguments
	def Properties(self, GroupNum=defaultNamedNotOptArg):
		'Query group'
		return self._oleobj_.InvokeTypes(38, LCID, 2, (3, 0), ((3, 0),),GroupNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(46, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(134, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save object as XML document'
		return self._ApplyTypes_(39, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	# The method SetProperties is actually a property, but must be used as a method to correctly pass the arguments
	def SetProperties(self, GroupNum=defaultNamedNotOptArg, arg1=defaultUnnamedArg):
		'Query group'
		return self._oleobj_.InvokeTypes(38, LCID, 4, (24, 0), ((3, 0), (3, 1)),GroupNum
			, arg1)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(40, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"ApTaxCode": (126, 2, (8, 0), (), "ApTaxCode", None),
		"ArTaxCode": (127, 2, (8, 0), (), "ArTaxCode", None),
		"AssetItem": (33, 2, (3, 0), (), "AssetItem", None),
		"AvgStdPrice": (96, 2, (5, 0), (), "AvgStdPrice", None),
		"BarCode": (10, 2, (8, 0), (), "BarCode", None),
		"BaseUnitName": (123, 2, (8, 0), (), "BaseUnitName", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (59, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CommissionGroup": (31, 2, (3, 0), (), "CommissionGroup", None),
		"CommissionPercent": (29, 2, (5, 0), (), "CommissionPercent", None),
		"CommissionSum": (30, 2, (5, 0), (), "CommissionSum", None),
		"CostAccountingMethod": (128, 2, (3, 0), (), "CostAccountingMethod", None),
		"CustomsGroupCode": (8, 2, (3, 0), (), "CustomsGroupCode", None),
		"DataExportCode": (37, 2, (8, 0), (), "DataExportCode", None),
		"DefaultWarehouse": (97, 2, (8, 0), (), "DefaultWarehouse", None),
		"DesiredInventory": (22, 2, (5, 0), (), "DesiredInventory", None),
		"ECExpensesAccount": (95, 2, (8, 0), (), "ECExpensesAccount", None),
		"ECRevenuesAccount": (93, 2, (8, 0), (), "ECRevenuesAccount", None),
		"ExemptIncomeAccount": (16, 2, (8, 0), (), "ExemptIncomeAccount", None),
		"ExpanseAccount": (17, 2, (8, 0), (), "ExpanseAccount", None),
		"ForceSelectionOfSerialNumber": (120, 2, (3, 0), (), "ForceSelectionOfSerialNumber", None),
		"ForeignExpensesAccount": (94, 2, (8, 0), (), "ForeignExpensesAccount", None),
		"ForeignName": (6, 2, (8, 0), (), "ForeignName", None),
		"ForeignRevenuesAccount": (92, 2, (8, 0), (), "ForeignRevenuesAccount", None),
		"Frozen": (55, 2, (3, 0), (), "Frozen", None),
		"FrozenFrom": (56, 2, (7, 0), (), "FrozenFrom", None),
		"FrozenRemarks": (58, 2, (8, 0), (), "FrozenRemarks", None),
		"FrozenTo": (57, 2, (7, 0), (), "FrozenTo", None),
		"GLMethod": (99, 2, (3, 0), (), "GLMethod", None),
		"IncomeAccount": (15, 2, (8, 0), (), "IncomeAccount", None),
		"IncomingServiceCode": (146, 2, (3, 0), (), "IncomingServiceCode", None),
		"IndirectTax": (130, 2, (3, 0), (), "IndirectTax", None),
		"InventoryItem": (14, 2, (3, 0), (), "InventoryItem", None),
		"InventoryUOM": (136, 2, (8, 0), (), "InventoryUOM", None),
		"IsPhantom": (135, 2, (3, 0), (), "IsPhantom", None),
		"IssueMethod": (131, 2, (3, 0), (), "IssueMethod", None),
		"ItemClass": (144, 2, (3, 0), (), "ItemClass", None),
		"ItemCode": (4, 2, (8, 0), (), "ItemCode", None),
		"ItemCountryOrg": (124, 2, (8, 0), (), "ItemCountryOrg", None),
		"ItemName": (5, 2, (8, 0), (), "ItemName", None),
		"ItemType": (143, 2, (3, 0), (), "ItemType", None),
		"ItemsGroupCode": (7, 2, (3, 0), (), "ItemsGroupCode", None),
		"LeadTime": (141, 2, (3, 0), (), "LeadTime", None),
		"Mainsupplier": (18, 2, (8, 0), (), "Mainsupplier", None),
		"ManageBatchNumbers": (50, 2, (3, 0), (), "ManageBatchNumbers", None),
		"ManageSerialNumbers": (49, 2, (3, 0), (), "ManageSerialNumbers", None),
		"ManageSerialNumbersOnReleaseOnly": (121, 2, (3, 0), (), "ManageSerialNumbersOnReleaseOnly", None),
		"ManageStockByWarehouse": (103, 2, (3, 0), (), "ManageStockByWarehouse", None),
		"Manufacturer": (42, 2, (3, 0), (), "Manufacturer", None),
		"MaterialGroup": (150, 2, (3, 0), (), "MaterialGroup", None),
		"MaterialType": (149, 2, (3, 0), (), "MaterialType", None),
		"MaxInventory": (102, 2, (5, 0), (), "MaxInventory", None),
		"MinInventory": (23, 2, (5, 0), (), "MinInventory", None),
		"MinOrderQuantity": (142, 2, (5, 0), (), "MinOrderQuantity", None),
		"MovingAveragePrice": (83, 2, (5, 0), (), "MovingAveragePrice", None),
		"NCMCode": (148, 2, (3, 0), (), "NCMCode", None),
		"OrderIntervals": (139, 2, (8, 0), (), "OrderIntervals", None),
		"OrderMultiple": (140, 2, (5, 0), (), "OrderMultiple", None),
		"OutgoingServiceCode": (145, 2, (3, 0), (), "OutgoingServiceCode", None),
		"Picture": (26, 2, (8, 0), (), "Picture", None),
		"PlanningSystem": (137, 2, (3, 0), (), "PlanningSystem", None),
		# Method 'PriceList' returns object of type 'IItems_Prices'
		"PriceList": (41, 2, (9, 0), (), "PriceList", '{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}'),
		"ProcurementMethod": (138, 2, (3, 0), (), "ProcurementMethod", None),
		"ProductSource": (151, 2, (3, 0), (), "ProductSource", None),
		"PurchaseFactor1": (79, 2, (5, 0), (), "PurchaseFactor1", None),
		"PurchaseFactor2": (80, 2, (5, 0), (), "PurchaseFactor2", None),
		"PurchaseFactor3": (81, 2, (5, 0), (), "PurchaseFactor3", None),
		"PurchaseFactor4": (82, 2, (5, 0), (), "PurchaseFactor4", None),
		"PurchaseHeightUnit": (90, 2, (3, 0), (), "PurchaseHeightUnit", None),
		"PurchaseHeightUnit1": (104, 2, (3, 0), (), "PurchaseHeightUnit1", None),
		"PurchaseItem": (12, 2, (3, 0), (), "PurchaseItem", None),
		"PurchaseItemsPerUnit": (21, 2, (5, 0), (), "PurchaseItemsPerUnit", None),
		"PurchaseLengthUnit": (89, 2, (3, 0), (), "PurchaseLengthUnit", None),
		"PurchaseLengthUnit1": (106, 2, (3, 0), (), "PurchaseLengthUnit1", None),
		"PurchasePackagingUnit": (66, 2, (8, 0), (), "PurchasePackagingUnit", None),
		"PurchaseQtyPerPackUnit": (67, 2, (5, 0), (), "PurchaseQtyPerPackUnit", None),
		"PurchaseUnit": (20, 2, (8, 0), (), "PurchaseUnit", None),
		"PurchaseUnitHeight": (70, 2, (5, 0), (), "PurchaseUnitHeight", None),
		"PurchaseUnitHeight1": (105, 2, (5, 0), (), "PurchaseUnitHeight1", None),
		"PurchaseUnitLength": (68, 2, (5, 0), (), "PurchaseUnitLength", None),
		"PurchaseUnitLength1": (107, 2, (5, 0), (), "PurchaseUnitLength1", None),
		"PurchaseUnitVolume": (71, 2, (5, 0), (), "PurchaseUnitVolume", None),
		"PurchaseUnitWeight": (73, 2, (5, 0), (), "PurchaseUnitWeight", None),
		"PurchaseUnitWeight1": (109, 2, (5, 0), (), "PurchaseUnitWeight1", None),
		"PurchaseUnitWidth": (69, 2, (5, 0), (), "PurchaseUnitWidth", None),
		"PurchaseUnitWidth1": (111, 2, (5, 0), (), "PurchaseUnitWidth1", None),
		"PurchaseVATGroup": (74, 2, (8, 0), (), "PurchaseVATGroup", None),
		"PurchaseVolumeUnit": (72, 2, (3, 0), (), "PurchaseVolumeUnit", None),
		"PurchaseWeightUnit": (91, 2, (3, 0), (), "PurchaseWeightUnit", None),
		"PurchaseWeightUnit1": (108, 2, (3, 0), (), "PurchaseWeightUnit1", None),
		"PurchaseWidthUnit": (88, 2, (3, 0), (), "PurchaseWidthUnit", None),
		"PurchaseWidthUnit1": (110, 2, (3, 0), (), "PurchaseWidthUnit1", None),
		"QuantityOnStock": (43, 2, (5, 0), (), "QuantityOnStock", None),
		"QuantityOrderedByCustomers": (45, 2, (5, 0), (), "QuantityOrderedByCustomers", None),
		"QuantityOrderedFromVendors": (44, 2, (5, 0), (), "QuantityOrderedFromVendors", None),
		"SRIAndBatchManageMethod": (132, 2, (3, 0), (), "SRIAndBatchManageMethod", None),
		"SWW": (125, 2, (8, 0), (), "SWW", None),
		"SalesFactor1": (75, 2, (5, 0), (), "SalesFactor1", None),
		"SalesFactor2": (76, 2, (5, 0), (), "SalesFactor2", None),
		"SalesFactor3": (77, 2, (5, 0), (), "SalesFactor3", None),
		"SalesFactor4": (78, 2, (5, 0), (), "SalesFactor4", None),
		"SalesHeightUnit": (86, 2, (3, 0), (), "SalesHeightUnit", None),
		"SalesHeightUnit1": (112, 2, (3, 0), (), "SalesHeightUnit1", None),
		"SalesItem": (13, 2, (3, 0), (), "SalesItem", None),
		"SalesItemsPerUnit": (25, 2, (5, 0), (), "SalesItemsPerUnit", None),
		"SalesLengthUnit": (84, 2, (3, 0), (), "SalesLengthUnit", None),
		"SalesLengthUnit1": (114, 2, (3, 0), (), "SalesLengthUnit1", None),
		"SalesPackagingUnit": (60, 2, (8, 0), (), "SalesPackagingUnit", None),
		"SalesQtyPerPackUnit": (61, 2, (5, 0), (), "SalesQtyPerPackUnit", None),
		"SalesUnit": (24, 2, (8, 0), (), "SalesUnit", None),
		"SalesUnitHeight": (34, 2, (5, 0), (), "SalesUnitHeight", None),
		"SalesUnitHeight1": (113, 2, (5, 0), (), "SalesUnitHeight1", None),
		"SalesUnitLength": (62, 2, (5, 0), (), "SalesUnitLength", None),
		"SalesUnitLength1": (115, 2, (5, 0), (), "SalesUnitLength1", None),
		"SalesUnitVolume": (36, 2, (5, 0), (), "SalesUnitVolume", None),
		"SalesUnitWeight": (65, 2, (5, 0), (), "SalesUnitWeight", None),
		"SalesUnitWeight1": (117, 2, (5, 0), (), "SalesUnitWeight1", None),
		"SalesUnitWidth": (63, 2, (5, 0), (), "SalesUnitWidth", None),
		"SalesUnitWidth1": (119, 2, (5, 0), (), "SalesUnitWidth1", None),
		"SalesVATGroup": (9, 2, (8, 0), (), "SalesVATGroup", None),
		"SalesVolumeUnit": (64, 2, (3, 0), (), "SalesVolumeUnit", None),
		"SalesWeightUnit": (87, 2, (3, 0), (), "SalesWeightUnit", None),
		"SalesWeightUnit1": (116, 2, (3, 0), (), "SalesWeightUnit1", None),
		"SalesWidthUnit": (85, 2, (3, 0), (), "SalesWidthUnit", None),
		"SalesWidthUnit1": (118, 2, (3, 0), (), "SalesWidthUnit1", None),
		"SerialNum": (28, 2, (8, 0), (), "SerialNum", None),
		"ServiceGroup": (147, 2, (3, 0), (), "ServiceGroup", None),
		"ShipType": (98, 2, (3, 0), (), "ShipType", None),
		"SupplierCatalogNo": (19, 2, (8, 0), (), "SupplierCatalogNo", None),
		"TaxType": (100, 2, (3, 0), (), "TaxType", None),
		"TreeType": (32, 2, (3, 0), (), "TreeType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"User_Text": (27, 2, (8, 0), (), "User_Text", None),
		"Valid": (51, 2, (3, 0), (), "Valid", None),
		"ValidFrom": (52, 2, (7, 0), (), "ValidFrom", None),
		"ValidRemarks": (54, 2, (8, 0), (), "ValidRemarks", None),
		"ValidTo": (53, 2, (7, 0), (), "ValidTo", None),
		"VatLiable": (11, 2, (3, 0), (), "VatLiable", None),
		"WTLiable": (122, 2, (3, 0), (), "WTLiable", None),
		"WarrantyTemplate": (129, 2, (8, 0), (), "WarrantyTemplate", None),
		# Method 'WhsInfo' returns object of type 'IItemWarehouseInfo'
		"WhsInfo": (101, 2, (9, 0), (), "WhsInfo", '{CDB52791-B0FC-4BE1-A712-06941AF91D52}'),
	}
	_prop_map_put_ = {
		"ApTaxCode": ((126, LCID, 4, 0),()),
		"ArTaxCode": ((127, LCID, 4, 0),()),
		"AssetItem": ((33, LCID, 4, 0),()),
		"AvgStdPrice": ((96, LCID, 4, 0),()),
		"BarCode": ((10, LCID, 4, 0),()),
		"BaseUnitName": ((123, LCID, 4, 0),()),
		"CommissionGroup": ((31, LCID, 4, 0),()),
		"CommissionPercent": ((29, LCID, 4, 0),()),
		"CommissionSum": ((30, LCID, 4, 0),()),
		"CostAccountingMethod": ((128, LCID, 4, 0),()),
		"CustomsGroupCode": ((8, LCID, 4, 0),()),
		"DataExportCode": ((37, LCID, 4, 0),()),
		"DefaultWarehouse": ((97, LCID, 4, 0),()),
		"DesiredInventory": ((22, LCID, 4, 0),()),
		"ECExpensesAccount": ((95, LCID, 4, 0),()),
		"ECRevenuesAccount": ((93, LCID, 4, 0),()),
		"ExemptIncomeAccount": ((16, LCID, 4, 0),()),
		"ExpanseAccount": ((17, LCID, 4, 0),()),
		"ForceSelectionOfSerialNumber": ((120, LCID, 4, 0),()),
		"ForeignExpensesAccount": ((94, LCID, 4, 0),()),
		"ForeignName": ((6, LCID, 4, 0),()),
		"ForeignRevenuesAccount": ((92, LCID, 4, 0),()),
		"Frozen": ((55, LCID, 4, 0),()),
		"FrozenFrom": ((56, LCID, 4, 0),()),
		"FrozenRemarks": ((58, LCID, 4, 0),()),
		"FrozenTo": ((57, LCID, 4, 0),()),
		"GLMethod": ((99, LCID, 4, 0),()),
		"IncomeAccount": ((15, LCID, 4, 0),()),
		"IncomingServiceCode": ((146, LCID, 4, 0),()),
		"IndirectTax": ((130, LCID, 4, 0),()),
		"InventoryItem": ((14, LCID, 4, 0),()),
		"InventoryUOM": ((136, LCID, 4, 0),()),
		"IsPhantom": ((135, LCID, 4, 0),()),
		"IssueMethod": ((131, LCID, 4, 0),()),
		"ItemClass": ((144, LCID, 4, 0),()),
		"ItemCode": ((4, LCID, 4, 0),()),
		"ItemCountryOrg": ((124, LCID, 4, 0),()),
		"ItemName": ((5, LCID, 4, 0),()),
		"ItemType": ((143, LCID, 4, 0),()),
		"ItemsGroupCode": ((7, LCID, 4, 0),()),
		"LeadTime": ((141, LCID, 4, 0),()),
		"Mainsupplier": ((18, LCID, 4, 0),()),
		"ManageBatchNumbers": ((50, LCID, 4, 0),()),
		"ManageSerialNumbers": ((49, LCID, 4, 0),()),
		"ManageSerialNumbersOnReleaseOnly": ((121, LCID, 4, 0),()),
		"ManageStockByWarehouse": ((103, LCID, 4, 0),()),
		"Manufacturer": ((42, LCID, 4, 0),()),
		"MaterialGroup": ((150, LCID, 4, 0),()),
		"MaterialType": ((149, LCID, 4, 0),()),
		"MaxInventory": ((102, LCID, 4, 0),()),
		"MinInventory": ((23, LCID, 4, 0),()),
		"MinOrderQuantity": ((142, LCID, 4, 0),()),
		"NCMCode": ((148, LCID, 4, 0),()),
		"OrderIntervals": ((139, LCID, 4, 0),()),
		"OrderMultiple": ((140, LCID, 4, 0),()),
		"OutgoingServiceCode": ((145, LCID, 4, 0),()),
		"Picture": ((26, LCID, 4, 0),()),
		"PlanningSystem": ((137, LCID, 4, 0),()),
		"ProcurementMethod": ((138, LCID, 4, 0),()),
		"ProductSource": ((151, LCID, 4, 0),()),
		"PurchaseFactor1": ((79, LCID, 4, 0),()),
		"PurchaseFactor2": ((80, LCID, 4, 0),()),
		"PurchaseFactor3": ((81, LCID, 4, 0),()),
		"PurchaseFactor4": ((82, LCID, 4, 0),()),
		"PurchaseHeightUnit": ((90, LCID, 4, 0),()),
		"PurchaseHeightUnit1": ((104, LCID, 4, 0),()),
		"PurchaseItem": ((12, LCID, 4, 0),()),
		"PurchaseItemsPerUnit": ((21, LCID, 4, 0),()),
		"PurchaseLengthUnit": ((89, LCID, 4, 0),()),
		"PurchaseLengthUnit1": ((106, LCID, 4, 0),()),
		"PurchasePackagingUnit": ((66, LCID, 4, 0),()),
		"PurchaseQtyPerPackUnit": ((67, LCID, 4, 0),()),
		"PurchaseUnit": ((20, LCID, 4, 0),()),
		"PurchaseUnitHeight": ((70, LCID, 4, 0),()),
		"PurchaseUnitHeight1": ((105, LCID, 4, 0),()),
		"PurchaseUnitLength": ((68, LCID, 4, 0),()),
		"PurchaseUnitLength1": ((107, LCID, 4, 0),()),
		"PurchaseUnitVolume": ((71, LCID, 4, 0),()),
		"PurchaseUnitWeight": ((73, LCID, 4, 0),()),
		"PurchaseUnitWeight1": ((109, LCID, 4, 0),()),
		"PurchaseUnitWidth": ((69, LCID, 4, 0),()),
		"PurchaseUnitWidth1": ((111, LCID, 4, 0),()),
		"PurchaseVATGroup": ((74, LCID, 4, 0),()),
		"PurchaseVolumeUnit": ((72, LCID, 4, 0),()),
		"PurchaseWeightUnit": ((91, LCID, 4, 0),()),
		"PurchaseWeightUnit1": ((108, LCID, 4, 0),()),
		"PurchaseWidthUnit": ((88, LCID, 4, 0),()),
		"PurchaseWidthUnit1": ((110, LCID, 4, 0),()),
		"SRIAndBatchManageMethod": ((132, LCID, 4, 0),()),
		"SWW": ((125, LCID, 4, 0),()),
		"SalesFactor1": ((75, LCID, 4, 0),()),
		"SalesFactor2": ((76, LCID, 4, 0),()),
		"SalesFactor3": ((77, LCID, 4, 0),()),
		"SalesFactor4": ((78, LCID, 4, 0),()),
		"SalesHeightUnit": ((86, LCID, 4, 0),()),
		"SalesHeightUnit1": ((112, LCID, 4, 0),()),
		"SalesItem": ((13, LCID, 4, 0),()),
		"SalesItemsPerUnit": ((25, LCID, 4, 0),()),
		"SalesLengthUnit": ((84, LCID, 4, 0),()),
		"SalesLengthUnit1": ((114, LCID, 4, 0),()),
		"SalesPackagingUnit": ((60, LCID, 4, 0),()),
		"SalesQtyPerPackUnit": ((61, LCID, 4, 0),()),
		"SalesUnit": ((24, LCID, 4, 0),()),
		"SalesUnitHeight": ((34, LCID, 4, 0),()),
		"SalesUnitHeight1": ((113, LCID, 4, 0),()),
		"SalesUnitLength": ((62, LCID, 4, 0),()),
		"SalesUnitLength1": ((115, LCID, 4, 0),()),
		"SalesUnitVolume": ((36, LCID, 4, 0),()),
		"SalesUnitWeight": ((65, LCID, 4, 0),()),
		"SalesUnitWeight1": ((117, LCID, 4, 0),()),
		"SalesUnitWidth": ((63, LCID, 4, 0),()),
		"SalesUnitWidth1": ((119, LCID, 4, 0),()),
		"SalesVATGroup": ((9, LCID, 4, 0),()),
		"SalesVolumeUnit": ((64, LCID, 4, 0),()),
		"SalesWeightUnit": ((87, LCID, 4, 0),()),
		"SalesWeightUnit1": ((116, LCID, 4, 0),()),
		"SalesWidthUnit": ((85, LCID, 4, 0),()),
		"SalesWidthUnit1": ((118, LCID, 4, 0),()),
		"SerialNum": ((28, LCID, 4, 0),()),
		"ServiceGroup": ((147, LCID, 4, 0),()),
		"ShipType": ((98, LCID, 4, 0),()),
		"SupplierCatalogNo": ((19, LCID, 4, 0),()),
		"TaxType": ((100, LCID, 4, 0),()),
		"User_Text": ((27, LCID, 4, 0),()),
		"Valid": ((51, LCID, 4, 0),()),
		"ValidFrom": ((52, LCID, 4, 0),()),
		"ValidRemarks": ((54, LCID, 4, 0),()),
		"ValidTo": ((53, LCID, 4, 0),()),
		"VatLiable": ((11, LCID, 4, 0),()),
		"WTLiable": ((122, LCID, 4, 0),()),
		"WarrantyTemplate": ((129, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IItems_Prices(DispatchBaseClass):
	'IItems_Prices Interface'
	CLSID = IID('{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}')
	coclass_clsid = IID('{5C63DF2C-6C18-4447-A9BB-B6277EF0DAF2}')

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Currency": (7, 2, (8, 0), (), "Currency", None),
		"Price": (6, 2, (5, 0), (), "Price", None),
		"PriceList": (4, 2, (3, 0), (), "PriceList", None),
		"PriceListName": (5, 2, (8, 0), (), "PriceListName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Currency": ((7, LCID, 4, 0),()),
		"Price": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IJournalEntries(DispatchBaseClass):
	'IJournalEntries Interface'
	CLSID = IID('{060F033E-2FC9-4266-90AE-3271AC203A59}')
	coclass_clsid = IID('{6E3987D0-11D5-4A95-B5B7-E5BCFE88E060}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(30, LCID, 1, (8, 0), (),)

	def GetByKey(self, JdtNum=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((3, 0),),JdtNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(31, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(16, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(26, LCID, 1, (24, 0), ((3, 1),),LineNum
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AutoVAT": (35, 2, (3, 0), (), "AutoVAT", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (21, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Count": (25, 2, (3, 0), (), "Count", None),
		"DueDate": (32, 2, (7, 0), (), "DueDate", None),
		"Indicator": (22, 2, (8, 0), (), "Indicator", None),
		"JdtNum": (15, 2, (3, 0), (), "JdtNum", None),
		# Method 'Lines' returns object of type 'IJournalEntries_Lines'
		"Lines": (2, 2, (9, 0), (), "Lines", '{55053980-777B-44CF-8D76-84DD975171AA}'),
		"Memo": (6, 2, (8, 0), (), "Memo", None),
		"ProjectCode": (12, 2, (8, 0), (), "ProjectCode", None),
		"Reference": (7, 2, (8, 0), (), "Reference", None),
		"Reference2": (8, 2, (8, 0), (), "Reference2", None),
		"ReferenceDate": (5, 2, (7, 0), (), "ReferenceDate", None),
		"Series": (28, 2, (3, 0), (), "Series", None),
		"StampTax": (29, 2, (3, 0), (), "StampTax", None),
		"StornoDate": (24, 2, (7, 0), (), "StornoDate", None),
		"TaxDate": (14, 2, (7, 0), (), "TaxDate", None),
		"TransactionCode": (9, 2, (8, 0), (), "TransactionCode", None),
		"UseAutoStorno": (23, 2, (3, 0), (), "UseAutoStorno", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatDate": (27, 2, (7, 0), (), "VatDate", None),
	}
	_prop_map_put_ = {
		"AutoVAT": ((35, LCID, 4, 0),()),
		"DueDate": ((32, LCID, 4, 0),()),
		"Indicator": ((22, LCID, 4, 0),()),
		"Memo": ((6, LCID, 4, 0),()),
		"ProjectCode": ((12, LCID, 4, 0),()),
		"Reference": ((7, LCID, 4, 0),()),
		"Reference2": ((8, LCID, 4, 0),()),
		"ReferenceDate": ((5, LCID, 4, 0),()),
		"Series": ((28, LCID, 4, 0),()),
		"StampTax": ((29, LCID, 4, 0),()),
		"StornoDate": ((24, LCID, 4, 0),()),
		"TaxDate": ((14, LCID, 4, 0),()),
		"TransactionCode": ((9, LCID, 4, 0),()),
		"UseAutoStorno": ((23, LCID, 4, 0),()),
		"VatDate": ((27, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(25, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IJournalEntries_Lines(DispatchBaseClass):
	'IJournalEntries_Lines Interface'
	CLSID = IID('{55053980-777B-44CF-8D76-84DD975171AA}')
	coclass_clsid = IID('{70BFE200-77E9-4D02-B0E6-49800F3E9AD2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (6, 2, (8, 0), (), "AccountCode", None),
		"AdditionalReference": (34, 2, (8, 0), (), "AdditionalReference", None),
		"BaseSum": (24, 2, (5, 0), (), "BaseSum", None),
		"CheckAbs": (35, 2, (3, 0), (), "CheckAbs", None),
		"ContraAccount": (14, 2, (8, 0), (), "ContraAccount", None),
		"CostingCode": (22, 2, (8, 0), (), "CostingCode", None),
		"CostingCode2": (36, 2, (8, 0), (), "CostingCode2", None),
		"CostingCode3": (37, 2, (8, 0), (), "CostingCode3", None),
		"CostingCode4": (38, 2, (8, 0), (), "CostingCode4", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Credit": (8, 2, (5, 0), (), "Credit", None),
		"CreditSys": (27, 2, (5, 0), (), "CreditSys", None),
		"Debit": (7, 2, (5, 0), (), "Debit", None),
		"DebitSys": (26, 2, (5, 0), (), "DebitSys", None),
		"DueDate": (12, 2, (7, 0), (), "DueDate", None),
		"FCCredit": (10, 2, (5, 0), (), "FCCredit", None),
		"FCCurrency": (11, 2, (8, 0), (), "FCCurrency", None),
		"FCDebit": (9, 2, (5, 0), (), "FCDebit", None),
		"GrossValue": (33, 2, (5, 0), (), "GrossValue", None),
		"LineMemo": (15, 2, (8, 0), (), "LineMemo", None),
		"Line_ID": (5, 2, (3, 0), (), "Line_ID", None),
		"ProjectCode": (20, 2, (8, 0), (), "ProjectCode", None),
		"Reference1": (18, 2, (8, 0), (), "Reference1", None),
		"Reference2": (19, 2, (8, 0), (), "Reference2", None),
		"ReferenceDate1": (16, 2, (7, 0), (), "ReferenceDate1", None),
		"ReferenceDate2": (17, 2, (7, 0), (), "ReferenceDate2", None),
		"ShortName": (13, 2, (8, 0), (), "ShortName", None),
		"SystemBaseAmount": (30, 2, (5, 0), (), "SystemBaseAmount", None),
		"SystemVatAmount": (32, 2, (5, 0), (), "SystemVatAmount", None),
		"TaxDate": (23, 2, (7, 0), (), "TaxDate", None),
		"TaxGroup": (25, 2, (8, 0), (), "TaxGroup", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatAmount": (31, 2, (5, 0), (), "VatAmount", None),
		"VatDate": (28, 2, (7, 0), (), "VatDate", None),
		"VatLine": (29, 2, (3, 0), (), "VatLine", None),
	}
	_prop_map_put_ = {
		"AccountCode": ((6, LCID, 4, 0),()),
		"AdditionalReference": ((34, LCID, 4, 0),()),
		"BaseSum": ((24, LCID, 4, 0),()),
		"ContraAccount": ((14, LCID, 4, 0),()),
		"CostingCode": ((22, LCID, 4, 0),()),
		"CostingCode2": ((36, LCID, 4, 0),()),
		"CostingCode3": ((37, LCID, 4, 0),()),
		"CostingCode4": ((38, LCID, 4, 0),()),
		"Credit": ((8, LCID, 4, 0),()),
		"CreditSys": ((27, LCID, 4, 0),()),
		"Debit": ((7, LCID, 4, 0),()),
		"DebitSys": ((26, LCID, 4, 0),()),
		"DueDate": ((12, LCID, 4, 0),()),
		"FCCredit": ((10, LCID, 4, 0),()),
		"FCCurrency": ((11, LCID, 4, 0),()),
		"FCDebit": ((9, LCID, 4, 0),()),
		"GrossValue": ((33, LCID, 4, 0),()),
		"LineMemo": ((15, LCID, 4, 0),()),
		"ProjectCode": ((20, LCID, 4, 0),()),
		"Reference1": ((18, LCID, 4, 0),()),
		"Reference2": ((19, LCID, 4, 0),()),
		"ReferenceDate1": ((16, LCID, 4, 0),()),
		"ReferenceDate2": ((17, LCID, 4, 0),()),
		"ShortName": ((13, LCID, 4, 0),()),
		"SystemBaseAmount": ((30, LCID, 4, 0),()),
		"SystemVatAmount": ((32, LCID, 4, 0),()),
		"TaxDate": ((23, LCID, 4, 0),()),
		"TaxGroup": ((25, LCID, 4, 0),()),
		"VatAmount": ((31, LCID, 4, 0),()),
		"VatDate": ((28, LCID, 4, 0),()),
		"VatLine": ((29, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IJournalVouchers(DispatchBaseClass):
	'IJournalVouchers Interface'
	CLSID = IID('{B9A56422-93A0-4480-BAF3-48907F403CB8}')
	coclass_clsid = IID('{FC75103E-6EAA-4246-A097-B6F81E9DD4A3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'JournalEntries' returns object of type 'IJournalEntries'
		"JournalEntries": (2, 2, (9, 0), (), "JournalEntries", '{060F033E-2FC9-4266-90AE-3271AC203A59}'),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IKnowledgeBaseSolutions(DispatchBaseClass):
	'IKnowledgeBaseSolutions Interface'
	CLSID = IID('{1E293D13-1EC1-4DF2-A5CC-7FE45030EEE5}')
	coclass_clsid = IID('{7A042067-2E94-48B5-A7CB-3534F6223B35}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(62, LCID, 1, (8, 0), (),)

	def GetByKey(self, SolutionCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),SolutionCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(63, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (18, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (19, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Cause": (16, 2, (8, 0), (), "Cause", None),
		"CreatedBy": (10, 2, (3, 0), (), "CreatedBy", None),
		"CreationDate": (11, 2, (7, 0), (), "CreationDate", None),
		"Description": (17, 2, (8, 0), (), "Description", None),
		"ItemCode": (7, 2, (8, 0), (), "ItemCode", None),
		"LastUpdateDate": (13, 2, (7, 0), (), "LastUpdateDate", None),
		"LastUpdatedBy": (12, 2, (3, 0), (), "LastUpdatedBy", None),
		"Owner": (9, 2, (3, 0), (), "Owner", None),
		"Solution": (14, 2, (8, 0), (), "Solution", None),
		"SolutionCode": (20, 2, (3, 0), (), "SolutionCode", None),
		"Status": (8, 2, (3, 0), (), "Status", None),
		"Symptom": (15, 2, (8, 0), (), "Symptom", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Cause": ((16, LCID, 4, 0),()),
		"Description": ((17, LCID, 4, 0),()),
		"ItemCode": ((7, LCID, 4, 0),()),
		"Solution": ((14, LCID, 4, 0),()),
		"Status": ((8, LCID, 4, 0),()),
		"Symptom": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILocalEra(DispatchBaseClass):
	'ILocalEra Interface'
	CLSID = IID('{B7A80F7E-77C0-404E-A8B3-01D0F9136DCF}')
	coclass_clsid = IID('{F0D891FD-5D68-466B-90C3-0EDE46E01241}')

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),bstrCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (9, 2, (8, 0), (), "Code", None),
		"EraName": (7, 2, (8, 0), (), "EraName", None),
		"StartDate": (8, 2, (7, 0), (), "StartDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IManufacturers(DispatchBaseClass):
	'IManufacturers Interface'
	CLSID = IID('{DBB3E886-60E7-4058-930A-1C7C07CADB2C}')
	coclass_clsid = IID('{04C582B6-340A-4E71-B18B-460A37A04A62}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (12, 2, (3, 0), (), "Code", None),
		"ManufacturerName": (13, 2, (8, 0), (), "ManufacturerName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ManufacturerName": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialRevaluation(DispatchBaseClass):
	'IMaterialRevaluation Interface'
	CLSID = IID('{461F000F-9DB2-45D0-808D-FA552126FF16}')
	coclass_clsid = IID('{B133843B-6DB2-4920-976F-1C7EB0AD60A2}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(29, LCID, 1, (8, 0), (),)

	def GetByKey(self, AbsEntry=defaultNamedNotOptArg):
		'Get by key'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (11, 0), ((3, 0),),AbsEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(30, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save object as XML document'
		return self._ApplyTypes_(14, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (19, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Comments": (7, 2, (8, 0), (), "Comments", None),
		"CreationDate": (21, 2, (7, 0), (), "CreationDate", None),
		"DataSource": (27, 2, (8, 0), (), "DataSource", None),
		"DocDate": (4, 2, (7, 0), (), "DocDate", None),
		"DocEntry": (20, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (3, 2, (3, 0), (), "DocNum", None),
		"DocTime": (9, 2, (7, 0), (), "DocTime", None),
		"JournalMemo": (8, 2, (8, 0), (), "JournalMemo", None),
		# Method 'Lines' returns object of type 'IMaterialRevaluation_lines'
		"Lines": (2, 2, (9, 0), (), "Lines", '{038A3F8E-2465-435E-8D05-F510620533C3}'),
		"Reference1": (5, 2, (8, 0), (), "Reference1", None),
		"Reference2": (6, 2, (8, 0), (), "Reference2", None),
		"RevalType": (24, 2, (8, 0), (), "RevalType", None),
		"RevaluationExpenseAccount": (26, 2, (8, 0), (), "RevaluationExpenseAccount", None),
		"RevaluationIncomeAccount": (25, 2, (8, 0), (), "RevaluationIncomeAccount", None),
		"Series": (10, 2, (3, 0), (), "Series", None),
		"TaxDate": (11, 2, (7, 0), (), "TaxDate", None),
		"TransNum": (23, 2, (3, 0), (), "TransNum", None),
		"UpdateDate": (22, 2, (7, 0), (), "UpdateDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (13, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (28, 2, (3, 0), (), "UserSignature", None),
	}
	_prop_map_put_ = {
		"Comments": ((7, LCID, 4, 0),()),
		"DocDate": ((4, LCID, 4, 0),()),
		"JournalMemo": ((8, LCID, 4, 0),()),
		"Reference2": ((6, LCID, 4, 0),()),
		"RevalType": ((24, LCID, 4, 0),()),
		"RevaluationExpenseAccount": ((26, LCID, 4, 0),()),
		"RevaluationIncomeAccount": ((25, LCID, 4, 0),()),
		"Series": ((10, LCID, 4, 0),()),
		"TaxDate": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialRevaluation_lines(DispatchBaseClass):
	'IMaterialRevaluation_lines Interface'
	CLSID = IID('{038A3F8E-2465-435E-8D05-F510620533C3}')
	coclass_clsid = IID('{64572B16-A58D-40D4-B869-10787D0A8EE2}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ActualPrice": (11, 2, (5, 0), (), "ActualPrice", None),
		"Count": (8, 2, (3, 0), (), "Count", None),
		"DebitCredit": (13, 2, (5, 0), (), "DebitCredit", None),
		"DocEntry": (14, 2, (3, 0), (), "DocEntry", None),
		"ItemCode": (3, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (4, 2, (8, 0), (), "ItemDescription", None),
		"LineNum": (2, 2, (3, 0), (), "LineNum", None),
		"OnHand": (12, 2, (5, 0), (), "OnHand", None),
		"Price": (6, 2, (5, 0), (), "Price", None),
		"Quantity": (5, 2, (5, 0), (), "Quantity", None),
		"RevalAmountToStock": (17, 2, (5, 0), (), "RevalAmountToStock", None),
		"RevaluationDecrementAccount": (15, 2, (8, 0), (), "RevaluationDecrementAccount", None),
		"RevaluationIncrementAccount": (16, 2, (8, 0), (), "RevaluationIncrementAccount", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (10, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WarehouseCode": (7, 2, (8, 0), (), "WarehouseCode", None),
	}
	_prop_map_put_ = {
		"DebitCredit": ((13, LCID, 4, 0),()),
		"ItemCode": ((3, LCID, 4, 0),()),
		"Price": ((6, LCID, 4, 0),()),
		"Quantity": ((5, LCID, 4, 0),()),
		"RevaluationDecrementAccount": ((15, LCID, 4, 0),()),
		"RevaluationIncrementAccount": ((16, LCID, 4, 0),()),
		"WarehouseCode": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(8, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IMessages(DispatchBaseClass):
	'IMessages Interface'
	CLSID = IID('{C4DCA924-9189-4969-8609-8564D6E5AFAA}')
	coclass_clsid = IID('{C397C564-B506-4649-9C12-E4B63BBD7711}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def AddDataColumn(self, Title=defaultNamedNotOptArg, Text=defaultNamedNotOptArg, Object=defaultNamedNotOptArg, ObjectKey=defaultNamedNotOptArg):
		'method AddDataColumn'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((8, 0), (8, 0), (3, 0), (8, 0)),Title
			, Text, Object, ObjectKey)

	_prop_map_get_ = {
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (8, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		"MessageText": (4, 2, (8, 0), (), "MessageText", None),
		"Priority": (2, 2, (3, 0), (), "Priority", None),
		# Method 'Recipients' returns object of type 'IRecipients'
		"Recipients": (9, 2, (9, 0), (), "Recipients", '{F408B086-B6E4-4EE0-9B95-710C117E56F0}'),
		"Subject": (3, 2, (8, 0), (), "Subject", None),
	}
	_prop_map_put_ = {
		"MessageText": ((4, LCID, 4, 0),()),
		"Priority": ((2, LCID, 4, 0),()),
		"Subject": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INotaFiscalCFOP(DispatchBaseClass):
	'INotaFiscalCFOP Interface'
	CLSID = IID('{AFFB904C-0D52-4359-B44B-FB594DC5618A}')
	coclass_clsid = IID('{9A38EECB-D61C-469C-9425-C66BAAA0623E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def GetByKey(self, ID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (11, 0), ((3, 0),),ID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Application": (4, 2, (8, 0), (), "Application", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (3, 2, (8, 0), (), "Code", None),
		"Description": (2, 2, (8, 0), (), "Description", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Application": ((4, LCID, 4, 0),()),
		"Code": ((3, LCID, 4, 0),()),
		"Description": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INotaFiscalCST(DispatchBaseClass):
	'INotaFiscalCST Interface'
	CLSID = IID('{54E2DDD8-87FE-415D-AA8E-2AC62C936C7A}')
	coclass_clsid = IID('{7CD6F364-32D1-4862-8470-E27D69A03F08}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def GetByKey(self, ID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (11, 0), ((3, 0),),ID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (2, 2, (8, 0), (), "Code", None),
		"Situation": (3, 2, (8, 0), (), "Situation", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Code": ((2, LCID, 4, 0),()),
		"Situation": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INotaFiscalUsage(DispatchBaseClass):
	'INotaFiscalUsage Interface'
	CLSID = IID('{E2C5A384-883B-4963-A4A4-30C6F553818F}')
	coclass_clsid = IID('{2C3D3B79-8BCD-4CF4-981D-1033A54CBF17}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def GetByKey(self, ID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (11, 0), ((3, 0),),ID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (8, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ID": (2, 2, (3, 0), (), "ID", None),
		"Usage": (3, 2, (8, 0), (), "Usage", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Usage": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPackagesTypes(DispatchBaseClass):
	'IPackagesTypes Interface'
	CLSID = IID('{CE69987E-8F99-4FC1-8C86-837E5246AFA2}')
	coclass_clsid = IID('{84FAFD4C-5213-4CB8-9F2F-7FECB428F0ED}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (2, 2, (3, 0), (), "Code", None),
		"Type": (1, 2, (8, 0), (), "Type", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Type": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPaymentRunExport(DispatchBaseClass):
	'IPaymentRunExport Interface'
	CLSID = IID('{9020ED56-6B7D-4FAC-8D93-B185D1E65A59}')
	coclass_clsid = IID('{856AB71E-0D54-4BA5-95CA-7135D77040EC}')

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(82, LCID, 1, (8, 0), (),)

	def GetByKey(self, PaymentRunExportCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (11, 0), ((3, 0),),PaymentRunExportCode
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(83, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save the object into xml file'
		return self._ApplyTypes_(4, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		"AdditionalIdNumber": (64, 2, (8, 0), (), "AdditionalIdNumber", None),
		"BankAccount": (30, 2, (8, 0), (), "BankAccount", None),
		"BankCode": (32, 2, (8, 0), (), "BankCode", None),
		"BankCountry": (31, 2, (8, 0), (), "BankCountry", None),
		"BankIBAN": (33, 2, (8, 0), (), "BankIBAN", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (3, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CollectionAuthorization": (45, 2, (3, 0), (), "CollectionAuthorization", None),
		"CompIsrBillerID": (62, 2, (8, 0), (), "CompIsrBillerID", None),
		"CompanyAddress": (60, 2, (8, 0), (), "CompanyAddress", None),
		"CompanyName": (59, 2, (8, 0), (), "CompanyName", None),
		"CompanyTaxNum": (12, 2, (8, 0), (), "CompanyTaxNum", None),
		"Countery": (11, 2, (8, 0), (), "Countery", None),
		"Currency": (35, 2, (8, 0), (), "Currency", None),
		"CustomerNum": (7, 2, (8, 0), (), "CustomerNum", None),
		"DebitMemo": (73, 2, (3, 0), (), "DebitMemo", None),
		"DocAmountForign": (38, 2, (5, 0), (), "DocAmountForign", None),
		"DocAmountLocal": (36, 2, (5, 0), (), "DocAmountLocal", None),
		"DocCashDiscount": (39, 2, (5, 0), (), "DocCashDiscount", None),
		"DocCashDiscountForign": (40, 2, (5, 0), (), "DocCashDiscountForign", None),
		"DocCurrnecy": (37, 2, (8, 0), (), "DocCurrnecy", None),
		"DocNum": (9, 2, (3, 0), (), "DocNum", None),
		"DocNumOffieldPaid": (41, 2, (3, 0), (), "DocNumOffieldPaid", None),
		"DocRate": (42, 2, (5, 0), (), "DocRate", None),
		"EUInternalTransfer": (74, 2, (3, 0), (), "EUInternalTransfer", None),
		"FilePath": (75, 2, (8, 0), (), "FilePath", None),
		"FiscalYear": (10, 2, (7, 0), (), "FiscalYear", None),
		"FormatName": (81, 2, (8, 0), (), "FormatName", None),
		"GLAccount": (34, 2, (8, 0), (), "GLAccount", None),
		"InstructionKey": (57, 2, (8, 0), (), "InstructionKey", None),
		# Method 'Lines' returns object of type 'IPaymentRunExport_Lines'
		"Lines": (2, 2, (9, 0), (), "Lines", '{917BA077-4D88-46A8-B78A-E396315D7E59}'),
		"OrderingParty": (76, 2, (8, 0), (), "OrderingParty", None),
		"OrganizationNumber": (65, 2, (8, 0), (), "OrganizationNumber", None),
		"PayeeBankAccount": (24, 2, (8, 0), (), "PayeeBankAccount", None),
		"PayeeBankBISR": (52, 2, (3, 0), (), "PayeeBankBISR", None),
		"PayeeBankBlock": (49, 2, (8, 0), (), "PayeeBankBlock", None),
		"PayeeBankBranch": (66, 2, (8, 0), (), "PayeeBankBranch", None),
		"PayeeBankCity": (21, 2, (8, 0), (), "PayeeBankCity", None),
		"PayeeBankCode": (25, 2, (8, 0), (), "PayeeBankCode", None),
		"PayeeBankCountry": (23, 2, (8, 0), (), "PayeeBankCountry", None),
		"PayeeBankCounty": (50, 2, (8, 0), (), "PayeeBankCounty", None),
		"PayeeBankCtrlKey": (26, 2, (8, 0), (), "PayeeBankCtrlKey", None),
		"PayeeBankHouseBank": (48, 2, (3, 0), (), "PayeeBankHouseBank", None),
		"PayeeBankIBAN": (28, 2, (8, 0), (), "PayeeBankIBAN", None),
		"PayeeBankName": (19, 2, (8, 0), (), "PayeeBankName", None),
		"PayeeBankNextCheckNumber": (47, 2, (3, 0), (), "PayeeBankNextCheckNumber", None),
		"PayeeBankPostOffice": (46, 2, (3, 0), (), "PayeeBankPostOffice", None),
		"PayeeBankState": (51, 2, (8, 0), (), "PayeeBankState", None),
		"PayeeBankStreet": (22, 2, (8, 0), (), "PayeeBankStreet", None),
		"PayeeBankSwiftNum": (27, 2, (8, 0), (), "PayeeBankSwiftNum", None),
		"PayeeBankUserNum1": (53, 2, (8, 0), (), "PayeeBankUserNum1", None),
		"PayeeBankUserNum2": (54, 2, (8, 0), (), "PayeeBankUserNum2", None),
		"PayeeBankUserNum3": (55, 2, (8, 0), (), "PayeeBankUserNum3", None),
		"PayeeBankUserNum4": (56, 2, (8, 0), (), "PayeeBankUserNum4", None),
		"PayeeBankZip": (20, 2, (8, 0), (), "PayeeBankZip", None),
		"PayeeCity": (15, 2, (8, 0), (), "PayeeCity", None),
		"PayeeCountry": (17, 2, (8, 0), (), "PayeeCountry", None),
		"PayeeName": (13, 2, (8, 0), (), "PayeeName", None),
		"PayeePostalCode": (14, 2, (8, 0), (), "PayeePostalCode", None),
		"PayeeReferenceDetails": (80, 2, (8, 0), (), "PayeeReferenceDetails", None),
		"PayeeState": (18, 2, (8, 0), (), "PayeeState", None),
		"PayeeStreet": (16, 2, (8, 0), (), "PayeeStreet", None),
		"PayeeTaxNumber": (78, 2, (8, 0), (), "PayeeTaxNumber", None),
		"PaymentBankBranch": (67, 2, (8, 0), (), "PaymentBankBranch", None),
		"PaymentBankControlKey": (77, 2, (8, 0), (), "PaymentBankControlKey", None),
		"PaymentFormat": (58, 2, (8, 0), (), "PaymentFormat", None),
		"PaymentKeyCode": (79, 2, (8, 0), (), "PaymentKeyCode", None),
		"PaymentMethod": (8, 2, (8, 0), (), "PaymentMethod", None),
		"PostingDate": (29, 2, (7, 0), (), "PostingDate", None),
		"RunDate": (5, 2, (7, 0), (), "RunDate", None),
		"Status": (61, 2, (3, 0), (), "Status", None),
		"UserDepartment": (72, 2, (3, 0), (), "UserDepartment", None),
		"UserEMail": (69, 2, (8, 0), (), "UserEMail", None),
		"UserFaxNumber": (71, 2, (8, 0), (), "UserFaxNumber", None),
		"UserMobilePhoneNumber": (70, 2, (8, 0), (), "UserMobilePhoneNumber", None),
		"UserName": (68, 2, (8, 0), (), "UserName", None),
		"VendorIsrBillerID": (63, 2, (8, 0), (), "VendorIsrBillerID", None),
		"VendorNum": (6, 2, (8, 0), (), "VendorNum", None),
		"WizCode": (44, 2, (3, 0), (), "WizCode", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPaymentRunExport_Lines(DispatchBaseClass):
	'IPaymentRunExport_Lines Interface'
	CLSID = IID('{917BA077-4D88-46A8-B78A-E396315D7E59}')
	coclass_clsid = IID('{A2A9F005-92C0-4949-B2D7-92B7D8AAA784}')

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPDebitPayableAccount": (16, 2, (8, 0), (), "BPDebitPayableAccount", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"CustomerNumber": (8, 2, (8, 0), (), "CustomerNumber", None),
		"DateOfPaymentRun": (5, 2, (7, 0), (), "DateOfPaymentRun", None),
		"DocumentCurrency": (17, 2, (8, 0), (), "DocumentCurrency", None),
		"DocumentLocalCurrency": (26, 2, (8, 0), (), "DocumentLocalCurrency", None),
		"DocumentObjectType": (13, 2, (3, 0), (), "DocumentObjectType", None),
		"DocumentObjectTypeEx": (28, 2, (8, 0), (), "DocumentObjectTypeEx", None),
		"DocumentPaymentTerms": (24, 2, (3, 0), (), "DocumentPaymentTerms", None),
		"DocumentPostingDate": (14, 2, (7, 0), (), "DocumentPostingDate", None),
		"DocumentRate": (18, 2, (5, 0), (), "DocumentRate", None),
		"DocumentRemarks": (23, 2, (8, 0), (), "DocumentRemarks", None),
		"DocumentTaxAmount": (21, 2, (5, 0), (), "DocumentTaxAmount", None),
		"DocumentTaxAmountFC": (22, 2, (5, 0), (), "DocumentTaxAmountFC", None),
		"DocumentTaxDate": (15, 2, (7, 0), (), "DocumentTaxDate", None),
		"DocumentTotal": (19, 2, (5, 0), (), "DocumentTotal", None),
		"DocumentTotalFC": (20, 2, (5, 0), (), "DocumentTotalFC", None),
		"FiscalYear": (11, 2, (7, 0), (), "FiscalYear", None),
		"PaymentDocNum": (10, 2, (3, 0), (), "PaymentDocNum", None),
		"PaymentDocReference": (25, 2, (8, 0), (), "PaymentDocReference", None),
		"PaymentMeans": (9, 2, (8, 0), (), "PaymentMeans", None),
		"PaymentTermsPeriod": (27, 2, (3, 0), (), "PaymentTermsPeriod", None),
		"PaymentWizardCode": (6, 2, (8, 0), (), "PaymentWizardCode", None),
		"RowNumber": (4, 2, (3, 0), (), "RowNumber", None),
		"VendorNumber": (7, 2, (8, 0), (), "VendorNumber", None),
		"VendorRefNum": (12, 2, (8, 0), (), "VendorRefNum", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPaymentTermsTypes(DispatchBaseClass):
	'IPaymentTermsTypes Interface'
	CLSID = IID('{F09A4CB0-F8CA-4342-A44D-82DE3395B011}')
	coclass_clsid = IID('{403E32F9-EBDD-4528-89C2-FE8BE8F7F0A6}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(26, LCID, 1, (8, 0), (),)

	def GetByKey(self, GroupNum=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),GroupNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(27, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"BaselineDate": (22, 2, (3, 0), (), "BaselineDate", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CreditLimit": (14, 2, (5, 0), (), "CreditLimit", None),
		"DiscountCode": (20, 2, (8, 0), (), "DiscountCode", None),
		"DunningCode": (21, 2, (8, 0), (), "DunningCode", None),
		"GeneralDiscount": (15, 2, (5, 0), (), "GeneralDiscount", None),
		"GroupNumber": (9, 2, (3, 0), (), "GroupNumber", None),
		"InterestOnArrears": (16, 2, (5, 0), (), "InterestOnArrears", None),
		"LoadLimit": (18, 2, (5, 0), (), "LoadLimit", None),
		"NumberOfAdditionalDays": (13, 2, (3, 0), (), "NumberOfAdditionalDays", None),
		"NumberOfAdditionalMonths": (12, 2, (3, 0), (), "NumberOfAdditionalMonths", None),
		"NumberOfInstallments": (23, 2, (3, 0), (), "NumberOfInstallments", None),
		"NumberOfToleranceDays": (24, 2, (3, 0), (), "NumberOfToleranceDays", None),
		"OpenReceipt": (19, 2, (3, 0), (), "OpenReceipt", None),
		"PaymentTermsGroupName": (10, 2, (8, 0), (), "PaymentTermsGroupName", None),
		"PriceListNo": (17, 2, (3, 0), (), "PriceListNo", None),
		"StartFrom": (11, 2, (3, 0), (), "StartFrom", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (25, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BaselineDate": ((22, LCID, 4, 0),()),
		"CreditLimit": ((14, LCID, 4, 0),()),
		"DiscountCode": ((20, LCID, 4, 0),()),
		"DunningCode": ((21, LCID, 4, 0),()),
		"GeneralDiscount": ((15, LCID, 4, 0),()),
		"InterestOnArrears": ((16, LCID, 4, 0),()),
		"LoadLimit": ((18, LCID, 4, 0),()),
		"NumberOfAdditionalDays": ((13, LCID, 4, 0),()),
		"NumberOfAdditionalMonths": ((12, LCID, 4, 0),()),
		"NumberOfToleranceDays": ((24, LCID, 4, 0),()),
		"OpenReceipt": ((19, LCID, 4, 0),()),
		"PaymentTermsGroupName": ((10, LCID, 4, 0),()),
		"PriceListNo": ((17, LCID, 4, 0),()),
		"StartFrom": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPayments(DispatchBaseClass):
	'IPayments Interface'
	CLSID = IID('{E79D3C41-BFE7-4C5A-B586-4F627E021A1C}')
	coclass_clsid = IID('{A52ED4BA-1C19-4553-9A60-D69B653E8CB5}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(43, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(44, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(76, LCID, 1, (8, 0), (),)

	def GetByKey(self, RctEntry=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((3, 0),),RctEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(42, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(77, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'AccountPayments' returns object of type 'IPayments_Accounts'
		"AccountPayments": (39, 2, (9, 0), (), "AccountPayments", '{231A13D7-5DA8-4467-A263-FDE84A268AC9}'),
		"Address": (13, 2, (8, 0), (), "Address", None),
		"ApplyVAT": (31, 2, (3, 0), (), "ApplyVAT", None),
		"BankAccount": (35, 2, (8, 0), (), "BankAccount", None),
		"BankChargeAmount": (78, 2, (5, 0), (), "BankChargeAmount", None),
		"BankChargeAmountInFC": (79, 2, (5, 0), (), "BankChargeAmountInFC", None),
		"BankChargeAmountInSC": (80, 2, (5, 0), (), "BankChargeAmountInSC", None),
		"BankCode": (34, 2, (8, 0), (), "BankCode", None),
		# Method 'BillOfExchange' returns object of type 'IBillOfExchange'
		"BillOfExchange": (54, 2, (9, 0), (), "BillOfExchange", '{741AA803-AB33-4FD7-B664-63116291D6CE}'),
		"BillOfExchangeAgent": (57, 2, (8, 0), (), "BillOfExchangeAgent", None),
		"BillOfExchangeAmount": (52, 2, (5, 0), (), "BillOfExchangeAmount", None),
		"BillOfExchangeAmountFC": (55, 2, (5, 0), (), "BillOfExchangeAmountFC", None),
		"BillOfExchangeAmountSC": (56, 2, (5, 0), (), "BillOfExchangeAmountSC", None),
		"BillofExchangeStatus": (53, 2, (3, 0), (), "BillofExchangeStatus", None),
		"BoeAccount": (51, 2, (8, 0), (), "BoeAccount", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (45, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (11, 2, (8, 0), (), "CardCode", None),
		"CardName": (12, 2, (8, 0), (), "CardName", None),
		"CashAccount": (14, 2, (8, 0), (), "CashAccount", None),
		"CashSum": (16, 2, (5, 0), (), "CashSum", None),
		"CashSumFC": (49, 2, (5, 0), (), "CashSumFC", None),
		"CashSumSys": (50, 2, (5, 0), (), "CashSumSys", None),
		"CheckAccount": (17, 2, (8, 0), (), "CheckAccount", None),
		# Method 'Checks' returns object of type 'IPayments_Checks'
		"Checks": (36, 2, (9, 0), (), "Checks", '{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}'),
		"ContactPersonCode": (30, 2, (3, 0), (), "ContactPersonCode", None),
		"CounterReference": (26, 2, (8, 0), (), "CounterReference", None),
		# Method 'CreditCards' returns object of type 'IPayments_CreditCards'
		"CreditCards": (38, 2, (9, 0), (), "CreditCards", '{CC3579ED-1C61-4864-8E51-208A3DCDFC93}'),
		"DeductionPercent": (47, 2, (5, 0), (), "DeductionPercent", None),
		"DeductionSum": (48, 2, (5, 0), (), "DeductionSum", None),
		"DocCurrency": (15, 2, (8, 0), (), "DocCurrency", None),
		"DocDate": (10, 2, (7, 0), (), "DocDate", None),
		"DocEntry": (73, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (6, 2, (3, 0), (), "DocNum", None),
		"DocObjectCode": (72, 2, (3, 0), (), "DocObjectCode", None),
		"DocRate": (23, 2, (5, 0), (), "DocRate", None),
		"DocType": (71, 2, (3, 0), (), "DocType", None),
		"DocTypte": (7, 2, (3, 0), (), "DocTypte", None),
		"HandWritten": (8, 2, (3, 0), (), "HandWritten", None),
		# Method 'Invoices' returns object of type 'IPayments_Invoices'
		"Invoices": (37, 2, (9, 0), (), "Invoices", '{AB7947CF-8191-498D-8B3C-8E04A00957E7}'),
		"IsPayToBank": (70, 2, (3, 0), (), "IsPayToBank", None),
		"JournalRemarks": (28, 2, (8, 0), (), "JournalRemarks", None),
		"LocalCurrency": (22, 2, (3, 0), (), "LocalCurrency", None),
		"PayToBankAccountNo": (67, 2, (8, 0), (), "PayToBankAccountNo", None),
		"PayToBankBranch": (75, 2, (8, 0), (), "PayToBankBranch", None),
		"PayToBankCode": (74, 2, (8, 0), (), "PayToBankCode", None),
		"PayToBankCountry": (69, 2, (8, 0), (), "PayToBankCountry", None),
		"PayToCode": (68, 2, (8, 0), (), "PayToCode", None),
		"PaymentPriority": (65, 2, (3, 0), (), "PaymentPriority", None),
		"PaymentType": (83, 2, (3, 0), (), "PaymentType", None),
		"Printed": (9, 2, (3, 0), (), "Printed", None),
		"Proforma": (64, 2, (3, 0), (), "Proforma", None),
		"ProjectCode": (41, 2, (8, 0), (), "ProjectCode", None),
		"Reference1": (24, 2, (8, 0), (), "Reference1", None),
		"Reference2": (25, 2, (8, 0), (), "Reference2", None),
		"Remarks": (27, 2, (8, 0), (), "Remarks", None),
		"Series": (33, 2, (3, 0), (), "Series", None),
		"TaxDate": (32, 2, (7, 0), (), "TaxDate", None),
		"TaxGroup": (66, 2, (8, 0), (), "TaxGroup", None),
		"TransactionCode": (82, 2, (8, 0), (), "TransactionCode", None),
		"TransferAccount": (18, 2, (8, 0), (), "TransferAccount", None),
		"TransferDate": (20, 2, (7, 0), (), "TransferDate", None),
		"TransferRealAmount": (84, 2, (5, 0), (), "TransferRealAmount", None),
		"TransferReference": (21, 2, (8, 0), (), "TransferReference", None),
		"TransferSum": (19, 2, (5, 0), (), "TransferSum", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatDate": (81, 2, (7, 0), (), "VatDate", None),
		"WTAccount": (62, 2, (8, 0), (), "WTAccount", None),
		"WTAmount": (59, 2, (5, 0), (), "WTAmount", None),
		"WTAmountFC": (60, 2, (5, 0), (), "WTAmountFC", None),
		"WTAmountSC": (61, 2, (5, 0), (), "WTAmountSC", None),
		"WTCode": (58, 2, (8, 0), (), "WTCode", None),
		"WTTaxableAmount": (63, 2, (5, 0), (), "WTTaxableAmount", None),
	}
	_prop_map_put_ = {
		"Address": ((13, LCID, 4, 0),()),
		"ApplyVAT": ((31, LCID, 4, 0),()),
		"BankAccount": ((35, LCID, 4, 0),()),
		"BankChargeAmount": ((78, LCID, 4, 0),()),
		"BankCode": ((34, LCID, 4, 0),()),
		"BillOfExchangeAgent": ((57, LCID, 4, 0),()),
		"BillOfExchangeAmount": ((52, LCID, 4, 0),()),
		"BillofExchangeStatus": ((53, LCID, 4, 0),()),
		"BoeAccount": ((51, LCID, 4, 0),()),
		"CardCode": ((11, LCID, 4, 0),()),
		"CardName": ((12, LCID, 4, 0),()),
		"CashAccount": ((14, LCID, 4, 0),()),
		"CashSum": ((16, LCID, 4, 0),()),
		"CheckAccount": ((17, LCID, 4, 0),()),
		"ContactPersonCode": ((30, LCID, 4, 0),()),
		"CounterReference": ((26, LCID, 4, 0),()),
		"DeductionPercent": ((47, LCID, 4, 0),()),
		"DeductionSum": ((48, LCID, 4, 0),()),
		"DocCurrency": ((15, LCID, 4, 0),()),
		"DocDate": ((10, LCID, 4, 0),()),
		"DocNum": ((6, LCID, 4, 0),()),
		"DocObjectCode": ((72, LCID, 4, 0),()),
		"DocRate": ((23, LCID, 4, 0),()),
		"DocType": ((71, LCID, 4, 0),()),
		"DocTypte": ((7, LCID, 4, 0),()),
		"HandWritten": ((8, LCID, 4, 0),()),
		"IsPayToBank": ((70, LCID, 4, 0),()),
		"JournalRemarks": ((28, LCID, 4, 0),()),
		"LocalCurrency": ((22, LCID, 4, 0),()),
		"PayToBankAccountNo": ((67, LCID, 4, 0),()),
		"PayToBankBranch": ((75, LCID, 4, 0),()),
		"PayToBankCode": ((74, LCID, 4, 0),()),
		"PayToBankCountry": ((69, LCID, 4, 0),()),
		"PayToCode": ((68, LCID, 4, 0),()),
		"PaymentPriority": ((65, LCID, 4, 0),()),
		"PaymentType": ((83, LCID, 4, 0),()),
		"Proforma": ((64, LCID, 4, 0),()),
		"ProjectCode": ((41, LCID, 4, 0),()),
		"Reference1": ((24, LCID, 4, 0),()),
		"Reference2": ((25, LCID, 4, 0),()),
		"Remarks": ((27, LCID, 4, 0),()),
		"Series": ((33, LCID, 4, 0),()),
		"TaxDate": ((32, LCID, 4, 0),()),
		"TaxGroup": ((66, LCID, 4, 0),()),
		"TransactionCode": ((82, LCID, 4, 0),()),
		"TransferAccount": ((18, LCID, 4, 0),()),
		"TransferDate": ((20, LCID, 4, 0),()),
		"TransferRealAmount": ((84, LCID, 4, 0),()),
		"TransferReference": ((21, LCID, 4, 0),()),
		"TransferSum": ((19, LCID, 4, 0),()),
		"VatDate": ((81, LCID, 4, 0),()),
		"WTAmount": ((59, LCID, 4, 0),()),
		"WTCode": ((58, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPayments_Accounts(DispatchBaseClass):
	'IPayments_Accounts Interface'
	CLSID = IID('{231A13D7-5DA8-4467-A263-FDE84A268AC9}')
	coclass_clsid = IID('{0E77E5DB-93A3-4FCF-BB4B-BE8323F27387}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (6, 2, (8, 0), (), "AccountCode", None),
		"AccountName": (11, 2, (8, 0), (), "AccountName", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"Decription": (9, 2, (8, 0), (), "Decription", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"SumPaid": (7, 2, (5, 0), (), "SumPaid", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatGroup": (10, 2, (8, 0), (), "VatGroup", None),
	}
	_prop_map_put_ = {
		"AccountCode": ((6, LCID, 4, 0),()),
		"AccountName": ((11, LCID, 4, 0),()),
		"Decription": ((9, LCID, 4, 0),()),
		"SumPaid": ((7, LCID, 4, 0),()),
		"VatGroup": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPayments_Checks(DispatchBaseClass):
	'IPayments_Checks Interface'
	CLSID = IID('{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}')
	coclass_clsid = IID('{6155B8DA-5812-48F9-8955-67CE75857600}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccounttNum": (10, 2, (8, 0), (), "AccounttNum", None),
		"BankCode": (8, 2, (8, 0), (), "BankCode", None),
		"Branch": (9, 2, (8, 0), (), "Branch", None),
		"CheckNumber": (7, 2, (3, 0), (), "CheckNumber", None),
		"CheckSum": (13, 2, (5, 0), (), "CheckSum", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"CountryCode": (14, 2, (8, 0), (), "CountryCode", None),
		"Details": (11, 2, (8, 0), (), "Details", None),
		"DueDate": (6, 2, (7, 0), (), "DueDate", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"Trnsfrable": (12, 2, (3, 0), (), "Trnsfrable", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AccounttNum": ((10, LCID, 4, 0),()),
		"BankCode": ((8, LCID, 4, 0),()),
		"Branch": ((9, LCID, 4, 0),()),
		"CheckNumber": ((7, LCID, 4, 0),()),
		"CheckSum": ((13, LCID, 4, 0),()),
		"CountryCode": ((14, LCID, 4, 0),()),
		"Details": ((11, LCID, 4, 0),()),
		"DueDate": ((6, LCID, 4, 0),()),
		"Trnsfrable": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPayments_CreditCards(DispatchBaseClass):
	'IPayments_CreditCards Interface'
	CLSID = IID('{CC3579ED-1C61-4864-8E51-208A3DCDFC93}')
	coclass_clsid = IID('{1C972937-3B53-45EE-9728-516996023C1A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AdditionalPaymentSum": (17, 2, (5, 0), (), "AdditionalPaymentSum", None),
		"CardValidUntil": (9, 2, (7, 0), (), "CardValidUntil", None),
		"ConfirmationNum": (21, 2, (8, 0), (), "ConfirmationNum", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"CreditAcct": (7, 2, (8, 0), (), "CreditAcct", None),
		"CreditCard": (6, 2, (3, 0), (), "CreditCard", None),
		"CreditCardNumber": (8, 2, (8, 0), (), "CreditCardNumber", None),
		"CreditSum": (18, 2, (5, 0), (), "CreditSum", None),
		"CreditType": (23, 2, (3, 0), (), "CreditType", None),
		"FirstPaymentDue": (15, 2, (7, 0), (), "FirstPaymentDue", None),
		"FirstPaymentSum": (16, 2, (5, 0), (), "FirstPaymentSum", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"NumOfCreditPayments": (22, 2, (3, 0), (), "NumOfCreditPayments", None),
		"NumOfPayments": (14, 2, (3, 0), (), "NumOfPayments", None),
		"OwnerIdNum": (11, 2, (8, 0), (), "OwnerIdNum", None),
		"OwnerPhone": (12, 2, (8, 0), (), "OwnerPhone", None),
		"PaymentMethodCode": (13, 2, (3, 0), (), "PaymentMethodCode", None),
		"SplitPayments": (24, 2, (3, 0), (), "SplitPayments", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VoucherNum": (10, 2, (8, 0), (), "VoucherNum", None),
	}
	_prop_map_put_ = {
		"AdditionalPaymentSum": ((17, LCID, 4, 0),()),
		"CardValidUntil": ((9, LCID, 4, 0),()),
		"ConfirmationNum": ((21, LCID, 4, 0),()),
		"CreditAcct": ((7, LCID, 4, 0),()),
		"CreditCard": ((6, LCID, 4, 0),()),
		"CreditCardNumber": ((8, LCID, 4, 0),()),
		"CreditSum": ((18, LCID, 4, 0),()),
		"CreditType": ((23, LCID, 4, 0),()),
		"FirstPaymentDue": ((15, LCID, 4, 0),()),
		"FirstPaymentSum": ((16, LCID, 4, 0),()),
		"NumOfCreditPayments": ((22, LCID, 4, 0),()),
		"NumOfPayments": ((14, LCID, 4, 0),()),
		"OwnerIdNum": ((11, LCID, 4, 0),()),
		"OwnerPhone": ((12, LCID, 4, 0),()),
		"PaymentMethodCode": ((13, LCID, 4, 0),()),
		"SplitPayments": ((24, LCID, 4, 0),()),
		"VoucherNum": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPayments_Invoices(DispatchBaseClass):
	'IPayments_Invoices Interface'
	CLSID = IID('{AB7947CF-8191-498D-8B3C-8E04A00957E7}')
	coclass_clsid = IID('{ADCC23F1-37CE-4327-BE13-88D1E14F8877}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AppliedFC": (8, 2, (5, 0), (), "AppliedFC", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"DiscountPercent": (13, 2, (5, 0), (), "DiscountPercent", None),
		"DocEntry": (6, 2, (3, 0), (), "DocEntry", None),
		"DocLine": (11, 2, (3, 0), (), "DocLine", None),
		"InstallmentId": (15, 2, (3, 0), (), "InstallmentId", None),
		"InvoiceType": (12, 2, (3, 0), (), "InvoiceType", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"LinkDate": (19, 2, (7, 0), (), "LinkDate", None),
		"PaidSum": (14, 2, (5, 0), (), "PaidSum", None),
		"SumApplied": (7, 2, (5, 0), (), "SumApplied", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WitholdingTaxApplied": (16, 2, (5, 0), (), "WitholdingTaxApplied", None),
		"WitholdingTaxAppliedFC": (17, 2, (5, 0), (), "WitholdingTaxAppliedFC", None),
		"WitholdingTaxAppliedSC": (18, 2, (5, 0), (), "WitholdingTaxAppliedSC", None),
	}
	_prop_map_put_ = {
		"AppliedFC": ((8, LCID, 4, 0),()),
		"DiscountPercent": ((13, LCID, 4, 0),()),
		"DocEntry": ((6, LCID, 4, 0),()),
		"DocLine": ((11, LCID, 4, 0),()),
		"InstallmentId": ((15, LCID, 4, 0),()),
		"InvoiceType": ((12, LCID, 4, 0),()),
		"SumApplied": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPriceLists(DispatchBaseClass):
	'IPriceLists Interface'
	CLSID = IID('{99FB9754-BDAE-4C8D-BA96-4F2263A73A6A}')
	coclass_clsid = IID('{C7E88977-022A-494D-BC9D-09FA85E7AC15}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(13, LCID, 1, (8, 0), (),)

	def GetByKey(self, QueueID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (11, 0), ((8, 1),),QueueID
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(3, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"BasePriceList": (9, 2, (3, 0), (), "BasePriceList", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (5, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Factor": (10, 2, (5, 0), (), "Factor", None),
		"GroupNum": (8, 2, (3, 0), (), "GroupNum", None),
		"PriceListName": (12, 2, (8, 0), (), "PriceListName", None),
		"PriceListNo": (11, 2, (3, 0), (), "PriceListNo", None),
		"RoundingMethod": (7, 2, (3, 0), (), "RoundingMethod", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (2, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BasePriceList": ((9, LCID, 4, 0),()),
		"Factor": ((10, LCID, 4, 0),()),
		"GroupNum": ((8, LCID, 4, 0),()),
		"PriceListName": ((12, LCID, 4, 0),()),
		"RoundingMethod": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProductTrees(DispatchBaseClass):
	'IProductTrees Interface'
	CLSID = IID('{9BCDAE48-582B-4E76-BD8F-E8A77BC6CF6E}')
	coclass_clsid = IID('{B2CC6793-FFCF-4389-980D-B5FF458B2EC8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(15, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((8, 0),),Key
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(16, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (13, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		# Method 'Items' returns object of type 'IProductTrees_Lines'
		"Items": (4, 2, (9, 0), (), "Items", '{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}'),
		"Quantity": (8, 2, (5, 0), (), "Quantity", None),
		"TreeCode": (6, 2, (8, 0), (), "TreeCode", None),
		"TreeType": (7, 2, (3, 0), (), "TreeType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (14, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Quantity": ((8, LCID, 4, 0),()),
		"TreeCode": ((6, LCID, 4, 0),()),
		"TreeType": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProductTrees_Lines(DispatchBaseClass):
	'IProductTrees_Lines Interface'
	CLSID = IID('{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}')
	coclass_clsid = IID('{D9F478E8-7891-4C69-A96D-39D5881CFE39}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Comment": (13, 2, (8, 0), (), "Comment", None),
		"Count": (8, 2, (3, 0), (), "Count", None),
		"Currency": (6, 2, (8, 0), (), "Currency", None),
		"InventoryUOM": (12, 2, (8, 0), (), "InventoryUOM", None),
		"IssueMethod": (11, 2, (3, 0), (), "IssueMethod", None),
		"ItemCode": (2, 2, (8, 0), (), "ItemCode", None),
		"ParentItem": (15, 2, (8, 0), (), "ParentItem", None),
		"Price": (5, 2, (5, 0), (), "Price", None),
		"PriceList": (16, 2, (3, 0), (), "PriceList", None),
		"Quantity": (3, 2, (5, 0), (), "Quantity", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (10, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"Warehouse": (4, 2, (8, 0), (), "Warehouse", None),
	}
	_prop_map_put_ = {
		"Comment": ((13, LCID, 4, 0),()),
		"Currency": ((6, LCID, 4, 0),()),
		"IssueMethod": ((11, LCID, 4, 0),()),
		"ItemCode": ((2, LCID, 4, 0),()),
		"ParentItem": ((15, LCID, 4, 0),()),
		"Price": ((5, LCID, 4, 0),()),
		"PriceList": ((16, LCID, 4, 0),()),
		"Quantity": ((3, LCID, 4, 0),()),
		"Warehouse": ((4, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(8, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IProductionOrders(DispatchBaseClass):
	'IProductionOrders Interface'
	CLSID = IID('{1C7C966F-B713-42BF-9A74-0B15A649E63D}')
	coclass_clsid = IID('{37C235F6-0465-4E85-80A0-776D4602B09B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsEntry=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lAbsEntry
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AbsoluteEntry": (12, 2, (3, 0), (), "AbsoluteEntry", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ClosingDate": (28, 2, (7, 0), (), "ClosingDate", None),
		"CompletedQuantity": (19, 2, (5, 0), (), "CompletedQuantity", None),
		"CreationDate": (35, 2, (7, 0), (), "CreationDate", None),
		"CustomerCode": (30, 2, (8, 0), (), "CustomerCode", None),
		"DocumentNumber": (13, 2, (3, 0), (), "DocumentNumber", None),
		"DueDate": (22, 2, (7, 0), (), "DueDate", None),
		"InventoryUOM": (32, 2, (8, 0), (), "InventoryUOM", None),
		"ItemNo": (15, 2, (8, 0), (), "ItemNo", None),
		"JournalRemarks": (33, 2, (8, 0), (), "JournalRemarks", None),
		# Method 'Lines' returns object of type 'IProductionOrders_Lines'
		"Lines": (36, 2, (9, 0), (), "Lines", '{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}'),
		"PlannedQuantity": (18, 2, (5, 0), (), "PlannedQuantity", None),
		"PostingDate": (21, 2, (7, 0), (), "PostingDate", None),
		"ProductionOrderOrigin": (25, 2, (3, 0), (), "ProductionOrderOrigin", None),
		"ProductionOrderOriginEntry": (23, 2, (3, 0), (), "ProductionOrderOriginEntry", None),
		"ProductionOrderOriginNumber": (24, 2, (3, 0), (), "ProductionOrderOriginNumber", None),
		"ProductionOrderStatus": (16, 2, (3, 0), (), "ProductionOrderStatus", None),
		"ProductionOrderType": (17, 2, (3, 0), (), "ProductionOrderType", None),
		"RejectedQuantity": (20, 2, (5, 0), (), "RejectedQuantity", None),
		"ReleaseDate": (29, 2, (7, 0), (), "ReleaseDate", None),
		"Remarks": (27, 2, (8, 0), (), "Remarks", None),
		"Series": (14, 2, (3, 0), (), "Series", None),
		"TransactionNumber": (34, 2, (3, 0), (), "TransactionNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (26, 2, (3, 0), (), "UserSignature", None),
		"Warehouse": (31, 2, (8, 0), (), "Warehouse", None),
	}
	_prop_map_put_ = {
		"CustomerCode": ((30, LCID, 4, 0),()),
		"DueDate": ((22, LCID, 4, 0),()),
		"ItemNo": ((15, LCID, 4, 0),()),
		"JournalRemarks": ((33, LCID, 4, 0),()),
		"PlannedQuantity": ((18, LCID, 4, 0),()),
		"PostingDate": ((21, LCID, 4, 0),()),
		"ProductionOrderOrigin": ((25, LCID, 4, 0),()),
		"ProductionOrderOriginEntry": ((23, LCID, 4, 0),()),
		"ProductionOrderStatus": ((16, LCID, 4, 0),()),
		"ProductionOrderType": ((17, LCID, 4, 0),()),
		"Remarks": ((27, LCID, 4, 0),()),
		"Series": ((14, LCID, 4, 0),()),
		"Warehouse": ((31, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProductionOrders_Lines(DispatchBaseClass):
	'IProductionOrders_Lines Interface'
	CLSID = IID('{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}')
	coclass_clsid = IID('{9AC69118-AA6E-44B4-ACDC-176426BCBA1C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseQuantity": (8, 2, (5, 0), (), "BaseQuantity", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"DocumentAbsoluteEntry": (5, 2, (3, 0), (), "DocumentAbsoluteEntry", None),
		"IssuedQuantity": (10, 2, (5, 0), (), "IssuedQuantity", None),
		"ItemNo": (7, 2, (8, 0), (), "ItemNo", None),
		"LineNumber": (6, 2, (3, 0), (), "LineNumber", None),
		"PlannedQuantity": (9, 2, (5, 0), (), "PlannedQuantity", None),
		"ProductionOrderIssueType": (11, 2, (3, 0), (), "ProductionOrderIssueType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VisualOrder": (13, 2, (3, 0), (), "VisualOrder", None),
		"Warehouse": (12, 2, (8, 0), (), "Warehouse", None),
	}
	_prop_map_put_ = {
		"BaseQuantity": ((8, LCID, 4, 0),()),
		"ItemNo": ((7, LCID, 4, 0),()),
		"ProductionOrderIssueType": ((11, LCID, 4, 0),()),
		"Warehouse": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IQueryCategories(DispatchBaseClass):
	'IQueryCategories Interface'
	CLSID = IID('{78A768C9-EDA6-4798-AFC3-114DEC3DE8E5}')
	coclass_clsid = IID('{D89C1B1F-B7A1-4669-B80D-E3A041767ABE}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (1, 2, (3, 0), (), "Code", None),
		"Name": (2, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IQueue(DispatchBaseClass):
	'IQueue Interface'
	CLSID = IID('{8C5510F0-AA36-4CBD-A5AC-7DCF29EE0249}')
	coclass_clsid = IID('{EA2133A7-F8D4-4444-834F-1129CE2081EB}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(14, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrQueueID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((8, 1),),bstrQueueID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(10, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (12, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Description": (2, 2, (8, 0), (), "Description", None),
		"Inactive": (3, 2, (3, 0), (), "Inactive", None),
		"QueueEmail": (5, 2, (8, 0), (), "QueueEmail", None),
		"QueueID": (1, 2, (8, 0), (), "QueueID", None),
		"QueueManager": (4, 2, (3, 0), (), "QueueManager", None),
		# Method 'QueueMembers' returns object of type 'IQueueMembers'
		"QueueMembers": (58, 2, (9, 0), (), "QueueMembers", '{A6D332DA-630B-44C7-AA91-69F2C1A2501D}'),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (11, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Description": ((2, LCID, 4, 0),()),
		"Inactive": ((3, LCID, 4, 0),()),
		"QueueEmail": ((5, LCID, 4, 0),()),
		"QueueID": ((1, LCID, 4, 0),()),
		"QueueManager": ((4, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IQueueMembers(DispatchBaseClass):
	'IQueueMembers Interface'
	CLSID = IID('{A6D332DA-630B-44C7-AA91-69F2C1A2501D}')
	coclass_clsid = IID('{79148B90-9790-418A-B904-DA8C72CCCDDF}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (4, 2, (3, 0), (), "Count", None),
		"MemberUserID": (2, 2, (3, 0), (), "MemberUserID", None),
		"QueueID": (1, 2, (8, 0), (), "QueueID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (3, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"MemberUserID": ((2, LCID, 4, 0),()),
		"QueueID": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(4, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IRecipients(DispatchBaseClass):
	'IRecipients Interface'
	CLSID = IID('{F408B086-B6E4-4EE0-9B95-710C117E56F0}')
	coclass_clsid = IID('{921DBA91-7B93-4AEB-859C-C4452CA0F739}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"CellularNumber": (9, 2, (8, 0), (), "CellularNumber", None),
		"Count": (1, 2, (3, 0), (), "Count", None),
		"EmailAddress": (10, 2, (8, 0), (), "EmailAddress", None),
		"FaxNumber": (11, 2, (8, 0), (), "FaxNumber", None),
		"NameTo": (5, 2, (8, 0), (), "NameTo", None),
		"SendEmail": (6, 2, (3, 0), (), "SendEmail", None),
		"SendFax": (8, 2, (3, 0), (), "SendFax", None),
		"SendInternal": (13, 2, (3, 0), (), "SendInternal", None),
		"SendSMS": (7, 2, (3, 0), (), "SendSMS", None),
		"UserCode": (4, 2, (8, 0), (), "UserCode", None),
		"UserType": (12, 2, (3, 0), (), "UserType", None),
	}
	_prop_map_put_ = {
		"CellularNumber": ((9, LCID, 4, 0),()),
		"EmailAddress": ((10, LCID, 4, 0),()),
		"FaxNumber": ((11, LCID, 4, 0),()),
		"NameTo": ((5, LCID, 4, 0),()),
		"SendEmail": ((6, LCID, 4, 0),()),
		"SendFax": ((8, LCID, 4, 0),()),
		"SendInternal": ((13, LCID, 4, 0),()),
		"SendSMS": ((7, LCID, 4, 0),()),
		"UserCode": ((4, LCID, 4, 0),()),
		"UserType": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IRecordset(DispatchBaseClass):
	'IRecordset Interface'
	CLSID = IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
	coclass_clsid = IID('{11FA87EF-9F44-4528-AE1D-DAF92AEA3545}')

	def DoQuery(self, QueryStr=defaultNamedNotOptArg):
		'Runs an SQL query'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((8, 0),),QueryStr
			)

	def GetAsXML(self):
		'Get records as XML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(13, LCID, 1, (8, 0), (),)

	def MoveFirst(self):
		'method MoveFirst'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), (),)

	def MoveLast(self):
		'method MoveLast'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), (),)

	def MoveNext(self):
		'Move to the next record'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def MovePrevious(self):
		'Move to the previous record'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		'Save records as XML document'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save records as XML document'
		return self._ApplyTypes_(9, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		"BoF": (5, 2, (11, 0), (), "BoF", None),
		# Method 'Command' returns object of type 'ICommand'
		"Command": (12, 2, (9, 0), (), "Command", '{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}'),
		"EoF": (6, 2, (11, 0), (), "EoF", None),
		# Method 'Fields' returns object of type 'IFields'
		"Fields": (0, 2, (9, 0), (), "Fields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
		"RecordCount": (8, 2, (3, 0), (), "RecordCount", None),
	}
	_prop_map_put_ = {
	}
	# Default property for this class is 'Fields'
	def __call__(self):
		return self._ApplyTypes_(*(0, 2, (9, 0), (), "Fields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IRelationships(DispatchBaseClass):
	'IRelationships Interface'
	CLSID = IID('{BBB45A32-F446-4ED3-915B-C811BBA6C2C7}')
	coclass_clsid = IID('{097DDC08-E989-4426-87DB-9EFAD0FF64C3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"RelationshipCode": (2, 2, (3, 0), (), "RelationshipCode", None),
		"RelationshipDescription": (1, 2, (8, 0), (), "RelationshipDescription", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"RelationshipDescription": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISBObob(DispatchBaseClass):
	'ISBObob Interface'
	CLSID = IID('{268D6CC3-E244-4AD7-B009-16C8ED7F710A}')
	coclass_clsid = IID('{A740D0B2-649F-40A6-AF5E-77FF340AEEFD}')

	def ConvertEnumValueToValidValue(self, enumName=defaultNamedNotOptArg, enumValue=defaultNamedNotOptArg):
		'method ConvertEnumValueToValidValue'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(18, LCID, 1, (8, 0), ((8, 1), (3, 1)),enumName
			, enumValue)

	def ConvertValidValueToEnumValue(self, enumName=defaultNamedNotOptArg, ValidValue=defaultNamedNotOptArg):
		'method ConvertValidValueToEnumValue'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (3, 0), ((8, 1), (8, 1)),enumName
			, ValidValue)

	# Result is of type IRecordset
	def Format_DateToString(self, inDate=defaultNamedNotOptArg):
		'method Format_DateToString'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((7, 1),),inDate
			)
		if ret is not None:
			ret = Dispatch(ret, u'Format_DateToString', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def Format_MoneyToString(self, inMoney=defaultNamedNotOptArg, inPrecision=defaultNamedNotOptArg):
		'method Format_MoneyToString'
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), ((5, 1), (3, 1)),inMoney
			, inPrecision)
		if ret is not None:
			ret = Dispatch(ret, u'Format_MoneyToString', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def Format_StringToDate(self, inStr=defaultNamedNotOptArg):
		'method Format_StringToDate'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((8, 1),),inStr
			)
		if ret is not None:
			ret = Dispatch(ret, u'Format_StringToDate', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetAccountSegmentsByCode(self, AccountCode=defaultNamedNotOptArg, AddSeperator=defaultNamedNotOptArg):
		'method GetAccountSegmentsByCode'
		ret = self._oleobj_.InvokeTypes(21, LCID, 1, (9, 0), ((8, 1), (11, 1)),AccountCode
			, AddSeperator)
		if ret is not None:
			ret = Dispatch(ret, u'GetAccountSegmentsByCode', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetBPList(self, CardType=defaultNamedNotOptArg):
		'method GetBPList'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 0),),CardType
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBPList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetContactEmployees(self, CardCode=defaultNamedNotOptArg):
		'method GetContactEmployees'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((8, 1),),CardCode
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetContactEmployees', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetCurrencyRate(self, Currency=defaultNamedNotOptArg, Date=defaultNamedNotOptArg):
		'method GetCurrencyRate'
		ret = self._oleobj_.InvokeTypes(5, LCID, 1, (9, 0), ((8, 1), (7, 1)),Currency
			, Date)
		if ret is not None:
			ret = Dispatch(ret, u'GetCurrencyRate', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetDueDate(self, CardCode=defaultNamedNotOptArg, refDate=defaultNamedNotOptArg):
		'method GetDueDate'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1), (7, 1)),CardCode
			, refDate)
		if ret is not None:
			ret = Dispatch(ret, u'GetDueDate', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetFieldValidValues(self, TableName=defaultNamedNotOptArg, FieldName=defaultNamedNotOptArg):
		'method GetFieldValidValues'
		ret = self._oleobj_.InvokeTypes(23, LCID, 1, (9, 0), ((8, 1), (8, 1)),TableName
			, FieldName)
		if ret is not None:
			ret = Dispatch(ret, u'GetFieldValidValues', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetIndexRate(self, Index=defaultNamedNotOptArg, Date=defaultNamedNotOptArg):
		'method GetIndexRate'
		ret = self._oleobj_.InvokeTypes(6, LCID, 1, (9, 0), ((8, 1), (7, 1)),Index
			, Date)
		if ret is not None:
			ret = Dispatch(ret, u'GetIndexRate', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetItemList(self):
		'method GetItemList'
		ret = self._oleobj_.InvokeTypes(8, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetItemList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetItemPrice(self, CardCode=defaultNamedNotOptArg, ItemCode=defaultNamedNotOptArg, amount=defaultNamedNotOptArg, Date=defaultNamedNotOptArg):
		'method GetItemPrice'
		ret = self._oleobj_.InvokeTypes(7, LCID, 1, (9, 0), ((8, 1), (8, 1), (5, 1), (7, 1)),CardCode
			, ItemCode, amount, Date)
		if ret is not None:
			ret = Dispatch(ret, u'GetItemPrice', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetLocalCurrency(self):
		'method GetLocalCurrency'
		ret = self._oleobj_.InvokeTypes(4, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetLocalCurrency', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetObjectKeyBySingleValue(self, ObjNum=defaultNamedNotOptArg, PropName=defaultNamedNotOptArg, Value=defaultNamedNotOptArg, Condition=defaultNamedNotOptArg):
		'method GetObjectKeyBySingleValue'
		ret = self._oleobj_.InvokeTypes(17, LCID, 1, (9, 0), ((3, 1), (8, 1), (8, 1), (3, 1)),ObjNum
			, PropName, Value, Condition)
		if ret is not None:
			ret = Dispatch(ret, u'GetObjectKeyBySingleValue', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetObjectPermission(self, Object=defaultNamedNotOptArg):
		'method GetObjectPermission'
		ret = self._oleobj_.InvokeTypes(24, LCID, 1, (9, 0), ((3, 1),),Object
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetObjectPermission', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetSystemCurrency(self):
		'method GetSystemCurrency'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetSystemCurrency', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetSystemPermission(self, UserName=defaultNamedNotOptArg, PermissionID=defaultNamedNotOptArg):
		'method GetSystemPermission'
		ret = self._oleobj_.InvokeTypes(26, LCID, 1, (9, 0), ((8, 1), (8, 1)),UserName
			, PermissionID)
		if ret is not None:
			ret = Dispatch(ret, u'GetSystemPermission', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetTableFieldList(self, TableName=defaultNamedNotOptArg):
		'method GetTableFieldList'
		ret = self._oleobj_.InvokeTypes(22, LCID, 1, (9, 0), ((8, 1),),TableName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetTableFieldList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetTableList(self):
		'method GetTableList'
		ret = self._oleobj_.InvokeTypes(25, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetTableList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetUserList(self):
		'method GetUserList'
		ret = self._oleobj_.InvokeTypes(9, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetUserList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	def GetValidValueDescription(self, ObjNum=defaultNamedNotOptArg, ObjectName=defaultNamedNotOptArg, PropertyName=defaultNamedNotOptArg, enumValue=defaultNamedNotOptArg):
		'method GetValidValueDescription'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(20, LCID, 1, (8, 0), ((3, 1), (8, 1), (8, 1), (3, 1)),ObjNum
			, ObjectName, PropertyName, enumValue)

	# Result is of type IRecordset
	def GetWareHouseList(self):
		'method GetWareHouseList'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetWareHouseList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	def SetCurrencyRate(self, Currency=defaultNamedNotOptArg, Date=defaultNamedNotOptArg, Value=defaultNamedNotOptArg, Update=False):
		'method SetCurrencyRate'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1), (7, 1), (5, 1), (11, 49)),Currency
			, Date, Value, Update)

	def SetSystemPermission(self, UserName=defaultNamedNotOptArg, PermissionID=defaultNamedNotOptArg, Permission=defaultNamedNotOptArg):
		'method SetSystemPermission'
		return self._oleobj_.InvokeTypes(27, LCID, 1, (24, 0), ((8, 1), (8, 1), (3, 1)),UserName
			, PermissionID, Permission)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesForecast(DispatchBaseClass):
	'ISalesForecast Interface'
	CLSID = IID('{0D31ADD3-85B1-40F1-979F-8612E10B8DD8}')
	coclass_clsid = IID('{3E6CC39D-A5A5-43E7-856E-4A1D4D97A77D}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(60, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(61, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(9, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (11, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ForecastCode": (3, 2, (8, 0), (), "ForecastCode", None),
		"ForecastEndDate": (2, 2, (7, 0), (), "ForecastEndDate", None),
		"ForecastName": (4, 2, (8, 0), (), "ForecastName", None),
		"ForecastStartDate": (1, 2, (7, 0), (), "ForecastStartDate", None),
		# Method 'Lines' returns object of type 'ISalesForecast_Lines'
		"Lines": (58, 2, (9, 0), (), "Lines", '{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}'),
		"Numerator": (59, 2, (3, 0), (), "Numerator", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (10, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ForecastCode": ((3, LCID, 4, 0),()),
		"ForecastEndDate": ((2, LCID, 4, 0),()),
		"ForecastName": ((4, LCID, 4, 0),()),
		"ForecastStartDate": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesForecast_Lines(DispatchBaseClass):
	'ISalesForecast_Lines Interface'
	CLSID = IID('{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}')
	coclass_clsid = IID('{8B560D21-5616-4D85-ACA9-BC8145B30A73}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"ForecastedDay": (2, 2, (7, 0), (), "ForecastedDay", None),
		"ItemNo": (3, 2, (8, 0), (), "ItemNo", None),
		"Quantity": (1, 2, (5, 0), (), "Quantity", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ForecastedDay": ((2, LCID, 4, 0),()),
		"ItemNo": ((3, LCID, 4, 0),()),
		"Quantity": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunities(DispatchBaseClass):
	'ISalesOpportunities Interface'
	CLSID = IID('{4F06C847-96F8-4421-B1C7-2FA41FCB0CFF}')
	coclass_clsid = IID('{E7843EA1-A67D-4C9A-B61D-EABDE49D4692}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(59, LCID, 1, (8, 0), (),)

	def GetByKey(self, OpprId=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),OpprId
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(60, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"BPChanelCode": (55, 2, (8, 0), (), "BPChanelCode", None),
		"BPChanelName": (47, 2, (8, 0), (), "BPChanelName", None),
		"BPChannelContact": (54, 2, (3, 0), (), "BPChannelContact", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (10, 2, (8, 0), (), "CardCode", None),
		"ClosingDate": (53, 2, (7, 0), (), "ClosingDate", None),
		"ClosingGrossProfitLocal": (34, 2, (5, 0), (), "ClosingGrossProfitLocal", None),
		"ClosingGrossProfitSystem": (35, 2, (5, 0), (), "ClosingGrossProfitSystem", None),
		"ClosingPercentage": (36, 2, (5, 0), (), "ClosingPercentage", None),
		"ClosingType": (56, 2, (3, 0), (), "ClosingType", None),
		# Method 'Competition' returns object of type 'ISalesOpportunitiesCompetition'
		"Competition": (39, 2, (9, 0), (), "Competition", '{19E6540E-4E64-48C1-9525-29D5710D1FFD}'),
		"ContactPerson": (12, 2, (3, 0), (), "ContactPerson", None),
		"CurrentStageNo": (37, 2, (5, 0), (), "CurrentStageNo", None),
		"CustomerName": (49, 2, (8, 0), (), "CustomerName", None),
		"DataOwnershipfield": (44, 2, (3, 0), (), "DataOwnershipfield", None),
		"DocumentCheckbox": (50, 2, (8, 0), (), "DocumentCheckbox", None),
		"GrossProfit": (25, 2, (5, 0), (), "GrossProfit", None),
		"GrossProfitTotalLocal": (26, 2, (5, 0), (), "GrossProfitTotalLocal", None),
		"GrossProfitTotalSystem": (27, 2, (5, 0), (), "GrossProfitTotalSystem", None),
		"Industry": (42, 2, (3, 0), (), "Industry", None),
		"InterestField1": (14, 2, (3, 0), (), "InterestField1", None),
		"InterestField2": (15, 2, (3, 0), (), "InterestField2", None),
		"InterestField3": (16, 2, (3, 0), (), "InterestField3", None),
		"InterestLevel": (17, 2, (3, 0), (), "InterestLevel", None),
		# Method 'Interests' returns object of type 'ISalesOpportunitiesInterests'
		"Interests": (57, 2, (9, 0), (), "Interests", '{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}'),
		# Method 'Lines' returns object of type 'ISalesOpportunitiesLines'
		"Lines": (38, 2, (9, 0), (), "Lines", '{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}'),
		"LinkedDocumentNumber": (51, 2, (8, 0), (), "LinkedDocumentNumber", None),
		"LinkedDocumentType": (43, 2, (3, 0), (), "LinkedDocumentType", None),
		"MaxLocalTotal": (21, 2, (5, 0), (), "MaxLocalTotal", None),
		"MaxSystemTotal": (22, 2, (5, 0), (), "MaxSystemTotal", None),
		"OpportunityName": (41, 2, (8, 0), (), "OpportunityName", None),
		# Method 'Partners' returns object of type 'ISalesOpportunitiesPartners'
		"Partners": (40, 2, (9, 0), (), "Partners", '{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}'),
		"PredictedClosingDate": (20, 2, (7, 0), (), "PredictedClosingDate", None),
		"ProjectCode": (46, 2, (8, 0), (), "ProjectCode", None),
		"ReasonForClosing": (31, 2, (3, 0), (), "ReasonForClosing", None),
		# Method 'Reasons' returns object of type 'ISalesOpportunitiesReasons'
		"Reasons": (58, 2, (9, 0), (), "Reasons", '{D4A7CE6F-B909-4273-8499-C210F94ED2D1}'),
		"Remarks": (28, 2, (8, 0), (), "Remarks", None),
		"SalesPerson": (11, 2, (3, 0), (), "SalesPerson", None),
		"SequentialNo": (9, 2, (3, 0), (), "SequentialNo", None),
		"Source": (13, 2, (3, 0), (), "Source", None),
		"StartDate": (18, 2, (7, 0), (), "StartDate", None),
		"Status": (29, 2, (3, 0), (), "Status", None),
		"StatusRemarks": (45, 2, (8, 0), (), "StatusRemarks", None),
		"Territory": (52, 2, (3, 0), (), "Territory", None),
		"TotalAmounSystem": (33, 2, (5, 0), (), "TotalAmounSystem", None),
		"TotalAmountLocal": (32, 2, (5, 0), (), "TotalAmountLocal", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (48, 2, (3, 0), (), "UserSignature", None),
		"WeightedSumLC": (23, 2, (5, 0), (), "WeightedSumLC", None),
		"WeightedSumSC": (24, 2, (5, 0), (), "WeightedSumSC", None),
	}
	_prop_map_put_ = {
		"BPChanelCode": ((55, LCID, 4, 0),()),
		"BPChanelName": ((47, LCID, 4, 0),()),
		"BPChannelContact": ((54, LCID, 4, 0),()),
		"CardCode": ((10, LCID, 4, 0),()),
		"ClosingType": ((56, LCID, 4, 0),()),
		"ContactPerson": ((12, LCID, 4, 0),()),
		"CustomerName": ((49, LCID, 4, 0),()),
		"DataOwnershipfield": ((44, LCID, 4, 0),()),
		"GrossProfit": ((25, LCID, 4, 0),()),
		"GrossProfitTotalLocal": ((26, LCID, 4, 0),()),
		"Industry": ((42, LCID, 4, 0),()),
		"InterestField1": ((14, LCID, 4, 0),()),
		"InterestField2": ((15, LCID, 4, 0),()),
		"InterestField3": ((16, LCID, 4, 0),()),
		"InterestLevel": ((17, LCID, 4, 0),()),
		"OpportunityName": ((41, LCID, 4, 0),()),
		"PredictedClosingDate": ((20, LCID, 4, 0),()),
		"ProjectCode": ((46, LCID, 4, 0),()),
		"ReasonForClosing": ((31, LCID, 4, 0),()),
		"Remarks": ((28, LCID, 4, 0),()),
		"SalesPerson": ((11, LCID, 4, 0),()),
		"Source": ((13, LCID, 4, 0),()),
		"StartDate": ((18, LCID, 4, 0),()),
		"Status": ((29, LCID, 4, 0),()),
		"StatusRemarks": ((45, LCID, 4, 0),()),
		"Territory": ((52, LCID, 4, 0),()),
		"TotalAmountLocal": ((32, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunitiesCompetition(DispatchBaseClass):
	'ISalesOpportunitiesCompetition Interface'
	CLSID = IID('{19E6540E-4E64-48C1-9525-29D5710D1FFD}')
	coclass_clsid = IID('{C27CB0AA-2304-4D4E-B292-8ED9651F34A3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Competition": (6, 2, (3, 0), (), "Competition", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Details": (7, 2, (8, 0), (), "Details", None),
		"RowNo": (5, 2, (3, 0), (), "RowNo", None),
		"SequenceNo": (8, 2, (3, 0), (), "SequenceNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WonOrLost": (9, 2, (8, 0), (), "WonOrLost", None),
	}
	_prop_map_put_ = {
		"Competition": ((6, LCID, 4, 0),()),
		"Details": ((7, LCID, 4, 0),()),
		"WonOrLost": ((9, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunitiesInterests(DispatchBaseClass):
	'ISalesOpportunitiesInterests Interface'
	CLSID = IID('{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}')
	coclass_clsid = IID('{D48A6D0F-F063-4ED4-B1E1-59B6998EE91A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (6, 2, (3, 0), (), "Count", None),
		"InterestId": (4, 2, (3, 0), (), "InterestId", None),
		"PrimaryInterest": (3, 2, (3, 0), (), "PrimaryInterest", None),
		"RowNo": (1, 2, (3, 0), (), "RowNo", None),
		"SequenceNo": (2, 2, (3, 0), (), "SequenceNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"InterestId": ((4, LCID, 4, 0),()),
		"PrimaryInterest": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(6, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunitiesLines(DispatchBaseClass):
	'ISalesOpportunitiesLines Interface'
	CLSID = IID('{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}')
	coclass_clsid = IID('{B9FED360-AD27-45E1-AB8A-714FB217B022}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPChanelCode": (24, 2, (8, 0), (), "BPChanelCode", None),
		"BPChanelName": (23, 2, (8, 0), (), "BPChanelName", None),
		"BPChannelContact": (27, 2, (3, 0), (), "BPChannelContact", None),
		"ClosingDate": (9, 2, (7, 0), (), "ClosingDate", None),
		"Contact": (15, 2, (3, 0), (), "Contact", None),
		"ContactPerson": (22, 2, (3, 0), (), "ContactPerson", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"DataOwnershipfield": (26, 2, (3, 0), (), "DataOwnershipfield", None),
		"DocumentCheckbox": (21, 2, (3, 0), (), "DocumentCheckbox", None),
		"DocumentNumber": (19, 2, (3, 0), (), "DocumentNumber", None),
		"DocumentType": (20, 2, (3, 0), (), "DocumentType", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"MaxLocalTotal": (12, 2, (5, 0), (), "MaxLocalTotal", None),
		"MaxSystemTotal": (13, 2, (5, 0), (), "MaxSystemTotal", None),
		"PercentageRate": (11, 2, (5, 0), (), "PercentageRate", None),
		"Remarks": (14, 2, (8, 0), (), "Remarks", None),
		"SalesPerson": (6, 2, (3, 0), (), "SalesPerson", None),
		"SequenceNo": (25, 2, (3, 0), (), "SequenceNo", None),
		"StageKey": (10, 2, (3, 0), (), "StageKey", None),
		"StartDate": (8, 2, (7, 0), (), "StartDate", None),
		"Status": (16, 2, (3, 0), (), "Status", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WeightedAmountLocal": (17, 2, (5, 0), (), "WeightedAmountLocal", None),
		"WeightedAmountSystem": (18, 2, (5, 0), (), "WeightedAmountSystem", None),
	}
	_prop_map_put_ = {
		"BPChanelCode": ((24, LCID, 4, 0),()),
		"BPChanelName": ((23, LCID, 4, 0),()),
		"BPChannelContact": ((27, LCID, 4, 0),()),
		"ClosingDate": ((9, LCID, 4, 0),()),
		"ContactPerson": ((22, LCID, 4, 0),()),
		"DataOwnershipfield": ((26, LCID, 4, 0),()),
		"DocumentCheckbox": ((21, LCID, 4, 0),()),
		"DocumentNumber": ((19, LCID, 4, 0),()),
		"DocumentType": ((20, LCID, 4, 0),()),
		"MaxLocalTotal": ((12, LCID, 4, 0),()),
		"PercentageRate": ((11, LCID, 4, 0),()),
		"Remarks": ((14, LCID, 4, 0),()),
		"SalesPerson": ((6, LCID, 4, 0),()),
		"StageKey": ((10, LCID, 4, 0),()),
		"StartDate": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunitiesPartners(DispatchBaseClass):
	'ISalesOpportunitiesPartners Interface'
	CLSID = IID('{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}')
	coclass_clsid = IID('{0DA4D491-BDE7-4126-81E1-BCDA814B5332}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Details": (7, 2, (8, 0), (), "Details", None),
		"Partners": (6, 2, (3, 0), (), "Partners", None),
		"RelationshipCode": (8, 2, (3, 0), (), "RelationshipCode", None),
		"RowNo": (5, 2, (3, 0), (), "RowNo", None),
		"SequenceNo": (9, 2, (3, 0), (), "SequenceNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Details": ((7, LCID, 4, 0),()),
		"Partners": ((6, LCID, 4, 0),()),
		"RelationshipCode": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunitiesReasons(DispatchBaseClass):
	'ISalesOpportunitiesReasons Interface'
	CLSID = IID('{D4A7CE6F-B909-4273-8499-C210F94ED2D1}')
	coclass_clsid = IID('{C3B4DABB-A057-4D70-AE0C-7ABD7A4254B0}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"Reason": (3, 2, (3, 0), (), "Reason", None),
		"RowNo": (1, 2, (3, 0), (), "RowNo", None),
		"SequenceNo": (2, 2, (3, 0), (), "SequenceNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Reason": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesTaxAuthorities(DispatchBaseClass):
	'ISalesTaxAuthorities Interface'
	CLSID = IID('{0D446022-9A79-4535-9174-EEAE21DF924A}')
	coclass_clsid = IID('{7F146AF0-3304-4133-BC4F-48797C66B12F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(16, LCID, 1, (8, 0), (),)

	def GetByKey(self, Code=defaultNamedNotOptArg, Type=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (11, 0), ((8, 1), (3, 1)),Code
			, Type)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(17, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(14, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AOrPTaxAccount": (6, 2, (8, 0), (), "AOrPTaxAccount", None),
		"AOrRTaxAccount": (4, 2, (8, 0), (), "AOrRTaxAccount", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"DeferredTaxAccount": (10, 2, (8, 0), (), "DeferredTaxAccount", None),
		"Name": (9, 2, (8, 0), (), "Name", None),
		"NonDeductibleAccount": (8, 2, (8, 0), (), "NonDeductibleAccount", None),
		"NonDeductiblePrecent": (7, 2, (5, 0), (), "NonDeductiblePrecent", None),
		"Rate": (5, 2, (5, 0), (), "Rate", None),
		"Type": (3, 2, (3, 0), (), "Type", None),
		"UseTaxAccount": (1, 2, (8, 0), (), "UseTaxAccount", None),
		"UserSignature": (2, 2, (3, 0), (), "UserSignature", None),
	}
	_prop_map_put_ = {
		"AOrPTaxAccount": ((6, LCID, 4, 0),()),
		"AOrRTaxAccount": ((4, LCID, 4, 0),()),
		"Code": ((11, LCID, 4, 0),()),
		"DeferredTaxAccount": ((10, LCID, 4, 0),()),
		"Name": ((9, LCID, 4, 0),()),
		"NonDeductibleAccount": ((8, LCID, 4, 0),()),
		"NonDeductiblePrecent": ((7, LCID, 4, 0),()),
		"Rate": ((5, LCID, 4, 0),()),
		"Type": ((3, LCID, 4, 0),()),
		"UseTaxAccount": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesTaxAuthoritiesTypes(DispatchBaseClass):
	'ISalesTaxAuthoritiesTypes Interface'
	CLSID = IID('{450A7F0E-0D42-4720-907E-C672EE2F6382}')
	coclass_clsid = IID('{717F1B41-306E-4695-8F4E-7DACA54EA87B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(9, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),Key
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Name": (2, 2, (8, 0), (), "Name", None),
		"Numerator": (4, 2, (3, 0), (), "Numerator", None),
		"UserSignature": (1, 2, (3, 0), (), "UserSignature", None),
		"VAT": (3, 2, (3, 0), (), "VAT", None),
	}
	_prop_map_put_ = {
		"Name": ((2, LCID, 4, 0),()),
		"VAT": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesTaxCodes(DispatchBaseClass):
	'ISalesTaxCodes Interface'
	CLSID = IID('{A07F5790-711E-49FC-9843-935F7C8CDB85}')
	coclass_clsid = IID('{97C9DB0B-4DBF-4EEA-98A9-04EE1F5B031E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(13, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (11, 0), ((8, 1),),Key
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(11, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Code": (7, 2, (8, 0), (), "Code", None),
		"Freight": (6, 2, (3, 0), (), "Freight", None),
		# Method 'Lines' returns object of type 'ISalesTaxCodes_Lines'
		"Lines": (8, 2, (9, 0), (), "Lines", '{98DF1BF3-2F28-46C7-8003-FB8D11276237}'),
		"Name": (5, 2, (8, 0), (), "Name", None),
		"Rate": (4, 2, (5, 0), (), "Rate", None),
		"UserSignature": (3, 2, (3, 0), (), "UserSignature", None),
		"ValidForAP": (2, 2, (3, 0), (), "ValidForAP", None),
		"ValidForAR": (1, 2, (3, 0), (), "ValidForAR", None),
	}
	_prop_map_put_ = {
		"Code": ((7, LCID, 4, 0),()),
		"Freight": ((6, LCID, 4, 0),()),
		"Name": ((5, LCID, 4, 0),()),
		"ValidForAP": ((2, LCID, 4, 0),()),
		"ValidForAR": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesTaxCodes_Lines(DispatchBaseClass):
	'ISalesTaxCodes_Lines Interface'
	CLSID = IID('{98DF1BF3-2F28-46C7-8003-FB8D11276237}')
	coclass_clsid = IID('{4385C84B-AE8C-424F-9071-546FF9E1D503}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (9, 2, (3, 0), (), "Count", None),
		"EffectiveRate": (7, 2, (5, 0), (), "EffectiveRate", None),
		"RowNumber": (6, 2, (3, 0), (), "RowNumber", None),
		"STACode": (5, 2, (8, 0), (), "STACode", None),
		"STATaxOnTaxType": (1, 2, (3, 0), (), "STATaxOnTaxType", None),
		"STATaxonTaxCode": (2, 2, (8, 0), (), "STATaxonTaxCode", None),
		"STAType": (4, 2, (3, 0), (), "STAType", None),
		"STCCode": (3, 2, (8, 0), (), "STCCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"STACode": ((5, LCID, 4, 0),()),
		"STATaxOnTaxType": ((1, LCID, 4, 0),()),
		"STATaxonTaxCode": ((2, LCID, 4, 0),()),
		"STAType": ((4, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(9, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISerialNumbers(DispatchBaseClass):
	'ISerialNumbers Interface'
	CLSID = IID('{93E5E52B-181E-46B8-96CB-1C066AC04DCA}')
	coclass_clsid = IID('{6BA3F221-1146-4650-AE35-03C139F04C02}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseLineNumber": (15, 2, (3, 0), (), "BaseLineNumber", None),
		"BatchID": (13, 2, (8, 0), (), "BatchID", None),
		"Count": (1, 2, (3, 0), (), "Count", None),
		"ExpiryDate": (6, 2, (7, 0), (), "ExpiryDate", None),
		"InternalSerialNumber": (5, 2, (8, 0), (), "InternalSerialNumber", None),
		"Location": (11, 2, (8, 0), (), "Location", None),
		"ManufactureDate": (7, 2, (7, 0), (), "ManufactureDate", None),
		"ManufacturerSerialNumber": (4, 2, (8, 0), (), "ManufacturerSerialNumber", None),
		"Notes": (12, 2, (8, 0), (), "Notes", None),
		"ReceptionDate": (8, 2, (7, 0), (), "ReceptionDate", None),
		"SystemSerialNumber": (14, 2, (3, 0), (), "SystemSerialNumber", None),
		"WarrantyEnd": (10, 2, (7, 0), (), "WarrantyEnd", None),
		"WarrantyStart": (9, 2, (7, 0), (), "WarrantyStart", None),
	}
	_prop_map_put_ = {
		"BaseLineNumber": ((15, LCID, 4, 0),()),
		"BatchID": ((13, LCID, 4, 0),()),
		"ExpiryDate": ((6, LCID, 4, 0),()),
		"InternalSerialNumber": ((5, LCID, 4, 0),()),
		"Location": ((11, LCID, 4, 0),()),
		"ManufactureDate": ((7, LCID, 4, 0),()),
		"ManufacturerSerialNumber": ((4, LCID, 4, 0),()),
		"Notes": ((12, LCID, 4, 0),()),
		"ReceptionDate": ((8, LCID, 4, 0),()),
		"SystemSerialNumber": ((14, LCID, 4, 0),()),
		"WarrantyEnd": ((10, LCID, 4, 0),()),
		"WarrantyStart": ((9, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallActivities(DispatchBaseClass):
	'IServiceCallActivities Interface'
	CLSID = IID('{0207412D-F955-46BA-AE96-E749573B4106}')
	coclass_clsid = IID('{0ED9BFD6-A5ED-40D2-8645-BE4ED8AC9CE5}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ActivityCode": (6, 2, (3, 0), (), "ActivityCode", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ActivityCode": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallInventoryExpenses(DispatchBaseClass):
	'IServiceCallInventoryExpenses Interface'
	CLSID = IID('{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}')
	coclass_clsid = IID('{692B8669-26B5-4D4F-A768-F92576E3EF85}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"DocEntry": (11, 2, (3, 0), (), "DocEntry", None),
		"DocumentNumber": (7, 2, (3, 0), (), "DocumentNumber", None),
		"DocumentPostingDate": (9, 2, (7, 0), (), "DocumentPostingDate", None),
		"DocumentType": (8, 2, (3, 0), (), "DocumentType", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"PartType": (6, 2, (3, 0), (), "PartType", None),
		"StockTransferDirection": (10, 2, (3, 0), (), "StockTransferDirection", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"DocEntry": ((11, LCID, 4, 0),()),
		"DocumentNumber": ((7, LCID, 4, 0),()),
		"DocumentType": ((8, LCID, 4, 0),()),
		"StockTransferDirection": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallSolutions(DispatchBaseClass):
	'IServiceCallSolutions Interface'
	CLSID = IID('{FA8FD318-6971-4E8B-B6E9-959A938455C6}')
	coclass_clsid = IID('{71ECA915-CB27-41B1-9E9F-DF819F1C52D6}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"SolutionID": (6, 2, (3, 0), (), "SolutionID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"SolutionID": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCalls(DispatchBaseClass):
	'IServiceCalls Interface'
	CLSID = IID('{A93CD1FA-F12F-47B0-8FAB-859692B8A653}')
	coclass_clsid = IID('{41501B90-66B9-49BC-920E-EAEF90F119B2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(57, LCID, 1, (8, 0), (),)

	def GetByKey(self, ServiceCallID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),ServiceCallID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(58, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Activities' returns object of type 'IServiceCallActivities'
		"Activities": (35, 2, (9, 0), (), "Activities", '{0207412D-F955-46BA-AE96-E749573B4106}'),
		"AssignedDate": (50, 2, (7, 0), (), "AssignedDate", None),
		"AssignedTime": (55, 2, (3, 0), (), "AssignedTime", None),
		"AssigneeCode": (30, 2, (3, 0), (), "AssigneeCode", None),
		"BelongsToAQueue": (43, 2, (3, 0), (), "BelongsToAQueue", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CallType": (28, 2, (3, 0), (), "CallType", None),
		"ClosingDate": (56, 2, (7, 0), (), "ClosingDate", None),
		"ClosingTime": (49, 2, (3, 0), (), "ClosingTime", None),
		"ContactCode": (13, 2, (3, 0), (), "ContactCode", None),
		"ContractEndDate": (17, 2, (7, 0), (), "ContractEndDate", None),
		"ContractID": (16, 2, (3, 0), (), "ContractID", None),
		"CreationDate": (38, 2, (7, 0), (), "CreationDate", None),
		"CreationTime": (39, 2, (7, 0), (), "CreationTime", None),
		"CustomerCode": (11, 2, (8, 0), (), "CustomerCode", None),
		"CustomerName": (12, 2, (8, 0), (), "CustomerName", None),
		"Description": (31, 2, (8, 0), (), "Description", None),
		"EntitledforService": (53, 2, (3, 0), (), "EntitledforService", None),
		# Method 'Expenses' returns object of type 'IServiceCallInventoryExpenses'
		"Expenses": (36, 2, (9, 0), (), "Expenses", '{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}'),
		"InternalSerialNum": (15, 2, (8, 0), (), "InternalSerialNum", None),
		"ItemCode": (23, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (24, 2, (8, 0), (), "ItemDescription", None),
		"ItemGroupCode": (25, 2, (3, 0), (), "ItemGroupCode", None),
		"ManufacturerSerialNum": (14, 2, (8, 0), (), "ManufacturerSerialNum", None),
		"Origin": (22, 2, (3, 0), (), "Origin", None),
		"Priority": (27, 2, (3, 0), (), "Priority", None),
		"ProblemType": (29, 2, (3, 0), (), "ProblemType", None),
		"Queue": (51, 2, (8, 0), (), "Queue", None),
		"Resolution": (34, 2, (8, 0), (), "Resolution", None),
		"ResolutionDate": (18, 2, (7, 0), (), "ResolutionDate", None),
		"ResolutionOnDate": (46, 2, (7, 0), (), "ResolutionOnDate", None),
		"ResolutionOnTime": (54, 2, (3, 0), (), "ResolutionOnTime", None),
		"ResolutionTime": (19, 2, (7, 0), (), "ResolutionTime", None),
		"Responder": (41, 2, (3, 0), (), "Responder", None),
		"ResponseAssignee": (52, 2, (3, 0), (), "ResponseAssignee", None),
		"ResponseByDate": (45, 2, (7, 0), (), "ResponseByDate", None),
		"ResponseByTime": (44, 2, (3, 0), (), "ResponseByTime", None),
		"ResponseOnDate": (48, 2, (7, 0), (), "ResponseOnDate", None),
		"ResponseOnTime": (47, 2, (3, 0), (), "ResponseOnTime", None),
		"ServiceCallID": (9, 2, (3, 0), (), "ServiceCallID", None),
		# Method 'Solutions' returns object of type 'IServiceCallSolutions'
		"Solutions": (37, 2, (9, 0), (), "Solutions", '{FA8FD318-6971-4E8B-B6E9-959A938455C6}'),
		"Status": (26, 2, (3, 0), (), "Status", None),
		"Subject": (10, 2, (8, 0), (), "Subject", None),
		"TechnicianCode": (33, 2, (3, 0), (), "TechnicianCode", None),
		"UpdatedTime": (42, 2, (3, 0), (), "UpdatedTime", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AssigneeCode": ((30, LCID, 4, 0),()),
		"BelongsToAQueue": ((43, LCID, 4, 0),()),
		"CallType": ((28, LCID, 4, 0),()),
		"ContactCode": ((13, LCID, 4, 0),()),
		"ContractID": ((16, LCID, 4, 0),()),
		"CustomerCode": ((11, LCID, 4, 0),()),
		"CustomerName": ((12, LCID, 4, 0),()),
		"Description": ((31, LCID, 4, 0),()),
		"InternalSerialNum": ((15, LCID, 4, 0),()),
		"ItemCode": ((23, LCID, 4, 0),()),
		"ItemDescription": ((24, LCID, 4, 0),()),
		"ManufacturerSerialNum": ((14, LCID, 4, 0),()),
		"Origin": ((22, LCID, 4, 0),()),
		"Priority": ((27, LCID, 4, 0),()),
		"ProblemType": ((29, LCID, 4, 0),()),
		"Queue": ((51, LCID, 4, 0),()),
		"Resolution": ((34, LCID, 4, 0),()),
		"ResolutionDate": ((18, LCID, 4, 0),()),
		"ResolutionTime": ((19, LCID, 4, 0),()),
		"Status": ((26, LCID, 4, 0),()),
		"Subject": ((10, LCID, 4, 0),()),
		"TechnicianCode": ((33, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceContract_Lines(DispatchBaseClass):
	'IServiceContract_Lines Interface'
	CLSID = IID('{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}')
	coclass_clsid = IID('{8F1131E9-C31E-4F6D-BC3A-1F94AE2CEACF}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"EndDate": (12, 2, (7, 0), (), "EndDate", None),
		"InternalSerialNum": (7, 2, (8, 0), (), "InternalSerialNum", None),
		"ItemCode": (8, 2, (8, 0), (), "ItemCode", None),
		"ItemGroup": (10, 2, (3, 0), (), "ItemGroup", None),
		"ItemGroupName": (13, 2, (8, 0), (), "ItemGroupName", None),
		"ItemName": (9, 2, (8, 0), (), "ItemName", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"ManufacturerSerialNum": (6, 2, (8, 0), (), "ManufacturerSerialNum", None),
		"StartDate": (11, 2, (7, 0), (), "StartDate", None),
		"TerminationDate": (14, 2, (7, 0), (), "TerminationDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"EndDate": ((12, LCID, 4, 0),()),
		"InternalSerialNum": ((7, LCID, 4, 0),()),
		"ItemCode": ((8, LCID, 4, 0),()),
		"ItemGroup": ((10, LCID, 4, 0),()),
		"ItemName": ((9, LCID, 4, 0),()),
		"ManufacturerSerialNum": ((6, LCID, 4, 0),()),
		"StartDate": ((11, LCID, 4, 0),()),
		"TerminationDate": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceContracts(DispatchBaseClass):
	'IServiceContracts Interface'
	CLSID = IID('{5C594028-D730-4298-952E-4616C5047BC6}')
	coclass_clsid = IID('{3267FC28-5E07-4BA5-B072-C8F160D7C1C4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(54, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(61, LCID, 1, (8, 0), (),)

	def GetByKey(self, ContractID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),ContractID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(62, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (49, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (53, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ContactCode": (10, 2, (3, 0), (), "ContactCode", None),
		"ContractID": (7, 2, (3, 0), (), "ContractID", None),
		"ContractTemplate": (13, 2, (8, 0), (), "ContractTemplate", None),
		"ContractType": (14, 2, (3, 0), (), "ContractType", None),
		"CustomerCode": (8, 2, (8, 0), (), "CustomerCode", None),
		"CustomerName": (9, 2, (8, 0), (), "CustomerName", None),
		"Description": (23, 2, (8, 0), (), "Description", None),
		"DurationOfCoverage": (18, 2, (3, 0), (), "DurationOfCoverage", None),
		"EndDate": (20, 2, (7, 0), (), "EndDate", None),
		"FridayEnabled": (29, 2, (3, 0), (), "FridayEnabled", None),
		"FridayEnd": (41, 2, (7, 0), (), "FridayEnd", None),
		"FridayStart": (40, 2, (7, 0), (), "FridayStart", None),
		"IncludeHolidays": (56, 2, (3, 0), (), "IncludeHolidays", None),
		"IncludeLabor": (47, 2, (3, 0), (), "IncludeLabor", None),
		"IncludeParts": (46, 2, (3, 0), (), "IncludeParts", None),
		"IncludeTravel": (48, 2, (3, 0), (), "IncludeTravel", None),
		# Method 'Lines' returns object of type 'IServiceContract_Lines'
		"Lines": (55, 2, (9, 0), (), "Lines", '{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}'),
		"MondayEnabled": (25, 2, (3, 0), (), "MondayEnabled", None),
		"MondayEnd": (33, 2, (7, 0), (), "MondayEnd", None),
		"MondayStart": (32, 2, (7, 0), (), "MondayStart", None),
		"Owner": (11, 2, (3, 0), (), "Owner", None),
		"Remarks": (51, 2, (8, 0), (), "Remarks", None),
		"RemindUnit": (17, 2, (3, 0), (), "RemindUnit", None),
		"ReminderTime": (16, 2, (3, 0), (), "ReminderTime", None),
		"Renewal": (15, 2, (3, 0), (), "Renewal", None),
		"ResolutionTime": (21, 2, (3, 0), (), "ResolutionTime", None),
		"ResolutionUnit": (22, 2, (3, 0), (), "ResolutionUnit", None),
		"ResponseTime": (59, 2, (3, 0), (), "ResponseTime", None),
		"ResponseUnit": (58, 2, (3, 0), (), "ResponseUnit", None),
		"SaturdayEnabled": (30, 2, (3, 0), (), "SaturdayEnabled", None),
		"SaturdayEnd": (43, 2, (7, 0), (), "SaturdayEnd", None),
		"SaturdayStart": (42, 2, (7, 0), (), "SaturdayStart", None),
		"ServiceType": (57, 2, (3, 0), (), "ServiceType", None),
		"StartDate": (19, 2, (7, 0), (), "StartDate", None),
		"Status": (12, 2, (3, 0), (), "Status", None),
		"SundayEnabled": (31, 2, (3, 0), (), "SundayEnabled", None),
		"SundayEnd": (45, 2, (7, 0), (), "SundayEnd", None),
		"SundayStart": (44, 2, (7, 0), (), "SundayStart", None),
		"TemplateRemarks": (50, 2, (8, 0), (), "TemplateRemarks", None),
		"TerminationDate": (60, 2, (7, 0), (), "TerminationDate", None),
		"ThursdayEnabled": (28, 2, (3, 0), (), "ThursdayEnabled", None),
		"ThursdayEnd": (39, 2, (7, 0), (), "ThursdayEnd", None),
		"ThursdayStart": (38, 2, (7, 0), (), "ThursdayStart", None),
		"TuesdayEnabled": (26, 2, (3, 0), (), "TuesdayEnabled", None),
		"TuesdayEnd": (35, 2, (7, 0), (), "TuesdayEnd", None),
		"TuesdayStart": (34, 2, (7, 0), (), "TuesdayStart", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WednesdayEnabled": (27, 2, (3, 0), (), "WednesdayEnabled", None),
		"WednesdayEnd": (37, 2, (7, 0), (), "WednesdayEnd", None),
		"WednesdayStart": (36, 2, (7, 0), (), "WednesdayStart", None),
	}
	_prop_map_put_ = {
		"ContactCode": ((10, LCID, 4, 0),()),
		"ContractTemplate": ((13, LCID, 4, 0),()),
		"ContractType": ((14, LCID, 4, 0),()),
		"CustomerCode": ((8, LCID, 4, 0),()),
		"CustomerName": ((9, LCID, 4, 0),()),
		"Description": ((23, LCID, 4, 0),()),
		"EndDate": ((20, LCID, 4, 0),()),
		"FridayEnabled": ((29, LCID, 4, 0),()),
		"FridayEnd": ((41, LCID, 4, 0),()),
		"FridayStart": ((40, LCID, 4, 0),()),
		"IncludeHolidays": ((56, LCID, 4, 0),()),
		"IncludeLabor": ((47, LCID, 4, 0),()),
		"IncludeParts": ((46, LCID, 4, 0),()),
		"IncludeTravel": ((48, LCID, 4, 0),()),
		"MondayEnabled": ((25, LCID, 4, 0),()),
		"MondayEnd": ((33, LCID, 4, 0),()),
		"MondayStart": ((32, LCID, 4, 0),()),
		"Owner": ((11, LCID, 4, 0),()),
		"Remarks": ((51, LCID, 4, 0),()),
		"RemindUnit": ((17, LCID, 4, 0),()),
		"ReminderTime": ((16, LCID, 4, 0),()),
		"Renewal": ((15, LCID, 4, 0),()),
		"ResolutionTime": ((21, LCID, 4, 0),()),
		"ResolutionUnit": ((22, LCID, 4, 0),()),
		"ResponseTime": ((59, LCID, 4, 0),()),
		"ResponseUnit": ((58, LCID, 4, 0),()),
		"SaturdayEnabled": ((30, LCID, 4, 0),()),
		"SaturdayEnd": ((43, LCID, 4, 0),()),
		"SaturdayStart": ((42, LCID, 4, 0),()),
		"ServiceType": ((57, LCID, 4, 0),()),
		"StartDate": ((19, LCID, 4, 0),()),
		"Status": ((12, LCID, 4, 0),()),
		"SundayEnabled": ((31, LCID, 4, 0),()),
		"SundayEnd": ((45, LCID, 4, 0),()),
		"SundayStart": ((44, LCID, 4, 0),()),
		"TerminationDate": ((60, LCID, 4, 0),()),
		"ThursdayEnabled": ((28, LCID, 4, 0),()),
		"ThursdayEnd": ((39, LCID, 4, 0),()),
		"ThursdayStart": ((38, LCID, 4, 0),()),
		"TuesdayEnabled": ((26, LCID, 4, 0),()),
		"TuesdayEnd": ((35, LCID, 4, 0),()),
		"TuesdayStart": ((34, LCID, 4, 0),()),
		"WednesdayEnabled": ((27, LCID, 4, 0),()),
		"WednesdayEnd": ((37, LCID, 4, 0),()),
		"WednesdayStart": ((36, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IShippingTypes(DispatchBaseClass):
	'IShippingTypes Interface'
	CLSID = IID('{EE047C63-413F-4CEA-B8BC-A4223AA6B482}')
	coclass_clsid = IID('{AFB12D1C-F0C3-4FA6-BF53-CA858C1BE796}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (12, 2, (3, 0), (), "Code", None),
		"Name": (13, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"Website": (14, 2, (8, 0), (), "Website", None),
	}
	_prop_map_put_ = {
		"Name": ((13, LCID, 4, 0),()),
		"Website": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISpecialPrices(DispatchBaseClass):
	'ISpecialPrices Interface'
	CLSID = IID('{2C1751BA-5CFF-4E47-8C1E-13CAF241A13F}')
	coclass_clsid = IID('{4F6D3681-33BD-41F5-BFEA-DE2059E4ADF4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(14, LCID, 1, (8, 0), (),)

	def GetByKey(self, ItemCode=defaultNamedNotOptArg, CardCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (11, 0), ((8, 1), (8, 1)),ItemCode
			, CardCode)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(12, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AutoUpdate": (11, 2, (3, 0), (), "AutoUpdate", None),
		"CardCode": (3, 2, (8, 0), (), "CardCode", None),
		"Currency": (5, 2, (8, 0), (), "Currency", None),
		"DiscountPercent": (6, 2, (5, 0), (), "DiscountPercent", None),
		"ItemCode": (2, 2, (8, 0), (), "ItemCode", None),
		"Price": (4, 2, (5, 0), (), "Price", None),
		"PriceListNum": (7, 2, (3, 0), (), "PriceListNum", None),
		# Method 'SpecialPricesDataAreas' returns object of type 'ISpecialPricesDataAreas'
		"SpecialPricesDataAreas": (13, 2, (9, 0), (), "SpecialPricesDataAreas", '{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}'),
	}
	_prop_map_put_ = {
		"AutoUpdate": ((11, LCID, 4, 0),()),
		"CardCode": ((3, LCID, 4, 0),()),
		"Currency": ((5, LCID, 4, 0),()),
		"DiscountPercent": ((6, LCID, 4, 0),()),
		"ItemCode": ((2, LCID, 4, 0),()),
		"Price": ((4, LCID, 4, 0),()),
		"PriceListNum": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISpecialPricesDataAreas(DispatchBaseClass):
	'ISpecialPricesDataAreas Interface'
	CLSID = IID('{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}')
	coclass_clsid = IID('{7A1326F7-9545-4AAC-B875-C317CF7D76B4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AutoUpdate": (2, 2, (3, 0), (), "AutoUpdate", None),
		"BPCode": (7, 2, (8, 0), (), "BPCode", None),
		"Count": (12, 2, (3, 0), (), "Count", None),
		"DateFrom": (6, 2, (7, 0), (), "DateFrom", None),
		"Dateto": (3, 2, (7, 0), (), "Dateto", None),
		"Discount": (4, 2, (5, 0), (), "Discount", None),
		"ItemNo": (9, 2, (8, 0), (), "ItemNo", None),
		"PriceCurrency": (1, 2, (8, 0), (), "PriceCurrency", None),
		"PriceListNo": (8, 2, (3, 0), (), "PriceListNo", None),
		"RowNumber": (10, 2, (3, 0), (), "RowNumber", None),
		"SpecialPrice": (5, 2, (5, 0), (), "SpecialPrice", None),
		# Method 'SpecialPricesQuantityAreas' returns object of type 'ISpecialPricesQuantityAreas'
		"SpecialPricesQuantityAreas": (15, 2, (9, 0), (), "SpecialPricesQuantityAreas", '{34995651-4568-4AAE-B831-60693B932A35}'),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (11, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AutoUpdate": ((2, LCID, 4, 0),()),
		"DateFrom": ((6, LCID, 4, 0),()),
		"Dateto": ((3, LCID, 4, 0),()),
		"Discount": ((4, LCID, 4, 0),()),
		"PriceCurrency": ((1, LCID, 4, 0),()),
		"PriceListNo": ((8, LCID, 4, 0),()),
		"SpecialPrice": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(12, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISpecialPricesQuantityAreas(DispatchBaseClass):
	'ISpecialPricesQuantityAreas Interface'
	CLSID = IID('{34995651-4568-4AAE-B831-60693B932A35}')
	coclass_clsid = IID('{36E908CF-6A46-413F-8BD6-C027651A58EA}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPCode": (5, 2, (8, 0), (), "BPCode", None),
		"Count": (10, 2, (3, 0), (), "Count", None),
		"Discountin": (8, 2, (5, 0), (), "Discountin", None),
		"ItemNo": (4, 2, (8, 0), (), "ItemNo", None),
		"PriceCurrency": (7, 2, (8, 0), (), "PriceCurrency", None),
		"Quantity": (1, 2, (5, 0), (), "Quantity", None),
		"RowNumber": (6, 2, (3, 0), (), "RowNumber", None),
		"SPDARowNumber": (2, 2, (3, 0), (), "SPDARowNumber", None),
		"SpecialPrice": (3, 2, (5, 0), (), "SpecialPrice", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (9, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Discountin": ((8, LCID, 4, 0),()),
		"PriceCurrency": ((7, LCID, 4, 0),()),
		"Quantity": ((1, LCID, 4, 0),()),
		"SpecialPrice": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(10, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IStockTaking(DispatchBaseClass):
	'IStockTaking Interface'
	CLSID = IID('{301718D4-11C9-4C5F-88DD-3609C5FA21FF}')
	coclass_clsid = IID('{CBC0A7DF-E458-45B8-B640-955215643708}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Counted": (4, 2, (5, 0), (), "Counted", None),
		"ItemCode": (2, 2, (8, 0), (), "ItemCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WarehouseCode": (3, 2, (8, 0), (), "WarehouseCode", None),
	}
	_prop_map_put_ = {
		"Counted": ((4, LCID, 4, 0),()),
		"ItemCode": ((2, LCID, 4, 0),()),
		"WarehouseCode": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IStockTransfer(DispatchBaseClass):
	'IStockTransfer Interface'
	CLSID = IID('{8DD14B84-6D7B-49E9-8137-A3E7F9A3642F}')
	coclass_clsid = IID('{E2174012-44BF-4A47-B117-283D13C66C5E}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(32, LCID, 1, (8, 0), (),)

	def GetByKey(self, AbsEntry=defaultNamedNotOptArg):
		'Get by key'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((3, 0),),AbsEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(33, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(28, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Address": (10, 2, (8, 0), (), "Address", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (21, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (8, 2, (8, 0), (), "CardCode", None),
		"CardName": (9, 2, (8, 0), (), "CardName", None),
		"Comments": (13, 2, (8, 0), (), "Comments", None),
		"ContactPerson": (30, 2, (3, 0), (), "ContactPerson", None),
		"CreationDate": (23, 2, (7, 0), (), "CreationDate", None),
		"DocDate": (7, 2, (7, 0), (), "DocDate", None),
		"DocEntry": (22, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (27, 2, (3, 0), (), "DocNum", None),
		"FinancialPeriod": (25, 2, (3, 0), (), "FinancialPeriod", None),
		"FromWarehouse": (17, 2, (8, 0), (), "FromWarehouse", None),
		"JournalMemo": (14, 2, (8, 0), (), "JournalMemo", None),
		# Method 'Lines' returns object of type 'IStockTransfer_Lines'
		"Lines": (1, 2, (9, 0), (), "Lines", '{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}'),
		"PriceList": (15, 2, (3, 0), (), "PriceList", None),
		"Printed": (6, 2, (3, 0), (), "Printed", None),
		"Reference1": (11, 2, (8, 0), (), "Reference1", None),
		"Reference2": (12, 2, (8, 0), (), "Reference2", None),
		"SalesPersonCode": (16, 2, (3, 0), (), "SalesPersonCode", None),
		"Series": (5, 2, (3, 0), (), "Series", None),
		"TaxDate": (29, 2, (7, 0), (), "TaxDate", None),
		"TransNum": (26, 2, (3, 0), (), "TransNum", None),
		"UpdateDate": (24, 2, (7, 0), (), "UpdateDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (31, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Address": ((10, LCID, 4, 0),()),
		"CardCode": ((8, LCID, 4, 0),()),
		"CardName": ((9, LCID, 4, 0),()),
		"Comments": ((13, LCID, 4, 0),()),
		"ContactPerson": ((30, LCID, 4, 0),()),
		"DocDate": ((7, LCID, 4, 0),()),
		"FromWarehouse": ((17, LCID, 4, 0),()),
		"JournalMemo": ((14, LCID, 4, 0),()),
		"PriceList": ((15, LCID, 4, 0),()),
		"Reference1": ((11, LCID, 4, 0),()),
		"Reference2": ((12, LCID, 4, 0),()),
		"SalesPersonCode": ((16, LCID, 4, 0),()),
		"Series": ((5, LCID, 4, 0),()),
		"TaxDate": ((29, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IStockTransfer_Lines(DispatchBaseClass):
	'IStockTransfer_Lines Interface'
	CLSID = IID('{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}')
	coclass_clsid = IID('{9C11E37D-538D-4819-85D1-00048E759E11}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		# Method 'BatchNumbers' returns object of type 'IBatchNumbers'
		"BatchNumbers": (21, 2, (9, 0), (), "BatchNumbers", '{1FEF5698-93E1-4167-AEA0-4BB151792623}'),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Currency": (9, 2, (8, 0), (), "Currency", None),
		"DiscountPercent": (11, 2, (5, 0), (), "DiscountPercent", None),
		"Factor": (16, 2, (5, 0), (), "Factor", None),
		"Factor2": (17, 2, (5, 0), (), "Factor2", None),
		"Factor3": (18, 2, (5, 0), (), "Factor3", None),
		"Factor4": (19, 2, (5, 0), (), "Factor4", None),
		"ItemCode": (5, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (6, 2, (8, 0), (), "ItemDescription", None),
		"LineNum": (4, 2, (3, 0), (), "LineNum", None),
		"Price": (8, 2, (5, 0), (), "Price", None),
		"ProjectCode": (15, 2, (8, 0), (), "ProjectCode", None),
		"Quantity": (7, 2, (5, 0), (), "Quantity", None),
		"Rate": (10, 2, (5, 0), (), "Rate", None),
		"SerialNumber": (13, 2, (8, 0), (), "SerialNumber", None),
		# Method 'SerialNumbers' returns object of type 'ISerialNumbers'
		"SerialNumbers": (20, 2, (9, 0), (), "SerialNumbers", '{93E5E52B-181E-46B8-96CB-1C066AC04DCA}'),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (22, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VendorNum": (12, 2, (8, 0), (), "VendorNum", None),
		"WarehouseCode": (14, 2, (8, 0), (), "WarehouseCode", None),
	}
	_prop_map_put_ = {
		"Currency": ((9, LCID, 4, 0),()),
		"DiscountPercent": ((11, LCID, 4, 0),()),
		"Factor": ((16, LCID, 4, 0),()),
		"Factor2": ((17, LCID, 4, 0),()),
		"Factor3": ((18, LCID, 4, 0),()),
		"Factor4": ((19, LCID, 4, 0),()),
		"ItemCode": ((5, LCID, 4, 0),()),
		"ItemDescription": ((6, LCID, 4, 0),()),
		"Price": ((8, LCID, 4, 0),()),
		"ProjectCode": ((15, LCID, 4, 0),()),
		"Quantity": ((7, LCID, 4, 0),()),
		"Rate": ((10, LCID, 4, 0),()),
		"SerialNumber": ((13, LCID, 4, 0),()),
		"VendorNum": ((12, LCID, 4, 0),()),
		"WarehouseCode": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxExtension(DispatchBaseClass):
	'ITaxExtension Interface'
	CLSID = IID('{8CC29ECE-02C3-4C7B-851B-5533D2C83627}')
	coclass_clsid = IID('{94BACBC3-E916-4D1F-9469-F7F44F8E39F0}')

	_prop_map_get_ = {
		"BlockB": (34, 2, (8, 0), (), "BlockB", None),
		"BlockS": (26, 2, (8, 0), (), "BlockS", None),
		"Brand": (20, 2, (8, 0), (), "Brand", None),
		"BuildingB": (35, 2, (8, 0), (), "BuildingB", None),
		"BuildingS": (27, 2, (8, 0), (), "BuildingS", None),
		"Carrier": (17, 2, (8, 0), (), "Carrier", None),
		"CityB": (36, 2, (8, 0), (), "CityB", None),
		"CityS": (28, 2, (8, 0), (), "CityS", None),
		"CountryB": (40, 2, (8, 0), (), "CountryB", None),
		"CountryS": (32, 2, (8, 0), (), "CountryS", None),
		"County": (12, 2, (8, 0), (), "County", None),
		"CountyB": (38, 2, (8, 0), (), "CountyB", None),
		"CountyS": (30, 2, (8, 0), (), "CountyS", None),
		"GrossWeight": (23, 2, (5, 0), (), "GrossWeight", None),
		"Incoterms": (13, 2, (8, 0), (), "Incoterms", None),
		"NFRef": (16, 2, (8, 0), (), "NFRef", None),
		"NetWeight": (22, 2, (5, 0), (), "NetWeight", None),
		"PackDescription": (19, 2, (8, 0), (), "PackDescription", None),
		"PackQuantity": (18, 2, (3, 0), (), "PackQuantity", None),
		"ShipUnitNo": (21, 2, (3, 0), (), "ShipUnitNo", None),
		"State": (11, 2, (8, 0), (), "State", None),
		"StateB": (39, 2, (8, 0), (), "StateB", None),
		"StateS": (31, 2, (8, 0), (), "StateS", None),
		"StreetB": (33, 2, (8, 0), (), "StreetB", None),
		"StreetS": (25, 2, (8, 0), (), "StreetS", None),
		"TaxId0": (1, 2, (8, 0), (), "TaxId0", None),
		"TaxId1": (2, 2, (8, 0), (), "TaxId1", None),
		"TaxId2": (3, 2, (8, 0), (), "TaxId2", None),
		"TaxId3": (4, 2, (8, 0), (), "TaxId3", None),
		"TaxId4": (5, 2, (8, 0), (), "TaxId4", None),
		"TaxId5": (6, 2, (8, 0), (), "TaxId5", None),
		"TaxId6": (7, 2, (8, 0), (), "TaxId6", None),
		"TaxId7": (8, 2, (8, 0), (), "TaxId7", None),
		"TaxId8": (9, 2, (8, 0), (), "TaxId8", None),
		"TaxId9": (10, 2, (8, 0), (), "TaxId9", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (24, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"Vehicle": (14, 2, (8, 0), (), "Vehicle", None),
		"VehicleState": (15, 2, (8, 0), (), "VehicleState", None),
		"ZipCodeB": (37, 2, (8, 0), (), "ZipCodeB", None),
		"ZipCodeS": (29, 2, (8, 0), (), "ZipCodeS", None),
	}
	_prop_map_put_ = {
		"BlockB": ((34, LCID, 4, 0),()),
		"BlockS": ((26, LCID, 4, 0),()),
		"Brand": ((20, LCID, 4, 0),()),
		"BuildingB": ((35, LCID, 4, 0),()),
		"BuildingS": ((27, LCID, 4, 0),()),
		"Carrier": ((17, LCID, 4, 0),()),
		"CityB": ((36, LCID, 4, 0),()),
		"CityS": ((28, LCID, 4, 0),()),
		"CountryB": ((40, LCID, 4, 0),()),
		"CountryS": ((32, LCID, 4, 0),()),
		"County": ((12, LCID, 4, 0),()),
		"CountyB": ((38, LCID, 4, 0),()),
		"CountyS": ((30, LCID, 4, 0),()),
		"GrossWeight": ((23, LCID, 4, 0),()),
		"Incoterms": ((13, LCID, 4, 0),()),
		"NFRef": ((16, LCID, 4, 0),()),
		"NetWeight": ((22, LCID, 4, 0),()),
		"PackDescription": ((19, LCID, 4, 0),()),
		"PackQuantity": ((18, LCID, 4, 0),()),
		"ShipUnitNo": ((21, LCID, 4, 0),()),
		"State": ((11, LCID, 4, 0),()),
		"StateB": ((39, LCID, 4, 0),()),
		"StateS": ((31, LCID, 4, 0),()),
		"StreetB": ((33, LCID, 4, 0),()),
		"StreetS": ((25, LCID, 4, 0),()),
		"TaxId0": ((1, LCID, 4, 0),()),
		"TaxId1": ((2, LCID, 4, 0),()),
		"TaxId2": ((3, LCID, 4, 0),()),
		"TaxId3": ((4, LCID, 4, 0),()),
		"TaxId4": ((5, LCID, 4, 0),()),
		"TaxId5": ((6, LCID, 4, 0),()),
		"TaxId6": ((7, LCID, 4, 0),()),
		"TaxId7": ((8, LCID, 4, 0),()),
		"TaxId8": ((9, LCID, 4, 0),()),
		"TaxId9": ((10, LCID, 4, 0),()),
		"Vehicle": ((14, LCID, 4, 0),()),
		"VehicleState": ((15, LCID, 4, 0),()),
		"ZipCodeB": ((37, LCID, 4, 0),()),
		"ZipCodeS": ((29, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxInvoice_Lines(DispatchBaseClass):
	'ITaxInvoice_Lines Interface'
	CLSID = IID('{D1DD9101-9264-450A-9FAC-C9D899078775}')
	coclass_clsid = IID('{411526CA-B3C4-489C-B4FB-6539B5BF09C2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseEntry": (1, 2, (3, 0), (), "BaseEntry", None),
		"BaseType": (3, 2, (3, 0), (), "BaseType", None),
		"Count": (6, 2, (3, 0), (), "Count", None),
		"LineNum": (2, 2, (3, 0), (), "LineNum", None),
		"Reference": (4, 2, (3, 0), (), "Reference", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Reference": ((4, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(6, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxInvoices(DispatchBaseClass):
	'ITaxInvoices Interface'
	CLSID = IID('{9370956A-E63B-4B62-9AA0-EA32A0673B8A}')
	coclass_clsid = IID('{2393BA89-A02B-4E4E-8703-0412A8B757C4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(28, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(29, LCID, 1, (8, 0), (),)

	def GetByKey(self, DocEntry=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(23, LCID, 1, (11, 0), ((3, 1),),DocEntry
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(30, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(24, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(25, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Address": (16, 2, (8, 0), (), "Address", None),
		"Address2": (17, 2, (8, 0), (), "Address2", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (27, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CancelDate": (33, 2, (7, 0), (), "CancelDate", None),
		"CardCode": (6, 2, (8, 0), (), "CardCode", None),
		"Comments": (14, 2, (8, 0), (), "Comments", None),
		"ContactPersonCode": (12, 2, (3, 0), (), "ContactPersonCode", None),
		"CreationDate": (7, 2, (7, 0), (), "CreationDate", None),
		"CurrencySource": (18, 2, (3, 0), (), "CurrencySource", None),
		"CustomerOrVendorName": (32, 2, (8, 0), (), "CustomerOrVendorName", None),
		"CustomerOrVendorRefNo": (31, 2, (8, 0), (), "CustomerOrVendorRefNo", None),
		"DocCurrency": (19, 2, (8, 0), (), "DocCurrency", None),
		"DocDate": (5, 2, (7, 0), (), "DocDate", None),
		"DocDueDate": (9, 2, (7, 0), (), "DocDueDate", None),
		"DocEntry": (1, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (2, 2, (3, 0), (), "DocNum", None),
		"DocType": (3, 2, (3, 0), (), "DocType", None),
		"DocumentTotal": (34, 2, (5, 0), (), "DocumentTotal", None),
		# Method 'Lines' returns object of type 'ITaxInvoice_Lines'
		"Lines": (20, 2, (9, 0), (), "Lines", '{D1DD9101-9264-450A-9FAC-C9D899078775}'),
		"PaymentRefDate": (37, 2, (7, 0), (), "PaymentRefDate", None),
		"PaymentRefNo": (36, 2, (8, 0), (), "PaymentRefNo", None),
		"Printed": (4, 2, (3, 0), (), "Printed", None),
		"Segment": (11, 2, (3, 0), (), "Segment", None),
		"Series": (10, 2, (3, 0), (), "Series", None),
		"ShipToCode": (15, 2, (8, 0), (), "ShipToCode", None),
		"TaxDate": (13, 2, (7, 0), (), "TaxDate", None),
		"TaxTotal": (35, 2, (5, 0), (), "TaxTotal", None),
		"UpdateDate": (8, 2, (7, 0), (), "UpdateDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (26, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Address": ((16, LCID, 4, 0),()),
		"Address2": ((17, LCID, 4, 0),()),
		"CardCode": ((6, LCID, 4, 0),()),
		"Comments": ((14, LCID, 4, 0),()),
		"ContactPersonCode": ((12, LCID, 4, 0),()),
		"CurrencySource": ((18, LCID, 4, 0),()),
		"CustomerOrVendorName": ((32, LCID, 4, 0),()),
		"CustomerOrVendorRefNo": ((31, LCID, 4, 0),()),
		"DocCurrency": ((19, LCID, 4, 0),()),
		"DocDate": ((5, LCID, 4, 0),()),
		"DocDueDate": ((9, LCID, 4, 0),()),
		"DocType": ((3, LCID, 4, 0),()),
		"PaymentRefDate": ((37, LCID, 4, 0),()),
		"PaymentRefNo": ((36, LCID, 4, 0),()),
		"Series": ((10, LCID, 4, 0),()),
		"ShipToCode": ((15, LCID, 4, 0),()),
		"TaxDate": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITeamMembers(DispatchBaseClass):
	'ITeamMembers Interface'
	CLSID = IID('{09C6E920-908C-4FD2-9CBF-21C3F4329A33}')
	coclass_clsid = IID('{D562FBDC-788B-4D80-B9EB-9238CC4EF91C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"EmployeeID": (7, 2, (3, 0), (), "EmployeeID", None),
		"RoleInTeam": (8, 2, (3, 0), (), "RoleInTeam", None),
		"TeamID": (6, 2, (3, 0), (), "TeamID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"EmployeeID": ((7, LCID, 4, 0),()),
		"RoleInTeam": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITeams(DispatchBaseClass):
	'ITeams Interface'
	CLSID = IID('{BCA3F54F-34D2-4E1C-A700-AD1C35F0B415}')
	coclass_clsid = IID('{65ABB505-DD62-4C94-8E7B-BF63BC35E51E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lTeamID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((3, 1),),lTeamID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Description": (13, 2, (8, 0), (), "Description", None),
		"TeamID": (11, 2, (3, 0), (), "TeamID", None),
		# Method 'TeamMembers' returns object of type 'ITeamMembers'
		"TeamMembers": (15, 2, (9, 0), (), "TeamMembers", '{09C6E920-908C-4FD2-9CBF-21C3F4329A33}'),
		"TeamName": (12, 2, (8, 0), (), "TeamName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Description": ((13, LCID, 4, 0),()),
		"TeamName": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITerritories(DispatchBaseClass):
	'ITerritories Interface'
	CLSID = IID('{BEB8ACDC-E50B-4DA3-8281-EF5228E55099}')
	coclass_clsid = IID('{B03EE5C0-48D5-4E20-A33A-FF2DBE5AF478}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(13, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(10, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (12, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Description": (2, 2, (8, 0), (), "Description", None),
		"Inactive": (4, 2, (3, 0), (), "Inactive", None),
		"LocationIndex": (3, 2, (3, 0), (), "LocationIndex", None),
		"Parent": (5, 2, (3, 0), (), "Parent", None),
		"TerritoryID": (1, 2, (3, 0), (), "TerritoryID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (11, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Description": ((2, LCID, 4, 0),()),
		"Inactive": ((4, LCID, 4, 0),()),
		"LocationIndex": ((3, LCID, 4, 0),()),
		"Parent": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserFields(DispatchBaseClass):
	'IUserFields Interface'
	CLSID = IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')
	coclass_clsid = IID('{A994F7F0-BF16-4C8E-B03C-74CE9EF2ECF5}')

	_prop_map_get_ = {
		# Method 'Fields' returns object of type 'IFields'
		"Fields": (0, 2, (9, 0), (), "Fields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
	}
	_prop_map_put_ = {
	}
	# Default property for this class is 'Fields'
	def __call__(self):
		return self._ApplyTypes_(*(0, 2, (9, 0), (), "Fields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserFieldsMD(DispatchBaseClass):
	'IUserFieldsMD Interface'
	CLSID = IID('{81D132DE-0549-460D-9BEC-2FEDEAB0A950}')
	coclass_clsid = IID('{E944AF70-E7E5-4414-833E-A62BFCF9EA65}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(19, LCID, 1, (8, 0), (),)

	def GetByKey(self, TableName=defaultNamedNotOptArg, FieldID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((8, 1), (3, 1)),TableName
			, FieldID)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"DefaultValue": (14, 2, (8, 0), (), "DefaultValue", None),
		"Description": (11, 2, (8, 0), (), "Description", None),
		"EditSize": (17, 2, (3, 0), (), "EditSize", None),
		"FieldID": (16, 2, (3, 0), (), "FieldID", None),
		"LinkedTable": (13, 2, (8, 0), (), "LinkedTable", None),
		"Mandatory": (18, 2, (3, 0), (), "Mandatory", None),
		"Name": (8, 2, (8, 0), (), "Name", None),
		"Size": (10, 2, (3, 0), (), "Size", None),
		"SubType": (12, 2, (3, 0), (), "SubType", None),
		"TableName": (15, 2, (8, 0), (), "TableName", None),
		"Type": (9, 2, (3, 0), (), "Type", None),
		# Method 'ValidValues' returns object of type 'IValidValuesMD'
		"ValidValues": (6, 2, (9, 0), (), "ValidValues", '{D435C006-B504-4847-B217-8AEA5439B779}'),
	}
	_prop_map_put_ = {
		"DefaultValue": ((14, LCID, 4, 0),()),
		"Description": ((11, LCID, 4, 0),()),
		"EditSize": ((17, LCID, 4, 0),()),
		"LinkedTable": ((13, LCID, 4, 0),()),
		"Mandatory": ((18, LCID, 4, 0),()),
		"Name": ((8, LCID, 4, 0),()),
		"Size": ((10, LCID, 4, 0),()),
		"SubType": ((12, LCID, 4, 0),()),
		"TableName": ((15, LCID, 4, 0),()),
		"Type": ((9, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserKeysMD(DispatchBaseClass):
	'IUserKeysMD Interface'
	CLSID = IID('{913C6394-89AD-47A9-9390-1B8686E65312}')
	coclass_clsid = IID('{208C7E76-4919-4468-AE9E-13976C9BE255}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(14, LCID, 1, (8, 0), (),)

	def GetByKey(self, TableName=defaultNamedNotOptArg, KeyIndex=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((8, 1), (3, 1)),TableName
			, KeyIndex)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		# Method 'Elements' returns object of type 'IUserKeysMD_Elements'
		"Elements": (9, 2, (9, 0), (), "Elements", '{ED79A1AF-2F5B-418E-A90C-1F504B49E364}'),
		"KeyIndex": (11, 2, (3, 0), (), "KeyIndex", None),
		"KeyName": (12, 2, (8, 0), (), "KeyName", None),
		"TableName": (10, 2, (8, 0), (), "TableName", None),
		"Unique": (13, 2, (3, 0), (), "Unique", None),
	}
	_prop_map_put_ = {
		"KeyName": ((12, LCID, 4, 0),()),
		"TableName": ((10, LCID, 4, 0),()),
		"Unique": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserKeysMD_Elements(DispatchBaseClass):
	'IUserKeysMD_Elements Interface'
	CLSID = IID('{ED79A1AF-2F5B-418E-A90C-1F504B49E364}')
	coclass_clsid = IID('{A2120F6A-992A-4AAE-A98B-F573035921E8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentline'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ColumnAlias": (10, 2, (8, 0), (), "ColumnAlias", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"SubKeyIndex": (9, 2, (3, 0), (), "SubKeyIndex", None),
	}
	_prop_map_put_ = {
		"ColumnAlias": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserObjectMD_ChildTables(DispatchBaseClass):
	'IUserObjectMD_ChildTables Interface'
	CLSID = IID('{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}')
	coclass_clsid = IID('{28F2FDF3-FCEC-4D90-983B-D4C805891EC0}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"LogTableName": (3, 2, (8, 0), (), "LogTableName", None),
		"SonNumber": (1, 2, (3, 0), (), "SonNumber", None),
		"TableName": (2, 2, (8, 0), (), "TableName", None),
	}
	_prop_map_put_ = {
		"LogTableName": ((3, LCID, 4, 0),()),
		"TableName": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserObjectMD_FindColumns(DispatchBaseClass):
	'IUserObjectMD_FindColumns Interface'
	CLSID = IID('{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}')
	coclass_clsid = IID('{1C59C249-B65E-472F-80BB-EE0A05F75666}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ColumnAlias": (2, 2, (8, 0), (), "ColumnAlias", None),
		"ColumnDescription": (3, 2, (8, 0), (), "ColumnDescription", None),
		"ColumnNumber": (1, 2, (3, 0), (), "ColumnNumber", None),
		"Count": (5, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
		"ColumnAlias": ((2, LCID, 4, 0),()),
		"ColumnDescription": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserObjectMD_FormColumns(DispatchBaseClass):
	'IUserObjectMD_FormColumns Interface'
	CLSID = IID('{0C607D21-E148-42CE-AF58-E8C38EB26275}')
	coclass_clsid = IID('{C1A276C6-FD68-4693-8D70-D9A7A3E69712}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (6, 2, (3, 0), (), "Count", None),
		"FormColumnAlias": (1, 2, (8, 0), (), "FormColumnAlias", None),
		"FormColumnDescription": (2, 2, (8, 0), (), "FormColumnDescription", None),
		"FormColumnNumber": (4, 2, (3, 0), (), "FormColumnNumber", None),
		"SonNumber": (5, 2, (3, 0), (), "SonNumber", None),
	}
	_prop_map_put_ = {
		"FormColumnAlias": ((1, LCID, 4, 0),()),
		"FormColumnDescription": ((2, LCID, 4, 0),()),
		"SonNumber": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(6, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserObjectsMD(DispatchBaseClass):
	'IUserObjectsMD Interface'
	CLSID = IID('{2E2720A5-8F7C-45D3-BF5A-DD5BE3769F84}')
	coclass_clsid = IID('{8AEF84A8-9762-4736-A6BC-778EA10CA4C2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	def GetByKey(self, Code=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (11, 0), ((8, 1),),Code
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"CanCancel": (7, 2, (3, 0), (), "CanCancel", None),
		"CanClose": (14, 2, (3, 0), (), "CanClose", None),
		"CanCreateDefaultForm": (4, 2, (3, 0), (), "CanCreateDefaultForm", None),
		"CanDelete": (8, 2, (3, 0), (), "CanDelete", None),
		"CanFind": (11, 2, (3, 0), (), "CanFind", None),
		"CanLog": (9, 2, (3, 0), (), "CanLog", None),
		"CanYearTransfer": (12, 2, (3, 0), (), "CanYearTransfer", None),
		# Method 'ChildTables' returns object of type 'IUserObjectMD_ChildTables'
		"ChildTables": (23, 2, (9, 0), (), "ChildTables", '{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}'),
		"Code": (2, 2, (8, 0), (), "Code", None),
		"ExtensionName": (6, 2, (8, 0), (), "ExtensionName", None),
		# Method 'FindColumns' returns object of type 'IUserObjectMD_FindColumns'
		"FindColumns": (21, 2, (9, 0), (), "FindColumns", '{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}'),
		# Method 'FormColumns' returns object of type 'IUserObjectMD_FormColumns'
		"FormColumns": (22, 2, (9, 0), (), "FormColumns", '{0C607D21-E148-42CE-AF58-E8C38EB26275}'),
		"LogTableName": (3, 2, (8, 0), (), "LogTableName", None),
		"ManageSeries": (10, 2, (3, 0), (), "ManageSeries", None),
		"Name": (13, 2, (8, 0), (), "Name", None),
		"ObjectType": (5, 2, (3, 0), (), "ObjectType", None),
		"TableName": (1, 2, (8, 0), (), "TableName", None),
	}
	_prop_map_put_ = {
		"CanCancel": ((7, LCID, 4, 0),()),
		"CanClose": ((14, LCID, 4, 0),()),
		"CanCreateDefaultForm": ((4, LCID, 4, 0),()),
		"CanDelete": ((8, LCID, 4, 0),()),
		"CanFind": ((11, LCID, 4, 0),()),
		"CanLog": ((9, LCID, 4, 0),()),
		"CanYearTransfer": ((12, LCID, 4, 0),()),
		"Code": ((2, LCID, 4, 0),()),
		"ExtensionName": ((6, LCID, 4, 0),()),
		"LogTableName": ((3, LCID, 4, 0),()),
		"ManageSeries": ((10, LCID, 4, 0),()),
		"Name": ((13, LCID, 4, 0),()),
		"ObjectType": ((5, LCID, 4, 0),()),
		"TableName": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserPermission(DispatchBaseClass):
	'IUserPermission Interface'
	CLSID = IID('{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}')
	coclass_clsid = IID('{F9779E16-EDDF-4C59-B80D-A24F34EA1ECE}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (6, 2, (3, 0), (), "Count", None),
		"Permission": (4, 2, (3, 0), (), "Permission", None),
		"PermissionID": (3, 2, (8, 0), (), "PermissionID", None),
		"UserCode": (2, 2, (3, 0), (), "UserCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Permission": ((4, LCID, 4, 0),()),
		"PermissionID": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(6, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserPermissionForms(DispatchBaseClass):
	'IUserPermissionForms Interface'
	CLSID = IID('{24464254-073D-4148-A045-3CFDB71DE48C}')
	coclass_clsid = IID('{6D4864DD-75DF-4305-A8CB-C7E2381DD7B3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"DisplayOrder": (2, 2, (3, 0), (), "DisplayOrder", None),
		"FormType": (1, 2, (8, 0), (), "FormType", None),
		"PermissionID": (3, 2, (8, 0), (), "PermissionID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"DisplayOrder": ((2, LCID, 4, 0),()),
		"FormType": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserPermissionTree(DispatchBaseClass):
	'IUserPermissionTree Interface'
	CLSID = IID('{55ACC8CD-3412-452A-9AF8-304A0A56FD3B}')
	coclass_clsid = IID('{950BE47C-4B36-49F3-A313-57146222DC3C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(16, LCID, 1, (8, 0), (),)

	def GetByKey(self, PermissionID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (11, 0), ((8, 1),),PermissionID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(17, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(12, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (15, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"DisplayOrder": (2, 2, (3, 0), (), "DisplayOrder", None),
		"IsItem": (7, 2, (3, 0), (), "IsItem", None),
		"Levels": (6, 2, (3, 0), (), "Levels", None),
		"Name": (5, 2, (8, 0), (), "Name", None),
		"Options": (4, 2, (3, 0), (), "Options", None),
		"ParentID": (8, 2, (8, 0), (), "ParentID", None),
		"PermissionID": (3, 2, (8, 0), (), "PermissionID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (14, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		# Method 'UserPermissionForms' returns object of type 'IUserPermissionForms'
		"UserPermissionForms": (9, 2, (9, 0), (), "UserPermissionForms", '{24464254-073D-4148-A045-3CFDB71DE48C}'),
		"UserSignature": (1, 2, (3, 0), (), "UserSignature", None),
	}
	_prop_map_put_ = {
		"IsItem": ((7, LCID, 4, 0),()),
		"Name": ((5, LCID, 4, 0),()),
		"Options": ((4, LCID, 4, 0),()),
		"ParentID": ((8, LCID, 4, 0),()),
		"PermissionID": ((3, LCID, 4, 0),()),
		"UserSignature": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserTable(DispatchBaseClass):
	'IUserTable Interface'
	CLSID = IID('{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')
	coclass_clsid = IID('{EBB0F6A6-D704-41FF-8D22-CC3B76407F5B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get table's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(11, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((8, 1),),Key
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the table's data in xml format."
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Code": (9, 2, (8, 0), (), "Code", None),
		"Name": (10, 2, (8, 0), (), "Name", None),
		"TableDescription": (8, 2, (8, 0), (), "TableDescription", None),
		"TableName": (7, 2, (8, 0), (), "TableName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Code": ((9, LCID, 4, 0),()),
		"Name": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserTables(DispatchBaseClass):
	'IUserTables Interface'
	CLSID = IID('{625162C1-3894-460F-94EC-72D6AFEA34D2}')
	coclass_clsid = IID('{CD793E21-582C-4408-8AF7-1B256D29BF5A}')

	# Result is of type IUserTable
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')
		return ret

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserTablesMD(DispatchBaseClass):
	'IUserTablesMD Interface'
	CLSID = IID('{FC571383-8375-4B7D-BDEF-4EF2B91B7751}')
	coclass_clsid = IID('{04A02F02-1211-4507-87DB-DBE6A4807718}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(9, LCID, 1, (8, 0), (),)

	def GetByKey(self, TableName=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((8, 1),),TableName
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"TableDescription": (7, 2, (8, 0), (), "TableDescription", None),
		"TableName": (6, 2, (8, 0), (), "TableName", None),
		"TableType": (8, 2, (3, 0), (), "TableType", None),
	}
	_prop_map_put_ = {
		"TableDescription": ((7, LCID, 4, 0),()),
		"TableName": ((6, LCID, 4, 0),()),
		"TableType": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUsers(DispatchBaseClass):
	'IUsers Interface'
	CLSID = IID('{ED256951-E65E-40BF-A2E9-2A21741D8720}')
	coclass_clsid = IID('{1B0F044E-5955-4426-8CEE-885A8388A8F9}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(22, LCID, 1, (8, 0), (),)

	def GetByKey(self, InternalKey=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),InternalKey
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(23, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Branch": (18, 2, (3, 0), (), "Branch", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Defaults": (16, 2, (8, 0), (), "Defaults", None),
		"Department": (19, 2, (3, 0), (), "Department", None),
		"FaxNumber": (17, 2, (8, 0), (), "FaxNumber", None),
		"InternalKey": (9, 2, (3, 0), (), "InternalKey", None),
		"MobilePhoneNumber": (15, 2, (8, 0), (), "MobilePhoneNumber", None),
		"Superuser": (13, 2, (3, 0), (), "Superuser", None),
		"UserCode": (11, 2, (8, 0), (), "UserCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (20, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserName": (12, 2, (8, 0), (), "UserName", None),
		"UserPassword": (10, 2, (8, 0), (), "UserPassword", None),
		# Method 'UserPermission' returns object of type 'IUserPermission'
		"UserPermission": (21, 2, (9, 0), (), "UserPermission", '{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}'),
		"eMail": (14, 2, (8, 0), (), "eMail", None),
	}
	_prop_map_put_ = {
		"Branch": ((18, LCID, 4, 0),()),
		"Defaults": ((16, LCID, 4, 0),()),
		"Department": ((19, LCID, 4, 0),()),
		"FaxNumber": ((17, LCID, 4, 0),()),
		"MobilePhoneNumber": ((15, LCID, 4, 0),()),
		"Superuser": ((13, LCID, 4, 0),()),
		"UserCode": ((11, LCID, 4, 0),()),
		"UserName": ((12, LCID, 4, 0),()),
		"UserPassword": ((10, LCID, 4, 0),()),
		"eMail": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IValidValue(DispatchBaseClass):
	'IValidValue Interface'
	CLSID = IID('{013F0389-85E2-4B8B-9285-18843E4236F3}')
	coclass_clsid = IID('{4838BBDC-5B48-44EF-A7F7-A705BB07B24F}')

	_prop_map_get_ = {
		"Description": (2, 2, (8, 0), (), "Description", None),
		"Value": (1, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(1, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IValidValues(DispatchBaseClass):
	'IValidValues Interface'
	CLSID = IID('{48B89C08-2AE9-435F-B7C4-D7219E938E46}')
	coclass_clsid = IID('{C54F7212-C3DC-4E35-B61C-73E6297F1AD6}')

	# Result is of type IValidValue
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{013F0389-85E2-4B8B-9285-18843E4236F3}')
		return ret

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{013F0389-85E2-4B8B-9285-18843E4236F3}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{013F0389-85E2-4B8B-9285-18843E4236F3}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IValidValuesMD(DispatchBaseClass):
	'IValidValuesMD Interface'
	CLSID = IID('{D435C006-B504-4847-B217-8AEA5439B779}')
	coclass_clsid = IID('{C868B9F4-6EC8-4A28-81AF-546DD81B1083}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Description": (5, 2, (8, 0), (), "Description", None),
		"Value": (4, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Description": ((5, LCID, 4, 0),()),
		"Value": ((4, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(4, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IWarehouses(DispatchBaseClass):
	'IWarehouses Interface'
	CLSID = IID('{43AC045C-DCA2-4150-B937-AB205DCA22E6}')
	coclass_clsid = IID('{57544A70-71BC-4A35-B018-BB43DD24941A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(50, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(57, LCID, 1, (8, 0), (),)

	def GetByKey(self, WhsCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(53, LCID, 1, (11, 0), ((8, 1),),WhsCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(52, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(58, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(54, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(51, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AllowUseTax": (10, 2, (3, 0), (), "AllowUseTax", None),
		"Block": (20, 2, (8, 0), (), "Block", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (56, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BuildingFloorRoom": (43, 2, (8, 0), (), "BuildingFloorRoom", None),
		"BusinessPlaceID": (59, 2, (3, 0), (), "BusinessPlaceID", None),
		"City": (30, 2, (8, 0), (), "City", None),
		"CostInflationAccount": (11, 2, (8, 0), (), "CostInflationAccount", None),
		"CostInflationOffsetAccount": (14, 2, (8, 0), (), "CostInflationOffsetAccount", None),
		"CostOfGoodsSold": (27, 2, (8, 0), (), "CostOfGoodsSold", None),
		"Country": (33, 2, (8, 0), (), "Country", None),
		"County": (44, 2, (8, 0), (), "County", None),
		"DecreaseGLAccount": (22, 2, (8, 0), (), "DecreaseGLAccount", None),
		"DecreasingAccount": (4, 2, (8, 0), (), "DecreasingAccount", None),
		"DropShip": (38, 2, (3, 0), (), "DropShip", None),
		"EUExpensesAccount": (13, 2, (8, 0), (), "EUExpensesAccount", None),
		"EURevenuesAccount": (6, 2, (8, 0), (), "EURevenuesAccount", None),
		"ExchangeRateDifferencesAccount": (35, 2, (8, 0), (), "ExchangeRateDifferencesAccount", None),
		"ExemptRevenuesAccount": (25, 2, (8, 0), (), "ExemptRevenuesAccount", None),
		"ExpenseAccount": (21, 2, (8, 0), (), "ExpenseAccount", None),
		"ExpenseOffsetingAct": (47, 2, (8, 0), (), "ExpenseOffsetingAct", None),
		"ExpensesClearingAccount": (15, 2, (8, 0), (), "ExpensesClearingAccount", None),
		"FederalTaxID": (18, 2, (8, 0), (), "FederalTaxID", None),
		"ForeignExpensesAccount": (12, 2, (8, 0), (), "ForeignExpensesAccount", None),
		"ForeignRevenuesAcc": (42, 2, (8, 0), (), "ForeignRevenuesAcc", None),
		"GoodsClearingAcc": (48, 2, (8, 0), (), "GoodsClearingAcc", None),
		"IncreaseGLAccount": (34, 2, (8, 0), (), "IncreaseGLAccount", None),
		"IncreasingAcc": (46, 2, (8, 0), (), "IncreasingAcc", None),
		"InternalKey": (41, 2, (3, 0), (), "InternalKey", None),
		"Location": (19, 2, (3, 0), (), "Location", None),
		"Nettable": (45, 2, (3, 0), (), "Nettable", None),
		"PriceDifferencesAccount": (31, 2, (8, 0), (), "PriceDifferencesAccount", None),
		"PurchaseAccount": (5, 2, (8, 0), (), "PurchaseAccount", None),
		"PurchaseOffsetAccount": (26, 2, (8, 0), (), "PurchaseOffsetAccount", None),
		"PurchaseReturningAccount": (16, 2, (8, 0), (), "PurchaseReturningAccount", None),
		"ReturningAccount": (7, 2, (8, 0), (), "ReturningAccount", None),
		"RevenuesAccount": (23, 2, (8, 0), (), "RevenuesAccount", None),
		"ShippedGoodsAccount": (8, 2, (8, 0), (), "ShippedGoodsAccount", None),
		"State": (29, 2, (8, 0), (), "State", None),
		"StockAccount": (49, 2, (8, 0), (), "StockAccount", None),
		"StockInflationAdjustAccount": (9, 2, (8, 0), (), "StockInflationAdjustAccount", None),
		"StockInflationOffsetAccount": (2, 2, (8, 0), (), "StockInflationOffsetAccount", None),
		"Street": (1, 2, (8, 0), (), "Street", None),
		"TaxGroup": (24, 2, (8, 0), (), "TaxGroup", None),
		"TransfersAcc": (40, 2, (8, 0), (), "TransfersAcc", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (55, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATInRevenueAccount": (17, 2, (8, 0), (), "VATInRevenueAccount", None),
		"VarianceAccount": (32, 2, (8, 0), (), "VarianceAccount", None),
		"WIPMaterialAccount": (36, 2, (8, 0), (), "WIPMaterialAccount", None),
		"WIPMaterialVarianceAccount": (39, 2, (8, 0), (), "WIPMaterialVarianceAccount", None),
		"WarehouseCode": (28, 2, (8, 0), (), "WarehouseCode", None),
		"WarehouseName": (37, 2, (8, 0), (), "WarehouseName", None),
		"ZipCode": (3, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AllowUseTax": ((10, LCID, 4, 0),()),
		"Block": ((20, LCID, 4, 0),()),
		"BuildingFloorRoom": ((43, LCID, 4, 0),()),
		"City": ((30, LCID, 4, 0),()),
		"CostInflationAccount": ((11, LCID, 4, 0),()),
		"CostInflationOffsetAccount": ((14, LCID, 4, 0),()),
		"CostOfGoodsSold": ((27, LCID, 4, 0),()),
		"Country": ((33, LCID, 4, 0),()),
		"County": ((44, LCID, 4, 0),()),
		"DecreaseGLAccount": ((22, LCID, 4, 0),()),
		"DecreasingAccount": ((4, LCID, 4, 0),()),
		"DropShip": ((38, LCID, 4, 0),()),
		"EUExpensesAccount": ((13, LCID, 4, 0),()),
		"EURevenuesAccount": ((6, LCID, 4, 0),()),
		"ExchangeRateDifferencesAccount": ((35, LCID, 4, 0),()),
		"ExemptRevenuesAccount": ((25, LCID, 4, 0),()),
		"ExpenseAccount": ((21, LCID, 4, 0),()),
		"ExpenseOffsetingAct": ((47, LCID, 4, 0),()),
		"ExpensesClearingAccount": ((15, LCID, 4, 0),()),
		"FederalTaxID": ((18, LCID, 4, 0),()),
		"ForeignExpensesAccount": ((12, LCID, 4, 0),()),
		"ForeignRevenuesAcc": ((42, LCID, 4, 0),()),
		"GoodsClearingAcc": ((48, LCID, 4, 0),()),
		"IncreaseGLAccount": ((34, LCID, 4, 0),()),
		"IncreasingAcc": ((46, LCID, 4, 0),()),
		"Location": ((19, LCID, 4, 0),()),
		"Nettable": ((45, LCID, 4, 0),()),
		"PriceDifferencesAccount": ((31, LCID, 4, 0),()),
		"PurchaseAccount": ((5, LCID, 4, 0),()),
		"PurchaseOffsetAccount": ((26, LCID, 4, 0),()),
		"PurchaseReturningAccount": ((16, LCID, 4, 0),()),
		"ReturningAccount": ((7, LCID, 4, 0),()),
		"RevenuesAccount": ((23, LCID, 4, 0),()),
		"ShippedGoodsAccount": ((8, LCID, 4, 0),()),
		"State": ((29, LCID, 4, 0),()),
		"StockAccount": ((49, LCID, 4, 0),()),
		"StockInflationAdjustAccount": ((9, LCID, 4, 0),()),
		"StockInflationOffsetAccount": ((2, LCID, 4, 0),()),
		"Street": ((1, LCID, 4, 0),()),
		"TaxGroup": ((24, LCID, 4, 0),()),
		"TransfersAcc": ((40, LCID, 4, 0),()),
		"VATInRevenueAccount": ((17, LCID, 4, 0),()),
		"VarianceAccount": ((32, LCID, 4, 0),()),
		"WIPMaterialAccount": ((36, LCID, 4, 0),()),
		"WIPMaterialVarianceAccount": ((39, LCID, 4, 0),()),
		"WarehouseCode": ((28, LCID, 4, 0),()),
		"WarehouseName": ((37, LCID, 4, 0),()),
		"ZipCode": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IWithholdingTaxData(DispatchBaseClass):
	'IWithholdingTaxData Interface'
	CLSID = IID('{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}')
	coclass_clsid = IID('{F00B2064-7046-4E6A-9286-1284170CFA80}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseDocEntry": (23, 2, (3, 0), (), "BaseDocEntry", None),
		"BaseDocLine": (24, 2, (3, 0), (), "BaseDocLine", None),
		"BaseDocType": (25, 2, (3, 0), (), "BaseDocType", None),
		"BaseType": (13, 2, (8, 0), (), "BaseType", None),
		"Category": (12, 2, (8, 0), (), "Category", None),
		"Count": (19, 2, (3, 0), (), "Count", None),
		"Criteria": (11, 2, (8, 0), (), "Criteria", None),
		"GLAccount": (17, 2, (8, 0), (), "GLAccount", None),
		"LineNum": (22, 2, (3, 0), (), "LineNum", None),
		"Rate": (10, 2, (5, 0), (), "Rate", None),
		"RoundingType": (9, 2, (8, 0), (), "RoundingType", None),
		"TaxableAmount": (8, 2, (5, 0), (), "TaxableAmount", None),
		"TaxableAmountFC": (7, 2, (5, 0), (), "TaxableAmountFC", None),
		"TaxableAmountinSys": (6, 2, (5, 0), (), "TaxableAmountinSys", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (18, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WTAmount": (4, 2, (5, 0), (), "WTAmount", None),
		"WTAmountFC": (3, 2, (5, 0), (), "WTAmountFC", None),
		"WTAmountSys": (2, 2, (5, 0), (), "WTAmountSys", None),
		"WTCode": (1, 2, (8, 0), (), "WTCode", None),
		"WithholdingType": (5, 2, (8, 0), (), "WithholdingType", None),
	}
	_prop_map_put_ = {
		"BaseDocEntry": ((23, LCID, 4, 0),()),
		"BaseDocLine": ((24, LCID, 4, 0),()),
		"BaseDocType": ((25, LCID, 4, 0),()),
		"TaxableAmount": ((8, LCID, 4, 0),()),
		"TaxableAmountFC": ((7, LCID, 4, 0),()),
		"TaxableAmountinSys": ((6, LCID, 4, 0),()),
		"WTAmount": ((4, LCID, 4, 0),()),
		"WTAmountFC": ((3, LCID, 4, 0),()),
		"WTAmountSys": ((2, LCID, 4, 0),()),
		"WTCode": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(19, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IWithholdingTaxLines(DispatchBaseClass):
	'IWithholdingTaxLines Interface'
	CLSID = IID('{458A15A5-B980-4543-A289-F6477A36EB24}')
	coclass_clsid = IID('{95AF3307-477A-4189-A934-CC32F18264F7}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseDocEntry": (23, 2, (3, 0), (), "BaseDocEntry", None),
		"BaseDocLine": (24, 2, (3, 0), (), "BaseDocLine", None),
		"BaseDocType": (25, 2, (3, 0), (), "BaseDocType", None),
		"BaseType": (13, 2, (8, 0), (), "BaseType", None),
		"Category": (12, 2, (8, 0), (), "Category", None),
		"Count": (19, 2, (3, 0), (), "Count", None),
		"Criteria": (11, 2, (8, 0), (), "Criteria", None),
		"GLAccount": (17, 2, (8, 0), (), "GLAccount", None),
		"LineNum": (22, 2, (3, 0), (), "LineNum", None),
		"Rate": (10, 2, (5, 0), (), "Rate", None),
		"RoundingType": (9, 2, (8, 0), (), "RoundingType", None),
		"TaxableAmount": (8, 2, (5, 0), (), "TaxableAmount", None),
		"TaxableAmountFC": (7, 2, (5, 0), (), "TaxableAmountFC", None),
		"TaxableAmountinSys": (6, 2, (5, 0), (), "TaxableAmountinSys", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (18, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WTAmount": (4, 2, (5, 0), (), "WTAmount", None),
		"WTAmountFC": (3, 2, (5, 0), (), "WTAmountFC", None),
		"WTAmountSys": (2, 2, (5, 0), (), "WTAmountSys", None),
		"WTCode": (1, 2, (8, 0), (), "WTCode", None),
		"WithholdingType": (5, 2, (8, 0), (), "WithholdingType", None),
	}
	_prop_map_put_ = {
		"BaseDocEntry": ((23, LCID, 4, 0),()),
		"BaseDocLine": ((24, LCID, 4, 0),()),
		"BaseDocType": ((25, LCID, 4, 0),()),
		"TaxableAmount": ((8, LCID, 4, 0),()),
		"TaxableAmountFC": ((7, LCID, 4, 0),()),
		"TaxableAmountinSys": ((6, LCID, 4, 0),()),
		"WTAmount": ((4, LCID, 4, 0),()),
		"WTAmountFC": ((3, LCID, 4, 0),()),
		"WTAmountSys": ((2, LCID, 4, 0),()),
		"WTCode": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(19, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IWorkOrder_Lines(DispatchBaseClass):
	'IWorkOrder_Lines Interface'
	CLSID = IID('{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}')
	coclass_clsid = IID('{457F56A9-7F85-4ABF-91A4-5384A0CED40C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ActiveAccountCode": (11, 2, (8, 0), (), "ActiveAccountCode", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"ItemCode": (5, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (6, 2, (8, 0), (), "ItemDescription", None),
		"ItemPrice": (8, 2, (5, 0), (), "ItemPrice", None),
		"ItemQuantity": (7, 2, (5, 0), (), "ItemQuantity", None),
		"ItemWarehouse": (10, 2, (8, 0), (), "ItemWarehouse", None),
		"PriceCurrency": (9, 2, (8, 0), (), "PriceCurrency", None),
		"RowNumber": (4, 2, (3, 0), (), "RowNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (15, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WorkSum": (12, 2, (5, 0), (), "WorkSum", None),
	}
	_prop_map_put_ = {
		"ActiveAccountCode": ((11, LCID, 4, 0),()),
		"ItemCode": ((5, LCID, 4, 0),()),
		"ItemPrice": ((8, LCID, 4, 0),()),
		"ItemQuantity": ((7, LCID, 4, 0),()),
		"ItemWarehouse": ((10, LCID, 4, 0),()),
		"PriceCurrency": ((9, LCID, 4, 0),()),
		"WorkSum": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IWorkOrders(DispatchBaseClass):
	'IWorkOrders Interface'
	CLSID = IID('{7615E097-E207-4E8D-A114-74031034136B}')
	coclass_clsid = IID('{0C610415-1BAF-4B92-B485-23D9F3E5AA9E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(30, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(34, LCID, 1, (8, 0), (),)

	def GetByKey(self, WkoKey=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (11, 0), ((3, 0),),WkoKey
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(35, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"ActiveAccountCode": (25, 2, (8, 0), (), "ActiveAccountCode", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (6, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Canceled": (9, 2, (3, 0), (), "Canceled", None),
		"Comment": (21, 2, (8, 0), (), "Comment", None),
		"ContactPerson": (23, 2, (3, 0), (), "ContactPerson", None),
		"CustomerRefNo": (17, 2, (8, 0), (), "CustomerRefNo", None),
		"ExpectedCompletionDate": (12, 2, (7, 0), (), "ExpectedCompletionDate", None),
		"FinancialPeriod": (29, 2, (3, 0), (), "FinancialPeriod", None),
		"GenerationTime": (20, 2, (7, 0), (), "GenerationTime", None),
		"InstructionNumber": (22, 2, (3, 0), (), "InstructionNumber", None),
		"JournalRemarks": (27, 2, (8, 0), (), "JournalRemarks", None),
		# Method 'Lines' returns object of type 'IWorkOrder_Lines'
		"Lines": (7, 2, (9, 0), (), "Lines", '{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}'),
		"OrderDate": (10, 2, (7, 0), (), "OrderDate", None),
		"OrderNum": (33, 2, (3, 0), (), "OrderNum", None),
		"OrderTotal": (18, 2, (5, 0), (), "OrderTotal", None),
		"OrdererCode": (15, 2, (8, 0), (), "OrdererCode", None),
		"OrdererName": (16, 2, (8, 0), (), "OrdererName", None),
		"PriceListNum": (28, 2, (3, 0), (), "PriceListNum", None),
		"ReceiverName": (14, 2, (8, 0), (), "ReceiverName", None),
		"Series": (24, 2, (3, 0), (), "Series", None),
		"Status": (8, 2, (3, 0), (), "Status", None),
		"TotalCurrency": (19, 2, (8, 0), (), "TotalCurrency", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (32, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WorkFinishDate": (13, 2, (7, 0), (), "WorkFinishDate", None),
		"WorkStartDate": (11, 2, (7, 0), (), "WorkStartDate", None),
		"WorkSum": (26, 2, (5, 0), (), "WorkSum", None),
	}
	_prop_map_put_ = {
		"ActiveAccountCode": ((25, LCID, 4, 0),()),
		"Comment": ((21, LCID, 4, 0),()),
		"ContactPerson": ((23, LCID, 4, 0),()),
		"CustomerRefNo": ((17, LCID, 4, 0),()),
		"ExpectedCompletionDate": ((12, LCID, 4, 0),()),
		"GenerationTime": ((20, LCID, 4, 0),()),
		"JournalRemarks": ((27, LCID, 4, 0),()),
		"OrderDate": ((10, LCID, 4, 0),()),
		"OrdererCode": ((15, LCID, 4, 0),()),
		"OrdererName": ((16, LCID, 4, 0),()),
		"PriceListNum": ((28, LCID, 4, 0),()),
		"ReceiverName": ((14, LCID, 4, 0),()),
		"Series": ((24, LCID, 4, 0),()),
		"Status": ((8, LCID, 4, 0),()),
		"WorkFinishDate": ((13, LCID, 4, 0),()),
		"WorkStartDate": ((11, LCID, 4, 0),()),
		"WorkSum": ((26, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class I_GenArrObj(DispatchBaseClass):
	'I_GenArrObj Interface'
	CLSID = IID('{D919D79B-2CE9-4A88-9C3D-59A67A334D81}')
	coclass_clsid = IID('{D3259ECE-289F-4B9B-9C81-AD71D8EACE67}')

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class _ICompanyEvents:
	'_ICompanyEvents Interface'
	CLSID = CLSID_Sink = IID('{57B97799-106E-4EA3-8203-1B30B6B7D463}')
	coclass_clsid = IID('{A355004F-AAB4-41D3-BDE0-7EAED1ED5FFF}')
	_public_methods_ = [] # For COM Server support
	_dispid_to_func_ = {
		        1 : "OnProgressIndicator",
		}

	def __init__(self, oobj = None):
		if oobj is None:
			self._olecp = None
		else:
			import win32com.server.util
			from win32com.server.policy import EventHandlerPolicy
			cpc=oobj._oleobj_.QueryInterface(pythoncom.IID_IConnectionPointContainer)
			cp=cpc.FindConnectionPoint(self.CLSID_Sink)
			cookie=cp.Advise(win32com.server.util.wrap(self, usePolicy=EventHandlerPolicy))
			self._olecp,self._olecp_cookie = cp,cookie
	def __del__(self):
		try:
			self.close()
		except pythoncom.com_error:
			pass
	def close(self):
		if self._olecp is not None:
			cp,cookie,self._olecp,self._olecp_cookie = self._olecp,self._olecp_cookie,None,None
			cp.Unadvise(cookie)
	def _query_interface_(self, iid):
		import win32com.server.util
		if iid==self.CLSID_Sink: return win32com.server.util.wrap(self)

	# Event Handlers
	# If you create handlers, they should have the following prototypes:
#	def OnProgressIndicator(self, MaxValue=defaultNamedNotOptArg, CurrentValue=defaultNamedNotOptArg):
#		'Progress Indicator'


from win32com.client import CoClassBaseClass
# This CoClass is known by the name 'SAPbobsCOM.ActivityLocations.90.0'
class ActivityLocations(CoClassBaseClass): # A CoClass
	# ActivityLocations Class
	CLSID = IID('{1FE6EEB5-6D21-4EE0-AC7C-8A2B181080C8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityLocations,
	]
	default_interface = IActivityLocations

# This CoClass is known by the name 'SAPbobsCOM.ActivityStatus.90.0'
class ActivityStatus(CoClassBaseClass): # A CoClass
	# ActivityStatus Class
	CLSID = IID('{07B255E1-6AF8-4615-BAC4-D258D316BF1B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityStatus,
	]
	default_interface = IActivityStatus

# This CoClass is known by the name 'SAPbobsCOM.ActivityTypes.90.0'
class ActivityTypes(CoClassBaseClass): # A CoClass
	# ActivityTypes Class
	CLSID = IID('{094BA05B-B730-4D86-8BCF-91F788C16057}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityTypes,
	]
	default_interface = IActivityTypes

# This CoClass is known by the name 'SAPbobsCOM.AdditionalExpenses.90.0'
class AdditionalExpenses(CoClassBaseClass): # A CoClass
	# AdditionalExpenses Class
	CLSID = IID('{F68150E3-371A-4D4F-990C-16CDFF1A04FA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAdditionalExpenses,
	]
	default_interface = IAdditionalExpenses

# This CoClass is known by the name 'SAPbobsCOM.AlternateCatNum.90.0'
class AlternateCatNum(CoClassBaseClass): # A CoClass
	# AlternateCatNum Class
	CLSID = IID('{BBC625E2-17DA-4434-83D6-56FE0401D9A6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlternateCatNum,
	]
	default_interface = IAlternateCatNum

# This CoClass is known by the name 'SAPbobsCOM.Attachment.90.0'
class Attachment(CoClassBaseClass): # A CoClass
	# Attachment Class
	CLSID = IID('{054C0B23-FE27-46A4-990C-901A4906BEB5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAttachment,
	]
	default_interface = IAttachment

# This CoClass is known by the name 'SAPbobsCOM.Attachments.90.0'
class Attachments(CoClassBaseClass): # A CoClass
	# Attachments Class
	CLSID = IID('{3C447394-4D07-46E5-8ADE-0E5973F97CF7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAttachments,
	]
	default_interface = IAttachments

# This CoClass is known by the name 'SAPbobsCOM.BPAccountReceivablePayble.90.0'
class BPAccountReceivablePayble(CoClassBaseClass): # A CoClass
	# BPAccountReceivablePayble Class
	CLSID = IID('{2795C6A1-A943-411B-BE58-A062A0E4711A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPAccountReceivablePayble,
	]
	default_interface = IBPAccountReceivablePayble

# This CoClass is known by the name 'SAPbobsCOM.BPAddresses.90.0'
class BPAddresses(CoClassBaseClass): # A CoClass
	# BPAddresses Class
	CLSID = IID('{1520690D-0D25-415A-B290-66DF277561FE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPAddresses,
	]
	default_interface = IBPAddresses

# This CoClass is known by the name 'SAPbobsCOM.BPBankAccounts.90.0'
class BPBankAccounts(CoClassBaseClass): # A CoClass
	# BPBankAccounts Class
	CLSID = IID('{0C9CE0A9-AA16-4C81-A474-9D960E735AA5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPBankAccounts,
	]
	default_interface = IBPBankAccounts

# This CoClass is known by the name 'SapBobsCom.BPFiscalRegistryID.90.0'
class BPFiscalRegistryID(CoClassBaseClass): # A CoClass
	# BPFiscalRegistryID Class
	CLSID = IID('{F2BCB557-408E-4D6C-B46D-7E5517D939B2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPFiscalRegistryID,
	]
	default_interface = IBPFiscalRegistryID

# This CoClass is known by the name 'SapBobsCom.BPFiscalTaxID.90.0'
class BPFiscalTaxID(CoClassBaseClass): # A CoClass
	# BPFiscalTaxID Class
	CLSID = IID('{578B1918-60ED-440F-9729-7C59AEE459E8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPFiscalTaxID,
	]
	default_interface = IBPFiscalTaxID

# This CoClass is known by the name 'SAPbobsCOM.BPPaymentDates.90.0'
class BPPaymentDates(CoClassBaseClass): # A CoClass
	# BPPaymentDates Class
	CLSID = IID('{727B34C7-DD01-4B31-9213-F5B02C5E3276}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPPaymentDates,
	]
	default_interface = IBPPaymentDates

# This CoClass is known by the name 'SAPbobsCOM.BPPaymentMethods.90.0'
class BPPaymentMethods(CoClassBaseClass): # A CoClass
	# BPPaymentMethods Class
	CLSID = IID('{9091A78F-FCC8-4399-88F3-53E1631F100F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPPaymentMethods,
	]
	default_interface = IBPPaymentMethods

# This CoClass is known by the name 'SAPbobsCOM.BPWithholdingTax.90.0'
class BPWithholdingTax(CoClassBaseClass): # A CoClass
	# BPWithholdingTax Class
	CLSID = IID('{740243E4-B946-4D50-94D9-7F7E3EC04FE9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPWithholdingTax,
	]
	default_interface = IBPWithholdingTax

# This CoClass is known by the name 'SAPbobsCOM.BankPages.90.0'
class BankPages(CoClassBaseClass): # A CoClass
	# BankPages Class
	CLSID = IID('{842BE793-D5A4-4C52-B7C1-99E189D39B8D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankPages,
	]
	default_interface = IBankPages

# This CoClass is known by the name 'SAPbobsCOM.BatchNumbers.90.0'
class BatchNumbers(CoClassBaseClass): # A CoClass
	# BatchNumbers Class
	CLSID = IID('{41172218-C619-4E35-9D03-59EAF1E0F300}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBatchNumbers,
	]
	default_interface = IBatchNumbers

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchange.90.0'
class BillOfExchange(CoClassBaseClass): # A CoClass
	# BillOfExchange Class
	CLSID = IID('{EA7AF142-F7C4-4E1A-BA6A-B5DBFCB71C3C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchange,
	]
	default_interface = IBillOfExchange

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchangeTrans_BankPages.90.0'
class BillOfExchangeTrans_BankPages(CoClassBaseClass): # A CoClass
	# BillOfExchangeTrans_BankPages Class
	CLSID = IID('{C057A0F5-A755-4C5E-A410-D4C4D1379487}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchangeTrans_BankPages,
	]
	default_interface = IBillOfExchangeTrans_BankPages

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchangeTrans_Deposits.90.0'
class BillOfExchangeTrans_Deposits(CoClassBaseClass): # A CoClass
	# BillOfExchangeTrans_Deposits Class
	CLSID = IID('{94DA073B-4599-4BC9-A22B-87D912159247}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchangeTrans_Deposits,
	]
	default_interface = IBillOfExchangeTrans_Deposits

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchangeTransaction.90.0'
class BillOfExchangeTransaction(CoClassBaseClass): # A CoClass
	# BillOfExchangeTransaction Class
	CLSID = IID('{CFAA1E6C-53D8-4C8E-A7DE-78ABE1601F30}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchangeTransaction,
	]
	default_interface = IBillOfExchangeTransaction

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchangeTransaction_Lines.90.0'
class BillOfExchangeTransaction_Lines(CoClassBaseClass): # A CoClass
	# BillOfExchangeTransaction_Lines Class
	CLSID = IID('{A8A658F8-0A8A-4CEF-B5F4-481C3D4652FA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchangeTransaction_Lines,
	]
	default_interface = IBillOfExchangeTransaction_Lines

# This CoClass is known by the name 'SAPbobsCOM.Budget.90.0'
class Budget(CoClassBaseClass): # A CoClass
	# Budget Class
	CLSID = IID('{11067A79-5484-43A2-945C-7408CDCF01E6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBudget,
	]
	default_interface = IBudget

# This CoClass is known by the name 'SAPbobsCOM.BudgetDistribution.90.0'
class BudgetDistribution(CoClassBaseClass): # A CoClass
	# BudgetDistribution Class
	CLSID = IID('{16F466DA-6A22-46AE-A5B2-5934A0194D7A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBudgetDistribution,
	]
	default_interface = IBudgetDistribution

# This CoClass is known by the name 'SAPbobsCOM.BudgetScenarios.90.0'
class BudgetScenarios(CoClassBaseClass): # A CoClass
	# BudgetScenarios Class
	CLSID = IID('{8DCD076F-BF30-45C6-822A-B23FDA1B37F5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBudgetScenarios,
	]
	default_interface = IBudgetScenarios

# This CoClass is known by the name 'SAPbobsCOM.Budget_Lines.90.0'
class Budget_Lines(CoClassBaseClass): # A CoClass
	# Budget_Lines Class
	CLSID = IID('{F105494C-B48F-4E8A-B6E7-C1947194E835}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBudget_Lines,
	]
	default_interface = IBudget_Lines

# This CoClass is known by the name 'SapBobsCom.BusinessPartnerGroups.90.0'
class BusinessPartnerGroups(CoClassBaseClass): # A CoClass
	# BusinessPartnerGroups Class
	CLSID = IID('{A3C87BAE-49A3-4A53-A50B-D20716733709}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPartnerGroups,
	]
	default_interface = IBusinessPartnerGroups

# This CoClass is known by the name 'SAPbobsCOM.BusinessPartners.90.0'
class BusinessPartners(CoClassBaseClass): # A CoClass
	# BusinessPartners Class
	CLSID = IID('{4A1DF035-9612-4CCC-B9B8-C58511D0D705}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPartners,
	]
	default_interface = IBusinessPartners

# This CoClass is known by the name 'SapBobsCom.BusinessPlaces.90.0'
class BusinessPlaces(CoClassBaseClass): # A CoClass
	# BusinessPlaces Class
	CLSID = IID('{ADDFFAB7-1BA1-4C06-8229-D3CE76605700}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPlaces,
	]
	default_interface = IBusinessPlaces

# This CoClass is known by the name 'SAPbobsCOM.ChartOfAccounts.90.0'
class ChartOfAccounts(CoClassBaseClass): # A CoClass
	# ChartOfAccounts Class
	CLSID = IID('{85EBDF2E-252D-4489-9E2F-FE17C36ACE86}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChartOfAccounts,
	]
	default_interface = IChartOfAccounts

# This CoClass is known by the name 'SAPbobsCOM.ChecksforPayment.90.0'
class ChecksforPayment(CoClassBaseClass): # A CoClass
	# ChecksforPayment Class
	CLSID = IID('{31341DF9-0A1F-4B75-BBAB-50B96478E579}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChecksforPayment,
	]
	default_interface = IChecksforPayment

# This CoClass is known by the name 'SAPbobsCOM.ChecksforPaymentLines.90.0'
class ChecksforPaymentLines(CoClassBaseClass): # A CoClass
	# ChecksforPaymentLines Class
	CLSID = IID('{36360587-E2A6-4BF4-BFED-92F2CEDDF03D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChecksforPaymentLines,
	]
	default_interface = IChecksforPaymentLines

# This CoClass is known by the name 'SAPbobsCOM.ClosingDateProcedure.90.0'
class ClosingDateProcedure(CoClassBaseClass): # A CoClass
	# ClosingDateProcedure Class
	CLSID = IID('{B50BD947-38AC-4ACE-97F4-8EA9ECD9AB77}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IClosingDateProcedure,
	]
	default_interface = IClosingDateProcedure

# This CoClass is known by the name 'SAPbobsCOM.Command.90.0'
class Command(CoClassBaseClass): # A CoClass
	# Command Class
	CLSID = IID('{15BD344C-48ED-4A6A-8A31-AFBD7A2ED57B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICommand,
	]
	default_interface = ICommand

# This CoClass is known by the name 'SAPbobsCOM.CommandParam.90.0'
class CommandParam(CoClassBaseClass): # A CoClass
	# CommandParam Class
	CLSID = IID('{13CC4089-F2FA-4B28-9BD9-75F6DC0E44B3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICommandParam,
	]
	default_interface = ICommandParam

# This CoClass is known by the name 'SAPbobsCOM.CommandParams.90.0'
class CommandParams(CoClassBaseClass): # A CoClass
	# CommandParams Class
	CLSID = IID('{9C536750-5FC9-45DF-AF6E-62DB9ACCAEA8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICommandParams,
	]
	default_interface = ICommandParams

# This CoClass is known by the name 'SAPbobsCOM.Company.6.7'
class Company(CoClassBaseClass): # A CoClass
	# Company Class
	CLSID = IID('{A355004F-AAB4-41D3-BDE0-7EAED1ED5FFF}')
	coclass_sources = [
		_ICompanyEvents,
	]
	default_source = _ICompanyEvents
	coclass_interfaces = [
		ICompany,
	]
	default_interface = ICompany

# This CoClass is known by the name 'SAPbobsCOM.ContactEmployees.90.0'
class ContactEmployees(CoClassBaseClass): # A CoClass
	# ContactEmployees Class
	CLSID = IID('{22DCA799-2F7B-4B31-ABB6-74F3C07CB367}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IContactEmployees,
	]
	default_interface = IContactEmployees

# This CoClass is known by the name 'SAPbobsCOM.Contacts.90.0'
class Contacts(CoClassBaseClass): # A CoClass
	# Contacts Class
	CLSID = IID('{161C44B9-9DAC-4D31-AB92-EED776B8C745}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IContacts,
	]
	default_interface = IContacts

# This CoClass is known by the name 'SAPbobsCOM.ContractTemplates.90.0'
class ContractTemplates(CoClassBaseClass): # A CoClass
	# ContractTemplates Class
	CLSID = IID('{835F6104-3A36-4122-8AE8-C4E1D7B15453}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IContractTemplates,
	]
	default_interface = IContractTemplates

# This CoClass is known by the name 'SAPbobsCOM.Currencies.90.0'
class Currencies(CoClassBaseClass): # A CoClass
	# Currencies Class
	CLSID = IID('{12788346-93BB-4D1C-8649-A3266A413D3F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICurrencies,
	]
	default_interface = ICurrencies

# This CoClass is known by the name 'SAPbobsCOM.CustomerEquipmentCards.90.0'
class CustomerEquipmentCards(CoClassBaseClass): # A CoClass
	# CustomerEquipmentCards Class
	CLSID = IID('{6EF2D0B5-8580-41AD-B879-42738445BE03}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICustomerEquipmentCards,
	]
	default_interface = ICustomerEquipmentCards

# This CoClass is known by the name 'SapBobsCom.CustomsGroups.90.0'
class CustomsGroups(CoClassBaseClass): # A CoClass
	# CustomsGroups Class
	CLSID = IID('{C7224CA0-BA56-4141-84AA-9E45D75208EF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICustomsGroups,
	]
	default_interface = ICustomsGroups

# This CoClass is known by the name 'SAPbobsCOM.DataBrowser.90.0'
class DataBrowser(CoClassBaseClass): # A CoClass
	# DataBrowser Class
	CLSID = IID('{0D5D4022-6FCC-49A4-AB69-7F4304B47EC9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDataBrowser,
	]
	default_interface = IDataBrowser

# This CoClass is known by the name 'SAPbobsCOM.Document_Lines.90.0'
class Document_Lines(CoClassBaseClass): # A CoClass
	# Document_Lines Class
	CLSID = IID('{E9B749CA-045B-4BDD-A5BD-143458EBA752}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocument_Lines,
	]
	default_interface = IDocument_Lines

# This CoClass is known by the name 'SAPbobsCOM.Document_LinesAdditionalExpenses.90.0'
class Document_LinesAdditionalExpenses(CoClassBaseClass): # A CoClass
	# Document_LinesAdditionalExpenses Class
	CLSID = IID('{7F3611B7-822C-41C3-82DB-2D8909B59C7A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocument_LinesAdditionalExpenses,
	]
	default_interface = IDocument_LinesAdditionalExpenses

# This CoClass is known by the name 'SAPbobsCOM.Documents.90.0'
class Documents(CoClassBaseClass): # A CoClass
	# Documents Class
	CLSID = IID('{4AFE074D-4F31-4E7B-87DF-64D55098DA5E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocuments,
	]
	default_interface = IDocuments

# This CoClass is known by the name 'SAPbobsCOM.DocumentsAdditionalExpenses.90.0'
class DocumentsAdditionalExpenses(CoClassBaseClass): # A CoClass
	# DocumentsAdditionalExpenses Class
	CLSID = IID('{5E9FC07C-E9A5-465A-A532-F12DC65304D4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocumentsAdditionalExpenses,
	]
	default_interface = IDocumentsAdditionalExpenses

# This CoClass is known by the name 'SAPbobsCOM.DunningLetters.90.0'
class DunningLetters(CoClassBaseClass): # A CoClass
	# DunningLetters Class
	CLSID = IID('{8C9A31B4-0BEA-4A72-8D4E-F4C00F683E6B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDunningLetters,
	]
	default_interface = IDunningLetters

# This CoClass is known by the name 'SAPbobsCOM.EmployeeAbsenceInfo.90.0'
class EmployeeAbsenceInfo(CoClassBaseClass): # A CoClass
	# EmployeeAbsenceInfo Class
	CLSID = IID('{A574B4DA-F87A-414B-AC49-ED8C6BF84B2C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeAbsenceInfo,
	]
	default_interface = IEmployeeAbsenceInfo

# This CoClass is known by the name 'SAPbobsCOM.EmployeeEducationInfo.90.0'
class EmployeeEducationInfo(CoClassBaseClass): # A CoClass
	# EmployeeEducationInfo Class
	CLSID = IID('{8D158412-BA39-4046-8326-2E22EE49F8C1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeEducationInfo,
	]
	default_interface = IEmployeeEducationInfo

# This CoClass is known by the name 'SAPbobsCOM.EmployeePrevEmpoymentInfo.90.0'
class EmployeePrevEmpoymentInfo(CoClassBaseClass): # A CoClass
	# EmployeePrevEmpoymentInfo Class
	CLSID = IID('{9E334DDA-DD14-48A7-8482-292392B27A13}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeePrevEmpoymentInfo,
	]
	default_interface = IEmployeePrevEmpoymentInfo

# This CoClass is known by the name 'SAPbobsCOM.EmployeeReviewsInfo.90.0'
class EmployeeReviewsInfo(CoClassBaseClass): # A CoClass
	# EmployeeReviewsInfo Class
	CLSID = IID('{3FF527E2-2FBB-4F74-BBF9-C0EDBF44E63C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeReviewsInfo,
	]
	default_interface = IEmployeeReviewsInfo

# This CoClass is known by the name 'SAPbobsCOM.EmployeeRolesInfo.90.0'
class EmployeeRolesInfo(CoClassBaseClass): # A CoClass
	# EmployeeRolesInfo Class
	CLSID = IID('{E644A5ED-C97E-4EE8-8191-E20EBC9508AB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeRolesInfo,
	]
	default_interface = IEmployeeRolesInfo

# This CoClass is known by the name 'SAPbobsCOM.EmployeesInfo.90.0'
class EmployeesInfo(CoClassBaseClass): # A CoClass
	# EmployeesInfo Class
	CLSID = IID('{EB49B71E-C20E-4D6D-8ECD-A641B0BAAA35}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeesInfo,
	]
	default_interface = IEmployeesInfo

# This CoClass is known by the name 'SAPbobsCOM.Field.90.0'
class Field(CoClassBaseClass): # A CoClass
	# Field Class
	CLSID = IID('{0B6BCB38-6594-4EAB-88A8-5EEB856FF1EB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IField,
	]
	default_interface = IField

# This CoClass is known by the name 'SAPbobsCOM.Fields.90.0'
class Fields(CoClassBaseClass): # A CoClass
	# Fields Class
	CLSID = IID('{9D3B180E-A24C-48C9-A742-093663FF1878}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFields,
	]
	default_interface = IFields

# This CoClass is known by the name 'SAPbobsCOM.Industries.90.0'
class Industries(CoClassBaseClass): # A CoClass
	# Industries Class
	CLSID = IID('{4E6D1836-16F8-4D8F-9BF8-0271F4856450}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IIndustries,
	]
	default_interface = IIndustries

# This CoClass is known by the name 'SAPbobsCOM.ItemGroups.90.0'
class ItemGroups(CoClassBaseClass): # A CoClass
	# ItemGroups Class
	CLSID = IID('{5F2AE736-E6D3-4D3A-BCB5-F9EE3A45872A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItemGroups,
	]
	default_interface = IItemGroups

# This CoClass is known by the name 'SAPbobsCOM.ItemWarehouseInfo.90.0'
class ItemWarehouseInfo(CoClassBaseClass): # A CoClass
	# ItemWarehouseInfo Class
	CLSID = IID('{494EAB50-0ED0-4773-8BCF-9F769A80B6BC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItemWarehouseInfo,
	]
	default_interface = IItemWarehouseInfo

# This CoClass is known by the name 'SAPbobsCOM.Items.90.0'
class Items(CoClassBaseClass): # A CoClass
	# Items Class
	CLSID = IID('{210393EC-DEF3-4E55-965C-C2891393A73C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItems,
	]
	default_interface = IItems

# This CoClass is known by the name 'SAPbobsCOM.Items_Prices.90.0'
class Items_Prices(CoClassBaseClass): # A CoClass
	# Items_Prices Class
	CLSID = IID('{5C63DF2C-6C18-4447-A9BB-B6277EF0DAF2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItems_Prices,
	]
	default_interface = IItems_Prices

# This CoClass is known by the name 'SAPbobsCOM.JournalEntries.90.0'
class JournalEntries(CoClassBaseClass): # A CoClass
	# JournalEntries Class
	CLSID = IID('{6E3987D0-11D5-4A95-B5B7-E5BCFE88E060}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalEntries,
	]
	default_interface = IJournalEntries

# This CoClass is known by the name 'SAPbobsCOM.JournalEntries_Lines.90.0'
class JournalEntries_Lines(CoClassBaseClass): # A CoClass
	# JournalEntries_Lines Class
	CLSID = IID('{70BFE200-77E9-4D02-B0E6-49800F3E9AD2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalEntries_Lines,
	]
	default_interface = IJournalEntries_Lines

# This CoClass is known by the name 'SAPbobsCOM.JournalVouchers.90.0'
class JournalVouchers(CoClassBaseClass): # A CoClass
	# JournalVouchers Class
	CLSID = IID('{FC75103E-6EAA-4246-A097-B6F81E9DD4A3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalVouchers,
	]
	default_interface = IJournalVouchers

# This CoClass is known by the name 'SAPbobsCOM.KnowledgeBaseSolutions.90.0'
class KnowledgeBaseSolutions(CoClassBaseClass): # A CoClass
	# KnowledgeBaseSolutions Class
	CLSID = IID('{7A042067-2E94-48B5-A7CB-3534F6223B35}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IKnowledgeBaseSolutions,
	]
	default_interface = IKnowledgeBaseSolutions

# This CoClass is known by the name 'SapBobsCom.LocalEra.90.0'
class LocalEra(CoClassBaseClass): # A CoClass
	# LocalEra Class
	CLSID = IID('{F0D891FD-5D68-466B-90C3-0EDE46E01241}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILocalEra,
	]
	default_interface = ILocalEra

# This CoClass is known by the name 'SapBobsCom.Manufacturers.90.0'
class Manufacturers(CoClassBaseClass): # A CoClass
	# Manufacturers Class
	CLSID = IID('{04C582B6-340A-4E71-B18B-460A37A04A62}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IManufacturers,
	]
	default_interface = IManufacturers

# This CoClass is known by the name 'SAPbobsCOM.MaterialRevaluation.90.0'
class MaterialRevaluation(CoClassBaseClass): # A CoClass
	# MaterialRevaluation Class
	CLSID = IID('{B133843B-6DB2-4920-976F-1C7EB0AD60A2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialRevaluation,
	]
	default_interface = IMaterialRevaluation

# This CoClass is known by the name 'SAPbobsCOM.MaterialRevaluation_lines.90.0'
class MaterialRevaluation_lines(CoClassBaseClass): # A CoClass
	# MaterialRevaluation_lines Class
	CLSID = IID('{64572B16-A58D-40D4-B869-10787D0A8EE2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialRevaluation_lines,
	]
	default_interface = IMaterialRevaluation_lines

# This CoClass is known by the name 'SAPbobsCOM.Messages.90.0'
class Messages(CoClassBaseClass): # A CoClass
	# Messages Class
	CLSID = IID('{C397C564-B506-4649-9C12-E4B63BBD7711}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessages,
	]
	default_interface = IMessages

# This CoClass is known by the name 'SAPbobsCOM.NotaFiscalCFOP.90.0'
class NotaFiscalCFOP(CoClassBaseClass): # A CoClass
	# NotaFiscalCFOP Class
	CLSID = IID('{9A38EECB-D61C-469C-9425-C66BAAA0623E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INotaFiscalCFOP,
	]
	default_interface = INotaFiscalCFOP

# This CoClass is known by the name 'SAPbobsCOM.NotaFiscalCST.90.0'
class NotaFiscalCST(CoClassBaseClass): # A CoClass
	# NotaFiscalCST Class
	CLSID = IID('{7CD6F364-32D1-4862-8470-E27D69A03F08}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INotaFiscalCST,
	]
	default_interface = INotaFiscalCST

# This CoClass is known by the name 'SAPbobsCOM.NotaFiscalUsage.90.0'
class NotaFiscalUsage(CoClassBaseClass): # A CoClass
	# NotaFiscalUsage Class
	CLSID = IID('{2C3D3B79-8BCD-4CF4-981D-1033A54CBF17}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INotaFiscalUsage,
	]
	default_interface = INotaFiscalUsage

# This CoClass is known by the name 'SAPbobsCOM.PackagesTypes.90.0'
class PackagesTypes(CoClassBaseClass): # A CoClass
	# PackagesTypes Class
	CLSID = IID('{84FAFD4C-5213-4CB8-9F2F-7FECB428F0ED}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPackagesTypes,
	]
	default_interface = IPackagesTypes

# This CoClass is known by the name 'SAPbobsCOM.PaymentRunExport.90.0'
class PaymentRunExport(CoClassBaseClass): # A CoClass
	# PaymentRunExport Class
	CLSID = IID('{856AB71E-0D54-4BA5-95CA-7135D77040EC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentRunExport,
	]
	default_interface = IPaymentRunExport

class PaymentRunExport_Lines(CoClassBaseClass): # A CoClass
	# PaymentRunExport_Lines Class
	CLSID = IID('{A2A9F005-92C0-4949-B2D7-92B7D8AAA784}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentRunExport_Lines,
	]
	default_interface = IPaymentRunExport_Lines

# This CoClass is known by the name 'SAPbobsCOM.PaymentTermsTypes.90.0'
class PaymentTermsTypes(CoClassBaseClass): # A CoClass
	# PaymentTermsTypes Class
	CLSID = IID('{403E32F9-EBDD-4528-89C2-FE8BE8F7F0A6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentTermsTypes,
	]
	default_interface = IPaymentTermsTypes

# This CoClass is known by the name 'SAPbobsCOM.Payments.90.0'
class Payments(CoClassBaseClass): # A CoClass
	# Payments Class
	CLSID = IID('{A52ED4BA-1C19-4553-9A60-D69B653E8CB5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments,
	]
	default_interface = IPayments

# This CoClass is known by the name 'SAPbobsCOM.Payments_Accounts.90.0'
class Payments_Accounts(CoClassBaseClass): # A CoClass
	# Payments_Accounts Class
	CLSID = IID('{0E77E5DB-93A3-4FCF-BB4B-BE8323F27387}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments_Accounts,
	]
	default_interface = IPayments_Accounts

# This CoClass is known by the name 'SAPbobsCOM.Payments_Checks.90.0'
class Payments_Checks(CoClassBaseClass): # A CoClass
	# Payments_Checks Class
	CLSID = IID('{6155B8DA-5812-48F9-8955-67CE75857600}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments_Checks,
	]
	default_interface = IPayments_Checks

# This CoClass is known by the name 'SAPbobsCOM.Payments_CreditCards.90.0'
class Payments_CreditCards(CoClassBaseClass): # A CoClass
	# Payments_CreditCards Class
	CLSID = IID('{1C972937-3B53-45EE-9728-516996023C1A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments_CreditCards,
	]
	default_interface = IPayments_CreditCards

# This CoClass is known by the name 'SAPbobsCOM.Payments_Invoices.90.0'
class Payments_Invoices(CoClassBaseClass): # A CoClass
	# Payments_Invoices Class
	CLSID = IID('{ADCC23F1-37CE-4327-BE13-88D1E14F8877}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments_Invoices,
	]
	default_interface = IPayments_Invoices

# This CoClass is known by the name 'SAPbobsCOM.PriceLists.90.0'
class PriceLists(CoClassBaseClass): # A CoClass
	# PriceLists Class
	CLSID = IID('{C7E88977-022A-494D-BC9D-09FA85E7AC15}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPriceLists,
	]
	default_interface = IPriceLists

# This CoClass is known by the name 'SAPbobsCOM.ProductTrees.90.0'
class ProductTrees(CoClassBaseClass): # A CoClass
	# ProductTrees Class
	CLSID = IID('{B2CC6793-FFCF-4389-980D-B5FF458B2EC8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProductTrees,
	]
	default_interface = IProductTrees

# This CoClass is known by the name 'SAPbobsCOM.ProductTrees_Lines.90.0'
class ProductTrees_Lines(CoClassBaseClass): # A CoClass
	# ProductTrees_Lines Class
	CLSID = IID('{D9F478E8-7891-4C69-A96D-39D5881CFE39}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProductTrees_Lines,
	]
	default_interface = IProductTrees_Lines

# This CoClass is known by the name 'SapBobsCom.ProductionOrders.90.0'
class ProductionOrders(CoClassBaseClass): # A CoClass
	# ProductionOrders Class
	CLSID = IID('{37C235F6-0465-4E85-80A0-776D4602B09B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProductionOrders,
	]
	default_interface = IProductionOrders

# This CoClass is known by the name 'SapBobsCom.ProductionOrders_Lines.90.0'
class ProductionOrders_Lines(CoClassBaseClass): # A CoClass
	# ProductionOrders_Lines Class
	CLSID = IID('{9AC69118-AA6E-44B4-ACDC-176426BCBA1C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProductionOrders_Lines,
	]
	default_interface = IProductionOrders_Lines

# This CoClass is known by the name 'SAPbobsCOM.QueryCategories.90.0'
class QueryCategories(CoClassBaseClass): # A CoClass
	# QueryCategories Class
	CLSID = IID('{D89C1B1F-B7A1-4669-B80D-E3A041767ABE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IQueryCategories,
	]
	default_interface = IQueryCategories

# This CoClass is known by the name 'SAPbobsCOM.Queue.90.0'
class Queue(CoClassBaseClass): # A CoClass
	# Queue Class
	CLSID = IID('{EA2133A7-F8D4-4444-834F-1129CE2081EB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IQueue,
	]
	default_interface = IQueue

# This CoClass is known by the name 'SAPbobsCOM.QueueMembers.90.0'
class QueueMembers(CoClassBaseClass): # A CoClass
	# QueueMembers Class
	CLSID = IID('{79148B90-9790-418A-B904-DA8C72CCCDDF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IQueueMembers,
	]
	default_interface = IQueueMembers

# This CoClass is known by the name 'SAPbobsCOM.Recipients.90.0'
class Recipients(CoClassBaseClass): # A CoClass
	# Recipients Class
	CLSID = IID('{921DBA91-7B93-4AEB-859C-C4452CA0F739}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRecipients,
	]
	default_interface = IRecipients

# This CoClass is known by the name 'SAPbobsCOM.Recordset.90.0'
class Recordset(CoClassBaseClass): # A CoClass
	# Recordset Class
	CLSID = IID('{11FA87EF-9F44-4528-AE1D-DAF92AEA3545}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRecordset,
	]
	default_interface = IRecordset

# This CoClass is known by the name 'SAPbobsCOM.Relationships.90.0'
class Relationships(CoClassBaseClass): # A CoClass
	# Relationships Class
	CLSID = IID('{097DDC08-E989-4426-87DB-9EFAD0FF64C3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRelationships,
	]
	default_interface = IRelationships

# This CoClass is known by the name 'SAPbobsCOM.SBObob.90.0'
class SBObob(CoClassBaseClass): # A CoClass
	# SBObob Class
	CLSID = IID('{A740D0B2-649F-40A6-AF5E-77FF340AEEFD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISBObob,
	]
	default_interface = ISBObob

# This CoClass is known by the name 'SAPbobsCOM.SalesForecast.90.0'
class SalesForecast(CoClassBaseClass): # A CoClass
	# SalesForecast Class
	CLSID = IID('{3E6CC39D-A5A5-43E7-856E-4A1D4D97A77D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesForecast,
	]
	default_interface = ISalesForecast

# This CoClass is known by the name 'SAPbobsCOM.SalesForecast_Lines.90.0'
class SalesForecast_Lines(CoClassBaseClass): # A CoClass
	# SalesForecast_Lines Class
	CLSID = IID('{8B560D21-5616-4D85-ACA9-BC8145B30A73}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesForecast_Lines,
	]
	default_interface = ISalesForecast_Lines

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunities.90.0'
class SalesOpportunities(CoClassBaseClass): # A CoClass
	# SalesOpportunities Class
	CLSID = IID('{E7843EA1-A67D-4C9A-B61D-EABDE49D4692}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunities,
	]
	default_interface = ISalesOpportunities

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesCompetition.90.0'
class SalesOpportunitiesCompetition(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesCompetition Class
	CLSID = IID('{C27CB0AA-2304-4D4E-B292-8ED9651F34A3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesCompetition,
	]
	default_interface = ISalesOpportunitiesCompetition

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesInterests.90.0'
class SalesOpportunitiesInterests(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesInterests Class
	CLSID = IID('{D48A6D0F-F063-4ED4-B1E1-59B6998EE91A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesInterests,
	]
	default_interface = ISalesOpportunitiesInterests

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesLines.90.0'
class SalesOpportunitiesLines(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesLines Class
	CLSID = IID('{B9FED360-AD27-45E1-AB8A-714FB217B022}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesLines,
	]
	default_interface = ISalesOpportunitiesLines

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesPartners.90.0'
class SalesOpportunitiesPartners(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesPartners Class
	CLSID = IID('{0DA4D491-BDE7-4126-81E1-BCDA814B5332}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesPartners,
	]
	default_interface = ISalesOpportunitiesPartners

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesReasons.90.0'
class SalesOpportunitiesReasons(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesReasons Class
	CLSID = IID('{C3B4DABB-A057-4D70-AE0C-7ABD7A4254B0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesReasons,
	]
	default_interface = ISalesOpportunitiesReasons

# This CoClass is known by the name 'SAPbobsCOM.SalesTaxAuthorities.90.0'
class SalesTaxAuthorities(CoClassBaseClass): # A CoClass
	# SalesTaxAuthorities Class
	CLSID = IID('{7F146AF0-3304-4133-BC4F-48797C66B12F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesTaxAuthorities,
	]
	default_interface = ISalesTaxAuthorities

# This CoClass is known by the name 'SAPbobsCOM.SalesTaxAuthoritiesTypes.90.0'
class SalesTaxAuthoritiesTypes(CoClassBaseClass): # A CoClass
	# SalesTaxAuthoritiesTypes Class
	CLSID = IID('{717F1B41-306E-4695-8F4E-7DACA54EA87B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesTaxAuthoritiesTypes,
	]
	default_interface = ISalesTaxAuthoritiesTypes

# This CoClass is known by the name 'SAPbobsCOM.SalesTaxCodes.90.0'
class SalesTaxCodes(CoClassBaseClass): # A CoClass
	# SalesTaxCodes Class
	CLSID = IID('{97C9DB0B-4DBF-4EEA-98A9-04EE1F5B031E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesTaxCodes,
	]
	default_interface = ISalesTaxCodes

# This CoClass is known by the name 'SAPbobsCOM.SalesTaxCodes_Lines.90.0'
class SalesTaxCodes_Lines(CoClassBaseClass): # A CoClass
	# SalesTaxCodes_Lines Class
	CLSID = IID('{4385C84B-AE8C-424F-9071-546FF9E1D503}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesTaxCodes_Lines,
	]
	default_interface = ISalesTaxCodes_Lines

# This CoClass is known by the name 'SAPbobsCOM.SerialNumbers.90.0'
class SerialNumbers(CoClassBaseClass): # A CoClass
	# SerialNumbers Class
	CLSID = IID('{6BA3F221-1146-4650-AE35-03C139F04C02}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISerialNumbers,
	]
	default_interface = ISerialNumbers

# This CoClass is known by the name 'SAPbobsCOM.ServiceCallActivities.90.0'
class ServiceCallActivities(CoClassBaseClass): # A CoClass
	# ServiceCallActivities Class
	CLSID = IID('{0ED9BFD6-A5ED-40D2-8645-BE4ED8AC9CE5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallActivities,
	]
	default_interface = IServiceCallActivities

# This CoClass is known by the name 'SAPbobsCOM.ServiceCallInventoryExpenses.90.0'
class ServiceCallInventoryExpenses(CoClassBaseClass): # A CoClass
	# ServiceCallInventoryExpenses Class
	CLSID = IID('{692B8669-26B5-4D4F-A768-F92576E3EF85}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallInventoryExpenses,
	]
	default_interface = IServiceCallInventoryExpenses

# This CoClass is known by the name 'SAPbobsCOM.ServiceCallSolutions.90.0'
class ServiceCallSolutions(CoClassBaseClass): # A CoClass
	# ServiceCallSolutions Class
	CLSID = IID('{71ECA915-CB27-41B1-9E9F-DF819F1C52D6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallSolutions,
	]
	default_interface = IServiceCallSolutions

# This CoClass is known by the name 'SAPbobsCOM.ServiceCalls.90.0'
class ServiceCalls(CoClassBaseClass): # A CoClass
	# ServiceCalls Class
	CLSID = IID('{41501B90-66B9-49BC-920E-EAEF90F119B2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCalls,
	]
	default_interface = IServiceCalls

# This CoClass is known by the name 'SAPbobsCOM.ServiceContract_Lines.90.0'
class ServiceContract_Lines(CoClassBaseClass): # A CoClass
	# ServiceContract_Lines Class
	CLSID = IID('{8F1131E9-C31E-4F6D-BC3A-1F94AE2CEACF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceContract_Lines,
	]
	default_interface = IServiceContract_Lines

# This CoClass is known by the name 'SAPbobsCOM.ServiceContracts.90.0'
class ServiceContracts(CoClassBaseClass): # A CoClass
	# ServiceContracts Class
	CLSID = IID('{3267FC28-5E07-4BA5-B072-C8F160D7C1C4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceContracts,
	]
	default_interface = IServiceContracts

# This CoClass is known by the name 'SapBobsCom.ShippingTypes.90.0'
class ShippingTypes(CoClassBaseClass): # A CoClass
	# ShippingTypes Class
	CLSID = IID('{AFB12D1C-F0C3-4FA6-BF53-CA858C1BE796}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IShippingTypes,
	]
	default_interface = IShippingTypes

# This CoClass is known by the name 'SAPbobsCOM.SpecialPrices.90.0'
class SpecialPrices(CoClassBaseClass): # A CoClass
	# SpecialPrices Class
	CLSID = IID('{4F6D3681-33BD-41F5-BFEA-DE2059E4ADF4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISpecialPrices,
	]
	default_interface = ISpecialPrices

# This CoClass is known by the name 'SAPbobsCOM.SpecialPricesDataAreas.90.0'
class SpecialPricesDataAreas(CoClassBaseClass): # A CoClass
	# SpecialPricesDataAreas Class
	CLSID = IID('{7A1326F7-9545-4AAC-B875-C317CF7D76B4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISpecialPricesDataAreas,
	]
	default_interface = ISpecialPricesDataAreas

# This CoClass is known by the name 'SAPbobsCOM.SpecialPricesQuantityAreas.90.0'
class SpecialPricesQuantityAreas(CoClassBaseClass): # A CoClass
	# SpecialPricesQuantityAreas Class
	CLSID = IID('{36E908CF-6A46-413F-8BD6-C027651A58EA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISpecialPricesQuantityAreas,
	]
	default_interface = ISpecialPricesQuantityAreas

# This CoClass is known by the name 'SAPbobsCOM.StockTaking.90.0'
class StockTaking(CoClassBaseClass): # A CoClass
	# StockTaking Class
	CLSID = IID('{CBC0A7DF-E458-45B8-B640-955215643708}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStockTaking,
	]
	default_interface = IStockTaking

# This CoClass is known by the name 'SAPbobsCOM.StockTransfer.90.0'
class StockTransfer(CoClassBaseClass): # A CoClass
	# StockTransfer Class
	CLSID = IID('{E2174012-44BF-4A47-B117-283D13C66C5E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStockTransfer,
	]
	default_interface = IStockTransfer

# This CoClass is known by the name 'SAPbobsCOM.StockTransfer_Lines.90.0'
class StockTransfer_Lines(CoClassBaseClass): # A CoClass
	# StockTransfer_Lines Class
	CLSID = IID('{9C11E37D-538D-4819-85D1-00048E759E11}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStockTransfer_Lines,
	]
	default_interface = IStockTransfer_Lines

# This CoClass is known by the name 'SAPbobsCOM.TaxExtension.90.0'
class TaxExtension(CoClassBaseClass): # A CoClass
	# TaxExtension Class
	CLSID = IID('{94BACBC3-E916-4D1F-9469-F7F44F8E39F0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxExtension,
	]
	default_interface = ITaxExtension

# This CoClass is known by the name 'SAPbobsCOM.TaxInvoice_Lines.90.0'
class TaxInvoice_Lines(CoClassBaseClass): # A CoClass
	# TaxInvoice_Lines Class
	CLSID = IID('{411526CA-B3C4-489C-B4FB-6539B5BF09C2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxInvoice_Lines,
	]
	default_interface = ITaxInvoice_Lines

# This CoClass is known by the name 'SAPbobsCOM.TaxInvoices.90.0'
class TaxInvoices(CoClassBaseClass): # A CoClass
	# TaxInvoices Class
	CLSID = IID('{2393BA89-A02B-4E4E-8703-0412A8B757C4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxInvoices,
	]
	default_interface = ITaxInvoices

class TeamMembers(CoClassBaseClass): # A CoClass
	# TeamMembers Class
	CLSID = IID('{D562FBDC-788B-4D80-B9EB-9238CC4EF91C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITeamMembers,
	]
	default_interface = ITeamMembers

class Teams(CoClassBaseClass): # A CoClass
	# Teams Class
	CLSID = IID('{65ABB505-DD62-4C94-8E7B-BF63BC35E51E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITeams,
	]
	default_interface = ITeams

# This CoClass is known by the name 'SAPbobsCOM.Territories.90.0'
class Territories(CoClassBaseClass): # A CoClass
	# Territories Class
	CLSID = IID('{B03EE5C0-48D5-4E20-A33A-FF2DBE5AF478}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITerritories,
	]
	default_interface = ITerritories

# This CoClass is known by the name 'SAPbobsCOM.UserFields.90.0'
class UserFields(CoClassBaseClass): # A CoClass
	# UserFields Class
	CLSID = IID('{A994F7F0-BF16-4C8E-B03C-74CE9EF2ECF5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserFields,
	]
	default_interface = IUserFields

# This CoClass is known by the name 'SAPbobsCOM.UserFieldsMD.90.0'
class UserFieldsMD(CoClassBaseClass): # A CoClass
	# UserFieldsMD Class
	CLSID = IID('{E944AF70-E7E5-4414-833E-A62BFCF9EA65}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserFieldsMD,
	]
	default_interface = IUserFieldsMD

# This CoClass is known by the name 'SAPbobsCOM.UserKeysMD.90.0'
class UserKeysMD(CoClassBaseClass): # A CoClass
	# UserKeysMD Class
	CLSID = IID('{208C7E76-4919-4468-AE9E-13976C9BE255}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserKeysMD,
	]
	default_interface = IUserKeysMD

# This CoClass is known by the name 'SAPbobsCOM.UserKeysMD_Elements.90.0'
class UserKeysMD_Elements(CoClassBaseClass): # A CoClass
	# UserKeysMD_Elements Class
	CLSID = IID('{A2120F6A-992A-4AAE-A98B-F573035921E8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserKeysMD_Elements,
	]
	default_interface = IUserKeysMD_Elements

# This CoClass is known by the name 'SAPbobsCOM.UserObjectMD_ChildTables.90.0'
class UserObjectMD_ChildTables(CoClassBaseClass): # A CoClass
	# UserObjectMD_ChildTables Class
	CLSID = IID('{28F2FDF3-FCEC-4D90-983B-D4C805891EC0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserObjectMD_ChildTables,
	]
	default_interface = IUserObjectMD_ChildTables

# This CoClass is known by the name 'SAPbobsCOM.UserObjectMD_FindColumns.90.0'
class UserObjectMD_FindColumns(CoClassBaseClass): # A CoClass
	# UserObjectMD_FindColumns Class
	CLSID = IID('{1C59C249-B65E-472F-80BB-EE0A05F75666}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserObjectMD_FindColumns,
	]
	default_interface = IUserObjectMD_FindColumns

# This CoClass is known by the name 'SAPbobsCOM.UserObjectMD_FormColumns.90.0'
class UserObjectMD_FormColumns(CoClassBaseClass): # A CoClass
	# UserObjectMD_FormColumns Class
	CLSID = IID('{C1A276C6-FD68-4693-8D70-D9A7A3E69712}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserObjectMD_FormColumns,
	]
	default_interface = IUserObjectMD_FormColumns

# This CoClass is known by the name 'SAPbobsCOM.UserObjectsMD.90.0'
class UserObjectsMD(CoClassBaseClass): # A CoClass
	# UserDefinedObjects Class
	CLSID = IID('{8AEF84A8-9762-4736-A6BC-778EA10CA4C2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserObjectsMD,
	]
	default_interface = IUserObjectsMD

# This CoClass is known by the name 'SAPbobsCOM.UserPermission.90.0'
class UserPermission(CoClassBaseClass): # A CoClass
	# UserPermission Class
	CLSID = IID('{F9779E16-EDDF-4C59-B80D-A24F34EA1ECE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserPermission,
	]
	default_interface = IUserPermission

# This CoClass is known by the name 'SAPbobsCOM.ExtendUserPermTree.90.0'
class UserPermissionForms(CoClassBaseClass): # A CoClass
	# ExtendUserPermTree Class
	CLSID = IID('{6D4864DD-75DF-4305-A8CB-C7E2381DD7B3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserPermissionForms,
	]
	default_interface = IUserPermissionForms

# This CoClass is known by the name 'SAPbobsCOM.UserPermissionTree.90.0'
class UserPermissionTree(CoClassBaseClass): # A CoClass
	# UserPermissionTree Class
	CLSID = IID('{950BE47C-4B36-49F3-A313-57146222DC3C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserPermissionTree,
	]
	default_interface = IUserPermissionTree

# This CoClass is known by the name 'SAPbobsCOM.UserTable.90.0'
class UserTable(CoClassBaseClass): # A CoClass
	# UserTable Class
	CLSID = IID('{EBB0F6A6-D704-41FF-8D22-CC3B76407F5B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserTable,
	]
	default_interface = IUserTable

# This CoClass is known by the name 'SAPbobsCOM.UserTables.90.0'
class UserTables(CoClassBaseClass): # A CoClass
	# UserTables Class
	CLSID = IID('{CD793E21-582C-4408-8AF7-1B256D29BF5A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserTables,
	]
	default_interface = IUserTables

# This CoClass is known by the name 'SAPbobsCOM.UserTablesMD.90.0'
class UserTablesMD(CoClassBaseClass): # A CoClass
	# UserTablesMD Class
	CLSID = IID('{04A02F02-1211-4507-87DB-DBE6A4807718}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserTablesMD,
	]
	default_interface = IUserTablesMD

# This CoClass is known by the name 'SAPbobsCOM.Users.90.0'
class Users(CoClassBaseClass): # A CoClass
	# Users Class
	CLSID = IID('{1B0F044E-5955-4426-8CEE-885A8388A8F9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUsers,
	]
	default_interface = IUsers

# This CoClass is known by the name 'SAPbobsCOM.ValidValue.90.0'
class ValidValue(CoClassBaseClass): # A CoClass
	# ValidValue Class
	CLSID = IID('{4838BBDC-5B48-44EF-A7F7-A705BB07B24F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IValidValue,
	]
	default_interface = IValidValue

# This CoClass is known by the name 'SAPbobsCOM.ValidValues.90.0'
class ValidValues(CoClassBaseClass): # A CoClass
	# ValidValues Class
	CLSID = IID('{C54F7212-C3DC-4E35-B61C-73E6297F1AD6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IValidValues,
	]
	default_interface = IValidValues

# This CoClass is known by the name 'SAPbobsCOM.ValidValuesMD.90.0'
class ValidValuesMD(CoClassBaseClass): # A CoClass
	# ValidValuesMD Class
	CLSID = IID('{C868B9F4-6EC8-4A28-81AF-546DD81B1083}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IValidValuesMD,
	]
	default_interface = IValidValuesMD

# This CoClass is known by the name 'SAPbobsCOM.Warehouses.90.0'
class Warehouses(CoClassBaseClass): # A CoClass
	# Warehouses Class
	CLSID = IID('{57544A70-71BC-4A35-B018-BB43DD24941A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWarehouses,
	]
	default_interface = IWarehouses

# This CoClass is known by the name 'SAPbobsCOM.WithholdingTaxData.90.0'
class WithholdingTaxData(CoClassBaseClass): # A CoClass
	# WithholdingTaxData Class
	CLSID = IID('{F00B2064-7046-4E6A-9286-1284170CFA80}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWithholdingTaxData,
	]
	default_interface = IWithholdingTaxData

# This CoClass is known by the name 'SapBobsCom.WithholdingTaxLines.90.0'
class WithholdingTaxLines(CoClassBaseClass): # A CoClass
	# WithholdingTaxLines Class
	CLSID = IID('{95AF3307-477A-4189-A934-CC32F18264F7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWithholdingTaxLines,
	]
	default_interface = IWithholdingTaxLines

# This CoClass is known by the name 'SAPbobsCOM.WorkOrder_Lines.90.0'
class WorkOrder_Lines(CoClassBaseClass): # A CoClass
	# WorkOrder_Lines Class
	CLSID = IID('{457F56A9-7F85-4ABF-91A4-5384A0CED40C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWorkOrder_Lines,
	]
	default_interface = IWorkOrder_Lines

# This CoClass is known by the name 'SAPbobsCOM.WorkOrders.90.0'
class WorkOrders(CoClassBaseClass): # A CoClass
	# WorkOrders Class
	CLSID = IID('{0C610415-1BAF-4B92-B485-23D9F3E5AA9E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWorkOrders,
	]
	default_interface = IWorkOrders

# This CoClass is known by the name 'SAPbobsCOM._GenArrObj.90.0'
class _GenArrObj(CoClassBaseClass): # A CoClass
	# _GenArrObj Class
	CLSID = IID('{D3259ECE-289F-4B9B-9C81-AD71D8EACE67}')
	coclass_sources = [
	]
	coclass_interfaces = [
		I_GenArrObj,
	]
	default_interface = I_GenArrObj

IActivityLocations_vtables_dispatch_ = 1
IActivityLocations_vtables_ = [
	(( u'Code' , u'plVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IActivityStatus_vtables_dispatch_ = 1
IActivityStatus_vtables_ = [
	(( u'StatusDescription' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'StatusDescription' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'StatusId' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'StatusName' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'StatusName' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ActivityID' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 6, (6, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IActivityTypes_vtables_dispatch_ = 1
IActivityTypes_vtables_ = [
	(( u'Code' , u'plVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IAdditionalExpenses_vtables_dispatch_ = 1
IAdditionalExpenses_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ExpnsCode' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccount' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccount' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'FixedAmountRevenues' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'FixedAmountRevenues' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'FixedAmountExpenses' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'FixedAmountExpenses' , u'pVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'OutputVATGroup' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'OutputVATGroup' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'InputVATGroup' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'InputVATGroup' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DistributionMethod' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DistributionMethod' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Includein1099' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Includein1099' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'FreightOffsetAccount' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'FreightOffsetAccount' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ExpensCode' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
]

IAlternateCatNum_vtables_dispatch_ = 1
IAlternateCatNum_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Substitute' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Substitute' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ItemCode' , u'CardCode' , u'Substitute' , u'Found' , 
			), 11, (11, (), [ (8, 1, None, None) , (8, 1, None, None) , (8, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IAttachment_vtables_dispatch_ = 1
IAttachment_vtables_ = [
	(( u'FileName' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'FileName' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
]

IAttachments_vtables_dispatch_ = 1
IAttachments_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{18B4A57B-206A-4CF7-B94B-7325AED96137}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Refresh' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 1 , )),
]

IBPAccountReceivablePayble_vtables_dispatch_ = 1
IBPAccountReceivablePayble_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AccountType' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AccountType' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBPAddresses_vtables_dispatch_ = 1
IBPAddresses_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
]

IBPBankAccounts_vtables_dispatch_ = 1
IBPBankAccounts_vtables_ = [
	(( u'LogInstance' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LogInstance' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserNo4' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserNo4' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UserNo2' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserNo2' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ControlKey' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ControlKey' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'UserNo3' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'UserNo3' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'AccountNo' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'AccountNo' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'UserNo1' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'UserNo1' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'InternalKey' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'InternalKey' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 22, (22, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 23, (23, (), [ ], 1 , 1 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 24, (24, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'BIK' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'BIK' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'CorrespondentAccount' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'CorrespondentAccount' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
]

IBPFiscalRegistryID_vtables_dispatch_ = 1
IBPFiscalRegistryID_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lGroupCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CNAECode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CNAECode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IBPFiscalTaxID_vtables_dispatch_ = 1
IBPFiscalTaxID_vtables_ = [
	(( u'UserFields' , u'ppRsltVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TaxId0' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TaxId0' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TaxId1' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TaxId1' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TaxId2' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxId2' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxId3' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxId3' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxId4' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxId4' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxId5' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxId5' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TaxId6' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxId6' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TaxId7' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TaxId7' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'TaxId8' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'TaxId8' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'TaxId9' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'TaxId9' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TaxId10' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TaxId10' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TaxId11' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TaxId11' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'CNAECode' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'CNAECode' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
]

IBPPaymentDates_vtables_dispatch_ = 1
IBPPaymentDates_vtables_ = [
	(( u'PaymentDate' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDate' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 4, (4, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IBPPaymentMethods_vtables_dispatch_ = 1
IBPPaymentMethods_vtables_ = [
	(( u'PaymentMethodCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 4, (4, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IBPWithholdingTax_vtables_dispatch_ = 1
IBPWithholdingTax_vtables_ = [
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 4, (4, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IBankPages_vtables_dispatch_ = 1
IBankPages_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AccountCode' , u'Sequence' , u'Found' , ), 5, (5, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Sequence' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DebitAmount' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DebitAmount' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CreditAmount' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CreditAmount' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BankMatch' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DataSource' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'StatementNumber' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'StatementNumber' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumber' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumber' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'PaymentCreated' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'PaymentCreated' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DocNumberType' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DocNumberType' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReference' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReference' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumberEx' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumberEx' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
]

IBatchNumbers_vtables_dispatch_ = 1
IBatchNumbers_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BatchNumber' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BatchNumber' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNumber' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNumber' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNumber' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNumber' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ExpiryDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ExpiryDate' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturingDate' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturingDate' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AddmisionDate' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AddmisionDate' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BaseLineNumber' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BaseLineNumber' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IBillOfExchange_vtables_dispatch_ = 1
IBillOfExchange_vtables_ = [
	(( u'BillOfExchangeNo' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeNo' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeDueDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeDueDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceNo' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceNo' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCode' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCode' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BPBankAct' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BPBankAct' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCountry' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCountry' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ControlKey' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus1' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus1' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus2' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus2' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus3' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus3' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 28, (28, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
]

IBillOfExchangeTrans_BankPages_vtables_dispatch_ = 1
IBillOfExchangeTrans_BankPages_vtables_ = [
	(( u'AccountCode' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Sequence' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Sequence' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IBillOfExchangeTrans_Deposits_vtables_dispatch_ = 1
IBillOfExchangeTrans_Deposits_vtables_ = [
	(( u'DepositNorm' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'DepositNorm' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'PostingType' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'PostingType' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BankDepositAccount' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BankDepositAccount' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IBillOfExchangeTransaction_vtables_dispatch_ = 1
IBillOfExchangeTransaction_vtables_ = [
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'InternalKey' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'StatusFrom' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'StatusFrom' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StatusTo' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'StatusTo' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TransactionDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TransactionTime' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'IsBoeReconciled' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'IsBoeReconciled' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TransactionNumber' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{2DBFED56-4DB4-455A-9C22-E2C01C052D39}')") , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Deposits' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BankPages' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}')") , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 17, (17, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BOETransactionkey' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IBillOfExchangeTransaction_Lines_vtables_dispatch_ = 1
IBillOfExchangeTransaction_Lines_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeNo' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeNo' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeType' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeType' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeDueDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IBudget_vtables_dispatch_ = 1
IBudget_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 4, (4, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualExpensesCreditSys' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualExpensesCreditLoc' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualExpensesDebitSys' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualExpensesDebitLoc' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualRevenuesCredit' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualRevenuesDebit' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'FutureRevenuesDebitSys' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FutureRevenuesDebitLoc' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ParentAccPercent' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ParentAccPercent' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'StartofFiscalYear' , u'pVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ParentAccountKey' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ParentAccountKey' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetDebitSys' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetDebitSys' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BudgetBalanceDebitSys' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BudgetBalanceDebitLoc' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetDebitLoc' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetDebitLoc' , u'pVal' , ), 21, (21, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetCreditSys' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetCreditSys' , u'pVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetCreditLoc' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetCreditLoc' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BudgetBalanceCreditSys' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BudgetBalanceCreditLoc' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DivisionCode' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DivisionCode' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 29, (29, (), [ (16393, 10, None, "IID('{D2BAB599-C7C6-4301-B925-B6BB51092A79}')") , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 30, (30, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 31, (31, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'BudgetScenario' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BudgetScenario' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
]

IBudgetDistribution_vtables_dispatch_ = 1
IBudgetDistribution_vtables_ = [
	(( u'September' , u'pVal' , ), 1, (1, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'September' , u'pVal' , ), 1, (1, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'August' , u'pVal' , ), 2, (2, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'August' , u'pVal' , ), 2, (2, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'July' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'July' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'June' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'June' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'May' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'May' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'April' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'April' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'March' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'March' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'February' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'February' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'December' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'December' , u'pVal' , ), 9, (9, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'November' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'November' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'October' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'October' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'January' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'January' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAmount' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAmount' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DivisionCode' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lBgdCode' , u'Found' , ), 19, (19, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 20, (20, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
]

IBudgetScenarios_vtables_dispatch_ = 1
IBudgetScenarios_vtables_ = [
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'InitialRatioPercentage' , u'pVal' , ), 2, (2, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'InitialRatioPercentage' , u'pVal' , ), 2, (2, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'StartofFiscalYear' , u'pVal' , ), 3, (3, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StartofFiscalYear' , u'pVal' , ), 3, (3, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BasicBudget' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BasicBudget' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsID' , u'Found' , ), 9, (9, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 10, (10, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
]

IBudget_Lines_vtables_dispatch_ = 1
IBudget_Lines_vtables_ = [
	(( u'PrecentOfAnnualBudgetAmount' , u'pVal' , ), 1, (1, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'RowDetails' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'RowDetails' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FutExpenSysDebit' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FutExpenDebit' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FutExpenSysCredit' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FutExpenCredit' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FutIncomesSysCredit' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FutIncomesSysDebit' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'FutIncomesCredit' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BudgetSysTotDebit' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BudgetSysTotDebit' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BalSysTotDebit' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BalTotDebit' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BudgetTotCredit' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BudgetTotCredit' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BudgetSysTotCredit' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BudgetSysTotCredit' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BudgetTotDebit' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BudgetTotDebit' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BalSysTotCredit' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BalTotCredit' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'BudgetKey' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 24, (24, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 25, (25, (), [ ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'FutureIncomeDeb' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
]

IBusinessPartnerGroups_vtables_dispatch_ = 1
IBusinessPartnerGroups_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lGroupCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IBusinessPartners_vtables_dispatch_ = 1
IBusinessPartners_vtables_ = [
	(( u'CardCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'CardType' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'CardType' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'MailAddress' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'MailAddress' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MailZipCode' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MailZipCode' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Phone1' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Phone1' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Phone2' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Phone2' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PayTermsGrpCode' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PayTermsGrpCode' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CreditLimit' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CreditLimit' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'MaxCommitment' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'MaxCommitment' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'VatLiable' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'VatLiable' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleAtSource' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleAtSource' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'DeductionValidUntil' , u'pVal' , ), 24, (24, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DeductionValidUntil' , u'pVal' , ), 24, (24, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'IntrestRatePercent' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'IntrestRatePercent' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercent' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercent' , u'pVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroupCode' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroupCode' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'RateDiffAccount' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'RateDiffAccount' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Cellular' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'Cellular' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'AvarageLate' , u'pVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'AvarageLate' , u'pVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'MailCity' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'MailCity' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'MailCounty' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'MailCounty' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'MailCountry' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'MailCountry' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'DefaultAccount' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'DefaultAccount' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBranch' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBranch' , u'pVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankCode' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankCode' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalID' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalID' , u'pVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'FatherCard' , u'pVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'FatherCard' , u'pVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'CardForeignName' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'CardForeignName' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'FatherType' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'FatherType' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'Properties' , u'GroupNum' , u'pVal' , ), 52, (52, (), [ (3, 0, None, None) , 
			(16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'Properties' , u'GroupNum' , u'pVal' , ), 52, (52, (), [ (3, 0, None, None) , 
			(3, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'DeductionOffice' , u'pVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'DeductionOffice' , u'pVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'ExportCode' , u'pVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'ExportCode' , u'pVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'MinIntrest' , u'pVal' , ), 55, (55, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'MinIntrest' , u'pVal' , ), 55, (55, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'CardCode' , u'Found' , ), 57, (57, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 58, (58, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 59, (59, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 60, (60, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'CurrentAccountBalance' , u'pVal' , ), 61, (61, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'OpenDeliveryNotesBalance' , u'pVal' , ), 62, (62, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'OpenOrdersBalance' , u'pVal' , ), 63, (63, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'ContactEmployees' , u'pVal' , ), 64, (64, (), [ (16393, 10, None, "IID('{52C8673B-CA79-4476-9F2E-28109AE17545}')") , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'ShippingType' , u'pVal' , ), 66, (66, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'ShippingType' , u'pVal' , ), 66, (66, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pVal' , ), 69, (69, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pVal' , ), 69, (69, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardCode' , u'pVal' , ), 70, (70, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardCode' , u'pVal' , ), 70, (70, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardNum' , u'pVal' , ), 71, (71, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardNum' , u'pVal' , ), 71, (71, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardExpiration' , u'pVal' , ), 72, (72, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardExpiration' , u'pVal' , ), 72, (72, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'DebitorAccount' , u'pVal' , ), 73, (73, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'DebitorAccount' , u'pVal' , ), 73, (73, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 75, (75, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 76, (76, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'OpenOpportunities' , u'pVal' , ), 77, (77, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'Valid' , u'pVal' , ), 78, (78, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'Valid' , u'pVal' , ), 78, (78, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pVal' , ), 79, (79, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pVal' , ), 79, (79, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pVal' , ), 80, (80, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pVal' , ), 80, (80, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'ValidRemarks' , u'pVal' , ), 81, (81, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'ValidRemarks' , u'pVal' , ), 81, (81, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'Frozen' , u'pVal' , ), 82, (82, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'Frozen' , u'pVal' , ), 82, (82, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'FrozenFrom' , u'pVal' , ), 83, (83, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'FrozenFrom' , u'pVal' , ), 83, (83, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'FrozenTo' , u'pVal' , ), 84, (84, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'FrozenTo' , u'pVal' , ), 84, (84, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'FrozenRemarks' , u'pVal' , ), 85, (85, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'FrozenRemarks' , u'pVal' , ), 85, (85, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 86, (86, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'Addresses' , u'pVal' , ), 87, (87, (), [ (16393, 10, None, "IID('{02F225DD-827F-4065-BC4A-14D5F4136D28}')") , ], 1 , 2 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 88, (88, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 88, (88, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'BillToState' , u'pVal' , ), 89, (89, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'BillToState' , u'pVal' , ), 89, (89, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'ExemptNum' , u'pVal' , ), 90, (90, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'ExemptNum' , u'pVal' , ), 90, (90, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 91, (91, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 91, (91, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'FormCode1099' , u'pVal' , ), 92, (92, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'FormCode1099' , u'pVal' , ), 92, (92, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pVal' , ), 93, (93, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pVal' , ), 93, (93, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'PeymentMethodCode' , u'pVal' , ), 94, (94, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'PeymentMethodCode' , u'pVal' , ), 94, (94, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'BackOrder' , u'pVal' , ), 95, (95, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'BackOrder' , u'pVal' , ), 95, (95, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'PartialDelivery' , u'pVal' , ), 96, (96, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'PartialDelivery' , u'pVal' , ), 96, (96, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunning' , u'pVal' , ), 97, (97, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunning' , u'pVal' , ), 97, (97, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 98, (98, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 98, (98, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'HouseBank' , u'pVal' , ), 99, (99, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankCountry' , u'pVal' , ), 100, (100, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankAccount' , u'pVal' , ), 101, (101, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'ShipToDefault' , u'pVal' , ), 102, (102, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'ShipToDefault' , u'pVal' , ), 102, (102, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'DunningLevel' , u'pVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'DunningDate' , u'pVal' , ), 104, (104, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'CollectionAuthorization' , u'pVal' , ), 105, (105, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'CollectionAuthorization' , u'pVal' , ), 105, (105, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'DME' , u'pVal' , ), 106, (106, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'DME' , u'pVal' , ), 106, (106, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'InstructionKey' , u'pVal' , ), 107, (107, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'InstructionKey' , u'pVal' , ), 107, (107, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'SinglePayment' , u'pVal' , ), 108, (108, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'SinglePayment' , u'pVal' , ), 108, (108, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pVal' , ), 109, (109, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pVal' , ), 109, (109, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 110, (110, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 110, (110, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDetails' , u'pVal' , ), 111, (111, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDetails' , u'pVal' , ), 111, (111, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankBranch' , u'pVal' , ), 112, (112, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'OwnerIDNumber' , u'pVal' , ), 113, (113, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'OwnerIDNumber' , u'pVal' , ), 113, (113, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockDescription' , u'pVal' , ), 114, (114, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockDescription' , u'pVal' , ), 114, (114, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptionLetterNum' , u'pVal' , ), 115, (115, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'MaxAmountOfExemption' , u'pVal' , ), 116, (116, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'MaxAmountOfExemption' , u'pVal' , ), 116, (116, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateFrom' , u'pVal' , ), 117, (117, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateTo' , u'pVal' , ), 118, (118, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'AccountRecivablePayables' , u'pVal' , ), 119, (119, (), [ (16393, 10, None, "IID('{4162242D-4217-47FA-BDFF-5070B6D03F30}')") , ], 1 , 2 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'LinkedBusinessPartner' , u'pVal' , ), 120, (120, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'LinkedBusinessPartner' , u'pVal' , ), 120, (120, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'LastMultiReconciliationNum' , u'pVal' , ), 121, (121, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'LastMultiReconciliationNum' , u'pVal' , ), 121, (121, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'Equalization' , u'pVal' , ), 122, (122, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'Equalization' , u'pVal' , ), 122, (122, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'SubjectToWithholdingTax' , u'pVal' , ), 123, (123, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'SubjectToWithholdingTax' , u'pVal' , ), 123, (123, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'CertificateNumber' , u'pVal' , ), 124, (124, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'CertificateNumber' , u'pVal' , ), 124, (124, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pVal' , ), 125, (125, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pVal' , ), 125, (125, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'NationalInsuranceNum' , u'pVal' , ), 126, (126, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'NationalInsuranceNum' , u'pVal' , ), 126, (126, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'AccrualCriteria' , u'pVal' , ), 127, (127, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
	(( u'AccrualCriteria' , u'pVal' , ), 127, (127, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 916 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 128, (128, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 920 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 128, (128, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 924 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 129, (129, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 928 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 129, (129, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 932 , (3, 0, None, None) , 0 , )),
	(( u'BillToBuildingFloorRoom' , u'pVal' , ), 130, (130, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 936 , (3, 0, None, None) , 0 , )),
	(( u'BillToBuildingFloorRoom' , u'pVal' , ), 130, (130, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 940 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentClearAct' , u'pVal' , ), 131, (131, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 944 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentClearAct' , u'pVal' , ), 131, (131, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 948 , (3, 0, None, None) , 0 , )),
	(( u'ChannelBP' , u'pVal' , ), 132, (132, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 952 , (3, 0, None, None) , 0 , )),
	(( u'ChannelBP' , u'pVal' , ), 132, (132, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 956 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTechnician' , u'pVal' , ), 133, (133, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 960 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTechnician' , u'pVal' , ), 133, (133, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 964 , (3, 0, None, None) , 0 , )),
	(( u'BilltoDefault' , u'pVal' , ), 134, (134, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 968 , (3, 0, None, None) , 0 , )),
	(( u'BilltoDefault' , u'pVal' , ), 134, (134, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 972 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangDisc' , u'pVal' , ), 135, (135, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 976 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangDisc' , u'pVal' , ), 135, (135, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 980 , (3, 0, None, None) , 0 , )),
	(( u'Territory' , u'pVal' , ), 136, (136, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 984 , (3, 0, None, None) , 0 , )),
	(( u'Territory' , u'pVal' , ), 136, (136, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 988 , (3, 0, None, None) , 0 , )),
	(( u'ShipToBuildingFloorRoom' , u'pVal' , ), 137, (137, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 992 , (3, 0, None, None) , 0 , )),
	(( u'ShipToBuildingFloorRoom' , u'pVal' , ), 137, (137, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 996 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangPres' , u'pVal' , ), 138, (138, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1000 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangPres' , u'pVal' , ), 138, (138, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1004 , (3, 0, None, None) , 0 , )),
	(( u'BPPaymentMethods' , u'pVal' , ), 139, (139, (), [ (16393, 10, None, "IID('{7D947F60-6017-44AA-AEAC-9721FF263D5E}')") , ], 1 , 2 , 4 , 0 , 1008 , (3, 0, None, None) , 0 , )),
	(( u'BPWithholdingTax' , u'pVal' , ), 140, (140, (), [ (16393, 10, None, "IID('{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}')") , ], 1 , 2 , 4 , 0 , 1012 , (3, 0, None, None) , 0 , )),
	(( u'BPPaymentDates' , u'pVal' , ), 141, (141, (), [ (16393, 10, None, "IID('{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}')") , ], 1 , 2 , 4 , 0 , 1016 , (3, 0, None, None) , 0 , )),
	(( u'BPBankAccounts' , u'pVal' , ), 142, (142, (), [ (16393, 10, None, "IID('{472B7A32-EB83-4D3A-9908-699D5C8DC33B}')") , ], 1 , 2 , 4 , 0 , 1020 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 143, (143, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1024 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 143, (143, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1028 , (3, 0, None, None) , 0 , )),
	(( u'VatGroupLatinAmerica' , u'pVal' , ), 144, (144, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1032 , (3, 0, None, None) , 0 , )),
	(( u'VatGroupLatinAmerica' , u'pVal' , ), 144, (144, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1036 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 145, (145, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 1040 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 146, (146, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 1044 , (3, 0, None, None) , 0 , )),
	(( u'DunningTerm' , u'pVal' , ), 147, (147, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1048 , (3, 0, None, None) , 0 , )),
	(( u'DunningTerm' , u'pVal' , ), 147, (147, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1052 , (3, 0, None, None) , 0 , )),
	(( u'HouseBank' , u'pVal' , ), 99, (99, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1056 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankCountry' , u'pVal' , ), 100, (100, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1060 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankAccount' , u'pVal' , ), 101, (101, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1064 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankBranch' , u'pVal' , ), 112, (112, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1068 , (3, 0, None, None) , 0 , )),
	(( u'Website' , u'pVal' , ), 148, (148, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1072 , (3, 0, None, None) , 0 , )),
	(( u'Website' , u'pVal' , ), 148, (148, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1076 , (3, 0, None, None) , 0 , )),
	(( u'OtherReceivablePayable' , u'pVal' , ), 149, (149, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1080 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDateProcedureNumber' , u'pVal' , ), 150, (150, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1084 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDateProcedureNumber' , u'pVal' , ), 150, (150, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1088 , (3, 0, None, None) , 0 , )),
	(( u'Profession' , u'pVal' , ), 151, (151, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1092 , (3, 0, None, None) , 0 , )),
	(( u'Profession' , u'pVal' , ), 151, (151, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1096 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeonCollection' , u'pbstrRsltVal' , ), 152, (152, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1100 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeonCollection' , u'pbstrRsltVal' , ), 152, (152, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1104 , (3, 0, None, None) , 0 , )),
	(( u'CompanyPrivate' , u'penumRsltVal' , ), 153, (153, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1108 , (3, 0, None, None) , 0 , )),
	(( u'CompanyPrivate' , u'penumRsltVal' , ), 153, (153, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1112 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 154, (154, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1116 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 154, (154, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1120 , (3, 0, None, None) , 0 , )),
	(( u'UnpaidBillofExchange' , u'pbstrRsltVal' , ), 155, (155, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1124 , (3, 0, None, None) , 0 , )),
	(( u'UnpaidBillofExchange' , u'pbstrRsltVal' , ), 155, (155, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1128 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxDeductionGroup' , u'pVal' , ), 156, (156, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1132 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxDeductionGroup' , u'pVal' , ), 156, (156, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1136 , (3, 0, None, None) , 0 , )),
	(( u'BankChargesAllocationCode' , u'pbstrRsltVal' , ), 157, (157, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1140 , (3, 0, None, None) , 0 , )),
	(( u'BankChargesAllocationCode' , u'pbstrRsltVal' , ), 157, (157, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1144 , (3, 0, None, None) , 0 , )),
	(( u'FiscalTaxID' , u'pVal' , ), 158, (158, (), [ (16393, 10, None, "IID('{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}')") , ], 1 , 2 , 4 , 0 , 1148 , (3, 0, None, None) , 0 , )),
]

IBusinessPlaces_vtables_dispatch_ = 1
IBusinessPlaces_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lBplId' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BPLName' , u'pbstrRsltVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BPLNameForeign' , u'pbstrRsltVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'VATRegNum' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RepName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Business' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Addressforeign' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MainBPL' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxOfficeNo' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Disabled' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

IChartOfAccounts_vtables_dispatch_ = 1
IChartOfAccounts_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AccountCode' , u'Found' , ), 2, (2, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Balance' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAccount' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAccount' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccount' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccount' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryAccount' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'AccountLevel' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DataExportCode' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DataExportCode' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'FatherAccountKey' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FatherAccountKey' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'RateConversion' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'RateConversion' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiableAccount' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiableAccount' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptAccount' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptAccount' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ExternalReconNo' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'InternalReconNo' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'AccountType' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'AccountType' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'AcctCurrency' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'AcctCurrency' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Balance_syscurr' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Balance_FrgnCurr' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Protected' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Protected' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ReconciledAccount' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'ReconciledAccount' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'LiableForAdvances' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'LiableForAdvances' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'ForeignName' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'ForeignName' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationCoordinated' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationCoordinated' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'LockManualTransaction' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'LockManualTransaction' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'FormatCode' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'FormatCode' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 40, (40, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'AllowChangeVatGroup' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'AllowChangeVatGroup' , u'pVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'DefaultVatGroup' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'DefaultVatGroup' , u'pVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
]

IChecksforPayment_vtables_dispatch_ = 1
IChecksforPayment_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'CheckKey' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CheckKey' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BankName' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CheckDate' , u'pVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CheckDate' , u'pVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'AccountNumber' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'AccountNumber' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntryReference' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntryReference' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDate' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDate' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PaymentNo' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CheckAmount' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Transferable' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Transferable' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'VendorCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'VendorCode' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'CheckCurrency' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Canceled' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'CardOrAccount' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'CardOrAccount' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'VendorName' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Signature' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Signature' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'CustomerAccountCode' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'CustomerAccountCode' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'TransactionNumber' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'CreateJournalEntry' , u'pVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'CreateJournalEntry' , u'pVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 36, (36, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotal' , u'pVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 38, (38, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'DeductionRefundAmount' , u'pVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'DeductionRefundAmount' , u'pVal' , ), 39, (39, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'PrintedBy' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'TotalinWords' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'TotalinWords' , u'pVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 43, (43, (), [ (16393, 10, None, "IID('{A6DB2CDA-3A42-4A70-918C-53595D6091C9}')") , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
]

IChecksforPaymentLines_vtables_dispatch_ = 1
IChecksforPaymentLines_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'RowDetails' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RowDetails' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'RowTotal' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'RowTotal' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'RowCurrency' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RowCurrency' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinition' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinition' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercent' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CreditedAccount' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CreditedAccount' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IClosingDateProcedure_vtables_dispatch_ = 1
IClosingDateProcedure_vtables_ = [
	(( u'UserFields' , u'ppRsltIUserFields' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDateNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDateCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BaselineDate' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'DueMonth' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ExtraMonth' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ExtraDay' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ClosingDateNum' , u'pbRsltFound' , ), 9, (9, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ICommand_vtables_dispatch_ = 1
ICommand_vtables_ = [
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Parameters' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{93CF87D1-95CB-459C-A906-729819461CA1}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Execute' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
]

ICommandParam_vtables_dispatch_ = 1
ICommandParam_vtables_ = [
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 2, (2, (), [ (16396, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 2, (2, (), [ (12, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Direction' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

ICommandParams_vtables_dispatch_ = 1
ICommandParams_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{8CA91808-D098-4416-8368-E426484BA8DB}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 1 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
]

ICompany_vtables_dispatch_ = 1
ICompany_vtables_ = [
	(( u'Connect' , u'RetVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Server' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Server' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'CompanyDB' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CompanyDB' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CompanyName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'WordDocsPath' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BitMapPath' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ExcelDocsPath' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Connected' , u'pVal' , ), 12, (12, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'AttachMentPath' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetBusinessObject' , u'Object' , u'pVal' , ), 14, (14, (), [ (3, 0, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetBusinessObjectFromXML' , u'FileName' , u'Index' , u'pVal' , ), 15, (15, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Disconnect' , ), 17, (17, (), [ ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'language' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'language' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GetLastError' , u'errCode' , u'errMsg' , ), 19, (19, (), [ (16387, 2, None, None) , 
			(16392, 2, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'StartTransaction' , ), 20, (20, (), [ ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'EndTransaction' , u'endType' , ), 21, (21, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'GetNewObjectCode' , u'ObjectCode' , ), 22, (22, (), [ (16392, 2, None, None) , ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'UseTrusted' , u'pVal' , ), 23, (23, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'UseTrusted' , u'pVal' , ), 23, (23, (), [ (11, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'GetCompanyList' , u'pVal' , ), 24, (24, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLobjectType' , u'FileName' , u'Index' , u'Object' , ), 25, (25, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLelementCount' , u'FileName' , u'Count' , ), 26, (26, (), [ (8, 1, None, None) , 
			(16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'UserTables' , u'pVal' , ), 27, (27, (), [ (16393, 10, None, "IID('{625162C1-3894-460F-94EC-72D6AFEA34D2}')") , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'XMLAsString' , u'pVal' , ), 28, (28, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'XMLAsString' , u'pVal' , ), 28, (28, (), [ (11, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'GetBusinessObjectXmlSchema' , u'Object' , u'SchemaStr' , ), 29, (29, (), [ (3, 1, None, None) , 
			(16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'XmlExportType' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'XmlExportType' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'InTransaction' , u'pVal' , ), 31, (31, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DbUserName' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DbUserName' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DbPassword' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DbPassword' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'GetContextCookie' , u'CookieStr' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'SetSboLoginContext' , u'conStr' , u'RetVal' , ), 35, (35, (), [ (8, 1, None, None) , 
			(16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DbServerType' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'DbServerType' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'AddonIdentifier' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'AddonIdentifier' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'LicenseServer' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'LicenseServer' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'GetLastErrorDescription' , u'errMsg' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'GetLastErrorCode' , u'errCode' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'GetNewObjectKey' , u'ObjectCode' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Version' , u'plRsltVersion' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'MinimalSupportedVersion' , u'plRsltMinimalSupVersion' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'DTCTransactionObject' , u'ppRsltIUnknown' , ), 44, (44, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'DTCTransactionObject' , u'ppRsltIUnknown' , ), 44, (44, (), [ (13, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'IsDTCTransactionObjectSet' , u'pbRslt' , ), 45, (45, (), [ (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
]

IContactEmployees_vtables_dispatch_ = 1
IContactEmployees_vtables_ = [
	(( u'Position' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Phone1' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Phone1' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Phone2' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Phone2' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'E_Mail' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'E_Mail' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Remarks1' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Remarks1' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Remarks2' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Remarks2' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 14, (14, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 15, (15, (), [ ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 17, (17, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'InternalCode' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'PlaceOfBirth' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PlaceOfBirth' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DateOfBirth' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DateOfBirth' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Gender' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Gender' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Profession' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Profession' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
]

IContacts_vtables_dispatch_ = 1
IContacts_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ContactCode' , u'Found' , ), 3, (3, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 4, (4, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ContactDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ContactDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ContactTime' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ContactTime' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Recontact' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Recontact' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Closed' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Closed' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CloseDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CloseDate' , u'pVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 20, (20, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Activity' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Activity' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'ActivityType' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'ActivityType' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'StartTime' , u'pVal' , ), 27, (27, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'StartTime' , u'pVal' , ), 27, (27, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'EndTime' , u'pVal' , ), 28, (28, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'EndTime' , u'pVal' , ), 28, (28, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Duration' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Duration' , u'pVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'DurationType' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'DurationType' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployee' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployee' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'HandledBy' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'HandledBy' , u'pVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 34, (34, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Reminder' , u'pVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'Reminder' , u'pVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ReminderPeriod' , u'pVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'ReminderPeriod' , u'pVal' , ), 36, (36, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'ReminderType' , u'pVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'ReminderType' , u'pVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'Personalflag' , u'pVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Personalflag' , u'pVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'ParentobjectId' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'Parentobjecttype' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Room' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Room' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Inactiveflag' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'Inactiveflag' , u'pVal' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'PreviousActivity' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'PreviousActivity' , u'pVal' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'Tentativeflag' , u'pVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'Tentativeflag' , u'pVal' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'EndDuedate' , u'pVal' , ), 50, (50, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'EndDuedate' , u'pVal' , ), 50, (50, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'DocTypeEx' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'DocTypeEx' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
]

IContractTemplates_vtables_dispatch_ = 1
IContractTemplates_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'TemplateName' , u'Found' , ), 5, (5, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TemplateName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TemplateName' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TemplateIsDeleted' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TemplateIsDeleted' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TemplateIsRenewal' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TemplateIsRenewal' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'RemindBeforeRenewal' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'RemindBeforeRenewal' , u'pVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DurationOfCoverage' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DurationOfCoverage' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ResponseValue' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ResponseValue' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionUnit' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionUnit' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ContractType' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ContractType' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnabled' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnabled' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnabled' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnabled' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnabled' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnabled' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnabled' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnabled' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnabled' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnabled' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnabled' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnabled' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnabled' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnabled' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'MondayStart' , u'pVal' , ), 24, (24, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'MondayStart' , u'pVal' , ), 24, (24, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnd' , u'pVal' , ), 25, (25, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnd' , u'pVal' , ), 25, (25, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayStart' , u'pVal' , ), 26, (26, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayStart' , u'pVal' , ), 26, (26, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnd' , u'pVal' , ), 27, (27, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnd' , u'pVal' , ), 27, (27, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayStart' , u'pVal' , ), 28, (28, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayStart' , u'pVal' , ), 28, (28, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnd' , u'pVal' , ), 29, (29, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnd' , u'pVal' , ), 29, (29, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayStart' , u'pVal' , ), 30, (30, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayStart' , u'pVal' , ), 30, (30, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnd' , u'pVal' , ), 31, (31, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnd' , u'pVal' , ), 31, (31, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'FridayStart' , u'pVal' , ), 32, (32, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'FridayStart' , u'pVal' , ), 32, (32, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnd' , u'pVal' , ), 33, (33, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnd' , u'pVal' , ), 33, (33, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayStart' , u'pVal' , ), 34, (34, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayStart' , u'pVal' , ), 34, (34, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnd' , u'pVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnd' , u'pVal' , ), 35, (35, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'SundayStart' , u'pVal' , ), 36, (36, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'SundayStart' , u'pVal' , ), 36, (36, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnd' , u'pVal' , ), 37, (37, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnd' , u'pVal' , ), 37, (37, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'IncludeParts' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'IncludeParts' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'IncludeLabor' , u'pVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'IncludeLabor' , u'pVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'IncludeTravel' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'IncludeTravel' , u'pVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 41, (41, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 44, (44, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 45, (45, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'IncludeHolidays' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'IncludeHolidays' , u'pVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'ResponseUnit' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'ResponseUnit' , u'pVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
]

ICurrencies_vtables_dispatch_ = 1
ICurrencies_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Currency' , u'Found' , ), 2, (2, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocumentsCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DocumentsCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ICustomerEquipmentCards_vtables_dispatch_ = 1
ICustomerEquipmentCards_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'EquipmentCardNum' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'EquipmentCardNum' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ContactEmployeeCode' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ContactEmployeeCode' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DirectCustomerCode' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DirectCustomerCode' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DirectCustomerName' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DirectCustomerName' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceCode' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceCode' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumber' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DeliveryDate' , u'pVal' , ), 26, (26, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ContactPhone' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'StateCode' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'StateCode' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'InstallLocation' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'InstallLocation' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 39, (39, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'DeliveryCode' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'DeliveryCode' , u'pVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'DeliveryNumber' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'StatusOfSerialNumber' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'StatusOfSerialNumber' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ReplaceSN' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'ReplaceSN' , u'pVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTechnician' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTechnician' , u'pVal' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'ReplacedBySN' , u'pVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ReplacedBySN' , u'pVal' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Defaultterritory' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'Defaultterritory' , u'pVal' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
]

ICustomsGroups_vtables_dispatch_ = 1
ICustomsGroups_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lGroupCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Customs' , u'pdblRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Customs' , u'pdblRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Purchase' , u'pdblRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Purchase' , u'pdblRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Other' , u'pdblRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Other' , u'pdblRsltVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Total' , u'pdblRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Total' , u'pdblRsltVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
]

IDataBrowser_vtables_dispatch_ = 1
IDataBrowser_vtables_ = [
	(( u'Recordset' , ), 1, (1, (), [ (9, 1, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 4 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'RecordCount' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'MoveFirst' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'MovePrevious' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'MoveNext' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'MoveLast' , ), 6, (6, (), [ ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BoF' , u'pVal' , ), 7, (7, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'EoF' , u'pVal' , ), 8, (8, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Refresh' , ), 9, (9, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ReadXml' , u'XmlFileStr' , u'Index' , ), 10, (10, (), [ (8, 1, None, None) , 
			(3, 1, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IDocument_Lines_vtables_dispatch_ = 1
IDocument_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ShipDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ShipDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PriceAfterVAT' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PriceAfterVAT' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SerialNum' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SerialNum' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CommisionPercent' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CommisionPercent' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'TreeType' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'UseBaseUnits' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'UseBaseUnits' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'SupplierCatNum' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'SupplierCatNum' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'BarCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'BarCode' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Height1' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Height1' , u'pVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Hight1Unit' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Hight1Unit' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Height2' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Height2' , u'pVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Height2Unit' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Height2Unit' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Lengh1' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'Lengh1' , u'pVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'Lengh1Unit' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Lengh1Unit' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Lengh2' , u'pVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'Lengh2' , u'pVal' , ), 31, (31, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Lengh2Unit' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Lengh2Unit' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'Weight1' , u'pVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'Weight1' , u'pVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'Weight1Unit' , u'pVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'Weight1Unit' , u'pVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'Weight2' , u'pVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Weight2' , u'pVal' , ), 35, (35, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'Weight2Unit' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Weight2Unit' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'Factor1' , u'pVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'Factor1' , u'pVal' , ), 37, (37, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Factor2' , u'pVal' , ), 38, (38, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Factor2' , u'pVal' , ), 38, (38, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Factor3' , u'pVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'Factor3' , u'pVal' , ), 39, (39, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'Factor4' , u'pVal' , ), 40, (40, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'Factor4' , u'pVal' , ), 40, (40, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 41, (41, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'BaseEntry' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'BaseEntry' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'BaseLine' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'BaseLine' , u'pVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'Volume' , u'pVal' , ), 45, (45, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'Volume' , u'pVal' , ), 45, (45, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'VolumeUnit' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'VolumeUnit' , u'pVal' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 48, (48, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 49, (49, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'Width1' , u'pVal' , ), 50, (50, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'Width1' , u'pVal' , ), 50, (50, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'Width1Unit' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'Width1Unit' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'Width2' , u'pVal' , ), 52, (52, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'Width2' , u'pVal' , ), 52, (52, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'Width2Unit' , u'pVal' , ), 53, (53, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'Width2Unit' , u'pVal' , ), 53, (53, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'PickStatus' , u'pVal' , ), 58, (58, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'PickQuantity' , u'pVal' , ), 59, (59, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'PickListIdNumber' , u'pVal' , ), 60, (60, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'OriginalItem' , u'pVal' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'BackOrder' , u'pVal' , ), 62, (62, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'BackOrder' , u'pVal' , ), 62, (62, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'ShippingMethod' , u'pVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'ShippingMethod' , u'pVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'POTargetNum' , u'pVal' , ), 65, (65, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'POTargetEntry' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'POTargetRowNum' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumbers' , u'pVal' , ), 68, (68, (), [ (16393, 10, None, "IID('{93E5E52B-181E-46B8-96CB-1C066AC04DCA}')") , ], 1 , 2 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'BatchNumbers' , u'pVal' , ), 69, (69, (), [ (16393, 10, None, "IID('{1FEF5698-93E1-4167-AEA0-4BB151792623}')") , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'Expenses' , u'pVal' , ), 70, (70, (), [ (16393, 10, None, "IID('{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}')") , ], 1 , 2 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'CorrectionInvoiceItem' , u'pVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'CorrectionInvoiceItem' , u'pVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'CorrInvAmountToStock' , u'pVal' , ), 72, (72, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'CorrInvAmountToStock' , u'pVal' , ), 72, (72, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'CorrInvAmountToDiffAcct' , u'pVal' , ), 73, (73, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'CorrInvAmountToDiffAcct' , u'pVal' , ), 73, (73, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'AppliedTax' , u'pVal' , ), 74, (74, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'AppliedTaxFC' , u'pVal' , ), 75, (75, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'AppliedTaxSC' , u'pVal' , ), 76, (76, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 77, (77, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxPercent' , u'pVal' , ), 78, (78, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTaxFC' , u'pVal' , ), 79, (79, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTaxSC' , u'pVal' , ), 80, (80, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'NetTaxAmount' , u'pVal' , ), 81, (81, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'NetTaxAmountFC' , u'pVal' , ), 82, (82, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'NetTaxAmountSC' , u'pVal' , ), 83, (83, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 84, (84, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 84, (84, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercentagePerRow' , u'pVal' , ), 86, (86, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercentagePerRow' , u'pVal' , ), 86, (86, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotal' , u'pVal' , ), 87, (87, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 88, (88, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 88, (88, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTax' , u'pVal' , ), 89, (89, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'MeasureUnit' , u'pVal' , ), 90, (90, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'UnitsOfMeasurment' , u'pVal' , ), 91, (91, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'ExciseAmount' , u'pVal' , ), 92, (92, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'ExciseAmount' , u'pVal' , ), 92, (92, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'TaxPerUnit' , u'pVal' , ), 93, (93, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'TotalInclTax' , u'pVal' , ), 94, (94, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'CountryOrg' , u'pVal' , ), 95, (95, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'CountryOrg' , u'pVal' , ), 95, (95, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'SWW' , u'pVal' , ), 96, (96, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'SWW' , u'pVal' , ), 96, (96, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'ConsumerSalesForecast' , u'pVal' , ), 97, (97, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'ConsumerSalesForecast' , u'pVal' , ), 97, (97, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxLines' , u'ppRsltVal' , ), 98, (98, (), [ (16393, 10, None, "IID('{458A15A5-B980-4543-A289-F6477A36EB24}')") , ], 1 , 2 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'CFOPCode' , u'pbstrRsltVal' , ), 99, (99, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'CFOPCode' , u'pbstrRsltVal' , ), 99, (99, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'CSTCode' , u'pVal' , ), 100, (100, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'CSTCode' , u'pVal' , ), 100, (100, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'Usage' , u'pVal' , ), 101, (101, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'Usage' , u'pVal' , ), 101, (101, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'TaxOnly' , u'penumRsltVal' , ), 102, (102, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'TaxOnly' , u'penumRsltVal' , ), 102, (102, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'TaxBeforeDPM' , u'pVal' , ), 103, (103, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'TaxBeforeDPMFC' , u'pVal' , ), 104, (104, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'TaxBeforeDPMSC' , u'pVal' , ), 105, (105, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'TransactionType' , u'ppRsltVal' , ), 106, (106, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'TransactionType' , u'ppRsltVal' , ), 106, (106, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'DistributeExpense' , u'penumRsltVal' , ), 107, (107, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'DistributeExpense' , u'penumRsltVal' , ), 107, (107, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pbstrRsltVal' , ), 108, (108, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pbstrRsltVal' , ), 108, (108, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'RowTotalFC' , u'pdblRsltVal' , ), 109, (109, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'RowTotalFC' , u'pdblRsltVal' , ), 109, (109, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'RowTotalSC' , u'pdblRsltVal' , ), 110, (110, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'LastBuyInmPrice' , u'pdblRsltVal' , ), 111, (111, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'LastBuyDistributeSumFc' , u'pdblRsltVal' , ), 112, (112, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'LastBuyDistributeSumSc' , u'pdblRsltVal' , ), 113, (113, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'LastBuyDistributeSum' , u'pdblRsltVal' , ), 114, (114, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'StockDistributesumForeign' , u'pdblRsltVal' , ), 115, (115, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'StockDistributesumSystem' , u'pdblRsltVal' , ), 116, (116, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'StockDistributesum' , u'pdblRsltVal' , ), 117, (117, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'StockInmPrice' , u'pdblRsltVal' , ), 118, (118, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'PickStatusEx' , u'pVal' , ), 119, (119, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 120, (120, (), [ ], 1 , 1 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'pVal' , ), 121, (121, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'BaseOpenQuantity' , u'pVal' , ), 122, (122, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'UnitPrice' , u'pVal' , ), 123, (123, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'UnitPrice' , u'pVal' , ), 123, (123, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'LineStatus' , u'penumRsltVal' , ), 124, (124, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'LineStatus' , u'penumRsltVal' , ), 124, (124, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'PackageQuantity' , u'pVal' , ), 125, (125, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'Text' , u'pVal' , ), 126, (126, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 77, (77, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
]

IDocument_LinesAdditionalExpenses_vtables_dispatch_ = 1
IDocument_LinesAdditionalExpenses_vtables_ = [
	(( u'LineNumber' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseCode' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseCode' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LineTotalFC' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LineTotalSys' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDate' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDateFC' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDateSys' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercent' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxSum' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxSumFC' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TaxSumSys' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSum' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSumFC' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSumSys' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'AquisitionTax' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaid' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaidFC' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaidSys' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxPercent' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxSum' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxFC' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxSys' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSum' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSumFC' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSumSys' , u'pVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 100, (100, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 101, (101, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 102, (102, (), [ ], 1 , 1 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 104, (104, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BaseGroup' , u'plVal' , ), 105, (105, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'BaseGroup' , u'plVal' , ), 105, (105, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 106, (106, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 106, (106, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 103, (103, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
]

IDocuments_vtables_dispatch_ = 1
IDocuments_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{248B28DD-1281-4C6C-9780-22D19BA13D1F}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DocDueDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocDueDate' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'NumAtCard' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'NumAtCard' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DocTotal' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DocTotal' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'PaymentGroupCode' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'PaymentGroupCode' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DocTime' , u'pVal' , ), 21, (21, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DocTime' , u'pVal' , ), 21, (21, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'TransportationCode' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'TransportationCode' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Confirmed' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Confirmed' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'ImportFileNum' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'SummeryType' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'SummeryType' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ShowSCN' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ShowSCN' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 31, (31, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 31, (31, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'PartialSupply' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'PartialSupply' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AbsEntry' , u'Found' , ), 35, (35, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 37, (37, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 38, (38, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 48, (48, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 49, (49, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 49, (49, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReference' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 52, (52, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 53, (53, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'FinancialPeriod' , u'pVal' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'TransNum' , u'pVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'VatSum' , u'pVal' , ), 56, (56, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'VatSumSys' , u'pVal' , ), 57, (57, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'VatSumFc' , u'pVal' , ), 58, (58, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'NetProcedure' , u'pVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'DocTotalFc' , u'pVal' , ), 60, (60, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'DocTotalSys' , u'pVal' , ), 61, (61, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'Form1099' , u'pVal' , ), 62, (62, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'Form1099' , u'pVal' , ), 62, (62, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'RevisionPo' , u'pVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'RevisionPo' , u'pVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'RequriedDate' , u'pVal' , ), 65, (65, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'RequriedDate' , u'pVal' , ), 65, (65, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'CancelDate' , u'pVal' , ), 66, (66, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'CancelDate' , u'pVal' , ), 66, (66, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunning' , u'pVal' , ), 67, (67, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunning' , u'pVal' , ), 67, (67, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'Submitted' , u'pVal' , ), 68, (68, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'Segment' , u'pVal' , ), 69, (69, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'PickStatus' , u'pVal' , ), 70, (70, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'Pick' , u'pVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethod' , u'pVal' , ), 72, (72, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethod' , u'pVal' , ), 72, (72, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 73, (73, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockEntry' , u'pVal' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockEntry' , u'pVal' , ), 74, (74, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'CentralBankIndicator' , u'pVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'CentralBankIndicator' , u'pVal' , ), 75, (75, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'MaximumCashDiscount' , u'pVal' , ), 76, (76, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'MaximumCashDiscount' , u'pVal' , ), 76, (76, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'Reserve' , u'pVal' , ), 77, (77, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pVal' , ), 78, (78, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pVal' , ), 78, (78, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateFrom' , u'pVal' , ), 80, (80, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateFrom' , u'pVal' , ), 80, (80, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateTo' , u'pVal' , ), 81, (81, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateTo' , u'pVal' , ), 81, (81, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'WareHouseUpdateType' , u'pVal' , ), 82, (82, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'WareHouseUpdateType' , u'pVal' , ), 82, (82, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'Expenses' , u'pVal' , ), 83, (83, (), [ (16393, 10, None, "IID('{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}')") , ], 1 , 2 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'Rounding' , u'pVal' , ), 84, (84, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'Rounding' , u'pVal' , ), 84, (84, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCorrectedDocNum' , u'pVal' , ), 89, (89, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCorrectedDocNum' , u'pVal' , ), 89, (89, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'InternalCorrectedDocNum' , u'pVal' , ), 90, (90, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'InternalCorrectedDocNum' , u'pVal' , ), 90, (90, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'NextCorrectingDocument' , u'pVal' , ), 91, (91, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 92, (92, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 92, (92, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptionLetterNum' , u'pVal' , ), 93, (93, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptionLetterNum' , u'pVal' , ), 93, (93, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'WTApplied' , u'pVal' , ), 94, (94, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'WTAppliedFC' , u'pVal' , ), 95, (95, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeReserved' , u'pVal' , ), 96, (96, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'AgentCode' , u'pVal' , ), 97, (97, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'AgentCode' , u'pVal' , ), 97, (97, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'WTAppliedSC' , u'pVal' , ), 98, (98, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTax' , u'pVal' , ), 99, (99, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTaxFC' , u'pVal' , ), 100, (100, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTaxSC' , u'pVal' , ), 101, (101, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfInstallments' , u'pVal' , ), 102, (102, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfInstallments' , u'pVal' , ), 102, (102, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'ApplyTaxOnFirstInstallment' , u'pVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'ApplyTaxOnFirstInstallment' , u'pVal' , ), 103, (103, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'WTNonSubjectAmount' , u'pVal' , ), 104, (104, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'WTNonSubjectAmountSC' , u'pVal' , ), 105, (105, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'WTNonSubjectAmountFC' , u'pVal' , ), 106, (106, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'WTExemptedAmount' , u'pVal' , ), 107, (107, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'WTExemptedAmountSC' , u'pVal' , ), 108, (108, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'WTExemptedAmountFC' , u'pVal' , ), 109, (109, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'BaseAmountSC' , u'pVal' , ), 110, (110, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'BaseAmountFC' , u'pVal' , ), 111, (111, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 112, (112, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSC' , u'pVal' , ), 113, (113, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'BaseAmount' , u'pVal' , ), 114, (114, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 115, (115, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 116, (116, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 116, (116, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'ManualNumber' , u'pVal' , ), 117, (117, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'ManualNumber' , u'pVal' , ), 117, (117, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'UseShpdGoodsAct' , u'pVal' , ), 118, (118, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'UseShpdGoodsAct' , u'pVal' , ), 118, (118, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'FolioNumber' , u'pVal' , ), 119, (119, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'FolioNumber' , u'pVal' , ), 119, (119, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pVal' , ), 120, (120, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pVal' , ), 120, (120, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelCode' , u'pVal' , ), 121, (121, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelCode' , u'pVal' , ), 121, (121, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 122, (122, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 122, (122, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxData' , u'ppRsltVal' , ), 123, (123, (), [ (16393, 10, None, "IID('{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}')") , ], 1 , 2 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCodeEx' , u'pVal' , ), 124, (124, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCodeEx' , u'pVal' , ), 124, (124, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'Address2' , u'pVal' , ), 125, (125, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'Address2' , u'pVal' , ), 125, (125, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'DocumentStatus' , u'pVal' , ), 126, (126, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'PeriodIndicator' , u'pVal' , ), 127, (127, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'PayToCode' , u'pVal' , ), 129, (129, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'PayToCode' , u'pVal' , ), 129, (129, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'DocumentsOwner' , u'pVal' , ), 130, (130, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'DocumentsOwner' , u'pVal' , ), 130, (130, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'FolioPrefixString' , u'pVal' , ), 131, (131, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'FolioPrefixString' , u'pVal' , ), 131, (131, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'IsPayToBank' , u'pVal' , ), 132, (132, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'IsPayToBank' , u'pVal' , ), 132, (132, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCountry' , u'pVal' , ), 133, (133, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCountry' , u'pVal' , ), 133, (133, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCode' , u'pVal' , ), 134, (134, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCode' , u'pVal' , ), 134, (134, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankAccountNo' , u'pVal' , ), 135, (135, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankAccountNo' , u'pVal' , ), 135, (135, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankBranch' , u'pVal' , ), 136, (136, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankBranch' , u'pVal' , ), 136, (136, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 137, (137, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 138, (138, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReference' , u'pVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'BPL_IDAssignedToInvoice' , u'pVal' , ), 139, (139, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'BPL_IDAssignedToInvoice' , u'pVal' , ), 139, (139, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 140, (140, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 140, (140, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'SequenceSerial' , u'pVal' , ), 141, (141, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'SequenceSerial' , u'pVal' , ), 141, (141, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'SequenceCode' , u'pVal' , ), 142, (142, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'SequenceCode' , u'pVal' , ), 142, (142, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'SeriesString' , u'pVal' , ), 143, (143, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'SeriesString' , u'pVal' , ), 143, (143, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'SubSeriesString' , u'pVal' , ), 144, (144, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'SubSeriesString' , u'pVal' , ), 144, (144, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'SequenceModel' , u'pVal' , ), 145, (145, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'SequenceModel' , u'pVal' , ), 145, (145, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'TaxExtension' , u'ppRsltVal' , ), 146, (146, (), [ (16393, 10, None, "IID('{8CC29ECE-02C3-4C7B-851B-5533D2C83627}')") , ], 1 , 2 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'DownPayment' , u'pdblRsltVal' , ), 147, (147, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'DownPayment' , u'pdblRsltVal' , ), 147, (147, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'ReserveInvoice' , u'penumRsltVal' , ), 148, (148, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 149, (149, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 149, (149, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'TrackingNumber' , u'pbstrRsltVal' , ), 150, (150, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'TrackingNumber' , u'pbstrRsltVal' , ), 150, (150, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
	(( u'PickRemark' , u'pbstrRsltVal' , ), 151, (151, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 916 , (3, 0, None, None) , 0 , )),
	(( u'PickRemark' , u'pbstrRsltVal' , ), 151, (151, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 920 , (3, 0, None, None) , 0 , )),
	(( u'ImportFileNum' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 924 , (3, 0, None, None) , 0 , )),
	(( u'UseCorrectionVATGroup' , u'pVal' , ), 152, (152, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 928 , (3, 0, None, None) , 0 , )),
	(( u'UseCorrectionVATGroup' , u'pVal' , ), 152, (152, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 932 , (3, 0, None, None) , 0 , )),
	(( u'TotalDiscount' , u'pVal' , ), 153, (153, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 936 , (3, 0, None, None) , 0 , )),
	(( u'Pick' , u'pVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 940 , (3, 0, None, None) , 0 , )),
	(( u'VatPercent' , u'pVal' , ), 154, (154, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 944 , (3, 0, None, None) , 0 , )),
	(( u'VatPercent' , u'pVal' , ), 154, (154, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 948 , (3, 0, None, None) , 0 , )),
]

IDocumentsAdditionalExpenses_vtables_dispatch_ = 1
IDocumentsAdditionalExpenses_vtables_ = [
	(( u'Count' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseCode' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseCode' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LineTotalFC' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LineTotalSys' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDate' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDateFC' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDateSys' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'DistributionMethod' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DistributionMethod' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercent' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TaxSum' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TaxSumFC' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'TaxSumSys' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSum' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSum' , u'pVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSumFC' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSumSys' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'AquisitionTax' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaid' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaidFC' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaidSys' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxPercent' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxSum' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxFC' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxSys' , u'pVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSum' , u'pVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSumFC' , u'pVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSumSys' , u'pVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 35, (35, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
]

IDunningLetters_vtables_dispatch_ = 1
IDunningLetters_vtables_ = [
	(( u'FeeCurrency' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'FeeCurrency' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LetterFormat' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LetterFormat' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Effectiveafter' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Effectiveafter' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalanceCurrency' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalanceCurrency' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Feeperletter' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Feeperletter' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CalcInterest' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CalcInterest' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalance' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalance' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 12, (12, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 13, (13, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 17, (17, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
]

IEmployeeAbsenceInfo_vtables_dispatch_ = 1
IEmployeeAbsenceInfo_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Reason' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Reason' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ApprovedBy' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ApprovedBy' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IEmployeeEducationInfo_vtables_dispatch_ = 1
IEmployeeEducationInfo_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'EducationType' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'EducationType' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Institute' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Institute' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Major' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Major' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Diploma' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Diploma' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

IEmployeePrevEmpoymentInfo_vtables_dispatch_ = 1
IEmployeePrevEmpoymentInfo_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FromDtae' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FromDtae' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Employer' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Employer' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IEmployeeReviewsInfo_vtables_dispatch_ = 1
IEmployeeReviewsInfo_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ReviewDescription' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ReviewDescription' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Manager' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Manager' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Grade' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Grade' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IEmployeeRolesInfo_vtables_dispatch_ = 1
IEmployeeRolesInfo_vtables_ = [
	(( u'RoleID' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'RoleID' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IEmployeesInfo_vtables_dispatch_ = 1
IEmployeesInfo_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'EmployeeID' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'LastName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LastName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'FirstName' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FirstName' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'MiddleName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MiddleName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Gender' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Gender' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'JobTitle' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'JobTitle' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeType' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeType' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Department' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Department' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'WorkStreet' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'WorkStreet' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'WorkBlock' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'WorkBlock' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'WorkZipCode' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'WorkZipCode' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'WorkCity' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'WorkCity' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'WorkCounty' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'WorkCounty' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'WorkCountryCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'WorkCountryCode' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'WorkStateCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'WorkStateCode' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Manager' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Manager' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ApplicationUserID' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'ApplicationUserID' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'OfficePhone' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'OfficePhone' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'OfficeExtension' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'OfficeExtension' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'HomePhone' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'HomePhone' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 35, (35, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'StatusCode' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'StatusCode' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'Salary' , u'pVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'Salary' , u'pVal' , ), 37, (37, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'SalaryUnit' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'SalaryUnit' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCosts' , u'pVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCosts' , u'pVal' , ), 39, (39, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCostUnit' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCostUnit' , u'pVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 41, (41, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 41, (41, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'TreminationReason' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'TreminationReason' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'BankBranchNum' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'BankBranchNum' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'HomeStreet' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'HomeStreet' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'HomeBlock' , u'pVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'HomeBlock' , u'pVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'HomeZipCode' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'HomeZipCode' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'HomeCity' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'HomeCity' , u'pVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'HomeCounty' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'HomeCounty' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'HomeCountry' , u'pVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'HomeCountry' , u'pVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'HomeState' , u'pVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'HomeState' , u'pVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'DateOfBirth' , u'pVal' , ), 54, (54, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'DateOfBirth' , u'pVal' , ), 54, (54, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'CountryOfBirth' , u'pVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'CountryOfBirth' , u'pVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'MartialStatus' , u'pVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'MartialStatus' , u'pVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'NumOfChildren' , u'pVal' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'NumOfChildren' , u'pVal' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'IdNumber' , u'pVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'IdNumber' , u'pVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'CitizenshipCountryCode' , u'pVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'CitizenshipCountryCode' , u'pVal' , ), 59, (59, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'PassportNumber' , u'pVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'PassportNumber' , u'pVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'PassportExpirationDate' , u'pVal' , ), 61, (61, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'PassportExpirationDate' , u'pVal' , ), 61, (61, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 64, (64, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'SalaryCurrency' , u'pVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'SalaryCurrency' , u'pVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCostsCurrency' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCostsCurrency' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'ReviewsInfo' , u'pVal' , ), 67, (67, (), [ (16393, 10, None, "IID('{C4397D01-E44E-4B76-80AB-4B888EEA10DD}')") , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'AbsenceInfo' , u'pVal' , ), 68, (68, (), [ (16393, 10, None, "IID('{CD47A725-AEA8-4224-93D3-F31848990C42}')") , ], 1 , 2 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'PreviousEmpoymentInfo' , u'pVal' , ), 69, (69, (), [ (16393, 10, None, "IID('{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}')") , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'EducationInfo' , u'pVal' , ), 70, (70, (), [ (16393, 10, None, "IID('{A5EC07B2-5898-4104-8015-F876A386D231}')") , ], 1 , 2 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeRolesInfo' , u'pVal' , ), 71, (71, (), [ (16393, 10, None, "IID('{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}')") , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 72, (72, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 73, (73, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'WorkBuildingFloorRoom' , u'pVal' , ), 74, (74, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'WorkBuildingFloorRoom' , u'pVal' , ), 74, (74, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'HomeBuildingFloorRoom' , u'pVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'HomeBuildingFloorRoom' , u'pVal' , ), 75, (75, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
]

IField_vtables_dispatch_ = 1
IField_vtables_ = [
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Size' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 4, (4, (), [ (16396, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 4, (4, (), [ (12, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ValidValue' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ValidValue' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ValidValues' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{48B89C08-2AE9-435F-B7C4-D7219E938E46}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SubType' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LinkedTable' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DefaultValue' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Mandatory' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IFields_vtables_dispatch_ = 1
IFields_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 1 , )),
]

IIndustries_vtables_dispatch_ = 1
IIndustries_vtables_ = [
	(( u'IndustryDescription' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'IndustryDescription' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'IndustryName' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'IndustryName' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'IndustryCode' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Code' , u'Found' , ), 7, (7, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 8, (8, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IItemGroups_vtables_dispatch_ = 1
IItemGroups_vtables_ = [
	(( u'PriceDifferencesAccount' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferencesAccount' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'MinimumOrderQuantity' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'MinimumOrderQuantity' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'OrderInterval' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'OrderInterval' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAccount' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAccount' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAccount' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAccount' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ProcurementMethod' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ProcurementMethod' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'InventorySystem' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'InventorySystem' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PlanningSystem' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PlanningSystem' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TransfersAccount' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'TransfersAccount' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'LeadTime' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'LeadTime' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'OrderMultiple' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'OrderMultiple' , u'pVal' , ), 20, (20, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'InventoryAccount' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'InventoryAccount' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAccount' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAccount' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAccount' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAccount' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAccount' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAccount' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Alert' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'Alert' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ExemptRevenuesAccount' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'ExemptRevenuesAccount' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAccount' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAccount' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'CycleCode' , u'pVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'CycleCode' , u'pVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'CostAccount' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'CostAccount' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'PAReturnAccount' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'PAReturnAccount' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'GroupName' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'GroupName' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'GroupCode' , u'Found' , ), 45, (45, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 46, (46, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 47, (47, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 48, (48, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAct' , u'pbstrRsltVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAct' , u'pbstrRsltVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
]

IItemWarehouseInfo_vtables_dispatch_ = 1
IItemWarehouseInfo_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'MaximalStock' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'MaximalStock' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'MinimalOrder' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'MinimalOrder' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'StandardAveragePrice' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'StandardAveragePrice' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'InventoryAccount' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'InventoryAccount' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CostAccount' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CostAccount' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TransferAccount' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TransferAccount' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'VarienceAccount' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'VarienceAccount' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenueAcc' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenueAcc' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensAcc' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensAcc' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'ExemptIncomeAcc' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'ExemptIncomeAcc' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferenceAcc' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferenceAcc' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'MinimalStock' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'MinimalStock' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'InStock' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Committed' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Ordered' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'CountedQuantity' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'WasCounted' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Counted' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 31, (31, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'WipVarianceAccount' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'WipVarianceAccount' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAct' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAct' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
]

IItems_vtables_dispatch_ = 1
IItems_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ItemCode' , u'Found' , ), 3, (3, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ForeignName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ForeignName' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ItemsGroupCode' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemsGroupCode' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CustomsGroupCode' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CustomsGroupCode' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SalesVATGroup' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SalesVATGroup' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BarCode' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BarCode' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'VatLiable' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'VatLiable' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseItem' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseItem' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SalesItem' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SalesItem' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'InventoryItem' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'InventoryItem' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'IncomeAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'IncomeAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ExemptIncomeAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ExemptIncomeAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ExpanseAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ExpanseAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Mainsupplier' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Mainsupplier' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'SupplierCatalogNo' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'SupplierCatalogNo' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnit' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnit' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseItemsPerUnit' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseItemsPerUnit' , u'pVal' , ), 21, (21, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DesiredInventory' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DesiredInventory' , u'pVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'MinInventory' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'MinInventory' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnit' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnit' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'SalesItemsPerUnit' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'SalesItemsPerUnit' , u'pVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'User_Text' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'User_Text' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'SerialNum' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'SerialNum' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercent' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercent' , u'pVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'CommissionSum' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'CommissionSum' , u'pVal' , ), 30, (30, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroup' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroup' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'TreeType' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'AssetItem' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'AssetItem' , u'pVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitHeight' , u'pVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitHeight' , u'pVal' , ), 34, (34, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitVolume' , u'pVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitVolume' , u'pVal' , ), 36, (36, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'DataExportCode' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'DataExportCode' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Properties' , u'GroupNum' , u'pVal' , ), 38, (38, (), [ (3, 0, None, None) , 
			(16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'Properties' , u'GroupNum' , u'pVal' , ), 38, (38, (), [ (3, 0, None, None) , 
			(3, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 39, (39, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 41, (41, (), [ (16393, 10, None, "IID('{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}')") , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Manufacturer' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'Manufacturer' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'QuantityOnStock' , u'pVal' , ), 43, (43, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'QuantityOrderedFromVendors' , u'pVal' , ), 44, (44, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'QuantityOrderedByCustomers' , u'pVal' , ), 45, (45, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'ManageSerialNumbers' , u'pVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'ManageSerialNumbers' , u'pVal' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'ManageBatchNumbers' , u'pVal' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'ManageBatchNumbers' , u'pVal' , ), 50, (50, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'Valid' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'Valid' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pVal' , ), 52, (52, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pVal' , ), 52, (52, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pVal' , ), 53, (53, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pVal' , ), 53, (53, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'ValidRemarks' , u'pVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'ValidRemarks' , u'pVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'Frozen' , u'pVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'Frozen' , u'pVal' , ), 55, (55, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'FrozenFrom' , u'pVal' , ), 56, (56, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'FrozenFrom' , u'pVal' , ), 56, (56, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'FrozenTo' , u'pVal' , ), 57, (57, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'FrozenTo' , u'pVal' , ), 57, (57, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'FrozenRemarks' , u'pVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'FrozenRemarks' , u'pVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 59, (59, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'SalesPackagingUnit' , u'pVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'SalesPackagingUnit' , u'pVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'SalesQtyPerPackUnit' , u'pVal' , ), 61, (61, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'SalesQtyPerPackUnit' , u'pVal' , ), 61, (61, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitLength' , u'pVal' , ), 62, (62, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitLength' , u'pVal' , ), 62, (62, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWidth' , u'pVal' , ), 63, (63, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWidth' , u'pVal' , ), 63, (63, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'SalesVolumeUnit' , u'pVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'SalesVolumeUnit' , u'pVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWeight' , u'pVal' , ), 65, (65, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWeight' , u'pVal' , ), 65, (65, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'PurchasePackagingUnit' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'PurchasePackagingUnit' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseQtyPerPackUnit' , u'pVal' , ), 67, (67, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseQtyPerPackUnit' , u'pVal' , ), 67, (67, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitLength' , u'pVal' , ), 68, (68, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitLength' , u'pVal' , ), 68, (68, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWidth' , u'pVal' , ), 69, (69, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWidth' , u'pVal' , ), 69, (69, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitHeight' , u'pVal' , ), 70, (70, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitHeight' , u'pVal' , ), 70, (70, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitVolume' , u'pVal' , ), 71, (71, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitVolume' , u'pVal' , ), 71, (71, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseVolumeUnit' , u'pVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseVolumeUnit' , u'pVal' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWeight' , u'pVal' , ), 73, (73, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWeight' , u'pVal' , ), 73, (73, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseVATGroup' , u'pVal' , ), 74, (74, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseVATGroup' , u'pVal' , ), 74, (74, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor1' , u'pVal' , ), 75, (75, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor1' , u'pVal' , ), 75, (75, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor2' , u'pVal' , ), 76, (76, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor2' , u'pVal' , ), 76, (76, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor3' , u'pVal' , ), 77, (77, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor3' , u'pVal' , ), 77, (77, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor4' , u'pVal' , ), 78, (78, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor4' , u'pVal' , ), 78, (78, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor1' , u'pVal' , ), 79, (79, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor1' , u'pVal' , ), 79, (79, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor2' , u'pVal' , ), 80, (80, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor2' , u'pVal' , ), 80, (80, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor3' , u'pVal' , ), 81, (81, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor3' , u'pVal' , ), 81, (81, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor4' , u'pVal' , ), 82, (82, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor4' , u'pVal' , ), 82, (82, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'MovingAveragePrice' , u'pVal' , ), 83, (83, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'SalesLengthUnit' , u'pVal' , ), 84, (84, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'SalesLengthUnit' , u'pVal' , ), 84, (84, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'SalesWidthUnit' , u'pVal' , ), 85, (85, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'SalesWidthUnit' , u'pVal' , ), 85, (85, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'SalesHeightUnit' , u'pVal' , ), 86, (86, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'SalesHeightUnit' , u'pVal' , ), 86, (86, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'SalesWeightUnit' , u'pVal' , ), 87, (87, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'SalesWeightUnit' , u'pVal' , ), 87, (87, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWidthUnit' , u'pVal' , ), 88, (88, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWidthUnit' , u'pVal' , ), 88, (88, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseLengthUnit' , u'pVal' , ), 89, (89, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseLengthUnit' , u'pVal' , ), 89, (89, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseHeightUnit' , u'pVal' , ), 90, (90, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseHeightUnit' , u'pVal' , ), 90, (90, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWeightUnit' , u'pVal' , ), 91, (91, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWeightUnit' , u'pVal' , ), 91, (91, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAccount' , u'pVal' , ), 92, (92, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAccount' , u'pVal' , ), 92, (92, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'ECRevenuesAccount' , u'pVal' , ), 93, (93, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'ECRevenuesAccount' , u'pVal' , ), 93, (93, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 94, (94, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 94, (94, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'ECExpensesAccount' , u'pVal' , ), 95, (95, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'ECExpensesAccount' , u'pVal' , ), 95, (95, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'AvgStdPrice' , u'pVal' , ), 96, (96, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'AvgStdPrice' , u'pVal' , ), 96, (96, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'DefaultWarehouse' , u'pVal' , ), 97, (97, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'DefaultWarehouse' , u'pVal' , ), 97, (97, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'ShipType' , u'pVal' , ), 98, (98, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'ShipType' , u'pVal' , ), 98, (98, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'GLMethod' , u'pVal' , ), 99, (99, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'GLMethod' , u'pVal' , ), 99, (99, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 100, (100, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 100, (100, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'WhsInfo' , u'pVal' , ), 101, (101, (), [ (16393, 10, None, "IID('{CDB52791-B0FC-4BE1-A712-06941AF91D52}')") , ], 1 , 2 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'MaxInventory' , u'pVal' , ), 102, (102, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'MaxInventory' , u'pVal' , ), 102, (102, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'ManageStockByWarehouse' , u'pVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'ManageStockByWarehouse' , u'pVal' , ), 103, (103, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseHeightUnit1' , u'pVal' , ), 104, (104, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseHeightUnit1' , u'pVal' , ), 104, (104, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitHeight1' , u'pVal' , ), 105, (105, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitHeight1' , u'pVal' , ), 105, (105, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseLengthUnit1' , u'pVal' , ), 106, (106, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseLengthUnit1' , u'pVal' , ), 106, (106, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitLength1' , u'pVal' , ), 107, (107, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitLength1' , u'pVal' , ), 107, (107, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWeightUnit1' , u'pVal' , ), 108, (108, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWeightUnit1' , u'pVal' , ), 108, (108, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWeight1' , u'pVal' , ), 109, (109, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWeight1' , u'pVal' , ), 109, (109, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWidthUnit1' , u'pVal' , ), 110, (110, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWidthUnit1' , u'pVal' , ), 110, (110, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWidth1' , u'pVal' , ), 111, (111, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWidth1' , u'pVal' , ), 111, (111, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'SalesHeightUnit1' , u'pVal' , ), 112, (112, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'SalesHeightUnit1' , u'pVal' , ), 112, (112, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitHeight1' , u'pVal' , ), 113, (113, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitHeight1' , u'pVal' , ), 113, (113, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'SalesLengthUnit1' , u'pVal' , ), 114, (114, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'SalesLengthUnit1' , u'pVal' , ), 114, (114, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitLength1' , u'pVal' , ), 115, (115, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitLength1' , u'pVal' , ), 115, (115, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'SalesWeightUnit1' , u'pVal' , ), 116, (116, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'SalesWeightUnit1' , u'pVal' , ), 116, (116, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWeight1' , u'pVal' , ), 117, (117, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWeight1' , u'pVal' , ), 117, (117, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'SalesWidthUnit1' , u'pVal' , ), 118, (118, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'SalesWidthUnit1' , u'pVal' , ), 118, (118, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWidth1' , u'pVal' , ), 119, (119, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWidth1' , u'pVal' , ), 119, (119, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'ForceSelectionOfSerialNumber' , u'pVal' , ), 120, (120, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'ForceSelectionOfSerialNumber' , u'pVal' , ), 120, (120, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
	(( u'ManageSerialNumbersOnReleaseOnly' , u'pVal' , ), 121, (121, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 916 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 122, (122, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 920 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 122, (122, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 924 , (3, 0, None, None) , 0 , )),
	(( u'BaseUnitName' , u'pVal' , ), 123, (123, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 928 , (3, 0, None, None) , 0 , )),
	(( u'BaseUnitName' , u'pVal' , ), 123, (123, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 932 , (3, 0, None, None) , 0 , )),
	(( u'ItemCountryOrg' , u'pVal' , ), 124, (124, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 936 , (3, 0, None, None) , 0 , )),
	(( u'ItemCountryOrg' , u'pVal' , ), 124, (124, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 940 , (3, 0, None, None) , 0 , )),
	(( u'SWW' , u'pVal' , ), 125, (125, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 944 , (3, 0, None, None) , 0 , )),
	(( u'SWW' , u'pVal' , ), 125, (125, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 948 , (3, 0, None, None) , 0 , )),
	(( u'ManageSerialNumbersOnReleaseOnly' , u'pVal' , ), 121, (121, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 952 , (3, 0, None, None) , 0 , )),
	(( u'ApTaxCode' , u'pbstrRsltVal' , ), 126, (126, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 956 , (3, 0, None, None) , 0 , )),
	(( u'ApTaxCode' , u'pbstrRsltVal' , ), 126, (126, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 960 , (3, 0, None, None) , 0 , )),
	(( u'ArTaxCode' , u'pbstrRsltVal' , ), 127, (127, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 964 , (3, 0, None, None) , 0 , )),
	(( u'ArTaxCode' , u'pbstrRsltVal' , ), 127, (127, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 968 , (3, 0, None, None) , 0 , )),
	(( u'CostAccountingMethod' , u'pVal' , ), 128, (128, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 972 , (3, 0, None, None) , 0 , )),
	(( u'CostAccountingMethod' , u'pVal' , ), 128, (128, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 976 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyTemplate' , u'pVal' , ), 129, (129, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 980 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyTemplate' , u'pVal' , ), 129, (129, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 984 , (3, 0, None, None) , 0 , )),
	(( u'IndirectTax' , u'penumRslt' , ), 130, (130, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 988 , (3, 0, None, None) , 0 , )),
	(( u'IndirectTax' , u'penumRslt' , ), 130, (130, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 992 , (3, 0, None, None) , 0 , )),
	(( u'IssueMethod' , u'pVal' , ), 131, (131, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 996 , (3, 0, None, None) , 0 , )),
	(( u'IssueMethod' , u'pVal' , ), 131, (131, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1000 , (3, 0, None, None) , 0 , )),
	(( u'SRIAndBatchManageMethod' , u'pVal' , ), 132, (132, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1004 , (3, 0, None, None) , 0 , )),
	(( u'SRIAndBatchManageMethod' , u'pVal' , ), 132, (132, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1008 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 133, (133, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 1012 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 134, (134, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 1016 , (3, 0, None, None) , 0 , )),
	(( u'IsPhantom' , u'penumRsltVal' , ), 135, (135, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1020 , (3, 0, None, None) , 0 , )),
	(( u'IsPhantom' , u'penumRsltVal' , ), 135, (135, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1024 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 136, (136, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1028 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 136, (136, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1032 , (3, 0, None, None) , 0 , )),
	(( u'PlanningSystem' , u'penumRsltVal' , ), 137, (137, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1036 , (3, 0, None, None) , 0 , )),
	(( u'PlanningSystem' , u'penumRsltVal' , ), 137, (137, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1040 , (3, 0, None, None) , 0 , )),
	(( u'ProcurementMethod' , u'penumRsltVal' , ), 138, (138, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1044 , (3, 0, None, None) , 0 , )),
	(( u'ProcurementMethod' , u'penumRsltVal' , ), 138, (138, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1048 , (3, 0, None, None) , 0 , )),
	(( u'OrderIntervals' , u'pbstrRsltVal' , ), 139, (139, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1052 , (3, 0, None, None) , 0 , )),
	(( u'OrderIntervals' , u'pbstrRsltVal' , ), 139, (139, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1056 , (3, 0, None, None) , 0 , )),
	(( u'OrderMultiple' , u'pdblRsltVal' , ), 140, (140, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1060 , (3, 0, None, None) , 0 , )),
	(( u'OrderMultiple' , u'pdblRsltVal' , ), 140, (140, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1064 , (3, 0, None, None) , 0 , )),
	(( u'LeadTime' , u'plRsltVal' , ), 141, (141, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1068 , (3, 0, None, None) , 0 , )),
	(( u'LeadTime' , u'plRsltVal' , ), 141, (141, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1072 , (3, 0, None, None) , 0 , )),
	(( u'MinOrderQuantity' , u'pdblRsltVal' , ), 142, (142, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1076 , (3, 0, None, None) , 0 , )),
	(( u'MinOrderQuantity' , u'pdblRsltVal' , ), 142, (142, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1080 , (3, 0, None, None) , 0 , )),
	(( u'ItemType' , u'penumRsltVal' , ), 143, (143, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1084 , (3, 0, None, None) , 0 , )),
	(( u'ItemType' , u'penumRsltVal' , ), 143, (143, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1088 , (3, 0, None, None) , 0 , )),
	(( u'ItemClass' , u'pVal' , ), 144, (144, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1092 , (3, 0, None, None) , 0 , )),
	(( u'ItemClass' , u'pVal' , ), 144, (144, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1096 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingServiceCode' , u'pVal' , ), 145, (145, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1100 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingServiceCode' , u'pVal' , ), 145, (145, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1104 , (3, 0, None, None) , 0 , )),
	(( u'IncomingServiceCode' , u'pVal' , ), 146, (146, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1108 , (3, 0, None, None) , 0 , )),
	(( u'IncomingServiceCode' , u'pVal' , ), 146, (146, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1112 , (3, 0, None, None) , 0 , )),
	(( u'ServiceGroup' , u'pVal' , ), 147, (147, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1116 , (3, 0, None, None) , 0 , )),
	(( u'ServiceGroup' , u'pVal' , ), 147, (147, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1120 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'pVal' , ), 148, (148, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1124 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'pVal' , ), 148, (148, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1128 , (3, 0, None, None) , 0 , )),
	(( u'MaterialType' , u'pVal' , ), 149, (149, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1132 , (3, 0, None, None) , 0 , )),
	(( u'MaterialType' , u'pVal' , ), 149, (149, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1136 , (3, 0, None, None) , 0 , )),
	(( u'MaterialGroup' , u'pVal' , ), 150, (150, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1140 , (3, 0, None, None) , 0 , )),
	(( u'MaterialGroup' , u'pVal' , ), 150, (150, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1144 , (3, 0, None, None) , 0 , )),
	(( u'ProductSource' , u'pVal' , ), 151, (151, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1148 , (3, 0, None, None) , 0 , )),
	(( u'ProductSource' , u'pVal' , ), 151, (151, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1152 , (3, 0, None, None) , 0 , )),
]

IItems_Prices_vtables_dispatch_ = 1
IItems_Prices_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'PriceListName' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IJournalEntries_vtables_dispatch_ = 1
IJournalEntries_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{55053980-777B-44CF-8D76-84DD975171AA}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'JdtNum' , u'Found' , ), 4, (4, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate' , u'pVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate' , u'pVal' , ), 5, (5, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'JdtNum' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 16, (16, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'UseAutoStorno' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'UseAutoStorno' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'StornoDate' , u'pVal' , ), 24, (24, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'StornoDate' , u'pVal' , ), 24, (24, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 1 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 27, (27, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 27, (27, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'StampTax' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'StampTax' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 32, (32, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 32, (32, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'AutoVAT' , u'penumRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'AutoVAT' , u'penumRsltVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
]

IJournalEntries_Lines_vtables_dispatch_ = 1
IJournalEntries_Lines_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Line_ID' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Debit' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Debit' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Credit' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Credit' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'FCDebit' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FCDebit' , u'pVal' , ), 9, (9, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'FCCredit' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'FCCredit' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'FCCurrency' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'FCCurrency' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ContraAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ContraAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'LineMemo' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'LineMemo' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate1' , u'pVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate1' , u'pVal' , ), 16, (16, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate2' , u'pVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate2' , u'pVal' , ), 17, (17, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 23, (23, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 23, (23, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BaseSum' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BaseSum' , u'pVal' , ), 24, (24, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DebitSys' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'CreditSys' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 28, (28, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 28, (28, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'VatLine' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'VatLine' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'SystemBaseAmount' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'SystemBaseAmount' , u'pVal' , ), 30, (30, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'VatAmount' , u'pVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'SystemVatAmount' , u'pVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'GrossValue' , u'pVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalReference' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalReference' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'CheckAbs' , u'plRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'GrossValue' , u'pVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'SystemVatAmount' , u'pVal' , ), 32, (32, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'VatAmount' , u'pVal' , ), 31, (31, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'DebitSys' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'CreditSys' , u'pVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode2' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode2' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode3' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode3' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode4' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode4' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
]

IJournalVouchers_vtables_dispatch_ = 1
IJournalVouchers_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntries' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{060F033E-2FC9-4266-90AE-3271AC203A59}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
]

IKnowledgeBaseSolutions_vtables_dispatch_ = 1
IKnowledgeBaseSolutions_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'SolutionCode' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CreatedBy' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdatedBy' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdateDate' , u'pVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Solution' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Solution' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Symptom' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Symptom' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Cause' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Cause' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'SolutionCode' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
]

ILocalEra_vtables_dispatch_ = 1
ILocalEra_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrCode' , u'pbRsltFound' , ), 6, (6, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'EraName' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdtRsltVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IManufacturers_vtables_dispatch_ = 1
IManufacturers_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IMaterialRevaluation_vtables_dispatch_ = 1
IMaterialRevaluation_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{038A3F8E-2465-435E-8D05-F510620533C3}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 4, (4, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 4, (4, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocTime' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AbsEntry' , u'Found' , ), 12, (12, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 13, (13, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 14, (14, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 21, (21, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 22, (22, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TransNum' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'RevalType' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'RevalType' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationIncomeAccount' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationIncomeAccount' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationExpenseAccount' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationExpenseAccount' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DataSource' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
]

IMaterialRevaluation_lines_vtables_dispatch_ = 1
IMaterialRevaluation_lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 9, (9, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ActualPrice' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'OnHand' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DebitCredit' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DebitCredit' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationDecrementAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationDecrementAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationIncrementAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationIncrementAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'RevalAmountToStock' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
]

IMessages_vtables_dispatch_ = 1
IMessages_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'MessageText' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'MessageText' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'AddDataColumn' , u'Title' , u'Text' , u'Object' , u'ObjectKey' , 
			), 7, (7, (), [ (8, 0, None, None) , (8, 0, None, None) , (3, 0, None, None) , (8, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Recipients' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{F408B086-B6E4-4EE0-9B95-710C117E56F0}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

INotaFiscalCFOP_vtables_dispatch_ = 1
INotaFiscalCFOP_vtables_ = [
	(( u'UserFields' , u'ppRsltIUserFields' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Application' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Application' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ID' , u'Found' , ), 8, (8, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

INotaFiscalCST_vtables_dispatch_ = 1
INotaFiscalCST_vtables_ = [
	(( u'UserFields' , u'ppRsltIUserFields' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Situation' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Situation' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ID' , u'Found' , ), 8, (8, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

INotaFiscalUsage_vtables_dispatch_ = 1
INotaFiscalUsage_vtables_ = [
	(( u'UserFields' , u'ppRsltIUserFields' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Usage' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Usage' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ID' , u'Found' , ), 7, (7, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IPackagesTypes_vtables_dispatch_ = 1
IPackagesTypes_vtables_ = [
	(( u'Type' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IPaymentRunExport_vtables_dispatch_ = 1
IPaymentRunExport_vtables_ = [
	(( u'GetByKey' , u'PaymentRunExportCode' , u'Found' , ), 1, (1, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{917BA077-4D88-46A8-B78A-E396315D7E59}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 3, (3, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 4, (4, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RunDate' , u'pVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CustomerNum' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethod' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FiscalYear' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Countery' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CompanyTaxNum' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PayeeName' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PayeePostalCode' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PayeeCity' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PayeeStreet' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PayeeCountry' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PayeeState' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankName' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankZip' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCity' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankStreet' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCountry' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankAccount' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCode' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCtrlKey' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankSwiftNum' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankIBAN' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pVal' , ), 29, (29, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BankIBAN' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DocAmountLocal' , u'pVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrnecy' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DocAmountForign' , u'pVal' , ), 38, (38, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DocCashDiscount' , u'pVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DocCashDiscountForign' , u'pVal' , ), 40, (40, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DocNumOffieldPaid' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 42, (42, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'WizCode' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'CollectionAuthorization' , u'pVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankPostOffice' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankNextCheckNumber' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankHouseBank' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankBlock' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCounty' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankState' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankBISR' , u'pVal' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankUserNum1' , u'pVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankUserNum2' , u'pVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankUserNum3' , u'pVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankUserNum4' , u'pVal' , ), 56, (56, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'InstructionKey' , u'pVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'PaymentFormat' , u'pVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'CompanyName' , u'pVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'CompanyAddress' , u'pVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 61, (61, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'CompIsrBillerID' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'VendorIsrBillerID' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalIdNumber' , u'pVal' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'OrganizationNumber' , u'pVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankBranch' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankBranch' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'UserEMail' , u'pVal' , ), 69, (69, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'UserMobilePhoneNumber' , u'pVal' , ), 70, (70, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'UserFaxNumber' , u'pVal' , ), 71, (71, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'UserDepartment' , u'pVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'DebitMemo' , u'pVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'EUInternalTransfer' , u'pVal' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'FilePath' , u'pVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'OrderingParty' , u'pVal' , ), 76, (76, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankControlKey' , u'pVal' , ), 77, (77, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'PayeeTaxNumber' , u'pVal' , ), 78, (78, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'PaymentKeyCode' , u'pVal' , ), 79, (79, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'PayeeReferenceDetails' , u'pVal' , ), 80, (80, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'FormatName' , u'pVal' , ), 81, (81, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 82, (82, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 83, (83, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
]

IPaymentRunExport_Lines_vtables_dispatch_ = 1
IPaymentRunExport_Lines_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DateOfPaymentRun' , u'pVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'PaymentWizardCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'VendorNumber' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CustomerNumber' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMeans' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDocNum' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FiscalYear' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'VendorRefNum' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DocumentObjectType' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocumentPostingDate' , u'pVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTaxDate' , u'pVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BPDebitPayableAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCurrency' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DocumentRate' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTotal' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTotalFC' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTaxAmount' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTaxAmountFC' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DocumentRemarks' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DocumentPaymentTerms' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDocReference' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DocumentLocalCurrency' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTermsPeriod' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DocumentObjectTypeEx' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
]

IPaymentTermsTypes_vtables_dispatch_ = 1
IPaymentTermsTypes_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'GroupNum' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GroupNumber' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTermsGroupName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTermsGroupName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'StartFrom' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'StartFrom' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfAdditionalMonths' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfAdditionalMonths' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfAdditionalDays' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfAdditionalDays' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CreditLimit' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CreditLimit' , u'pVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'GeneralDiscount' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GeneralDiscount' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'InterestOnArrears' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'InterestOnArrears' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'LoadLimit' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'LoadLimit' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'OpenReceipt' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'OpenReceipt' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DiscountCode' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DiscountCode' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DunningCode' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DunningCode' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BaselineDate' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'BaselineDate' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfInstallments' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfToleranceDays' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfToleranceDays' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 25, (25, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
]

IPayments_vtables_dispatch_ = 1
IPayments_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'RctEntry' , u'Found' , ), 4, (4, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocTypte' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocTypte' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CashSum' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'CashSum' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CheckAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CheckAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TransferAccount' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TransferAccount' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'TransferSum' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'TransferSum' , u'pVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'TransferDate' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'TransferDate' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TransferReference' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'TransferReference' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'LocalCurrency' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'LocalCurrency' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'CounterReference' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'CounterReference' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ApplyVAT' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ApplyVAT' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 32, (32, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 32, (32, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'Checks' , u'pVal' , ), 36, (36, (), [ (16393, 10, None, "IID('{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}')") , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'Invoices' , u'pVal' , ), 37, (37, (), [ (16393, 10, None, "IID('{AB7947CF-8191-498D-8B3C-8E04A00957E7}')") , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'CreditCards' , u'pVal' , ), 38, (38, (), [ (16393, 10, None, "IID('{CC3579ED-1C61-4864-8E51-208A3DCDFC93}')") , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'AccountPayments' , u'pVal' , ), 39, (39, (), [ (16393, 10, None, "IID('{231A13D7-5DA8-4467-A263-FDE84A268AC9}')") , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 45, (45, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'pVal' , ), 47, (47, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'pVal' , ), 47, (47, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'DeductionSum' , u'pVal' , ), 48, (48, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'DeductionSum' , u'pVal' , ), 48, (48, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'CashSumFC' , u'pVal' , ), 49, (49, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'CashSumSys' , u'pVal' , ), 50, (50, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'BoeAccount' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'BoeAccount' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAmount' , u'pVal' , ), 52, (52, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAmount' , u'pVal' , ), 52, (52, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeStatus' , u'pVal' , ), 53, (53, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeStatus' , u'pVal' , ), 53, (53, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchange' , u'pVal' , ), 54, (54, (), [ (16393, 10, None, "IID('{741AA803-AB33-4FD7-B664-63116291D6CE}')") , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAmountFC' , u'pVal' , ), 55, (55, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAmountSC' , u'pVal' , ), 56, (56, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAgent' , u'pVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAgent' , u'pVal' , ), 57, (57, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 59, (59, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 59, (59, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 60, (60, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSC' , u'pVal' , ), 61, (61, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'WTAccount' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'WTTaxableAmount' , u'pVal' , ), 63, (63, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'Proforma' , u'pVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'Proforma' , u'pVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'PaymentPriority' , u'pVal' , ), 65, (65, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'PaymentPriority' , u'pVal' , ), 65, (65, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankAccountNo' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankAccountNo' , u'pVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'PayToCode' , u'pVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'PayToCode' , u'pVal' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCountry' , u'pVal' , ), 69, (69, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCountry' , u'pVal' , ), 69, (69, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'IsPayToBank' , u'pVal' , ), 70, (70, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'IsPayToBank' , u'pVal' , ), 70, (70, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCode' , u'pVal' , ), 74, (74, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCode' , u'pVal' , ), 74, (74, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankBranch' , u'pVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankBranch' , u'pVal' , ), 75, (75, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 76, (76, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 77, (77, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeAmount' , u'pVal' , ), 78, (78, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeAmount' , u'pVal' , ), 78, (78, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeAmountInFC' , u'pVal' , ), 79, (79, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeAmountInSC' , u'pVal' , ), 80, (80, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 81, (81, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 81, (81, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pVal' , ), 82, (82, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pVal' , ), 82, (82, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'PaymentType' , u'pVal' , ), 83, (83, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'PaymentType' , u'pVal' , ), 83, (83, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'TransferRealAmount' , u'pVal' , ), 84, (84, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'TransferRealAmount' , u'pVal' , ), 84, (84, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
]

IPayments_Accounts_vtables_dispatch_ = 1
IPayments_Accounts_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SumPaid' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SumPaid' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Decription' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Decription' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IPayments_Checks_vtables_dispatch_ = 1
IPayments_Checks_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AccounttNum' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AccounttNum' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Trnsfrable' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Trnsfrable' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'CheckSum' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CheckSum' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IPayments_CreditCards_vtables_dispatch_ = 1
IPayments_CreditCards_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CreditCard' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CreditCard' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CreditAcct' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CreditAcct' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardNumber' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardNumber' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CardValidUntil' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CardValidUntil' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'VoucherNum' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'VoucherNum' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'OwnerIdNum' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'OwnerIdNum' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'OwnerPhone' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'OwnerPhone' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'NumOfPayments' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'NumOfPayments' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'FirstPaymentDue' , u'pVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'FirstPaymentDue' , u'pVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'FirstPaymentSum' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'FirstPaymentSum' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalPaymentSum' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalPaymentSum' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CreditSum' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'CreditSum' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ConfirmationNum' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ConfirmationNum' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'NumOfCreditPayments' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'NumOfCreditPayments' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'CreditType' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'CreditType' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'SplitPayments' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SplitPayments' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
]

IPayments_Invoices_vtables_dispatch_ = 1
IPayments_Invoices_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SumApplied' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SumApplied' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AppliedFC' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AppliedFC' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DocLine' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocLine' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceType' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceType' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PaidSum' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'InstallmentId' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'InstallmentId' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'WitholdingTaxApplied' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'WitholdingTaxAppliedFC' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'WitholdingTaxAppliedSC' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'LinkDate' , u'pVal' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
]

IPriceLists_vtables_dispatch_ = 1
IPriceLists_vtables_ = [
	(( u'GetByKey' , u'QueueID' , u'Found' , ), 1, (1, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 3, (3, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GroupNum' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GroupNum' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BasePriceList' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BasePriceList' , u'pVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PriceListName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PriceListName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

IProductTrees_vtables_dispatch_ = 1
IProductTrees_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 3, (3, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Items' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TreeCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TreeCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TreeType' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TreeType' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 13, (13, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

IProductTrees_Lines_vtables_dispatch_ = 1
IProductTrees_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 9, (9, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'IssueMethod' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'IssueMethod' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ParentItem' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ParentItem' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IProductionOrders_vtables_dispatch_ = 1
IProductionOrders_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsEntry' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderStatus' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderStatus' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderType' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderType' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PlannedQuantity' , u'pdbllRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PlannedQuantity' , u'pdbllRsltVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CompletedQuantity' , u'pdblRsltVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'RejectedQuantity' , u'pdblRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pdtRsltVal' , ), 21, (21, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pdtRsltVal' , ), 21, (21, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdtRsltVal' , ), 22, (22, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdtRsltVal' , ), 22, (22, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOriginEntry' , u'plRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOriginEntry' , u'plRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOriginNumber' , u'plRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOrigin' , u'penumRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOrigin' , u'penumRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'plRsltVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pdtRsltVal' , ), 28, (28, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'ReleaseDate' , u'pdtRsltVal' , ), 29, (29, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'TransactionNumber' , u'plRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pdtRsltVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 36, (36, (), [ (16393, 10, None, "IID('{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}')") , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
]

IProductionOrders_Lines_vtables_dispatch_ = 1
IProductionOrders_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'DocumentAbsoluteEntry' , u'plRsltVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BaseQuantity' , u'pdblRsltVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BaseQuantity' , u'pdblRsltVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PlannedQuantity' , u'pdblRsltVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'IssuedQuantity' , u'pdblRsltVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderIssueType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderIssueType' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IQueryCategories_vtables_dispatch_ = 1
IQueryCategories_vtables_ = [
	(( u'Code' , u'plVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IQueue_vtables_dispatch_ = 1
IQueue_vtables_ = [
	(( u'QueueID' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'QueueID' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'QueueManager' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'QueueManager' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'QueueEmail' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'QueueEmail' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'QueueMembers' , u'ppRsltVal' , ), 58, (58, (), [ (16393, 10, None, "IID('{A6D332DA-630B-44C7-AA91-69F2C1A2501D}')") , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrQueueID' , u'Found' , ), 9, (9, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 10, (10, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IQueueMembers_vtables_dispatch_ = 1
IQueueMembers_vtables_ = [
	(( u'QueueID' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'QueueID' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'MemberUserID' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'MemberUserID' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 3, (3, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 5, (5, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 6, (6, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IRecipients_vtables_dispatch_ = 1
IRecipients_vtables_ = [
	(( u'Count' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'NameTo' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'NameTo' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SendEmail' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SendEmail' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SendSMS' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SendSMS' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SendFax' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SendFax' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CellularNumber' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CellularNumber' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'UserType' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'UserType' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SendInternal' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SendInternal' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IRecordset_vtables_dispatch_ = 1
IRecordset_vtables_ = [
	(( u'Fields' , u'pVal' , ), 0, (0, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'MoveNext' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'MovePrevious' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BoF' , u'pVal' , ), 5, (5, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'EoF' , u'pVal' , ), 6, (6, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DoQuery' , u'QueryStr' , ), 7, (7, (), [ (8, 0, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RecordCount' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 9, (9, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MoveFirst' , ), 10, (10, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'MoveLast' , ), 11, (11, (), [ ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Command' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}')") , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IRelationships_vtables_dispatch_ = 1
IRelationships_vtables_ = [
	(( u'RelationshipDescription' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipDescription' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipCode' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ISBObob_vtables_dispatch_ = 1
ISBObob_vtables_ = [
	(( u'GetBPList' , u'CardType' , u'pVal' , ), 1, (1, (), [ (3, 0, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDueDate' , u'CardCode' , u'refDate' , u'pVal' , ), 2, (2, (), [ 
			(8, 1, None, None) , (7, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetSystemCurrency' , u'pVal' , ), 3, (3, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetLocalCurrency' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetCurrencyRate' , u'Currency' , u'Date' , u'pVal' , ), 5, (5, (), [ 
			(8, 1, None, None) , (7, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetIndexRate' , u'Index' , u'Date' , u'pVal' , ), 6, (6, (), [ 
			(8, 1, None, None) , (7, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetItemPrice' , u'CardCode' , u'ItemCode' , u'amount' , u'Date' , 
			u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , (8, 1, None, None) , (5, 1, None, None) , 
			(7, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetItemList' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GetUserList' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetWareHouseList' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrencyRate' , u'Currency' , u'Date' , u'Value' , u'Update' , 
			), 11, (11, (), [ (8, 1, None, None) , (7, 1, None, None) , (5, 1, None, None) , (11, 49, 'False', None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetContactEmployees' , u'CardCode' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Format_DateToString' , u'inDate' , u'pVal' , ), 13, (13, (), [ (7, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Format_StringToDate' , u'inStr' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Format_MoneyToString' , u'inMoney' , u'inPrecision' , u'pVal' , ), 15, (15, (), [ 
			(5, 1, None, None) , (3, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'GetObjectKeyBySingleValue' , u'ObjNum' , u'PropName' , u'Value' , u'Condition' , 
			u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , (8, 1, None, None) , (8, 1, None, None) , 
			(3, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ConvertEnumValueToValidValue' , u'enumName' , u'enumValue' , u'retValidValue' , ), 18, (18, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ConvertValidValueToEnumValue' , u'enumName' , u'ValidValue' , u'retEnumValue' , ), 19, (19, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'GetValidValueDescription' , u'ObjNum' , u'ObjectName' , u'PropertyName' , u'enumValue' , 
			u'Description' , ), 20, (20, (), [ (3, 1, None, None) , (8, 1, None, None) , (8, 1, None, None) , 
			(3, 1, None, None) , (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GetAccountSegmentsByCode' , u'AccountCode' , u'AddSeperator' , u'pVal' , ), 21, (21, (), [ 
			(8, 1, None, None) , (11, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GetTableFieldList' , u'TableName' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GetFieldValidValues' , u'TableName' , u'FieldName' , u'pVal' , ), 23, (23, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'GetObjectPermission' , u'Object' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'GetTableList' , u'pVal' , ), 25, (25, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'GetSystemPermission' , u'UserName' , u'PermissionID' , u'pVal' , ), 26, (26, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'SetSystemPermission' , u'UserName' , u'PermissionID' , u'Permission' , ), 27, (27, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (3, 1, None, None) , ], 1 , 1 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
]

ISalesForecast_vtables_dispatch_ = 1
ISalesForecast_vtables_ = [
	(( u'ForecastStartDate' , u'pVal' , ), 1, (1, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ForecastStartDate' , u'pVal' , ), 1, (1, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ForecastEndDate' , u'pVal' , ), 2, (2, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ForecastEndDate' , u'pVal' , ), 2, (2, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ForecastCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ForecastCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ForecastName' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ForecastName' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 8, (8, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 9, (9, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'ppRsltVal' , ), 58, (58, (), [ (16393, 10, None, "IID('{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'pVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 61, (61, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

ISalesForecast_Lines_vtables_dispatch_ = 1
ISalesForecast_Lines_vtables_ = [
	(( u'Quantity' , u'pVal' , ), 1, (1, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 1, (1, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ForecastedDay' , u'pVal' , ), 2, (2, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ForecastedDay' , u'pVal' , ), 2, (2, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunities_vtables_dispatch_ = 1
ISalesOpportunities_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'OpprId' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SequentialNo' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SalesPerson' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SalesPerson' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Source' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Source' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'InterestField1' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'InterestField1' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'InterestField2' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'InterestField2' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'InterestField3' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'InterestField3' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'InterestLevel' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'InterestLevel' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 18, (18, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 18, (18, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PredictedClosingDate' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'PredictedClosingDate' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'MaxLocalTotal' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'MaxSystemTotal' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'WeightedSumLC' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'WeightedSumSC' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfit' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfit' , u'pVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitTotalLocal' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitTotalLocal' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitTotalSystem' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'ReasonForClosing' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'ReasonForClosing' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'TotalAmountLocal' , u'pVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'TotalAmountLocal' , u'pVal' , ), 32, (32, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'TotalAmounSystem' , u'pVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'ClosingGrossProfitLocal' , u'pVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ClosingGrossProfitSystem' , u'pVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ClosingPercentage' , u'pVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'CurrentStageNo' , u'pVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 38, (38, (), [ (16393, 10, None, "IID('{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}')") , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Competition' , u'pVal' , ), 39, (39, (), [ (16393, 10, None, "IID('{19E6540E-4E64-48C1-9525-29D5710D1FFD}')") , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Partners' , u'pVal' , ), 40, (40, (), [ (16393, 10, None, "IID('{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}')") , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'OpportunityName' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'OpportunityName' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'LinkedDocumentType' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipfield' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipfield' , u'pVal' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'StatusRemarks' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'StatusRemarks' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelName' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelName' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCheckbox' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'LinkedDocumentNumber' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Territory' , u'pVal' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Territory' , u'pVal' , ), 52, (52, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 53, (53, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 54, (54, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelCode' , u'pVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelCode' , u'pVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'ClosingType' , u'pVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'ClosingType' , u'pVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'Interests' , u'ppRsltVal' , ), 57, (57, (), [ (16393, 10, None, "IID('{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}')") , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'Reasons' , u'ppRsltVal' , ), 58, (58, (), [ (16393, 10, None, "IID('{D4A7CE6F-B909-4273-8499-C210F94ED2D1}')") , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesCompetition_vtables_dispatch_ = 1
ISalesOpportunitiesCompetition_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RowNo' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Competition' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Competition' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'WonOrLost' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'WonOrLost' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesInterests_vtables_dispatch_ = 1
ISalesOpportunitiesInterests_vtables_ = [
	(( u'RowNo' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryInterest' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryInterest' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'InterestId' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'InterestId' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 7, (7, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesLines_vtables_dispatch_ = 1
ISalesOpportunitiesLines_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SalesPerson' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SalesPerson' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'StageKey' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'StageKey' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PercentageRate' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PercentageRate' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MaxLocalTotal' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'MaxLocalTotal' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'MaxSystemTotal' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Contact' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'WeightedAmountLocal' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'WeightedAmountSystem' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCheckbox' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCheckbox' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelName' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelName' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelCode' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipfield' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipfield' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesPartners_vtables_dispatch_ = 1
ISalesOpportunitiesPartners_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RowNo' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Partners' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Partners' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipCode' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipCode' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesReasons_vtables_dispatch_ = 1
ISalesOpportunitiesReasons_vtables_ = [
	(( u'RowNo' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Reason' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Reason' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISalesTaxAuthorities_vtables_dispatch_ = 1
ISalesTaxAuthorities_vtables_ = [
	(( u'UseTaxAccount' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'UseTaxAccount' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AOrRTaxAccount' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AOrRTaxAccount' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AOrPTaxAccount' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AOrPTaxAccount' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductiblePrecent' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductiblePrecent' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductibleAccount' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductibleAccount' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTaxAccount' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTaxAccount' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Code' , u'Type' , u'Found' , ), 13, (13, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 14, (14, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
]

ISalesTaxAuthoritiesTypes_vtables_dispatch_ = 1
ISalesTaxAuthoritiesTypes_vtables_ = [
	(( u'UserSignature' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'VAT' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'VAT' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ISalesTaxCodes_vtables_dispatch_ = 1
ISalesTaxCodes_vtables_ = [
	(( u'ValidForAR' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ValidForAR' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ValidForAP' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ValidForAP' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Freight' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Freight' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{98DF1BF3-2F28-46C7-8003-FB8D11276237}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 10, (10, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 11, (11, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

ISalesTaxCodes_Lines_vtables_dispatch_ = 1
ISalesTaxCodes_Lines_vtables_ = [
	(( u'STATaxOnTaxType' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'STATaxOnTaxType' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'STATaxonTaxCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'STATaxonTaxCode' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'STCCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'STAType' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'STAType' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'STACode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'STACode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'EffectiveRate' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 10, (10, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 11, (11, (), [ ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ISerialNumbers_vtables_dispatch_ = 1
ISerialNumbers_vtables_ = [
	(( u'Count' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNumber' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNumber' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNumber' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNumber' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ExpiryDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ExpiryDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ManufactureDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ManufactureDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ReceptionDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ReceptionDate' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyStart' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyStart' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyEnd' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyEnd' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BatchID' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BatchID' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SystemSerialNumber' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'SystemSerialNumber' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'BaseLineNumber' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'BaseLineNumber' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
]

IServiceCallActivities_vtables_dispatch_ = 1
IServiceCallActivities_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ActivityCode' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ActivityCode' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceCallInventoryExpenses_vtables_dispatch_ = 1
IServiceCallInventoryExpenses_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PartType' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocumentPostingDate' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'StockTransferDirection' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'StockTransferDirection' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IServiceCallSolutions_vtables_dispatch_ = 1
IServiceCallSolutions_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SolutionID' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SolutionID' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceCalls_vtables_dispatch_ = 1
IServiceCalls_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ServiceCallID' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ServiceCallID' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ContractID' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ContractEndDate' , u'pVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionDate' , u'pVal' , ), 18, (18, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionDate' , u'pVal' , ), 18, (18, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 19, (19, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Origin' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Origin' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroupCode' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'CallType' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'CallType' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ProblemType' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ProblemType' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'AssigneeCode' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'AssigneeCode' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'TechnicianCode' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'TechnicianCode' , u'pVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Resolution' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Resolution' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Activities' , u'pVal' , ), 35, (35, (), [ (16393, 10, None, "IID('{0207412D-F955-46BA-AE96-E749573B4106}')") , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Expenses' , u'pVal' , ), 36, (36, (), [ (16393, 10, None, "IID('{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}')") , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Solutions' , u'pVal' , ), 37, (37, (), [ (16393, 10, None, "IID('{FA8FD318-6971-4E8B-B6E9-959A938455C6}')") , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 38, (38, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CreationTime' , u'pVal' , ), 39, (39, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'Responder' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'UpdatedTime' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'BelongsToAQueue' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'BelongsToAQueue' , u'pVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ResponseByTime' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'ResponseByDate' , u'pVal' , ), 45, (45, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionOnDate' , u'pVal' , ), 46, (46, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'ResponseOnTime' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'ResponseOnDate' , u'pVal' , ), 48, (48, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ClosingTime' , u'pVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'AssignedDate' , u'pVal' , ), 50, (50, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Queue' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'Queue' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'ResponseAssignee' , u'pVal' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'EntitledforService' , u'pVal' , ), 53, (53, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionOnTime' , u'pVal' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'AssignedTime' , u'pVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 56, (56, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'ContractID' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
]

IServiceContract_Lines_vtables_dispatch_ = 1
IServiceContract_Lines_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroup' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroup' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroupName' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
]

IServiceContracts_vtables_dispatch_ = 1
IServiceContracts_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ContractID' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ContractID' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ContractTemplate' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ContractTemplate' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ContractType' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ContractType' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Renewal' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Renewal' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ReminderTime' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ReminderTime' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DurationOfCoverage' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 19, (19, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionUnit' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionUnit' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnabled' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnabled' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnabled' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnabled' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnabled' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnabled' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnabled' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnabled' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnabled' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnabled' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnabled' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnabled' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnabled' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnabled' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'MondayStart' , u'pVal' , ), 32, (32, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'MondayStart' , u'pVal' , ), 32, (32, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnd' , u'pVal' , ), 33, (33, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnd' , u'pVal' , ), 33, (33, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayStart' , u'pVal' , ), 34, (34, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayStart' , u'pVal' , ), 34, (34, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnd' , u'pVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnd' , u'pVal' , ), 35, (35, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayStart' , u'pVal' , ), 36, (36, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayStart' , u'pVal' , ), 36, (36, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnd' , u'pVal' , ), 37, (37, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnd' , u'pVal' , ), 37, (37, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayStart' , u'pVal' , ), 38, (38, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayStart' , u'pVal' , ), 38, (38, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnd' , u'pVal' , ), 39, (39, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnd' , u'pVal' , ), 39, (39, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'FridayStart' , u'pVal' , ), 40, (40, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'FridayStart' , u'pVal' , ), 40, (40, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnd' , u'pVal' , ), 41, (41, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnd' , u'pVal' , ), 41, (41, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayStart' , u'pVal' , ), 42, (42, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayStart' , u'pVal' , ), 42, (42, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnd' , u'pVal' , ), 43, (43, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnd' , u'pVal' , ), 43, (43, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'SundayStart' , u'pVal' , ), 44, (44, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'SundayStart' , u'pVal' , ), 44, (44, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnd' , u'pVal' , ), 45, (45, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnd' , u'pVal' , ), 45, (45, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'IncludeParts' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'IncludeParts' , u'pVal' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'IncludeLabor' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'IncludeLabor' , u'pVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'IncludeTravel' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'IncludeTravel' , u'pVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 49, (49, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'TemplateRemarks' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 53, (53, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 55, (55, (), [ (16393, 10, None, "IID('{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}')") , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'IncludeHolidays' , u'pVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'IncludeHolidays' , u'pVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'ServiceType' , u'pVal' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'ServiceType' , u'pVal' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'ResponseUnit' , u'pVal' , ), 58, (58, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'ResponseUnit' , u'pVal' , ), 58, (58, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'ResponseTime' , u'pVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'ResponseTime' , u'pVal' , ), 59, (59, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 60, (60, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 60, (60, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
]

IShippingTypes_vtables_dispatch_ = 1
IShippingTypes_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Website' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Website' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

ISpecialPrices_vtables_dispatch_ = 1
ISpecialPrices_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ItemCode' , u'CardCode' , u'Found' , ), 10, (10, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'AutoUpdate' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'AutoUpdate' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 12, (12, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPricesDataAreas' , u'pVal' , ), 13, (13, (), [ (16393, 10, None, "IID('{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
]

ISpecialPricesDataAreas_vtables_dispatch_ = 1
ISpecialPricesDataAreas_vtables_ = [
	(( u'PriceCurrency' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'AutoUpdate' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AutoUpdate' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Dateto' , u'pVal' , ), 3, (3, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Dateto' , u'pVal' , ), 3, (3, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Discount' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Discount' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPrice' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPrice' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DateFrom' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DateFrom' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 13, (13, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 14, (14, (), [ ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPricesQuantityAreas' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{34995651-4568-4AAE-B831-60693B932A35}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
]

ISpecialPricesQuantityAreas_vtables_dispatch_ = 1
ISpecialPricesQuantityAreas_vtables_ = [
	(( u'Quantity' , u'pVal' , ), 1, (1, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 1, (1, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SPDARowNumber' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPrice' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPrice' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Discountin' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Discountin' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 11, (11, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 12, (12, (), [ ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IStockTaking_vtables_dispatch_ = 1
IStockTaking_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Counted' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Counted' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IStockTransfer_vtables_dispatch_ = 1
IStockTransfer_vtables_ = [
	(( u'Lines' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AbsEntry' , u'Found' , ), 3, (3, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'FromWarehouse' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'FromWarehouse' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 23, (23, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 24, (24, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'FinancialPeriod' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'TransNum' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 28, (28, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 29, (29, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 29, (29, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 31, (31, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
]

IStockTransfer_Lines_vtables_dispatch_ = 1
IStockTransfer_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumber' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumber' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Factor2' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Factor2' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Factor3' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Factor3' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Factor4' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Factor4' , u'pVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumbers' , u'pVal' , ), 20, (20, (), [ (16393, 10, None, "IID('{93E5E52B-181E-46B8-96CB-1C066AC04DCA}')") , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'BatchNumbers' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{1FEF5698-93E1-4167-AEA0-4BB151792623}')") , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
]

ITaxExtension_vtables_dispatch_ = 1
ITaxExtension_vtables_ = [
	(( u'TaxId0' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'TaxId0' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'TaxId1' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'TaxId1' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'TaxId2' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TaxId2' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TaxId3' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TaxId3' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TaxId4' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TaxId4' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TaxId5' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxId5' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxId6' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxId6' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxId7' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxId7' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxId8' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxId8' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TaxId9' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxId9' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Incoterms' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Incoterms' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Vehicle' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Vehicle' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'VehicleState' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'VehicleState' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'NFRef' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'NFRef' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Carrier' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Carrier' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'PackQuantity' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'PackQuantity' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'PackDescription' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'PackDescription' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Brand' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Brand' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ShipUnitNo' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ShipUnitNo' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'NetWeight' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'NetWeight' , u'pVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'GrossWeight' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'GrossWeight' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 24, (24, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'StreetS' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'StreetS' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'BlockS' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'BlockS' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'BuildingS' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'BuildingS' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CityS' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CityS' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'ZipCodeS' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'ZipCodeS' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'CountyS' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'CountyS' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'StateS' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'StateS' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'CountryS' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'CountryS' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'StreetB' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'StreetB' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'BlockB' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'BlockB' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'BuildingB' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'BuildingB' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'CityB' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'CityB' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'ZipCodeB' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'ZipCodeB' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'CountyB' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'CountyB' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'StateB' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'StateB' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'CountryB' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'CountryB' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
]

ITaxInvoice_Lines_vtables_dispatch_ = 1
ITaxInvoice_Lines_vtables_ = [
	(( u'BaseEntry' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 7, (7, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ITaxInvoices_vtables_dispatch_ = 1
ITaxInvoices_vtables_ = [
	(( u'DocEntry' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 5, (5, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DocDueDate' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocDueDate' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Segment' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Address2' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Address2' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CurrencySource' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CurrencySource' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 20, (20, (), [ (16393, 10, None, "IID('{D1DD9101-9264-450A-9FAC-C9D899078775}')") , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'DocEntry' , u'Found' , ), 23, (23, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 24, (24, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 26, (26, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 27, (27, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'CustomerOrVendorRefNo' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'CustomerOrVendorRefNo' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'CustomerOrVendorName' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'CustomerOrVendorName' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'CancelDate' , u'pVal' , ), 33, (33, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTotal' , u'pVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotal' , u'pVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'PaymentRefNo' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'PaymentRefNo' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'PaymentRefDate' , u'pVal' , ), 37, (37, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'PaymentRefDate' , u'pVal' , ), 37, (37, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
]

ITeamMembers_vtables_dispatch_ = 1
ITeamMembers_vtables_ = [
	(( u'UserFields' , u'ppRsltVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'TeamID' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'plRsltVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'RoleInTeam' , u'penumRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'RoleInTeam' , u'penumRsltVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ITeams_vtables_dispatch_ = 1
ITeams_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lTeamID' , u'pbRsltIsFound' , ), 9, (9, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TeamID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TeamName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TeamName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TeamMembers' , u'ppRsltVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{09C6E920-908C-4FD2-9CBF-21C3F4329A33}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ITerritories_vtables_dispatch_ = 1
ITerritories_vtables_ = [
	(( u'TerritoryID' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'LocationIndex' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LocationIndex' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Parent' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Parent' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 9, (9, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 10, (10, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

IUserFields_vtables_dispatch_ = 1
IUserFields_vtables_ = [
	(( u'Fields' , u'pVal' , ), 0, (0, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
]

IUserFieldsMD_vtables_dispatch_ = 1
IUserFieldsMD_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'TableName' , u'FieldID' , u'Found' , ), 5, (5, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ValidValues' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{D435C006-B504-4847-B217-8AEA5439B779}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Size' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Size' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SubType' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SubType' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'LinkedTable' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'LinkedTable' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DefaultValue' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DefaultValue' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FieldID' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'EditSize' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'EditSize' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Mandatory' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Mandatory' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
]

IUserKeysMD_vtables_dispatch_ = 1
IUserKeysMD_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'TableName' , u'KeyIndex' , u'Found' , ), 4, (4, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Elements' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{ED79A1AF-2F5B-418E-A90C-1F504B49E364}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'KeyIndex' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'KeyName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'KeyName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Unique' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Unique' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IUserKeysMD_Elements_vtables_dispatch_ = 1
IUserKeysMD_Elements_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SubKeyIndex' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IUserObjectMD_ChildTables_vtables_dispatch_ = 1
IUserObjectMD_ChildTables_vtables_ = [
	(( u'SonNumber' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'LogTableName' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LogTableName' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IUserObjectMD_FindColumns_vtables_dispatch_ = 1
IUserObjectMD_FindColumns_vtables_ = [
	(( u'ColumnNumber' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ColumnDescription' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ColumnDescription' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IUserObjectMD_FormColumns_vtables_dispatch_ = 1
IUserObjectMD_FormColumns_vtables_ = [
	(( u'FormColumnAlias' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'FormColumnAlias' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'FormColumnDescription' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FormColumnDescription' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FormColumnNumber' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SonNumber' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SonNumber' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 7, (7, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IUserObjectsMD_vtables_dispatch_ = 1
IUserObjectsMD_vtables_ = [
	(( u'TableName' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LogTableName' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LogTableName' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CanCreateDefaultForm' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CanCreateDefaultForm' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ObjectType' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ObjectType' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionName' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CanCancel' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CanCancel' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CanDelete' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CanDelete' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CanLog' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CanLog' , u'pVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ManageSeries' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ManageSeries' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CanFind' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CanFind' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'CanYearTransfer' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'CanYearTransfer' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CanClose' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Code' , u'Found' , ), 16, (16, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'FindColumns' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}')") , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'FormColumns' , u'pVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{0C607D21-E148-42CE-AF58-E8C38EB26275}')") , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ChildTables' , u'pVal' , ), 23, (23, (), [ (16393, 10, None, "IID('{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}')") , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'CanClose' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
]

IUserPermission_vtables_dispatch_ = 1
IUserPermission_vtables_ = [
	(( u'UserCode' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Permission' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Permission' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 7, (7, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IUserPermissionForms_vtables_dispatch_ = 1
IUserPermissionForms_vtables_ = [
	(( u'FormType' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'FormType' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DisplayOrder' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DisplayOrder' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IUserPermissionTree_vtables_dispatch_ = 1
IUserPermissionTree_vtables_ = [
	(( u'UserSignature' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DisplayOrder' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Options' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Options' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Levels' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'IsItem' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'IsItem' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ParentID' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ParentID' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UserPermissionForms' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{24464254-073D-4148-A045-3CFDB71DE48C}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'PermissionID' , u'Found' , ), 11, (11, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 12, (12, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
]

IUserTable_vtables_dispatch_ = 1
IUserTable_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 4, (4, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TableDescription' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IUserTables_vtables_dispatch_ = 1
IUserTables_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 1 , )),
]

IUserTablesMD_vtables_dispatch_ = 1
IUserTablesMD_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'TableName' , u'Found' , ), 5, (5, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TableDescription' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TableDescription' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TableType' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TableType' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IUsers_vtables_dispatch_ = 1
IUsers_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'InternalKey' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InternalKey' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserPassword' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UserPassword' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Superuser' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Superuser' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhoneNumber' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhoneNumber' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Defaults' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Defaults' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Department' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Department' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 20, (20, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'UserPermission' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}')") , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
]

IValidValue_vtables_dispatch_ = 1
IValidValue_vtables_ = [
	(( u'Value' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
]

IValidValues_vtables_dispatch_ = 1
IValidValues_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{013F0389-85E2-4B8B-9285-18843E4236F3}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 1 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
]

IValidValuesMD_vtables_dispatch_ = 1
IValidValuesMD_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IWarehouses_vtables_dispatch_ = 1
IWarehouses_vtables_ = [
	(( u'Street' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'AllowUseTax' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'AllowUseTax' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesClearingAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesClearingAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseReturningAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseReturningAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccount' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccount' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAccount' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAccount' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ExemptRevenuesAccount' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ExemptRevenuesAccount' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'CostOfGoodsSold' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CostOfGoodsSold' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferencesAccount' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferencesAccount' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAccount' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAccount' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAccount' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAccount' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseName' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseName' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'DropShip' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'DropShip' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'TransfersAcc' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'TransfersAcc' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'InternalKey' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAcc' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAcc' , u'pVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'Nettable' , u'pVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'Nettable' , u'pVal' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAcc' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAcc' , u'pVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsetingAct' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsetingAct' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAcc' , u'pVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAcc' , u'pVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'StockAccount' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'StockAccount' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'WhsCode' , u'Found' , ), 53, (53, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 54, (54, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 55, (55, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 56, (56, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'BusinessPlaceID' , u'pVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
]

IWithholdingTaxData_vtables_dispatch_ = 1
IWithholdingTaxData_vtables_ = [
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSys' , u'pVal' , ), 2, (2, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSys' , u'pVal' , ), 2, (2, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingType' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountinSys' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountinSys' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountFC' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountFC' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmount' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmount' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'RoundingType' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Criteria' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 20, (20, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 21, (21, (), [ ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
]

IWithholdingTaxLines_vtables_dispatch_ = 1
IWithholdingTaxLines_vtables_ = [
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSys' , u'pVal' , ), 2, (2, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSys' , u'pVal' , ), 2, (2, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingType' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountinSys' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountinSys' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountFC' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountFC' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmount' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmount' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'RoundingType' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Criteria' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 20, (20, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 21, (21, (), [ ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
]

IWorkOrder_Lines_vtables_dispatch_ = 1
IWorkOrder_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemQuantity' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ItemQuantity' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ItemPrice' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemPrice' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ItemWarehouse' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ItemWarehouse' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccountCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccountCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'WorkSum' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'WorkSum' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IWorkOrders_vtables_dispatch_ = 1
IWorkOrders_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'WkoKey' , u'Found' , ), 2, (2, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Canceled' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'OrderDate' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'OrderDate' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'WorkStartDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'WorkStartDate' , u'pVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ExpectedCompletionDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ExpectedCompletionDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'WorkFinishDate' , u'pVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'WorkFinishDate' , u'pVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ReceiverName' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ReceiverName' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'OrdererCode' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'OrdererCode' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'OrdererName' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'OrdererName' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'CustomerRefNo' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CustomerRefNo' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'OrderTotal' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TotalCurrency' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'GenerationTime' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'GenerationTime' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'InstructionNumber' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccountCode' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccountCode' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'WorkSum' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'WorkSum' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'FinancialPeriod' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 32, (32, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'OrderNum' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
]

I_GenArrObj_vtables_dispatch_ = 1
I_GenArrObj_vtables_ = [
]

RecordMap = {
}

CLSIDToClassMap = {
	'{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}' : IItems_Prices,
	'{F105494C-B48F-4E8A-B6E7-C1947194E835}' : Budget_Lines,
	'{6C92660E-0507-4C90-8DDB-1C5B61AB41AA}' : IBusinessPlaces,
	'{9E334DDA-DD14-48A7-8482-292392B27A13}' : EmployeePrevEmpoymentInfo,
	'{4F6D3681-33BD-41F5-BFEA-DE2059E4ADF4}' : SpecialPrices,
	'{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}' : IUserPermission,
	'{C4DCA924-9189-4969-8609-8564D6E5AFAA}' : IMessages,
	'{A6DB2CDA-3A42-4A70-918C-53595D6091C9}' : IChecksforPaymentLines,
	'{1520690D-0D25-415A-B290-66DF277561FE}' : BPAddresses,
	'{A3C87BAE-49A3-4A53-A50B-D20716733709}' : BusinessPartnerGroups,
	'{7F3611B7-822C-41C3-82DB-2D8909B59C7A}' : Document_LinesAdditionalExpenses,
	'{4F06C847-96F8-4421-B1C7-2FA41FCB0CFF}' : ISalesOpportunities,
	'{D435C006-B504-4847-B217-8AEA5439B779}' : IValidValuesMD,
	'{E2C5A384-883B-4963-A4A4-30C6F553818F}' : INotaFiscalUsage,
	'{C868B9F4-6EC8-4A28-81AF-546DD81B1083}' : ValidValuesMD,
	'{3FF527E2-2FBB-4F74-BBF9-C0EDBF44E63C}' : EmployeeReviewsInfo,
	'{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}' : IBPWithholdingTax,
	'{95AF3307-477A-4189-A934-CC32F18264F7}' : WithholdingTaxLines,
	'{9C11E37D-538D-4819-85D1-00048E759E11}' : StockTransfer_Lines,
	'{37C235F6-0465-4E85-80A0-776D4602B09B}' : ProductionOrders,
	'{5E6A92D1-9BAB-4BB4-A379-2428006247C3}' : IChecksforPayment,
	'{0ED9BFD6-A5ED-40D2-8645-BE4ED8AC9CE5}' : ServiceCallActivities,
	'{98DF1BF3-2F28-46C7-8003-FB8D11276237}' : ISalesTaxCodes_Lines,
	'{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}' : IField,
	'{8B560D21-5616-4D85-ACA9-BC8145B30A73}' : SalesForecast_Lines,
	'{596CFFFE-E95F-472D-8243-37094A850DCF}' : ICurrencies,
	'{DBB3E886-60E7-4058-930A-1C7C07CADB2C}' : IManufacturers,
	'{054C0B23-FE27-46A4-990C-901A4906BEB5}' : Attachment,
	'{1B0F044E-5955-4426-8CEE-885A8388A8F9}' : Users,
	'{C4397D01-E44E-4B76-80AB-4B888EEA10DD}' : IEmployeeReviewsInfo,
	'{A740D0B2-649F-40A6-AF5E-77FF340AEEFD}' : SBObob,
	'{11067A79-5484-43A2-945C-7408CDCF01E6}' : Budget,
	'{31341DF9-0A1F-4B75-BBAB-50B96478E579}' : ChecksforPayment,
	'{8C9A31B4-0BEA-4A72-8D4E-F4C00F683E6B}' : DunningLetters,
	'{09C6E920-908C-4FD2-9CBF-21C3F4329A33}' : ITeamMembers,
	'{78A768C9-EDA6-4798-AFC3-114DEC3DE8E5}' : IQueryCategories,
	'{B2CC6793-FFCF-4389-980D-B5FF458B2EC8}' : ProductTrees,
	'{99FB9754-BDAE-4C8D-BA96-4F2263A73A6A}' : IPriceLists,
	'{C397C564-B506-4649-9C12-E4B63BBD7711}' : Messages,
	'{060F033E-2FC9-4266-90AE-3271AC203A59}' : IJournalEntries,
	'{494EAB50-0ED0-4773-8BCF-9F769A80B6BC}' : ItemWarehouseInfo,
	'{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}' : IDocumentsAdditionalExpenses,
	'{8CA3AB92-1930-4511-4AA8-82D53C3150C3}' : IRecordset,
	'{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}' : IBPPaymentDates,
	'{578B1918-60ED-440F-9729-7C59AEE459E8}' : BPFiscalTaxID,
	'{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}' : ISpecialPricesDataAreas,
	'{9C536750-5FC9-45DF-AF6E-62DB9ACCAEA8}' : CommandParams,
	'{CDB52791-B0FC-4BE1-A712-06941AF91D52}' : IItemWarehouseInfo,
	'{727B34C7-DD01-4B31-9213-F5B02C5E3276}' : BPPaymentDates,
	'{A6D332DA-630B-44C7-AA91-69F2C1A2501D}' : IQueueMembers,
	'{F09A4CB0-F8CA-4342-A44D-82DE3395B011}' : IPaymentTermsTypes,
	'{A994F7F0-BF16-4C8E-B03C-74CE9EF2ECF5}' : UserFields,
	'{4AFE074D-4F31-4E7B-87DF-64D55098DA5E}' : Documents,
	'{57544A70-71BC-4A35-B018-BB43DD24941A}' : Warehouses,
	'{6E3987D0-11D5-4A95-B5B7-E5BCFE88E060}' : JournalEntries,
	'{913C6394-89AD-47A9-9390-1B8686E65312}' : IUserKeysMD,
	'{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}' : ISalesForecast_Lines,
	'{93CF87D1-95CB-459C-A906-729819461CA1}' : ICommandParams,
	'{96D7BBA9-27E7-4893-BC78-CC4313BE0DD1}' : IContacts,
	'{4385C84B-AE8C-424F-9071-546FF9E1D503}' : SalesTaxCodes_Lines,
	'{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}' : IProductionOrders_Lines,
	'{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}' : IWithholdingTaxData,
	'{9D3B180E-A24C-48C9-A742-093663FF1878}' : Fields,
	'{07B255E1-6AF8-4615-BAC4-D258D316BF1B}' : ActivityStatus,
	'{ADDFFAB7-1BA1-4C06-8229-D3CE76605700}' : BusinessPlaces,
	'{8D158412-BA39-4046-8326-2E22EE49F8C1}' : EmployeeEducationInfo,
	'{8CA91808-D098-4416-8368-E426484BA8DB}' : ICommandParam,
	'{A5EC07B2-5898-4104-8015-F876A386D231}' : IEmployeeEducationInfo,
	'{FC571383-8375-4B7D-BDEF-4EF2B91B7751}' : IUserTablesMD,
	'{8F1131E9-C31E-4F6D-BC3A-1F94AE2CEACF}' : ServiceContract_Lines,
	'{1EFF6EB3-9368-4A68-B619-0B57A134F0CE}' : IItems,
	'{D2BAB599-C7C6-4301-B925-B6BB51092A79}' : IBudget_Lines,
	'{A8A658F8-0A8A-4CEF-B5F4-481C3D4652FA}' : BillOfExchangeTransaction_Lines,
	'{B50BD947-38AC-4ACE-97F4-8EA9ECD9AB77}' : ClosingDateProcedure,
	'{842BE793-D5A4-4C52-B7C1-99E189D39B8D}' : BankPages,
	'{1FEF5698-93E1-4167-AEA0-4BB151792623}' : IBatchNumbers,
	'{8DD14B84-6D7B-49E9-8137-A3E7F9A3642F}' : IStockTransfer,
	'{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}' : IEmployeePrevEmpoymentInfo,
	'{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}' : IBillOfExchangeTrans_BankPages,
	'{22DCA799-2F7B-4B31-ABB6-74F3C07CB367}' : ContactEmployees,
	'{231A13D7-5DA8-4467-A263-FDE84A268AC9}' : IPayments_Accounts,
	'{4838BBDC-5B48-44EF-A7F7-A705BB07B24F}' : ValidValue,
	'{0207412D-F955-46BA-AE96-E749573B4106}' : IServiceCallActivities,
	'{210393EC-DEF3-4E55-965C-C2891393A73C}' : Items,
	'{3267FC28-5E07-4BA5-B072-C8F160D7C1C4}' : ServiceContracts,
	'{5E9FC07C-E9A5-465A-A532-F12DC65304D4}' : DocumentsAdditionalExpenses,
	'{A07F5790-711E-49FC-9843-935F7C8CDB85}' : ISalesTaxCodes,
	'{2C3D3B79-8BCD-4CF4-981D-1033A54CBF17}' : NotaFiscalUsage,
	'{BEB8ACDC-E50B-4DA3-8281-EF5228E55099}' : ITerritories,
	'{2CF2E472-CA6D-4D8E-8B80-046D28E75C40}' : IChartOfAccounts,
	'{7A1326F7-9545-4AAC-B875-C317CF7D76B4}' : SpecialPricesDataAreas,
	'{EE047C63-413F-4CEA-B8BC-A4223AA6B482}' : IShippingTypes,
	'{E2174012-44BF-4A47-B117-283D13C66C5E}' : StockTransfer,
	'{625162C1-3894-460F-94EC-72D6AFEA34D2}' : IUserTables,
	'{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}' : IDocument_LinesAdditionalExpenses,
	'{3C447394-4D07-46E5-8ADE-0E5973F97CF7}' : Attachments,
	'{5F2AE736-E6D3-4D3A-BCB5-F9EE3A45872A}' : ItemGroups,
	'{AFFB904C-0D52-4359-B44B-FB594DC5618A}' : INotaFiscalCFOP,
	'{C3B4DABB-A057-4D70-AE0C-7ABD7A4254B0}' : SalesOpportunitiesReasons,
	'{41501B90-66B9-49BC-920E-EAEF90F119B2}' : ServiceCalls,
	'{268D6CC3-E244-4AD7-B009-16C8ED7F710A}' : ISBObob,
	'{950BE47C-4B36-49F3-A313-57146222DC3C}' : UserPermissionTree,
	'{0C9CE0A9-AA16-4C81-A474-9D960E735AA5}' : BPBankAccounts,
	'{70BFE200-77E9-4D02-B0E6-49800F3E9AD2}' : JournalEntries_Lines,
	'{9BCDAE48-582B-4E76-BD8F-E8A77BC6CF6E}' : IProductTrees,
	'{34995651-4568-4AAE-B831-60693B932A35}' : ISpecialPricesQuantityAreas,
	'{EBB0F6A6-D704-41FF-8D22-CC3B76407F5B}' : UserTable,
	'{8AEF84A8-9762-4736-A6BC-778EA10CA4C2}' : UserObjectsMD,
	'{F2BCB557-408E-4D6C-B46D-7E5517D939B2}' : BPFiscalRegistryID,
	'{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}' : IUserTable,
	'{5C594028-D730-4298-952E-4616C5047BC6}' : IServiceContracts,
	'{A574B4DA-F87A-414B-AC49-ED8C6BF84B2C}' : EmployeeAbsenceInfo,
	'{0677DAD5-92DA-441E-A674-13DE601888FB}' : IAlternateCatNum,
	'{4162242D-4217-47FA-BDFF-5070B6D03F30}' : IBPAccountReceivablePayble,
	'{E7843EA1-A67D-4C9A-B61D-EABDE49D4692}' : SalesOpportunities,
	'{D89C1B1F-B7A1-4669-B80D-E3A041767ABE}' : QueryCategories,
	'{9EB0E81A-9442-4C9A-B096-93C6134E684D}' : IContractTemplates,
	'{85EBDF2E-252D-4489-9E2F-FE17C36ACE86}' : ChartOfAccounts,
	'{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}' : IUserObjectMD_FindColumns,
	'{41172218-C619-4E35-9D03-59EAF1E0F300}' : BatchNumbers,
	'{2DBFED56-4DB4-455A-9C22-E2C01C052D39}' : IBillOfExchangeTransaction_Lines,
	'{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}' : ISalesOpportunitiesPartners,
	'{BBB45A32-F446-4ED3-915B-C811BBA6C2C7}' : IRelationships,
	'{ED256951-E65E-40BF-A2E9-2A21741D8720}' : IUsers,
	'{0C607D21-E148-42CE-AF58-E8C38EB26275}' : IUserObjectMD_FormColumns,
	'{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}' : IServiceContract_Lines,
	'{1E293D13-1EC1-4DF2-A5CC-7FE45030EEE5}' : IKnowledgeBaseSolutions,
	'{04C582B6-340A-4E71-B18B-460A37A04A62}' : Manufacturers,
	'{EA2133A7-F8D4-4444-834F-1129CE2081EB}' : Queue,
	'{7CD6F364-32D1-4862-8470-E27D69A03F08}' : NotaFiscalCST,
	'{0CFCFE82-D222-486A-9E49-0FBE58FDD534}' : IBudgetDistribution,
	'{FA8FD318-6971-4E8B-B6E9-959A938455C6}' : IServiceCallSolutions,
	'{921DBA91-7B93-4AEB-859C-C4452CA0F739}' : Recipients,
	'{71ECA915-CB27-41B1-9E9F-DF819F1C52D6}' : ServiceCallSolutions,
	'{64572B16-A58D-40D4-B869-10787D0A8EE2}' : MaterialRevaluation_lines,
	'{0B6BCB38-6594-4EAB-88A8-5EEB856FF1EB}' : Field,
	'{2C35D508-856B-43E0-A1A5-EC6BCA16E62A}' : IBPFiscalRegistryID,
	'{B7A80F7E-77C0-404E-A8B3-01D0F9136DCF}' : ILocalEra,
	'{038A3F8E-2465-435E-8D05-F510620533C3}' : IMaterialRevaluation_lines,
	'{717F1B41-306E-4695-8F4E-7DACA54EA87B}' : SalesTaxAuthoritiesTypes,
	'{B9FED360-AD27-45E1-AB8A-714FB217B022}' : SalesOpportunitiesLines,
	'{F0D891FD-5D68-466B-90C3-0EDE46E01241}' : LocalEra,
	'{24464254-073D-4148-A045-3CFDB71DE48C}' : IUserPermissionForms,
	'{28F2FDF3-FCEC-4D90-983B-D4C805891EC0}' : UserObjectMD_ChildTables,
	'{301718D4-11C9-4C5F-88DD-3609C5FA21FF}' : IStockTaking,
	'{0C610415-1BAF-4B92-B485-23D9F3E5AA9E}' : WorkOrders,
	'{D562FBDC-788B-4D80-B9EB-9238CC4EF91C}' : TeamMembers,
	'{C057A0F5-A755-4C5E-A410-D4C4D1379487}' : BillOfExchangeTrans_BankPages,
	'{B728546D-EA5F-4122-9FE0-759C89BF95D0}' : IAttachments,
	'{CE69987E-8F99-4FC1-8C86-837E5246AFA2}' : IPackagesTypes,
	'{9AC69118-AA6E-44B4-ACDC-176426BCBA1C}' : ProductionOrders_Lines,
	'{8DCD076F-BF30-45C6-822A-B23FDA1B37F5}' : BudgetScenarios,
	'{0D31ADD3-85B1-40F1-979F-8612E10B8DD8}' : ISalesForecast,
	'{BCA3F54F-34D2-4E1C-A700-AD1C35F0B415}' : ITeams,
	'{ED79A1AF-2F5B-418E-A90C-1F504B49E364}' : IUserKeysMD_Elements,
	'{5BB202A1-E560-4E34-ACB3-2ECA52FFB274}' : IBankPages,
	'{C7224CA0-BA56-4141-84AA-9E45D75208EF}' : CustomsGroups,
	'{CBC0A7DF-E458-45B8-B640-955215643708}' : StockTaking,
	'{36E908CF-6A46-413F-8BD6-C027651A58EA}' : SpecialPricesQuantityAreas,
	'{7F146AF0-3304-4133-BC4F-48797C66B12F}' : SalesTaxAuthorities,
	'{11FA87EF-9F44-4528-AE1D-DAF92AEA3545}' : Recordset,
	'{02F225DD-827F-4065-BC4A-14D5F4136D28}' : IBPAddresses,
	'{450A7F0E-0D42-4720-907E-C672EE2F6382}' : ISalesTaxAuthoritiesTypes,
	'{4A1DF035-9612-4CCC-B9B8-C58511D0D705}' : BusinessPartners,
	'{E985FCDC-43E0-47C4-821D-7F60D4BC9009}' : IActivityStatus,
	'{55ACC8CD-3412-452A-9AF8-304A0A56FD3B}' : IUserPermissionTree,
	'{43AC045C-DCA2-4150-B937-AB205DCA22E6}' : IWarehouses,
	'{F408B086-B6E4-4EE0-9B95-710C117E56F0}' : IRecipients,
	'{CC3579ED-1C61-4864-8E51-208A3DCDFC93}' : IPayments_CreditCards,
	'{D48A6D0F-F063-4ED4-B1E1-59B6998EE91A}' : SalesOpportunitiesInterests,
	'{0383EE76-4325-42FE-8164-91C2E8FDE242}' : IActivityLocations,
	'{55053980-777B-44CF-8D76-84DD975171AA}' : IJournalEntries_Lines,
	'{B2CFCDE5-3753-4A47-9199-38D08718B3AE}' : IEmployeesInfo,
	'{1FE6EEB5-6D21-4EE0-AC7C-8A2B181080C8}' : ActivityLocations,
	'{E9B749CA-045B-4BDD-A5BD-143458EBA752}' : Document_Lines,
	'{1C7C966F-B713-42BF-9A74-0B15A649E63D}' : IProductionOrders,
	'{7D947F60-6017-44AA-AEAC-9721FF263D5E}' : IBPPaymentMethods,
	'{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}' : ISalesOpportunitiesInterests,
	'{CC279FBE-7088-42E9-A579-EB2E3E971076}' : IUserFields,
	'{AFB12D1C-F0C3-4FA6-BF53-CA858C1BE796}' : ShippingTypes,
	'{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}' : IServiceCallInventoryExpenses,
	'{1C59C249-B65E-472F-80BB-EE0A05F75666}' : UserObjectMD_FindColumns,
	'{F9779E16-EDDF-4C59-B80D-A24F34EA1ECE}' : UserPermission,
	'{9020ED56-6B7D-4FAC-8D93-B185D1E65A59}' : IPaymentRunExport,
	'{B133843B-6DB2-4920-976F-1C7EB0AD60A2}' : MaterialRevaluation,
	'{2C1751BA-5CFF-4E47-8C1E-13CAF241A13F}' : ISpecialPrices,
	'{C1F83FBE-3A3F-4A81-8B0B-B5485DC6ADF9}' : IBudget,
	'{013F0389-85E2-4B8B-9285-18843E4236F3}' : IValidValue,
	'{15BD344C-48ED-4A6A-8A31-AFBD7A2ED57B}' : Command,
	'{04A02F02-1211-4507-87DB-DBE6A4807718}' : UserTablesMD,
	'{57B97799-106E-4EA3-8203-1B30B6B7D463}' : _ICompanyEvents,
	'{A2120F6A-992A-4AAE-A98B-F573035921E8}' : UserKeysMD_Elements,
	'{458A15A5-B980-4543-A289-F6477A36EB24}' : IWithholdingTaxLines,
	'{2795C6A1-A943-411B-BE58-A062A0E4711A}' : BPAccountReceivablePayble,
	'{BBC625E2-17DA-4434-83D6-56FE0401D9A6}' : AlternateCatNum,
	'{CD793E21-582C-4408-8AF7-1B256D29BF5A}' : UserTables,
	'{48B89C08-2AE9-435F-B7C4-D7219E938E46}' : IValidValues,
	'{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}' : IPayments_Checks,
	'{93E5E52B-181E-46B8-96CB-1C066AC04DCA}' : ISerialNumbers,
	'{A93CD1FA-F12F-47B0-8FAB-859692B8A653}' : IServiceCalls,
	'{18B4A57B-206A-4CF7-B94B-7325AED96137}' : IAttachment,
	'{C7E88977-022A-494D-BC9D-09FA85E7AC15}' : PriceLists,
	'{741AA803-AB33-4FD7-B664-63116291D6CE}' : IBillOfExchange,
	'{7615E097-E207-4E8D-A114-74031034136B}' : IWorkOrders,
	'{D8BCB8BC-6DD1-4D3A-ABBF-FA7A18396B2C}' : ICustomerEquipmentCards,
	'{3BA8DAED-5B33-4CE4-A4B8-B4308D86E524}' : ICompany,
	'{F00B2064-7046-4E6A-9286-1284170CFA80}' : WithholdingTaxData,
	'{E644A5ED-C97E-4EE8-8191-E20EBC9508AB}' : EmployeeRolesInfo,
	'{A52E0922-634E-4827-9B4A-10D6D46ECE74}' : IDataBrowser,
	'{0C60C86B-3CB9-4E78-80D0-1AACB3C1C6F0}' : IActivityTypes,
	'{097DDC08-E989-4426-87DB-9EFAD0FF64C3}' : Relationships,
	'{E79D3C41-BFE7-4C5A-B586-4F627E021A1C}' : IPayments,
	'{0E77E5DB-93A3-4FCF-BB4B-BE8323F27387}' : Payments_Accounts,
	'{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}' : IStockTransfer_Lines,
	'{ADCC23F1-37CE-4327-BE13-88D1E14F8877}' : Payments_Invoices,
	'{457F56A9-7F85-4ABF-91A4-5384A0CED40C}' : WorkOrder_Lines,
	'{461F000F-9DB2-45D0-808D-FA552126FF16}' : IMaterialRevaluation,
	'{692B8669-26B5-4D4F-A768-F92576E3EF85}' : ServiceCallInventoryExpenses,
	'{C1A276C6-FD68-4693-8D70-D9A7A3E69712}' : UserObjectMD_FormColumns,
	'{EB49B71E-C20E-4D6D-8ECD-A641B0BAAA35}' : EmployeesInfo,
	'{5C63DF2C-6C18-4447-A9BB-B6277EF0DAF2}' : Items_Prices,
	'{6EF2D0B5-8580-41AD-B879-42738445BE03}' : CustomerEquipmentCards,
	'{94BACBC3-E916-4D1F-9469-F7F44F8E39F0}' : TaxExtension,
	'{910FEA90-B652-4099-9817-3AA0CF635963}' : IClosingDateProcedure,
	'{19E6540E-4E64-48C1-9525-29D5710D1FFD}' : ISalesOpportunitiesCompetition,
	'{842F5C3F-67A6-42B4-8181-98EFB9520A5F}' : ICustomsGroups,
	'{0DA4D491-BDE7-4126-81E1-BCDA814B5332}' : SalesOpportunitiesPartners,
	'{A6DA575B-E105-4585-9F4B-50CC4044EEDD}' : IDocuments,
	'{5D48514C-4B40-4C2A-9FC9-8CC2518B0F8E}' : IBudgetScenarios,
	'{97C9DB0B-4DBF-4EEA-98A9-04EE1F5B031E}' : SalesTaxCodes,
	'{0FCFCE88-47F3-4F05-9803-3081D83C92DC}' : IAdditionalExpenses,
	'{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}' : ICommand,
	'{161C44B9-9DAC-4D31-AB92-EED776B8C745}' : Contacts,
	'{16F466DA-6A22-46AE-A5B2-5934A0194D7A}' : BudgetDistribution,
	'{94DA073B-4599-4BC9-A22B-87D912159247}' : BillOfExchangeTrans_Deposits,
	'{DE680833-445E-4AF0-A7E3-377D5135268B}' : IFields,
	'{AB7947CF-8191-498D-8B3C-8E04A00957E7}' : IPayments_Invoices,
	'{9091A78F-FCC8-4399-88F3-53E1631F100F}' : BPPaymentMethods,
	'{248B28DD-1281-4C6C-9780-22D19BA13D1F}' : IDocument_Lines,
	'{A355004F-AAB4-41D3-BDE0-7EAED1ED5FFF}' : Company,
	'{68C60132-0DD3-4AD2-B4FF-DB358A6184BC}' : IIndustries,
	'{F68150E3-371A-4D4F-990C-16CDFF1A04FA}' : AdditionalExpenses,
	'{7A042067-2E94-48B5-A7CB-3534F6223B35}' : KnowledgeBaseSolutions,
	'{D919D79B-2CE9-4A88-9C3D-59A67A334D81}' : I_GenArrObj,
	'{835F6104-3A36-4122-8AE8-C4E1D7B15453}' : ContractTemplates,
	'{6D4864DD-75DF-4305-A8CB-C7E2381DD7B3}' : UserPermissionForms,
	'{D1DD9101-9264-450A-9FAC-C9D899078775}' : ITaxInvoice_Lines,
	'{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}' : IProductTrees_Lines,
	'{F8DE7AAE-13BF-46BD-A4B0-CD9535AAED63}' : IDunningLetters,
	'{FC75103E-6EAA-4246-A097-B6F81E9DD4A3}' : JournalVouchers,
	'{208C7E76-4919-4468-AE9E-13976C9BE255}' : UserKeysMD,
	'{472B7A32-EB83-4D3A-9908-699D5C8DC33B}' : IBPBankAccounts,
	'{403E32F9-EBDD-4528-89C2-FE8BE8F7F0A6}' : PaymentTermsTypes,
	'{81D132DE-0549-460D-9BEC-2FEDEAB0A950}' : IUserFieldsMD,
	'{0D5D4022-6FCC-49A4-AB69-7F4304B47EC9}' : DataBrowser,
	'{65ABB505-DD62-4C94-8E7B-BF63BC35E51E}' : Teams,
	'{84FAFD4C-5213-4CB8-9F2F-7FECB428F0ED}' : PackagesTypes,
	'{094BA05B-B730-4D86-8BCF-91F788C16057}' : ActivityTypes,
	'{1C972937-3B53-45EE-9728-516996023C1A}' : Payments_CreditCards,
	'{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}' : IUserObjectMD_ChildTables,
	'{36360587-E2A6-4BF4-BFED-92F2CEDDF03D}' : ChecksforPaymentLines,
	'{EA7AF142-F7C4-4E1A-BA6A-B5DBFCB71C3C}' : BillOfExchange,
	'{4E6D1836-16F8-4D8F-9BF8-0271F4856450}' : Industries,
	'{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}' : IWorkOrder_Lines,
	'{216974E8-B66D-4022-9AB1-97BAA96084A3}' : IItemGroups,
	'{2E2720A5-8F7C-45D3-BF5A-DD5BE3769F84}' : IUserObjectsMD,
	'{C27CB0AA-2304-4D4E-B292-8ED9651F34A3}' : SalesOpportunitiesCompetition,
	'{9DF321C2-6A1D-446B-AE8A-F7C33987D792}' : IBusinessPartners,
	'{917BA077-4D88-46A8-B78A-E396315D7E59}' : IPaymentRunExport_Lines,
	'{CD47A725-AEA8-4224-93D3-F31848990C42}' : IEmployeeAbsenceInfo,
	'{CFAA1E6C-53D8-4C8E-A7DE-78ABE1601F30}' : BillOfExchangeTransaction,
	'{C54F7212-C3DC-4E35-B61C-73E6297F1AD6}' : ValidValues,
	'{0D446022-9A79-4535-9174-EEAE21DF924A}' : ISalesTaxAuthorities,
	'{A52ED4BA-1C19-4553-9A60-D69B653E8CB5}' : Payments,
	'{E944AF70-E7E5-4414-833E-A62BFCF9EA65}' : UserFieldsMD,
	'{6BA3F221-1146-4650-AE35-03C139F04C02}' : SerialNumbers,
	'{3E6CC39D-A5A5-43E7-856E-4A1D4D97A77D}' : SalesForecast,
	'{9147FC50-6FF2-40EC-B59B-2F9302B4A31D}' : IBusinessPartnerGroups,
	'{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}' : IBillOfExchangeTrans_Deposits,
	'{9A38EECB-D61C-469C-9425-C66BAAA0623E}' : NotaFiscalCFOP,
	'{A2A9F005-92C0-4949-B2D7-92B7D8AAA784}' : PaymentRunExport_Lines,
	'{13CC4089-F2FA-4B28-9BD9-75F6DC0E44B3}' : CommandParam,
	'{856AB71E-0D54-4BA5-95CA-7135D77040EC}' : PaymentRunExport,
	'{9370956A-E63B-4B62-9AA0-EA32A0673B8A}' : ITaxInvoices,
	'{D3259ECE-289F-4B9B-9C81-AD71D8EACE67}' : _GenArrObj,
	'{2393BA89-A02B-4E4E-8703-0412A8B757C4}' : TaxInvoices,
	'{DB038EC5-97EC-4D04-8E6A-AF01A5C05900}' : IBillOfExchangeTransaction,
	'{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}' : ISalesOpportunitiesLines,
	'{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}' : IBPFiscalTaxID,
	'{8CC29ECE-02C3-4C7B-851B-5533D2C83627}' : ITaxExtension,
	'{740243E4-B946-4D50-94D9-7F7E3EC04FE9}' : BPWithholdingTax,
	'{6155B8DA-5812-48F9-8955-67CE75857600}' : Payments_Checks,
	'{52C8673B-CA79-4476-9F2E-28109AE17545}' : IContactEmployees,
	'{12788346-93BB-4D1C-8649-A3266A413D3F}' : Currencies,
	'{8C5510F0-AA36-4CBD-A5AC-7DCF29EE0249}' : IQueue,
	'{D4A7CE6F-B909-4273-8499-C210F94ED2D1}' : ISalesOpportunitiesReasons,
	'{B03EE5C0-48D5-4E20-A33A-FF2DBE5AF478}' : Territories,
	'{411526CA-B3C4-489C-B4FB-6539B5BF09C2}' : TaxInvoice_Lines,
	'{79148B90-9790-418A-B904-DA8C72CCCDDF}' : QueueMembers,
	'{54E2DDD8-87FE-415D-AA8E-2AC62C936C7A}' : INotaFiscalCST,
	'{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}' : IEmployeeRolesInfo,
	'{B9A56422-93A0-4480-BAF3-48907F403CB8}' : IJournalVouchers,
	'{D9F478E8-7891-4C69-A96D-39D5881CFE39}' : ProductTrees_Lines,
}
CLSIDToPackageMap = {}
win32com.client.CLSIDToClass.RegisterCLSIDsFromDict( CLSIDToClassMap )
VTablesToPackageMap = {}
VTablesToClassMap = {
	'{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}' : 'IItems_Prices',
	'{6C92660E-0507-4C90-8DDB-1C5B61AB41AA}' : 'IBusinessPlaces',
	'{0383EE76-4325-42FE-8164-91C2E8FDE242}' : 'IActivityLocations',
	'{DBB3E886-60E7-4058-930A-1C7C07CADB2C}' : 'IManufacturers',
	'{C4DCA924-9189-4969-8609-8564D6E5AFAA}' : 'IMessages',
	'{A6DB2CDA-3A42-4A70-918C-53595D6091C9}' : 'IChecksforPaymentLines',
	'{4F06C847-96F8-4421-B1C7-2FA41FCB0CFF}' : 'ISalesOpportunities',
	'{D435C006-B504-4847-B217-8AEA5439B779}' : 'IValidValuesMD',
	'{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}' : 'IBPWithholdingTax',
	'{5E6A92D1-9BAB-4BB4-A379-2428006247C3}' : 'IChecksforPayment',
	'{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}' : 'IField',
	'{596CFFFE-E95F-472D-8243-37094A850DCF}' : 'ICurrencies',
	'{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}' : 'IStockTransfer_Lines',
	'{09C6E920-908C-4FD2-9CBF-21C3F4329A33}' : 'ITeamMembers',
	'{78A768C9-EDA6-4798-AFC3-114DEC3DE8E5}' : 'IQueryCategories',
	'{A6DA575B-E105-4585-9F4B-50CC4044EEDD}' : 'IDocuments',
	'{99FB9754-BDAE-4C8D-BA96-4F2263A73A6A}' : 'IPriceLists',
	'{060F033E-2FC9-4266-90AE-3271AC203A59}' : 'IJournalEntries',
	'{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}' : 'IDocumentsAdditionalExpenses',
	'{8CA3AB92-1930-4511-4AA8-82D53C3150C3}' : 'IRecordset',
	'{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}' : 'IBPPaymentDates',
	'{0D446022-9A79-4535-9174-EEAE21DF924A}' : 'ISalesTaxAuthorities',
	'{CDB52791-B0FC-4BE1-A712-06941AF91D52}' : 'IItemWarehouseInfo',
	'{A6D332DA-630B-44C7-AA91-69F2C1A2501D}' : 'IQueueMembers',
	'{F09A4CB0-F8CA-4342-A44D-82DE3395B011}' : 'IPaymentTermsTypes',
	'{E2C5A384-883B-4963-A4A4-30C6F553818F}' : 'INotaFiscalUsage',
	'{913C6394-89AD-47A9-9390-1B8686E65312}' : 'IUserKeysMD',
	'{93CF87D1-95CB-459C-A906-729819461CA1}' : 'ICommandParams',
	'{96D7BBA9-27E7-4893-BC78-CC4313BE0DD1}' : 'IContacts',
	'{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}' : 'IProductionOrders_Lines',
	'{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}' : 'IWithholdingTaxData',
	'{842F5C3F-67A6-42B4-8181-98EFB9520A5F}' : 'ICustomsGroups',
	'{D2BAB599-C7C6-4301-B925-B6BB51092A79}' : 'IBudget_Lines',
	'{8CA91808-D098-4416-8368-E426484BA8DB}' : 'ICommandParam',
	'{A5EC07B2-5898-4104-8015-F876A386D231}' : 'IEmployeeEducationInfo',
	'{FC571383-8375-4B7D-BDEF-4EF2B91B7751}' : 'IUserTablesMD',
	'{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}' : 'ISalesOpportunitiesLines',
	'{1FEF5698-93E1-4167-AEA0-4BB151792623}' : 'IBatchNumbers',
	'{8DD14B84-6D7B-49E9-8137-A3E7F9A3642F}' : 'IStockTransfer',
	'{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}' : 'IWorkOrder_Lines',
	'{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}' : 'IBillOfExchangeTrans_BankPages',
	'{0207412D-F955-46BA-AE96-E749573B4106}' : 'IServiceCallActivities',
	'{A07F5790-711E-49FC-9843-935F7C8CDB85}' : 'ISalesTaxCodes',
	'{BEB8ACDC-E50B-4DA3-8281-EF5228E55099}' : 'ITerritories',
	'{2CF2E472-CA6D-4D8E-8B80-046D28E75C40}' : 'IChartOfAccounts',
	'{EE047C63-413F-4CEA-B8BC-A4223AA6B482}' : 'IShippingTypes',
	'{625162C1-3894-460F-94EC-72D6AFEA34D2}' : 'IUserTables',
	'{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}' : 'IDocument_LinesAdditionalExpenses',
	'{AFFB904C-0D52-4359-B44B-FB594DC5618A}' : 'INotaFiscalCFOP',
	'{268D6CC3-E244-4AD7-B009-16C8ED7F710A}' : 'ISBObob',
	'{CD47A725-AEA8-4224-93D3-F31848990C42}' : 'IEmployeeAbsenceInfo',
	'{9BCDAE48-582B-4E76-BD8F-E8A77BC6CF6E}' : 'IProductTrees',
	'{34995651-4568-4AAE-B831-60693B932A35}' : 'ISpecialPricesQuantityAreas',
	'{1EFF6EB3-9368-4A68-B619-0B57A134F0CE}' : 'IItems',
	'{9370956A-E63B-4B62-9AA0-EA32A0673B8A}' : 'ITaxInvoices',
	'{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}' : 'IUserTable',
	'{5C594028-D730-4298-952E-4616C5047BC6}' : 'IServiceContracts',
	'{0677DAD5-92DA-441E-A674-13DE601888FB}' : 'IAlternateCatNum',
	'{4162242D-4217-47FA-BDFF-5070B6D03F30}' : 'IBPAccountReceivablePayble',
	'{9EB0E81A-9442-4C9A-B096-93C6134E684D}' : 'IContractTemplates',
	'{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}' : 'IUserObjectMD_FindColumns',
	'{2DBFED56-4DB4-455A-9C22-E2C01C052D39}' : 'IBillOfExchangeTransaction_Lines',
	'{BBB45A32-F446-4ED3-915B-C811BBA6C2C7}' : 'IRelationships',
	'{ED256951-E65E-40BF-A2E9-2A21741D8720}' : 'IUsers',
	'{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}' : 'IServiceContract_Lines',
	'{1E293D13-1EC1-4DF2-A5CC-7FE45030EEE5}' : 'IKnowledgeBaseSolutions',
	'{0CFCFE82-D222-486A-9E49-0FBE58FDD534}' : 'IBudgetDistribution',
	'{FA8FD318-6971-4E8B-B6E9-959A938455C6}' : 'IServiceCallSolutions',
	'{450A7F0E-0D42-4720-907E-C672EE2F6382}' : 'ISalesTaxAuthoritiesTypes',
	'{2C35D508-856B-43E0-A1A5-EC6BCA16E62A}' : 'IBPFiscalRegistryID',
	'{B7A80F7E-77C0-404E-A8B3-01D0F9136DCF}' : 'ILocalEra',
	'{038A3F8E-2465-435E-8D05-F510620533C3}' : 'IMaterialRevaluation_lines',
	'{24464254-073D-4148-A045-3CFDB71DE48C}' : 'IUserPermissionForms',
	'{301718D4-11C9-4C5F-88DD-3609C5FA21FF}' : 'IStockTaking',
	'{0FCFCE88-47F3-4F05-9803-3081D83C92DC}' : 'IAdditionalExpenses',
	'{B728546D-EA5F-4122-9FE0-759C89BF95D0}' : 'IAttachments',
	'{CE69987E-8F99-4FC1-8C86-837E5246AFA2}' : 'IPackagesTypes',
	'{0D31ADD3-85B1-40F1-979F-8612E10B8DD8}' : 'ISalesForecast',
	'{BCA3F54F-34D2-4E1C-A700-AD1C35F0B415}' : 'ITeams',
	'{ED79A1AF-2F5B-418E-A90C-1F504B49E364}' : 'IUserKeysMD_Elements',
	'{5BB202A1-E560-4E34-ACB3-2ECA52FFB274}' : 'IBankPages',
	'{02F225DD-827F-4065-BC4A-14D5F4136D28}' : 'IBPAddresses',
	'{E985FCDC-43E0-47C4-821D-7F60D4BC9009}' : 'IActivityStatus',
	'{43AC045C-DCA2-4150-B937-AB205DCA22E6}' : 'IWarehouses',
	'{F408B086-B6E4-4EE0-9B95-710C117E56F0}' : 'IRecipients',
	'{CC3579ED-1C61-4864-8E51-208A3DCDFC93}' : 'IPayments_CreditCards',
	'{55053980-777B-44CF-8D76-84DD975171AA}' : 'IJournalEntries_Lines',
	'{7D947F60-6017-44AA-AEAC-9721FF263D5E}' : 'IBPPaymentMethods',
	'{CC279FBE-7088-42E9-A579-EB2E3E971076}' : 'IUserFields',
	'{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}' : 'IServiceCallInventoryExpenses',
	'{9020ED56-6B7D-4FAC-8D93-B185D1E65A59}' : 'IPaymentRunExport',
	'{2C1751BA-5CFF-4E47-8C1E-13CAF241A13F}' : 'ISpecialPrices',
	'{013F0389-85E2-4B8B-9285-18843E4236F3}' : 'IValidValue',
	'{458A15A5-B980-4543-A289-F6477A36EB24}' : 'IWithholdingTaxLines',
	'{48B89C08-2AE9-435F-B7C4-D7219E938E46}' : 'IValidValues',
	'{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}' : 'IPayments_Checks',
	'{93E5E52B-181E-46B8-96CB-1C066AC04DCA}' : 'ISerialNumbers',
	'{A93CD1FA-F12F-47B0-8FAB-859692B8A653}' : 'IServiceCalls',
	'{18B4A57B-206A-4CF7-B94B-7325AED96137}' : 'IAttachment',
	'{741AA803-AB33-4FD7-B664-63116291D6CE}' : 'IBillOfExchange',
	'{7615E097-E207-4E8D-A114-74031034136B}' : 'IWorkOrders',
	'{B2CFCDE5-3753-4A47-9199-38D08718B3AE}' : 'IEmployeesInfo',
	'{3BA8DAED-5B33-4CE4-A4B8-B4308D86E524}' : 'ICompany',
	'{0C60C86B-3CB9-4E78-80D0-1AACB3C1C6F0}' : 'IActivityTypes',
	'{E79D3C41-BFE7-4C5A-B586-4F627E021A1C}' : 'IPayments',
	'{C4397D01-E44E-4B76-80AB-4B888EEA10DD}' : 'IEmployeeReviewsInfo',
	'{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}' : 'ISalesForecast_Lines',
	'{461F000F-9DB2-45D0-808D-FA552126FF16}' : 'IMaterialRevaluation',
	'{231A13D7-5DA8-4467-A263-FDE84A268AC9}' : 'IPayments_Accounts',
	'{910FEA90-B652-4099-9817-3AA0CF635963}' : 'IClosingDateProcedure',
	'{19E6540E-4E64-48C1-9525-29D5710D1FFD}' : 'ISalesOpportunitiesCompetition',
	'{5D48514C-4B40-4C2A-9FC9-8CC2518B0F8E}' : 'IBudgetScenarios',
	'{55ACC8CD-3412-452A-9AF8-304A0A56FD3B}' : 'IUserPermissionTree',
	'{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}' : 'ICommand',
	'{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}' : 'ISalesOpportunitiesInterests',
	'{DE680833-445E-4AF0-A7E3-377D5135268B}' : 'IFields',
	'{AB7947CF-8191-498D-8B3C-8E04A00957E7}' : 'IPayments_Invoices',
	'{248B28DD-1281-4C6C-9780-22D19BA13D1F}' : 'IDocument_Lines',
	'{68C60132-0DD3-4AD2-B4FF-DB358A6184BC}' : 'IIndustries',
	'{216974E8-B66D-4022-9AB1-97BAA96084A3}' : 'IItemGroups',
	'{D919D79B-2CE9-4A88-9C3D-59A67A334D81}' : 'I_GenArrObj',
	'{D1DD9101-9264-450A-9FAC-C9D899078775}' : 'ITaxInvoice_Lines',
	'{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}' : 'IProductTrees_Lines',
	'{F8DE7AAE-13BF-46BD-A4B0-CD9535AAED63}' : 'IDunningLetters',
	'{0C607D21-E148-42CE-AF58-E8C38EB26275}' : 'IUserObjectMD_FormColumns',
	'{472B7A32-EB83-4D3A-9908-699D5C8DC33B}' : 'IBPBankAccounts',
	'{81D132DE-0549-460D-9BEC-2FEDEAB0A950}' : 'IUserFieldsMD',
	'{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}' : 'ISpecialPricesDataAreas',
	'{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}' : 'IUserObjectMD_ChildTables',
	'{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}' : 'IEmployeePrevEmpoymentInfo',
	'{1C7C966F-B713-42BF-9A74-0B15A649E63D}' : 'IProductionOrders',
	'{2E2720A5-8F7C-45D3-BF5A-DD5BE3769F84}' : 'IUserObjectsMD',
	'{9DF321C2-6A1D-446B-AE8A-F7C33987D792}' : 'IBusinessPartners',
	'{917BA077-4D88-46A8-B78A-E396315D7E59}' : 'IPaymentRunExport_Lines',
	'{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}' : 'ISalesOpportunitiesPartners',
	'{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}' : 'IUserPermission',
	'{9147FC50-6FF2-40EC-B59B-2F9302B4A31D}' : 'IBusinessPartnerGroups',
	'{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}' : 'IBillOfExchangeTrans_Deposits',
	'{98DF1BF3-2F28-46C7-8003-FB8D11276237}' : 'ISalesTaxCodes_Lines',
	'{A52E0922-634E-4827-9B4A-10D6D46ECE74}' : 'IDataBrowser',
	'{D8BCB8BC-6DD1-4D3A-ABBF-FA7A18396B2C}' : 'ICustomerEquipmentCards',
	'{DB038EC5-97EC-4D04-8E6A-AF01A5C05900}' : 'IBillOfExchangeTransaction',
	'{C1F83FBE-3A3F-4A81-8B0B-B5485DC6ADF9}' : 'IBudget',
	'{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}' : 'IBPFiscalTaxID',
	'{8CC29ECE-02C3-4C7B-851B-5533D2C83627}' : 'ITaxExtension',
	'{52C8673B-CA79-4476-9F2E-28109AE17545}' : 'IContactEmployees',
	'{8C5510F0-AA36-4CBD-A5AC-7DCF29EE0249}' : 'IQueue',
	'{D4A7CE6F-B909-4273-8499-C210F94ED2D1}' : 'ISalesOpportunitiesReasons',
	'{54E2DDD8-87FE-415D-AA8E-2AC62C936C7A}' : 'INotaFiscalCST',
	'{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}' : 'IEmployeeRolesInfo',
	'{B9A56422-93A0-4480-BAF3-48907F403CB8}' : 'IJournalVouchers',
}


NamesToIIDMap = {
	'IUserPermissionTree' : '{55ACC8CD-3412-452A-9AF8-304A0A56FD3B}',
	'IUserTables' : '{625162C1-3894-460F-94EC-72D6AFEA34D2}',
	'IDocument_Lines' : '{248B28DD-1281-4C6C-9780-22D19BA13D1F}',
	'ISalesTaxCodes_Lines' : '{98DF1BF3-2F28-46C7-8003-FB8D11276237}',
	'ISalesTaxAuthorities' : '{0D446022-9A79-4535-9174-EEAE21DF924A}',
	'IBPBankAccounts' : '{472B7A32-EB83-4D3A-9908-699D5C8DC33B}',
	'IShippingTypes' : '{EE047C63-413F-4CEA-B8BC-A4223AA6B482}',
	'ISerialNumbers' : '{93E5E52B-181E-46B8-96CB-1C066AC04DCA}',
	'IBPAccountReceivablePayble' : '{4162242D-4217-47FA-BDFF-5070B6D03F30}',
	'IAttachment' : '{18B4A57B-206A-4CF7-B94B-7325AED96137}',
	'IPaymentRunExport' : '{9020ED56-6B7D-4FAC-8D93-B185D1E65A59}',
	'IUserPermission' : '{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}',
	'ISalesTaxAuthoritiesTypes' : '{450A7F0E-0D42-4720-907E-C672EE2F6382}',
	'IProductionOrders_Lines' : '{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}',
	'ICustomerEquipmentCards' : '{D8BCB8BC-6DD1-4D3A-ABBF-FA7A18396B2C}',
	'IBillOfExchangeTransaction' : '{DB038EC5-97EC-4D04-8E6A-AF01A5C05900}',
	'IServiceContracts' : '{5C594028-D730-4298-952E-4616C5047BC6}',
	'IDunningLetters' : '{F8DE7AAE-13BF-46BD-A4B0-CD9535AAED63}',
	'IBPAddresses' : '{02F225DD-827F-4065-BC4A-14D5F4136D28}',
	'IPackagesTypes' : '{CE69987E-8F99-4FC1-8C86-837E5246AFA2}',
	'IBatchNumbers' : '{1FEF5698-93E1-4167-AEA0-4BB151792623}',
	'ISalesOpportunities' : '{4F06C847-96F8-4421-B1C7-2FA41FCB0CFF}',
	'IContractTemplates' : '{9EB0E81A-9442-4C9A-B096-93C6134E684D}',
	'IUsers' : '{ED256951-E65E-40BF-A2E9-2A21741D8720}',
	'IProductTrees' : '{9BCDAE48-582B-4E76-BD8F-E8A77BC6CF6E}',
	'IMessages' : '{C4DCA924-9189-4969-8609-8564D6E5AFAA}',
	'IItems_Prices' : '{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}',
	'IUserKeysMD' : '{913C6394-89AD-47A9-9390-1B8686E65312}',
	'ISalesTaxCodes' : '{A07F5790-711E-49FC-9843-935F7C8CDB85}',
	'ICurrencies' : '{596CFFFE-E95F-472D-8243-37094A850DCF}',
	'ICustomsGroups' : '{842F5C3F-67A6-42B4-8181-98EFB9520A5F}',
	'IQueryCategories' : '{78A768C9-EDA6-4798-AFC3-114DEC3DE8E5}',
	'IBPPaymentDates' : '{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}',
	'IDocumentsAdditionalExpenses' : '{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}',
	'ISalesForecast_Lines' : '{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}',
	'IDataBrowser' : '{A52E0922-634E-4827-9B4A-10D6D46ECE74}',
	'IUserObjectsMD' : '{2E2720A5-8F7C-45D3-BF5A-DD5BE3769F84}',
	'IMaterialRevaluation' : '{461F000F-9DB2-45D0-808D-FA552126FF16}',
	'IBudget' : '{C1F83FBE-3A3F-4A81-8B0B-B5485DC6ADF9}',
	'IClosingDateProcedure' : '{910FEA90-B652-4099-9817-3AA0CF635963}',
	'IQueueMembers' : '{A6D332DA-630B-44C7-AA91-69F2C1A2501D}',
	'IServiceCallActivities' : '{0207412D-F955-46BA-AE96-E749573B4106}',
	'IPayments_Checks' : '{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}',
	'IFields' : '{DE680833-445E-4AF0-A7E3-377D5135268B}',
	'IChecksforPaymentLines' : '{A6DB2CDA-3A42-4A70-918C-53595D6091C9}',
	'IBudgetScenarios' : '{5D48514C-4B40-4C2A-9FC9-8CC2518B0F8E}',
	'ITaxInvoices' : '{9370956A-E63B-4B62-9AA0-EA32A0673B8A}',
	'IUserPermissionForms' : '{24464254-073D-4148-A045-3CFDB71DE48C}',
	'IEmployeeEducationInfo' : '{A5EC07B2-5898-4104-8015-F876A386D231}',
	'IUserTablesMD' : '{FC571383-8375-4B7D-BDEF-4EF2B91B7751}',
	'IBusinessPartnerGroups' : '{9147FC50-6FF2-40EC-B59B-2F9302B4A31D}',
	'IBusinessPlaces' : '{6C92660E-0507-4C90-8DDB-1C5B61AB41AA}',
	'INotaFiscalCFOP' : '{AFFB904C-0D52-4359-B44B-FB594DC5618A}',
	'ISalesOpportunitiesReasons' : '{D4A7CE6F-B909-4273-8499-C210F94ED2D1}',
	'IServiceContract_Lines' : '{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}',
	'IDocuments' : '{A6DA575B-E105-4585-9F4B-50CC4044EEDD}',
	'IServiceCallInventoryExpenses' : '{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}',
	'IContactEmployees' : '{52C8673B-CA79-4476-9F2E-28109AE17545}',
	'IWarehouses' : '{43AC045C-DCA2-4150-B937-AB205DCA22E6}',
	'IServiceCallSolutions' : '{FA8FD318-6971-4E8B-B6E9-959A938455C6}',
	'IJournalEntries_Lines' : '{55053980-777B-44CF-8D76-84DD975171AA}',
	'IRecordset' : '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}',
	'IAttachments' : '{B728546D-EA5F-4122-9FE0-759C89BF95D0}',
	'ISalesOpportunitiesInterests' : '{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}',
	'IChartOfAccounts' : '{2CF2E472-CA6D-4D8E-8B80-046D28E75C40}',
	'IStockTransfer' : '{8DD14B84-6D7B-49E9-8137-A3E7F9A3642F}',
	'IActivityStatus' : '{E985FCDC-43E0-47C4-821D-7F60D4BC9009}',
	'IUserKeysMD_Elements' : '{ED79A1AF-2F5B-418E-A90C-1F504B49E364}',
	'IEmployeesInfo' : '{B2CFCDE5-3753-4A47-9199-38D08718B3AE}',
	'ICommandParams' : '{93CF87D1-95CB-459C-A906-729819461CA1}',
	'IPayments_Invoices' : '{AB7947CF-8191-498D-8B3C-8E04A00957E7}',
	'IWorkOrders' : '{7615E097-E207-4E8D-A114-74031034136B}',
	'ITeams' : '{BCA3F54F-34D2-4E1C-A700-AD1C35F0B415}',
	'IServiceCalls' : '{A93CD1FA-F12F-47B0-8FAB-859692B8A653}',
	'IRecipients' : '{F408B086-B6E4-4EE0-9B95-710C117E56F0}',
	'IPriceLists' : '{99FB9754-BDAE-4C8D-BA96-4F2263A73A6A}',
	'IBillOfExchangeTrans_BankPages' : '{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}',
	'IItems' : '{1EFF6EB3-9368-4A68-B619-0B57A134F0CE}',
	'IValidValuesMD' : '{D435C006-B504-4847-B217-8AEA5439B779}',
	'IUserObjectMD_ChildTables' : '{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}',
	'ITeamMembers' : '{09C6E920-908C-4FD2-9CBF-21C3F4329A33}',
	'IUserFieldsMD' : '{81D132DE-0549-460D-9BEC-2FEDEAB0A950}',
	'IUserFields' : '{CC279FBE-7088-42E9-A579-EB2E3E971076}',
	'IAdditionalExpenses' : '{0FCFCE88-47F3-4F05-9803-3081D83C92DC}',
	'IBillOfExchangeTransaction_Lines' : '{2DBFED56-4DB4-455A-9C22-E2C01C052D39}',
	'ISalesForecast' : '{0D31ADD3-85B1-40F1-979F-8612E10B8DD8}',
	'IWithholdingTaxLines' : '{458A15A5-B980-4543-A289-F6477A36EB24}',
	'ISpecialPrices' : '{2C1751BA-5CFF-4E47-8C1E-13CAF241A13F}',
	'IManufacturers' : '{DBB3E886-60E7-4058-930A-1C7C07CADB2C}',
	'IUserObjectMD_FormColumns' : '{0C607D21-E148-42CE-AF58-E8C38EB26275}',
	'IWithholdingTaxData' : '{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}',
	'IIndustries' : '{68C60132-0DD3-4AD2-B4FF-DB358A6184BC}',
	'_ICompanyEvents' : '{57B97799-106E-4EA3-8203-1B30B6B7D463}',
	'IEmployeeReviewsInfo' : '{C4397D01-E44E-4B76-80AB-4B888EEA10DD}',
	'IStockTaking' : '{301718D4-11C9-4C5F-88DD-3609C5FA21FF}',
	'IBankPages' : '{5BB202A1-E560-4E34-ACB3-2ECA52FFB274}',
	'IItemGroups' : '{216974E8-B66D-4022-9AB1-97BAA96084A3}',
	'ITaxInvoice_Lines' : '{D1DD9101-9264-450A-9FAC-C9D899078775}',
	'IActivityLocations' : '{0383EE76-4325-42FE-8164-91C2E8FDE242}',
	'IPayments_Accounts' : '{231A13D7-5DA8-4467-A263-FDE84A268AC9}',
	'IPaymentTermsTypes' : '{F09A4CB0-F8CA-4342-A44D-82DE3395B011}',
	'ILocalEra' : '{B7A80F7E-77C0-404E-A8B3-01D0F9136DCF}',
	'IEmployeeRolesInfo' : '{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}',
	'INotaFiscalCST' : '{54E2DDD8-87FE-415D-AA8E-2AC62C936C7A}',
	'IQueue' : '{8C5510F0-AA36-4CBD-A5AC-7DCF29EE0249}',
	'IBPFiscalTaxID' : '{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}',
	'ICompany' : '{3BA8DAED-5B33-4CE4-A4B8-B4308D86E524}',
	'IValidValue' : '{013F0389-85E2-4B8B-9285-18843E4236F3}',
	'ISalesOpportunitiesPartners' : '{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}',
	'IBPFiscalRegistryID' : '{2C35D508-856B-43E0-A1A5-EC6BCA16E62A}',
	'ISBObob' : '{268D6CC3-E244-4AD7-B009-16C8ED7F710A}',
	'IEmployeeAbsenceInfo' : '{CD47A725-AEA8-4224-93D3-F31848990C42}',
	'ISpecialPricesDataAreas' : '{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}',
	'IJournalVouchers' : '{B9A56422-93A0-4480-BAF3-48907F403CB8}',
	'IActivityTypes' : '{0C60C86B-3CB9-4E78-80D0-1AACB3C1C6F0}',
	'IStockTransfer_Lines' : '{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}',
	'IAlternateCatNum' : '{0677DAD5-92DA-441E-A674-13DE601888FB}',
	'IPayments' : '{E79D3C41-BFE7-4C5A-B586-4F627E021A1C}',
	'IPayments_CreditCards' : '{CC3579ED-1C61-4864-8E51-208A3DCDFC93}',
	'IBillOfExchangeTrans_Deposits' : '{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}',
	'IWorkOrder_Lines' : '{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}',
	'IItemWarehouseInfo' : '{CDB52791-B0FC-4BE1-A712-06941AF91D52}',
	'IMaterialRevaluation_lines' : '{038A3F8E-2465-435E-8D05-F510620533C3}',
	'IPaymentRunExport_Lines' : '{917BA077-4D88-46A8-B78A-E396315D7E59}',
	'IField' : '{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}',
	'IBPPaymentMethods' : '{7D947F60-6017-44AA-AEAC-9721FF263D5E}',
	'IBusinessPartners' : '{9DF321C2-6A1D-446B-AE8A-F7C33987D792}',
	'IRelationships' : '{BBB45A32-F446-4ED3-915B-C811BBA6C2C7}',
	'IProductionOrders' : '{1C7C966F-B713-42BF-9A74-0B15A649E63D}',
	'INotaFiscalUsage' : '{E2C5A384-883B-4963-A4A4-30C6F553818F}',
	'ISalesOpportunitiesCompetition' : '{19E6540E-4E64-48C1-9525-29D5710D1FFD}',
	'ITaxExtension' : '{8CC29ECE-02C3-4C7B-851B-5533D2C83627}',
	'IKnowledgeBaseSolutions' : '{1E293D13-1EC1-4DF2-A5CC-7FE45030EEE5}',
	'I_GenArrObj' : '{D919D79B-2CE9-4A88-9C3D-59A67A334D81}',
	'IUserObjectMD_FindColumns' : '{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}',
	'IBPWithholdingTax' : '{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}',
	'IBudgetDistribution' : '{0CFCFE82-D222-486A-9E49-0FBE58FDD534}',
	'IDocument_LinesAdditionalExpenses' : '{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}',
	'IJournalEntries' : '{060F033E-2FC9-4266-90AE-3271AC203A59}',
	'IUserTable' : '{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}',
	'ISalesOpportunitiesLines' : '{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}',
	'ICommand' : '{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}',
	'IProductTrees_Lines' : '{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}',
	'IBillOfExchange' : '{741AA803-AB33-4FD7-B664-63116291D6CE}',
	'ISpecialPricesQuantityAreas' : '{34995651-4568-4AAE-B831-60693B932A35}',
	'IValidValues' : '{48B89C08-2AE9-435F-B7C4-D7219E938E46}',
	'IChecksforPayment' : '{5E6A92D1-9BAB-4BB4-A379-2428006247C3}',
	'IContacts' : '{96D7BBA9-27E7-4893-BC78-CC4313BE0DD1}',
	'IEmployeePrevEmpoymentInfo' : '{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}',
	'IBudget_Lines' : '{D2BAB599-C7C6-4301-B925-B6BB51092A79}',
	'ICommandParam' : '{8CA91808-D098-4416-8368-E426484BA8DB}',
	'ITerritories' : '{BEB8ACDC-E50B-4DA3-8281-EF5228E55099}',
}

win32com.client.constants.__dicts__.append(constants.__dict__)

