# -*- coding: mbcs -*-
# Created by makepy.py version 0.5.01
# By python version 2.7.10 (default, May 23 2015, 09:40:32) [MSC v.1500 32 bit (Intel)]
# From type library 'SAPbobsCOM88.dll'
# On Mon Jul 20 15:03:58 2015
'SAP Business One DI API Version 8.82'
makepy_version = '0.5.01'
python_version = 0x2070af0

import win32com.client.CLSIDToClass, pythoncom, pywintypes
import win32com.client.util
from pywintypes import IID
from win32com.client import Dispatch

# The following 3 lines may need tweaking for the particular server
# Candidates are pythoncom.Missing, .Empty and .ArgNotFound
defaultNamedOptArg=pythoncom.Empty
defaultNamedNotOptArg=pythoncom.Empty
defaultUnnamedArg=pythoncom.Empty

CLSID = IID('{FC8030BE-F5D2-4B8E-8F92-44228FE30088}')
MajorVersion = 8
MinorVersion = 8
LibraryFlags = 8
LCID = 0x0

class constants:
	acsAccountCategoriesParams    =1          # from enum AccountCategoryServiceDataInterfaces
	acsAccountCategory            =0          # from enum AccountCategoryServiceDataInterfaces
	acsAccountCategoryParams      =2          # from enum AccountCategoryServiceDataInterfaces
	acsBalanceSheet               =0          # from enum AccountCategorySourceEnum
	acsProfitAndLoss              =1          # from enum AccountCategorySourceEnum
	ast_Alphanumeric              =0          # from enum AccountSegmentationTypeEnum
	ast_Numeric                   =1          # from enum AccountSegmentationTypeEnum
	asdiGLAccounts                =1          # from enum AccountsServiceDataInterfaces
	asdiOpenningBalanceAccount    =0          # from enum AccountsServiceDataInterfaces
	atsAccrualType                =0          # from enum AccrualTypesServiceDataInterfaces
	atsAccrualTypeParams          =2          # from enum AccrualTypesServiceDataInterfaces
	atsAccrualTypesParams         =1          # from enum AccrualTypesServiceDataInterfaces
	asActivitiesParams            =1          # from enum ActivitiesServiceDataInterfaces
	asActivity                    =0          # from enum ActivitiesServiceDataInterfaces
	asActivityInstanceParams      =4          # from enum ActivitiesServiceDataInterfaces
	asActivityInstancesListParams =5          # from enum ActivitiesServiceDataInterfaces
	asActivityInstancesParams     =3          # from enum ActivitiesServiceDataInterfaces
	asActivityParams              =2          # from enum ActivitiesServiceDataInterfaces
	atd_ChecksForPayment          =13         # from enum AlertManagementDocumentEnum
	atd_CorrectionInvoice         =14         # from enum AlertManagementDocumentEnum
	atd_DeliveryNotes             =3          # from enum AlertManagementDocumentEnum
	atd_DownPaymentIncoming       =15         # from enum AlertManagementDocumentEnum
	atd_DownPaymentOutgoing       =16         # from enum AlertManagementDocumentEnum
	atd_IncomingPayments          =10         # from enum AlertManagementDocumentEnum
	atd_Invoices                  =1          # from enum AlertManagementDocumentEnum
	atd_JournalEntries            =11         # from enum AlertManagementDocumentEnum
	atd_NOB                       =0          # from enum AlertManagementDocumentEnum
	atd_Orders                    =5          # from enum AlertManagementDocumentEnum
	atd_OutgoingPayments          =12         # from enum AlertManagementDocumentEnum
	atd_PurchaseDeliveryNotes     =7          # from enum AlertManagementDocumentEnum
	atd_PurchaseInvoices          =6          # from enum AlertManagementDocumentEnum
	atd_PurchaseOrders            =8          # from enum AlertManagementDocumentEnum
	atd_Quotations                =9          # from enum AlertManagementDocumentEnum
	atd_Returns                   =4          # from enum AlertManagementDocumentEnum
	atd_RevertInvoice             =2          # from enum AlertManagementDocumentEnum
	atfi_Days                     =2          # from enum AlertManagementFrequencyType
	atfi_Hours                    =1          # from enum AlertManagementFrequencyType
	atfi_Minutes                  =0          # from enum AlertManagementFrequencyType
	atfi_Monthly                  =4          # from enum AlertManagementFrequencyType
	atfi_Weeks                    =3          # from enum AlertManagementFrequencyType
	atp_High                      =2          # from enum AlertManagementPriorityEnum
	atp_Low                       =0          # from enum AlertManagementPriorityEnum
	atp_Normal                    =1          # from enum AlertManagementPriorityEnum
	atsdiAlertManagement          =0          # from enum AlertManagementServiceDataInterfaces
	atsdiAlertManagementParams    =1          # from enum AlertManagementServiceDataInterfaces
	att_System                    =1          # from enum AlertManagementTypeEnum
	att_User                      =0          # from enum AlertManagementTypeEnum
	aisOriginalItem               =0          # from enum AlternativeItemsServiceDataInterfaces
	aisOriginalItemParams         =1          # from enum AlternativeItemsServiceDataInterfaces
	arsApprovalRequest            =0          # from enum ApprovalRequestsServiceDataInterfaces
	arsApprovalRequestParams      =2          # from enum ApprovalRequestsServiceDataInterfaces
	arsApprovalRequestsParams     =1          # from enum ApprovalRequestsServiceDataInterfaces
	assdiApprovalStage            =1          # from enum ApprovalStagesServiceDataInterfaces
	assdiApprovalStageParams      =0          # from enum ApprovalStagesServiceDataInterfaces
	atctDeviationFromBudget       =5          # from enum ApprovalTemplateConditionTypeEnum
	atctDeviationFromCreditLine   =1          # from enum ApprovalTemplateConditionTypeEnum
	atctDeviationFromObligo       =2          # from enum ApprovalTemplateConditionTypeEnum
	atctDiscountPercent           =4          # from enum ApprovalTemplateConditionTypeEnum
	atctGrossProfitPercent        =3          # from enum ApprovalTemplateConditionTypeEnum
	atctTotalDocument             =6          # from enum ApprovalTemplateConditionTypeEnum
	atctUndefined                 =0          # from enum ApprovalTemplateConditionTypeEnum
	opcodeDoesNotEqual            =6          # from enum ApprovalTemplateOperationTypeEnum
	opcodeEqual                   =5          # from enum ApprovalTemplateOperationTypeEnum
	opcodeGreaterOrEqual          =2          # from enum ApprovalTemplateOperationTypeEnum
	opcodeGreaterThan             =1          # from enum ApprovalTemplateOperationTypeEnum
	opcodeInRange                 =7          # from enum ApprovalTemplateOperationTypeEnum
	opcodeLessOrEqual             =4          # from enum ApprovalTemplateOperationTypeEnum
	opcodeLessThan                =3          # from enum ApprovalTemplateOperationTypeEnum
	opcodeNotInRange              =8          # from enum ApprovalTemplateOperationTypeEnum
	opcodeUndefined               =0          # from enum ApprovalTemplateOperationTypeEnum
	atdtApCreditMemo              =19         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtApDownPayment             =204        # from enum ApprovalTemplatesDocumentTypeEnum
	atdtApInvoice                 =18         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtArCreditMemo              =14         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtArDownPayment             =203        # from enum ApprovalTemplatesDocumentTypeEnum
	atdtArInvoice                 =13         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtCorrectionInvoice         =132        # from enum ApprovalTemplatesDocumentTypeEnum
	atdtDelivery                  =15         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtGoodsIssue                =60         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtGoodsReceipt              =59         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtGoodsReceiptPO            =20         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtGoodsReturns              =21         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtInventoryTransfer         =67         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtInventoryTransferRequest  =1250000001 # from enum ApprovalTemplatesDocumentTypeEnum
	atdtOrder                     =17         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtOutgoingPayment           =46         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtPurchaseOrder             =22         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtPurchaseQuotation         =540000006  # from enum ApprovalTemplatesDocumentTypeEnum
	atdtQuotation                 =23         # from enum ApprovalTemplatesDocumentTypeEnum
	atdtReturns                   =16         # from enum ApprovalTemplatesDocumentTypeEnum
	atsdiApprovalTemplate         =0          # from enum ApprovalTemplatesServiceDataInterfaces
	atsdiApprovalTemplateParams   =1          # from enum ApprovalTemplatesServiceDataInterfaces
	atCompany                     =0          # from enum AssesseeTypeEnum
	atOthers                      =1          # from enum AssesseeTypeEnum
	aturBadUserOrPassword         =-8023      # from enum AuthenticateUserResultsEnum
	aturDBErrors                  =-8032      # from enum AuthenticateUserResultsEnum
	aturLogOnUserNotAdmin         =-8031      # from enum AuthenticateUserResultsEnum
	aturNotConnectedToCompany     =-8033      # from enum AuthenticateUserResultsEnum
	aturPasswordExpired           =-8025      # from enum AuthenticateUserResultsEnum
	aturUserHasBeenLocked         =-8024      # from enum AuthenticateUserResultsEnum
	aturUsernamePasswordMatch     =0          # from enum AuthenticateUserResultsEnum
	apFeeOnly                     =3          # from enum AutomaticPostingEnum
	apInterestAndFee              =1          # from enum AutomaticPostingEnum
	apInterestOnly                =2          # from enum AutomaticPostingEnum
	apNo                          =0          # from enum AutomaticPostingEnum
	boedtsBOEDocumentType         =1          # from enum BOEDocumentTypesServiceDataInterfaces
	boedtsBOEDocumentTypeParams   =3          # from enum BOEDocumentTypesServiceDataInterfaces
	boedtsBOEDocumentTypes        =0          # from enum BOEDocumentTypesServiceDataInterfaces
	boedtsBOEDocumentTypesParams  =2          # from enum BOEDocumentTypesServiceDataInterfaces
	boeisBOEInstruction           =1          # from enum BOEInstructionsServiceDataInterfaces
	boeisBOEInstructionParams     =3          # from enum BOEInstructionsServiceDataInterfaces
	boeisBOEInstructions          =0          # from enum BOEInstructionsServiceDataInterfaces
	boeisBOEInstructionsParams    =2          # from enum BOEInstructionsServiceDataInterfaces
	boelsBOELineParams            =1          # from enum BOELinesServiceDataInterfaces
	boelsBOELinesParams           =0          # from enum BOELinesServiceDataInterfaces
	boepsBOEPortfolio             =1          # from enum BOEPortfoliosServiceDataInterfaces
	boepsBOEPortfolioParams       =3          # from enum BOEPortfoliosServiceDataInterfaces
	boepsBOEPortfolios            =0          # from enum BOEPortfoliosServiceDataInterfaces
	boepsBOEPortfoliosParams      =2          # from enum BOEPortfoliosServiceDataInterfaces
	bcacsBankChargesAllocationCode=0          # from enum BankChargesAllocationCodesServiceDataInterfaces
	bcacsBankChargesAllocationCodeParams=2          # from enum BankChargesAllocationCodesServiceDataInterfaces
	bcacsBankChargesAllocationCodesParams=1          # from enum BankChargesAllocationCodesServiceDataInterfaces
	bsdtDownPaymentIncoming       =4          # from enum BankStatementDocTypeEnum
	bsdtDownPaymentOutgoing       =5          # from enum BankStatementDocTypeEnum
	bsdtInvoices                  =2          # from enum BankStatementDocTypeEnum
	bsdtJournalEntry              =8          # from enum BankStatementDocTypeEnum
	bsdtPaymentToVendor           =1          # from enum BankStatementDocTypeEnum
	bsdtPurchases                 =3          # from enum BankStatementDocTypeEnum
	bsdtReceipts                  =0          # from enum BankStatementDocTypeEnum
	bsdtRevertInvoices            =6          # from enum BankStatementDocTypeEnum
	bsdtRevertPurchases           =7          # from enum BankStatementDocTypeEnum
	bsImported                    =0          # from enum BankStatementRowSourceEnum
	bsImportedAndAmended          =1          # from enum BankStatementRowSourceEnum
	bsManuallyEntered             =2          # from enum BankStatementRowSourceEnum
	bssDraft                      =1          # from enum BankStatementStatusEnum
	bssExecuted                   =0          # from enum BankStatementStatusEnum
	bssOld                        =2          # from enum BankStatementStatusEnum
	bssBankStatement              =1          # from enum BankStatementsServiceDataInterfaces
	bssBankStatementParams        =3          # from enum BankStatementsServiceDataInterfaces
	bssBankStatements             =0          # from enum BankStatementsServiceDataInterfaces
	bssBankStatementsFilter       =4          # from enum BankStatementsServiceDataInterfaces
	bssBankStatementsParams       =2          # from enum BankStatementsServiceDataInterfaces
	bdsFromDueDate                =0          # from enum BaseDateSelectEnum
	bdsFromLastDunningRun         =1          # from enum BaseDateSelectEnum
	bndsBatchNumberDetail         =0          # from enum BatchNumberDetailsServiceDataInterfaces
	bndsBatchNumberDetailParams   =1          # from enum BatchNumberDetailsServiceDataInterfaces
	Annually                      =5          # from enum BlanketAgreementDatePeriodsEnum
	Daily                         =0          # from enum BlanketAgreementDatePeriodsEnum
	Monthly                       =2          # from enum BlanketAgreementDatePeriodsEnum
	OneTime                       =6          # from enum BlanketAgreementDatePeriodsEnum
	Quarterly                     =3          # from enum BlanketAgreementDatePeriodsEnum
	Semiannually                  =4          # from enum BlanketAgreementDatePeriodsEnum
	Weekly                        =1          # from enum BlanketAgreementDatePeriodsEnum
	APCorrectionInvoice           =11         # from enum BlanketAgreementDocTypeEnum
	APCorrectionInvoiceReversal   =12         # from enum BlanketAgreementDocTypeEnum
	APCreditMemo                  =6          # from enum BlanketAgreementDocTypeEnum
	APDownPayment                 =16         # from enum BlanketAgreementDocTypeEnum
	APInvoice                     =5          # from enum BlanketAgreementDocTypeEnum
	ARCorrectionInvoice           =13         # from enum BlanketAgreementDocTypeEnum
	ARCorrectionInvoiceReversal   =14         # from enum BlanketAgreementDocTypeEnum
	ARCreditMemo                  =1          # from enum BlanketAgreementDocTypeEnum
	ARDownPayment                 =15         # from enum BlanketAgreementDocTypeEnum
	ARInvoice                     =0          # from enum BlanketAgreementDocTypeEnum
	Delivery                      =2          # from enum BlanketAgreementDocTypeEnum
	GoodsReceiptPO                =7          # from enum BlanketAgreementDocTypeEnum
	GoodsReturn                   =8          # from enum BlanketAgreementDocTypeEnum
	PurchaseOrder                 =9          # from enum BlanketAgreementDocTypeEnum
	PurchaseQuotation             =17         # from enum BlanketAgreementDocTypeEnum
	Return                        =3          # from enum BlanketAgreementDocTypeEnum
	SalesOrder                    =4          # from enum BlanketAgreementDocTypeEnum
	SalesQuotation                =10         # from enum BlanketAgreementDocTypeEnum
	amItem                        =0          # from enum BlanketAgreementMethodEnum
	amMonetary                    =1          # from enum BlanketAgreementMethodEnum
	asApproved                    =0          # from enum BlanketAgreementStatusEnum
	asDraft                       =2          # from enum BlanketAgreementStatusEnum
	asOnHold                      =1          # from enum BlanketAgreementStatusEnum
	asTerminated                  =3          # from enum BlanketAgreementStatusEnum
	atGeneral                     =0          # from enum BlanketAgreementTypeEnum
	atSpecific                    =1          # from enum BlanketAgreementTypeEnum
	basBlanketAgreement           =0          # from enum BlanketAgreementsServiceDataInterfaces
	basBlanketAgreementParams     =4          # from enum BlanketAgreementsServiceDataInterfaces
	basBlanketAgreementsDocument  =2          # from enum BlanketAgreementsServiceDataInterfaces
	basBlanketAgreementsDocuments =1          # from enum BlanketAgreementsServiceDataInterfaces
	basBlanketAgreementsParams    =3          # from enum BlanketAgreementsServiceDataInterfaces
	bodt_CorrectionAPInvoice      =163        # from enum BoAPARDocumentTypes
	bodt_CorrectionARInvoice      =165        # from enum BoAPARDocumentTypes
	bodt_CreditNote               =14         # from enum BoAPARDocumentTypes
	bodt_DeliveryNote             =15         # from enum BoAPARDocumentTypes
	bodt_Invoice                  =13         # from enum BoAPARDocumentTypes
	bodt_Order                    =17         # from enum BoAPARDocumentTypes
	bodt_PurchaseCreditNote       =19         # from enum BoAPARDocumentTypes
	bodt_PurchaseDeliveryNote     =20         # from enum BoAPARDocumentTypes
	bodt_PurchaseInvoice          =18         # from enum BoAPARDocumentTypes
	bodt_PurchaseOrder            =22         # from enum BoAPARDocumentTypes
	bodt_PurchaseReturn           =21         # from enum BoAPARDocumentTypes
	bodt_Quotation                =23         # from enum BoAPARDocumentTypes
	bodt_Return                   =16         # from enum BoAPARDocumentTypes
	at_Expenses                   =1          # from enum BoAccountTypes
	at_Other                      =2          # from enum BoAccountTypes
	at_Revenues                   =0          # from enum BoAccountTypes
	cn_Campaign                   =5          # from enum BoActivities
	cn_Conversation               =0          # from enum BoActivities
	cn_Meeting                    =1          # from enum BoActivities
	cn_Note                       =4          # from enum BoActivities
	cn_Other                      =3          # from enum BoActivities
	cn_Task                       =2          # from enum BoActivities
	aedm_Equally                  =4          # from enum BoAdEpnsDistribMethods
	aedm_None                     =0          # from enum BoAdEpnsDistribMethods
	aedm_Quantity                 =1          # from enum BoAdEpnsDistribMethods
	aedm_RowTotal                 =5          # from enum BoAdEpnsDistribMethods
	aedm_Volume                   =2          # from enum BoAdEpnsDistribMethods
	aedm_Weight                   =3          # from enum BoAdEpnsDistribMethods
	aext_NoTax                    =1          # from enum BoAdEpnsTaxTypes
	aext_NormalTax                =0          # from enum BoAdEpnsTaxTypes
	aext_UseTax                   =2          # from enum BoAdEpnsTaxTypes
	bo_BillTo                     =1          # from enum BoAddressType
	bo_ShipTo                     =0          # from enum BoAddressType
	aed_Equally                   =4          # from enum BoAeDistMthd
	aed_LineTotal                 =5          # from enum BoAeDistMthd
	aed_None                      =0          # from enum BoAeDistMthd
	aed_Quantity                  =1          # from enum BoAeDistMthd
	aed_Volume                    =2          # from enum BoAeDistMthd
	aed_Weight                    =3          # from enum BoAeDistMthd
	atfwhs_Block                  =1          # from enum BoAlertTypeforWHStockEnum
	atfwhs_NoMessage              =2          # from enum BoAlertTypeforWHStockEnum
	atfwhs_WarningOnly            =0          # from enum BoAlertTypeforWHStockEnum
	ab_CashValueAfterCustoms      =1          # from enum BoAllocationByEnum
	ab_CashValueBeforeCustoms     =0          # from enum BoAllocationByEnum
	ab_Equal                      =5          # from enum BoAllocationByEnum
	ab_Quantity                   =2          # from enum BoAllocationByEnum
	ab_Volume                     =4          # from enum BoAllocationByEnum
	ab_Weight                     =3          # from enum BoAllocationByEnum
	ardApproved                   =1          # from enum BoApprovalRequestDecisionEnum
	ardNotApproved                =2          # from enum BoApprovalRequestDecisionEnum
	ardPending                    =0          # from enum BoApprovalRequestDecisionEnum
	arsApproved                   =1          # from enum BoApprovalRequestStatusEnum
	arsCancelled                  =5          # from enum BoApprovalRequestStatusEnum
	arsGenerated                  =3          # from enum BoApprovalRequestStatusEnum
	arsGeneratedByAuthorizer      =4          # from enum BoApprovalRequestStatusEnum
	arsNotApproved                =2          # from enum BoApprovalRequestStatusEnum
	arsPending                    =0          # from enum BoApprovalRequestStatusEnum
	bobt_Incoming                 =0          # from enum BoBOETypes
	bobt_Outgoing                 =1          # from enum BoBOETypes
	btfs_Deposited                =2          # from enum BoBOTFromStatus
	btfs_Generated                =1          # from enum BoBOTFromStatus
	btfs_Paid                     =3          # from enum BoBOTFromStatus
	btfs_Sent                     =0          # from enum BoBOTFromStatus
	btts_Canceled                 =0          # from enum BoBOTToStatus
	btts_Closed                   =5          # from enum BoBOTToStatus
	btts_Deposit                  =2          # from enum BoBOTToStatus
	btts_Failed                   =4          # from enum BoBOTToStatus
	btts_Generated                =1          # from enum BoBOTToStatus
	btts_Paid                     =3          # from enum BoBOTToStatus
	rlbsCode128                   =2          # from enum BoBarCodeStandardEnum
	rlbsCode39                    =1          # from enum BoBarCodeStandardEnum
	rlbsEan13                     =0          # from enum BoBarCodeStandardEnum
	bdr_PostingDate               =0          # from enum BoBaseDateRateEnum
	bdr_TaxDate                   =1          # from enum BoBaseDateRateEnum
	bld_ClosingDate               =3          # from enum BoBaselineDate
	bld_PostingDate               =0          # from enum BoBaselineDate
	bld_SystemDate                =1          # from enum BoBaselineDate
	bld_TaxDate                   =2          # from enum BoBaselineDate
	bb_Block                      =2          # from enum BoBlockBudget
	bb_MonthlyAlertOnly           =1          # from enum BoBlockBudget
	bb_OnlyAnnualAlert            =0          # from enum BoBlockBudget
	boes_Cancelled                =4          # from enum BoBoeStatus
	boes_Closed                   =5          # from enum BoBoeStatus
	boes_Created                  =0          # from enum BoBoeStatus
	boes_Deposited                =2          # from enum BoBoeStatus
	boes_Failed                   =6          # from enum BoBoeStatus
	boes_Paid                     =3          # from enum BoBoeStatus
	boes_Sent                     =1          # from enum BoBoeStatus
	bpat_AssetsAccount            =2          # from enum BoBpAccountTypes
	bpat_AssetsPayable            =7          # from enum BoBpAccountTypes
	bpat_Discounted               =8          # from enum BoBpAccountTypes
	bpat_Domestic                 =11         # from enum BoBpAccountTypes
	bpat_DownPayment              =1          # from enum BoBpAccountTypes
	bpat_Foreign                  =12         # from enum BoBpAccountTypes
	bpat_General                  =0          # from enum BoBpAccountTypes
	bpat_OnCollection             =5          # from enum BoBpAccountTypes
	bpat_OpenDebts                =10         # from enum BoBpAccountTypes
	bpat_Payable                  =4          # from enum BoBpAccountTypes
	bpat_Presentation             =6          # from enum BoBpAccountTypes
	bpat_Receivable               =3          # from enum BoBpAccountTypes
	bpat_Unpaid                   =9          # from enum BoBpAccountTypes
	bpdt_DocNum                   =2          # from enum BoBpsDocTypes
	bpdt_ISR                      =1          # from enum BoBpsDocTypes
	bpdt_PaymentReference         =0          # from enum BoBpsDocTypes
	ba_AnnualAlert                =0          # from enum BoBudgetAlert
	ba_MonthlyAlert               =1          # from enum BoBudgetAlert
	baPurchase                    =1          # from enum BoBusinessAreaEnum
	baSales                       =0          # from enum BoBusinessAreaEnum
	baSalesAndPurchase            =2          # from enum BoBusinessAreaEnum
	bbpgt_CustomerGroup           =0          # from enum BoBusinessPartnerGroupTypes
	bbpgt_VendorGroup             =1          # from enum BoBusinessPartnerGroupTypes
	cCompany                      =0          # from enum BoCardCompanyTypes
	cPrivate                      =1          # from enum BoCardCompanyTypes
	cCustomer                     =0          # from enum BoCardTypes
	cLid                          =2          # from enum BoCardTypes
	cSupplier                     =1          # from enum BoCardTypes
	clAdditionalExpenses          =28         # from enum BoChangeLogEnum
	clAdminInfo                   =19         # from enum BoChangeLogEnum
	clBillOfExchange              =38         # from enum BoChangeLogEnum
	clBusinessPartners            =1          # from enum BoChangeLogEnum
	clChartOfAccounts             =0          # from enum BoChangeLogEnum
	clCorrectionInvoice           =33         # from enum BoChangeLogEnum
	clCorrectionInvoiceReversal   =34         # from enum BoChangeLogEnum
	clCorrectionPurchaseInvoice   =31         # from enum BoChangeLogEnum
	clCorrectionPurchaseInvoiceReversal=32         # from enum BoChangeLogEnum
	clCreditCards                 =18         # from enum BoChangeLogEnum
	clCreditNotes                 =6          # from enum BoChangeLogEnum
	clCustomerEquipmentCards      =36         # from enum BoChangeLogEnum
	clDeliveryNotes               =7          # from enum BoChangeLogEnum
	clDownPayments                =41         # from enum BoChangeLogEnum
	clEmployeesInfo               =35         # from enum BoChangeLogEnum
	clExternalBankOperationCodes  =47         # from enum BoChangeLogEnum
	clFinancePeriods              =27         # from enum BoChangeLogEnum
	clHouseBankAccounts           =44         # from enum BoChangeLogEnum
	clIncomingExciseInvoice       =50         # from enum BoChangeLogEnum
	clIncomingPayments            =16         # from enum BoChangeLogEnum
	clInternalBankOperationCodes  =48         # from enum BoChangeLogEnum
	clInventoryGeneralEntry       =22         # from enum BoChangeLogEnum
	clInventoryGeneralExit        =23         # from enum BoChangeLogEnum
	clInventoryTransferRequests   =51         # from enum BoChangeLogEnum
	clInvoices                    =5          # from enum BoChangeLogEnum
	clItemGroups                  =21         # from enum BoChangeLogEnum
	clItems                       =2          # from enum BoChangeLogEnum
	clJournalEntries              =17         # from enum BoChangeLogEnum
	clMaterialRevaluation         =30         # from enum BoChangeLogEnum
	clOrders                      =9          # from enum BoChangeLogEnum
	clOutgoingExciseInvoice       =49         # from enum BoChangeLogEnum
	clPeriodCategory              =43         # from enum BoChangeLogEnum
	clPickLists                   =29         # from enum BoChangeLogEnum
	clProductTrees                =25         # from enum BoChangeLogEnum
	clProductionOrders            =40         # from enum BoChangeLogEnum
	clPurchaseCreditNotes         =11         # from enum BoChangeLogEnum
	clPurchaseDeliveryNotes       =12         # from enum BoChangeLogEnum
	clPurchaseDownPayments        =42         # from enum BoChangeLogEnum
	clPurchaseInvoices            =10         # from enum BoChangeLogEnum
	clPurchaseOrders              =14         # from enum BoChangeLogEnum
	clPurchaseQuotation           =52         # from enum BoChangeLogEnum
	clPurchaseReturns             =13         # from enum BoChangeLogEnum
	clPurchaseTaxInvoice          =46         # from enum BoChangeLogEnum
	clQuotations                  =15         # from enum BoChangeLogEnum
	clReturns                     =8          # from enum BoChangeLogEnum
	clSalesTaxInvoice             =45         # from enum BoChangeLogEnum
	clServiceCalls                =39         # from enum BoChangeLogEnum
	clStockTransfers              =26         # from enum BoChangeLogEnum
	clUDO                         =100        # from enum BoChangeLogEnum
	clUsers                       =4          # from enum BoChangeLogEnum
	clVatGroups                   =3          # from enum BoChangeLogEnum
	clVendorPayments              =20         # from enum BoChangeLogEnum
	clWarehouses                  =24         # from enum BoChangeLogEnum
	clWithholdingTaxCodes         =37         # from enum BoChangeLogEnum
	bocpdbld_BaseSystemDate       =1          # from enum BoClosingDateProcedureBaseDateEnum
	bocpdbld_PostingDate          =0          # from enum BoClosingDateProcedureBaseDateEnum
	bocpddm_HalfMonth             =1          # from enum BoClosingDateProcedureDueMonthEnum
	bocpddm_MonthEnd              =0          # from enum BoClosingDateProcedureDueMonthEnum
	bocpddm_MonthStart            =2          # from enum BoClosingDateProcedureDueMonthEnum
	bocpddm_None                  =3          # from enum BoClosingDateProcedureDueMonthEnum
	cptt_TemplateCockpit          =1          # from enum BoCockpitTypeEnum
	cptt_UserCockpit              =0          # from enum BoCockpitTypeEnum
	cm_BackwardForward            =0          # from enum BoConsumptionMethod
	cm_ForwardBackward            =1          # from enum BoConsumptionMethod
	ct_Customer                   =0          # from enum BoContractTypes
	ct_ItemGroup                  =1          # from enum BoContractTypes
	ct_SerialNumber               =2          # from enum BoContractTypes
	ciis_ShouldBe                 =1          # from enum BoCorInvItemStatus
	ciis_Was                      =0          # from enum BoCorInvItemStatus
	cfp_Account                   =1          # from enum BoCpCardAcct
	cfp_Card                      =0          # from enum BoCpCardAcct
	cc_Block                      =0          # from enum BoCurrencyCheck
	cc_NoMessage                  =1          # from enum BoCurrencyCheck
	bocs_BPCurrency               =2          # from enum BoCurrencySources
	bocs_LocalCurrency            =0          # from enum BoCurrencySources
	bocs_SystemCurrency           =1          # from enum BoCurrencySources
	dst_DB_2                      =2          # from enum BoDataServerTypes
	dst_MAXDB                     =5          # from enum BoDataServerTypes
	dst_MSSQL                     =1          # from enum BoDataServerTypes
	dst_MSSQL2005                 =4          # from enum BoDataServerTypes
	dst_MSSQL2008                 =6          # from enum BoDataServerTypes
	dst_MSSQL2012                 =7          # from enum BoDataServerTypes
	dst_SYBASE                    =3          # from enum BoDataServerTypes
	rldsDatabase                  =2          # from enum BoDataSourceEnum
	rldsFormula                   =3          # from enum BoDataSourceEnum
	rldsFreeText                  =0          # from enum BoDataSourceEnum
	rldsSystemVariable            =1          # from enum BoDataSourceEnum
	dt_CCYYMMDD                   =4          # from enum BoDateTemplate
	dt_DDMMCCYY                   =1          # from enum BoDateTemplate
	dt_DDMMYY                     =0          # from enum BoDateTemplate
	dt_DDMonthYYYY                =5          # from enum BoDateTemplate
	dt_MMDDCCYY                   =3          # from enum BoDateTemplate
	dt_MMDDYY                     =2          # from enum BoDateTemplate
	dtgcDividendPayments          =18         # from enum BoDeductionTaxGroupCodeEnum
	dtgcEmployeeReceivingCommission=2          # from enum BoDeductionTaxGroupCodeEnum
	dtgcInterestReceivers         =1          # from enum BoDeductionTaxGroupCodeEnum
	dtgcInvalidPaymentFromCompensationFund=11         # from enum BoDeductionTaxGroupCodeEnum
	dtgcPaidServices              =6          # from enum BoDeductionTaxGroupCodeEnum
	dtgcPaymentsForCitizensInForeignCountries=8          # from enum BoDeductionTaxGroupCodeEnum
	dtgcPaymentsFromStudyFund     =14         # from enum BoDeductionTaxGroupCodeEnum
	dtgcPaymentsToForeignCitizens =7          # from enum BoDeductionTaxGroupCodeEnum
	dtgcRentalPayments            =13         # from enum BoDeductionTaxGroupCodeEnum
	dtgcRepaymentToEmployerFromCompensationFund=12         # from enum BoDeductionTaxGroupCodeEnum
	dtgcWritersPrice              =3          # from enum BoDeductionTaxGroupCodeEnum
	dbs_Locked                    =2          # from enum BoDefaultBatchStatus
	dbs_NotAccessible             =1          # from enum BoDefaultBatchStatus
	dbs_Released                  =0          # from enum BoDefaultBatchStatus
	datBankAccount                =0          # from enum BoDepositAccountTypeEnum
	datBusinessPartner            =1          # from enum BoDepositAccountTypeEnum
	dcAsCash                      =1          # from enum BoDepositCheckEnum
	dtAsPostdated                 =2          # from enum BoDepositCheckEnum
	dtNo                          =0          # from enum BoDepositCheckEnum
	dpt_Collection                =0          # from enum BoDepositPostingTypes
	dpt_Discounted                =1          # from enum BoDepositPostingTypes
	dtBOE                         =3          # from enum BoDepositTypeEnum
	dtCash                        =2          # from enum BoDepositTypeEnum
	dtChecks                      =0          # from enum BoDepositTypeEnum
	dtCredit                      =1          # from enum BoDepositTypeEnum
	dlt_Alternative               =1          # from enum BoDocLineType
	dlt_Regular                   =0          # from enum BoDocLineType
	dslt_Subtotal                 =1          # from enum BoDocSpecialLineType
	dslt_Text                     =0          # from enum BoDocSpecialLineType
	dByDocuments                  =2          # from enum BoDocSummaryTypes
	dByItems                      =1          # from enum BoDocSummaryTypes
	dNoSummary                    =0          # from enum BoDocSummaryTypes
	dwh_Consignment               =3          # from enum BoDocWhsUpdateTypes
	dwh_CustomerOrders            =2          # from enum BoDocWhsUpdateTypes
	dwh_No                        =0          # from enum BoDocWhsUpdateTypes
	dwh_OrdersFromVendors         =1          # from enum BoDocWhsUpdateTypes
	dwh_Stock                     =4          # from enum BoDocWhsUpdateTypes
	dlps_NotPicked                =1          # from enum BoDocumentLinePickStatus
	dlps_PartiallyPicked          =3          # from enum BoDocumentLinePickStatus
	dlps_Picked                   =0          # from enum BoDocumentLinePickStatus
	dlps_ReleasedForPicking       =2          # from enum BoDocumentLinePickStatus
	bod_Bill                      =3          # from enum BoDocumentSubType
	bod_DebitMemo                 =2          # from enum BoDocumentSubType
	bod_ExemptBill                =4          # from enum BoDocumentSubType
	bod_ExportInvoice             =6          # from enum BoDocumentSubType
	bod_InvoiceExempt             =1          # from enum BoDocumentSubType
	bod_None                      =0          # from enum BoDocumentSubType
	bod_PurchaseDebitMemo         =5          # from enum BoDocumentSubType
	dDocument_Items               =0          # from enum BoDocumentTypes
	dDocument_Service             =1          # from enum BoDocumentTypes
	boddDateOfPaymentRun          =0          # from enum BoDueDateEnum
	boddDueDateOfInvoice          =1          # from enum BoDueDateEnum
	boddPaymentTerms              =2          # from enum BoDueDateEnum
	du_Days                       =2          # from enum BoDurations
	du_Hours                      =1          # from enum BoDurations
	du_Minuts                     =0          # from enum BoDurations
	eeaIgnore                     =1          # from enum BoExtensionErrorActionEnum
	eeaPrompt                     =2          # from enum BoExtensionErrorActionEnum
	eeaStop                       =0          # from enum BoExtensionErrorActionEnum
	cDelivery_sum                 =1          # from enum BoFatherCardTypes
	cPayments_sum                 =0          # from enum BoFatherCardTypes
	db_Alpha                      =0          # from enum BoFieldTypes
	db_Date                       =3          # from enum BoFieldTypes
	db_Float                      =4          # from enum BoFieldTypes
	db_Memo                       =1          # from enum BoFieldTypes
	db_Numeric                    =2          # from enum BoFieldTypes
	st_Address                    =63         # from enum BoFldSubTypes
	st_Image                      =73         # from enum BoFldSubTypes
	st_Link                       =66         # from enum BoFldSubTypes
	st_Measurement                =77         # from enum BoFldSubTypes
	st_None                       =0          # from enum BoFldSubTypes
	st_Percentage                 =37         # from enum BoFldSubTypes
	st_Phone                      =35         # from enum BoFldSubTypes
	st_Price                      =80         # from enum BoFldSubTypes
	st_Quantity                   =81         # from enum BoFldSubTypes
	st_Rate                       =82         # from enum BoFldSubTypes
	st_Sum                        =83         # from enum BoFldSubTypes
	st_Time                       =84         # from enum BoFldSubTypes
	bofsaNone                     =0          # from enum BoFormattedSearchActionEnum
	bofsaQuery                    =2          # from enum BoFormattedSearchActionEnum
	bofsaValidValues              =1          # from enum BoFormattedSearchActionEnum
	bof_Annually                  =6          # from enum BoFrequency
	bof_Daily                     =0          # from enum BoFrequency
	bof_Every4Weeks               =2          # from enum BoFrequency
	bof_EveryXDays                =8          # from enum BoFrequency
	bof_HalfYearly                =5          # from enum BoFrequency
	bof_Monthly                   =3          # from enum BoFrequency
	bof_OneTime                   =7          # from enum BoFrequency
	bof_Quarterly                 =4          # from enum BoFrequency
	bof_Weekly                    =1          # from enum BoFrequency
	glm_ItemClass                 =1          # from enum BoGLMethods
	glm_ItemLevel                 =2          # from enum BoGLMethods
	glm_WH                        =0          # from enum BoGLMethods
	gt_Female                     =0          # from enum BoGenderTypes
	gt_Male                       =1          # from enum BoGenderTypes
	gt_Undefined                  =2          # from enum BoGenderTypes
	gtBrokenLine                  =2          # from enum BoGridTypeEnum
	gtCombination                 =0          # from enum BoGridTypeEnum
	gtContinuousLine              =1          # from enum BoGridTypeEnum
	gtDots                        =3          # from enum BoGridTypeEnum
	rlhjCentralized               =2          # from enum BoHorizontalAlignmentEnum
	rlhjLanguageDependent         =3          # from enum BoHorizontalAlignmentEnum
	rlhjLeft                      =1          # from enum BoHorizontalAlignmentEnum
	rlhjRight                     =0          # from enum BoHorizontalAlignmentEnum
	bis_FIFO                      =2          # from enum BoInventorySystem
	bis_MovingAverage             =0          # from enum BoInventorySystem
	bis_Standard                  =1          # from enum BoInventorySystem
	im_Backflush                  =0          # from enum BoIssueMethod
	im_Manual                     =1          # from enum BoIssueMethod
	iAssemblyTree                 =1          # from enum BoItemTreeTypes
	iIngredient                   =5          # from enum BoItemTreeTypes
	iNotATree                     =0          # from enum BoItemTreeTypes
	iProductionTree               =3          # from enum BoItemTreeTypes
	iSalesTree                    =2          # from enum BoItemTreeTypes
	iTemplateTree                 =4          # from enum BoItemTreeTypes
	rlsAdjustToCell               =1          # from enum BoLineBreakEnum
	rlsAllowOverflow              =0          # from enum BoLineBreakEnum
	rlsDivideIntoRows             =2          # from enum BoLineBreakEnum
	bomm_OnEveryTransaction       =0          # from enum BoManageMethod
	bomm_OnReleaseOnly            =1          # from enum BoManageMethod
	mt_ConsumerMaterial           =7          # from enum BoMaterialTypes
	mt_FinishedGoods              =1          # from enum BoMaterialTypes
	mt_FixedAsset                 =8          # from enum BoMaterialTypes
	mt_GoodsForReseller           =0          # from enum BoMaterialTypes
	mt_GoodsInProcess             =2          # from enum BoMaterialTypes
	mt_IntermediateMaterial       =6          # from enum BoMaterialTypes
	mt_Other                      =99         # from enum BoMaterialTypes
	mt_OtherInput                 =10         # from enum BoMaterialTypes
	mt_Package                    =4          # from enum BoMaterialTypes
	mt_RawMaterial                =3          # from enum BoMaterialTypes
	mt_Service                    =9          # from enum BoMaterialTypes
	mt_SubProduct                 =5          # from enum BoMaterialTypes
	mts_Divorced                  =2          # from enum BoMeritalStatuses
	mts_Married                   =1          # from enum BoMeritalStatuses
	mts_Single                    =0          # from enum BoMeritalStatuses
	mts_Widowed                   =3          # from enum BoMeritalStatuses
	mpt_Measure                   =5          # from enum BoMoneyPrecisionTypes
	mpt_Percent                   =4          # from enum BoMoneyPrecisionTypes
	mpt_Price                     =1          # from enum BoMoneyPrecisionTypes
	mpt_Quantity                  =3          # from enum BoMoneyPrecisionTypes
	mpt_Rate                      =2          # from enum BoMoneyPrecisionTypes
	mpt_Sum                       =0          # from enum BoMoneyPrecisionTypes
	mpt_Tax                       =6          # from enum BoMoneyPrecisionTypes
	pr_High                       =2          # from enum BoMsgPriorities
	pr_Low                        =0          # from enum BoMsgPriorities
	pr_Normal                     =1          # from enum BoMsgPriorities
	rt_ContactPerson              =11         # from enum BoMsgRcpTypes
	rt_InternalUser               =12         # from enum BoMsgRcpTypes
	rt_RandomUser                 =-1         # from enum BoMsgRcpTypes
	bopt_Electronic               =1          # from enum BoORCTPaymentTypeEnum
	bopt_Express                  =4          # from enum BoORCTPaymentTypeEnum
	bopt_None                     =0          # from enum BoORCTPaymentTypeEnum
	bopt_Post                     =2          # from enum BoORCTPaymentTypeEnum
	bopt_Telegraph                =3          # from enum BoORCTPaymentTypeEnum
	BoBridge                      =305        # from enum BoObjectTypes
	BoRecordset                   =300        # from enum BoObjectTypes
	oAccountSegmentationCategories=143        # from enum BoObjectTypes
	oAccountSegmentations         =142        # from enum BoObjectTypes
	oActivityLocations            =104        # from enum BoObjectTypes
	oActivityStatus               =217        # from enum BoObjectTypes
	oActivityTypes                =103        # from enum BoObjectTypes
	oAdditionalExpenses           =125        # from enum BoObjectTypes
	oAlternateCatNum              =73         # from enum BoObjectTypes
	oAttachments2                 =221        # from enum BoObjectTypes
	oBPFiscalRegistryID           =278        # from enum BoObjectTypes
	oBPPriorities                 =150        # from enum BoObjectTypes
	oBankPages                    =42         # from enum BoObjectTypes
	oBanks                        =3          # from enum BoObjectTypes
	oBillOfExchangeTransactions   =182        # from enum BoObjectTypes
	oBudget                       =77         # from enum BoObjectTypes
	oBudgetDistribution           =78         # from enum BoObjectTypes
	oBudgetScenarios              =91         # from enum BoObjectTypes
	oBusinessPartnerGroups        =10         # from enum BoObjectTypes
	oBusinessPartners             =2          # from enum BoObjectTypes
	oBusinessPlaces               =247        # from enum BoObjectTypes
	oChartOfAccounts              =1          # from enum BoObjectTypes
	oChecksforPayment             =57         # from enum BoObjectTypes
	oChooseFromList               =218        # from enum BoObjectTypes
	oClosingDateProcedure         =261        # from enum BoObjectTypes
	oCommissionGroups             =65         # from enum BoObjectTypes
	oContacts                     =33         # from enum BoObjectTypes
	oContractTemplates            =170        # from enum BoObjectTypes
	oCorrectionInvoice            =165        # from enum BoObjectTypes
	oCorrectionInvoiceReversal    =166        # from enum BoObjectTypes
	oCorrectionPurchaseInvoice    =163        # from enum BoObjectTypes
	oCorrectionPurchaseInvoiceReversal=164        # from enum BoObjectTypes
	oCreditCardPayments           =71         # from enum BoObjectTypes
	oCreditCards                  =36         # from enum BoObjectTypes
	oCreditNotes                  =14         # from enum BoObjectTypes
	oCreditPaymentMethods         =70         # from enum BoObjectTypes
	oCurrencyCodes                =37         # from enum BoObjectTypes
	oCustomerEquipmentCards       =176        # from enum BoObjectTypes
	oCustomsGroups                =56         # from enum BoObjectTypes
	oDeductionTaxGroups           =117        # from enum BoObjectTypes
	oDeductionTaxHierarchies      =116        # from enum BoObjectTypes
	oDeliveryNotes                =15         # from enum BoObjectTypes
	oDownPayments                 =203        # from enum BoObjectTypes
	oDrafts                       =112        # from enum BoObjectTypes
	oDunningLetters               =151        # from enum BoObjectTypes
	oDynamicSystemStrings         =229        # from enum BoObjectTypes
	oEmployeesInfo                =171        # from enum BoObjectTypes
	oFactoringIndicators          =138        # from enum BoObjectTypes
	oFormattedSearches            =219        # from enum BoObjectTypes
	oForms1099                    =145        # from enum BoObjectTypes
	oHouseBankAccounts            =231        # from enum BoObjectTypes
	oIncomingPayments             =24         # from enum BoObjectTypes
	oIndustries                   =201        # from enum BoObjectTypes
	oInventoryCycles              =146        # from enum BoObjectTypes
	oInventoryGenEntry            =59         # from enum BoObjectTypes
	oInventoryGenExit             =60         # from enum BoObjectTypes
	oInventoryTransferRequest     =1250000001 # from enum BoObjectTypes
	oInvoices                     =13         # from enum BoObjectTypes
	oItemGroups                   =52         # from enum BoObjectTypes
	oItemProperties               =8          # from enum BoObjectTypes
	oItems                        =4          # from enum BoObjectTypes
	oJournalEntries               =30         # from enum BoObjectTypes
	oJournalVouchers              =28         # from enum BoObjectTypes
	oKnowledgeBaseSolutions       =189        # from enum BoObjectTypes
	oLandedCostsCodes             =48         # from enum BoObjectTypes
	oLengthMeasures               =50         # from enum BoObjectTypes
	oLocalEra                     =250        # from enum BoObjectTypes
	oManufacturers                =43         # from enum BoObjectTypes
	oMaterialRevaluation          =162        # from enum BoObjectTypes
	oMessages                     =81         # from enum BoObjectTypes
	oMultiLanguageTranslations    =224        # from enum BoObjectTypes
	oNotaFiscalCFOP               =258        # from enum BoObjectTypes
	oNotaFiscalCST                =259        # from enum BoObjectTypes
	oNotaFiscalUsage              =260        # from enum BoObjectTypes
	oOrders                       =17         # from enum BoObjectTypes
	oPackagesTypes                =205        # from enum BoObjectTypes
	oPaymentRunExport             =158        # from enum BoObjectTypes
	oPaymentTermsTypes            =40         # from enum BoObjectTypes
	oPaymentsDrafts               =140        # from enum BoObjectTypes
	oPickLists                    =156        # from enum BoObjectTypes
	oPriceLists                   =6          # from enum BoObjectTypes
	oProductTrees                 =66         # from enum BoObjectTypes
	oProductionOrders             =202        # from enum BoObjectTypes
	oPurchaseCreditNotes          =19         # from enum BoObjectTypes
	oPurchaseDeliveryNotes        =20         # from enum BoObjectTypes
	oPurchaseDownPayments         =204        # from enum BoObjectTypes
	oPurchaseInvoices             =18         # from enum BoObjectTypes
	oPurchaseOrders               =22         # from enum BoObjectTypes
	oPurchaseQuotations           =540000006  # from enum BoObjectTypes
	oPurchaseReturns              =21         # from enum BoObjectTypes
	oPurchaseTaxInvoice           =281        # from enum BoObjectTypes
	oQueryCategories              =134        # from enum BoObjectTypes
	oQueue                        =194        # from enum BoObjectTypes
	oQuotations                   =23         # from enum BoObjectTypes
	oRelationships                =212        # from enum BoObjectTypes
	oReturns                      =16         # from enum BoObjectTypes
	oSalesForecast                =198        # from enum BoObjectTypes
	oSalesOpportunities           =97         # from enum BoObjectTypes
	oSalesPersons                 =53         # from enum BoObjectTypes
	oSalesStages                  =101        # from enum BoObjectTypes
	oSalesTaxAuthorities          =126        # from enum BoObjectTypes
	oSalesTaxAuthoritiesTypes     =127        # from enum BoObjectTypes
	oSalesTaxCodes                =128        # from enum BoObjectTypes
	oSalesTaxInvoice              =280        # from enum BoObjectTypes
	oServiceCalls                 =191        # from enum BoObjectTypes
	oServiceContracts             =190        # from enum BoObjectTypes
	oShippingTypes                =49         # from enum BoObjectTypes
	oSpecialPrices                =7          # from enum BoObjectTypes
	oStockTakings                 =31         # from enum BoObjectTypes
	oStockTransfer                =67         # from enum BoObjectTypes
	oStockTransferDraft           =1179       # from enum BoObjectTypes
	oTeams                        =211        # from enum BoObjectTypes
	oTerritories                  =200        # from enum BoObjectTypes
	oUserDefaultGroups            =93         # from enum BoObjectTypes
	oUserFields                   =152        # from enum BoObjectTypes
	oUserKeys                     =193        # from enum BoObjectTypes
	oUserLanguages                =223        # from enum BoObjectTypes
	oUserObjectsMD                =206        # from enum BoObjectTypes
	oUserPermissionTree           =214        # from enum BoObjectTypes
	oUserQueries                  =160        # from enum BoObjectTypes
	oUserTables                   =153        # from enum BoObjectTypes
	oUsers                        =12         # from enum BoObjectTypes
	oVatGroups                    =5          # from enum BoObjectTypes
	oVendorPayments               =46         # from enum BoObjectTypes
	oWarehouseLocations           =144        # from enum BoObjectTypes
	oWarehouses                   =64         # from enum BoObjectTypes
	oWeightMeasures               =51         # from enum BoObjectTypes
	oWithholdingTaxCodes          =178        # from enum BoObjectTypes
	oWizardPaymentMethods         =147        # from enum BoObjectTypes
	oWorkOrders                   =68         # from enum BoObjectTypes
	oip_BankTransfer              =4          # from enum BoOpenIncPayment
	oip_Cash                      =1          # from enum BoOpenIncPayment
	oip_Checks                    =2          # from enum BoOpenIncPayment
	oip_Credit                    =3          # from enum BoOpenIncPayment
	oip_No                        =0          # from enum BoOpenIncPayment
	bos_Close                     =1          # from enum BoOpexStatus
	bos_Open                      =0          # from enum BoOpexStatus
	ortHorizontal                 =1          # from enum BoOrientationEnum
	ortVertical                   =0          # from enum BoOrientationEnum
	pdt_HalfMonth                 =1          # from enum BoPayTermDueTypes
	pdt_MonthEnd                  =0          # from enum BoPayTermDueTypes
	pdt_MonthStart                =2          # from enum BoPayTermDueTypes
	pdt_None                      =3          # from enum BoPayTermDueTypes
	bopmBankTransfer              =1          # from enum BoPaymentMeansEnum
	bopmBillOfExchange            =2          # from enum BoPaymentMeansEnum
	bopmCheck                     =0          # from enum BoPaymentMeansEnum
	bopp_Priority_1               =0          # from enum BoPaymentPriorities
	bopp_Priority_2               =1          # from enum BoPaymentPriorities
	bopp_Priority_3               =2          # from enum BoPaymentPriorities
	bopp_Priority_4               =3          # from enum BoPaymentPriorities
	bopp_Priority_5               =4          # from enum BoPaymentPriorities
	bopp_Priority_6               =5          # from enum BoPaymentPriorities
	boptIncoming                  =0          # from enum BoPaymentTypeEnum
	boptOutgoing                  =1          # from enum BoPaymentTypeEnum
	bopot_IncomingPayments        =0          # from enum BoPaymentsObjectType
	bopot_OutgoingPayments        =1          # from enum BoPaymentsObjectType
	boper_Full                    =1          # from enum BoPermission
	boper_None                    =3          # from enum BoPermission
	boper_ReadOnly                =2          # from enum BoPermission
	boper_Undefined               =6          # from enum BoPermission
	boper_Various                 =4          # from enum BoPermission
	ps_Closed                     =4          # from enum BoPickStatus
	ps_PartiallyDelivered         =3          # from enum BoPickStatus
	ps_PartiallyPicked            =2          # from enum BoPickStatus
	ps_Picked                     =1          # from enum BoPickStatus
	ps_Released                   =0          # from enum BoPickStatus
	rlpsFitFieldHeight            =3          # from enum BoPictureSizeEnum
	rlpsFitFieldSizeNonProportionally=1          # from enum BoPictureSizeEnum
	rlpsFitFieldSizeProportionally=2          # from enum BoPictureSizeEnum
	rlpsFitFieldWidth             =4          # from enum BoPictureSizeEnum
	rlpsOriginalSize              =0          # from enum BoPictureSizeEnum
	bop_MRP                       =0          # from enum BoPlanningSystem
	bop_None                      =1          # from enum BoPlanningSystem
	boplgn_Group1                 =0          # from enum BoPriceListGroupNum
	boplgn_Group2                 =1          # from enum BoPriceListGroupNum
	boplgn_Group3                 =2          # from enum BoPriceListGroupNum
	boplgn_Group4                 =3          # from enum BoPriceListGroupNum
	boprcAlways                   =0          # from enum BoPrintReceiptEnum
	boprcNo                       =2          # from enum BoPrintReceiptEnum
	boprcOnlyWhenAdding           =1          # from enum BoPrintReceiptEnum
	bom_Buy                       =0          # from enum BoProcurementMethod
	bom_Make                      =1          # from enum BoProcurementMethod
	bps_ImportedByCompany         =2          # from enum BoProductSources
	bps_ImportedGoodsPurchasedFromDomVendor=3          # from enum BoProductSources
	bps_ProducedByCompany         =4          # from enum BoProductSources
	bps_PurchasedFromDomVendor    =1          # from enum BoProductSources
	bopooMRP                      =1          # from enum BoProductionOrderOriginEnum
	bopooManual                   =0          # from enum BoProductionOrderOriginEnum
	bopooSalesOrder               =2          # from enum BoProductionOrderOriginEnum
	boposCancelled                =3          # from enum BoProductionOrderStatusEnum
	boposClosed                   =2          # from enum BoProductionOrderStatusEnum
	boposPlanned                  =0          # from enum BoProductionOrderStatusEnum
	boposReleased                 =1          # from enum BoProductionOrderStatusEnum
	bopotDisassembly              =2          # from enum BoProductionOrderTypeEnum
	bopotSpecial                  =1          # from enum BoProductionOrderTypeEnum
	bopotStandard                 =0          # from enum BoProductionOrderTypeEnum
	bqc_Equal                     =0          # from enum BoQueryConditions
	bqc_Like                      =2          # from enum BoQueryConditions
	bqc_NotEqual                  =1          # from enum BoQueryConditions
	qtRegular                     =0          # from enum BoQueryTypeEnum
	qtWizard                      =1          # from enum BoQueryTypeEnum
	cr_InternetTransaction        =2          # from enum BoRcptCredTypes
	cr_Regular                    =0          # from enum BoRcptCredTypes
	cr_Telephone                  =1          # from enum BoRcptCredTypes
	it_APCorrectionInvoice        =163        # from enum BoRcptInvTypes
	it_ARCorrectionInvoice        =165        # from enum BoRcptInvTypes
	it_AllTransactions            =-1         # from enum BoRcptInvTypes
	it_ChequesForPayment          =57         # from enum BoRcptInvTypes
	it_ClosingBalance             =-3         # from enum BoRcptInvTypes
	it_CorrectionInvoice          =132        # from enum BoRcptInvTypes
	it_CredItnote                 =14         # from enum BoRcptInvTypes
	it_DeferredDeposit            =76         # from enum BoRcptInvTypes
	it_Deposit                    =25         # from enum BoRcptInvTypes
	it_DownPayment                =203        # from enum BoRcptInvTypes
	it_GeneralReceiptToStock      =59         # from enum BoRcptInvTypes
	it_GeneralReleaseFromStock    =60         # from enum BoRcptInvTypes
	it_Invoice                    =13         # from enum BoRcptInvTypes
	it_JournalEntry               =30         # from enum BoRcptInvTypes
	it_OpeningBalance             =-2         # from enum BoRcptInvTypes
	it_PaymentAdvice              =46         # from enum BoRcptInvTypes
	it_PurchaseCreditNote         =19         # from enum BoRcptInvTypes
	it_PurchaseDeliveryNote       =20         # from enum BoRcptInvTypes
	it_PurchaseDownPayment        =204        # from enum BoRcptInvTypes
	it_PurchaseInvoice            =18         # from enum BoRcptInvTypes
	it_PurchaseReturn             =21         # from enum BoRcptInvTypes
	it_Receipt                    =24         # from enum BoRcptInvTypes
	it_Return                     =16         # from enum BoRcptInvTypes
	it_StockReconciliations       =58         # from enum BoRcptInvTypes
	it_TaxInvoice                 =15         # from enum BoRcptInvTypes
	it_TransferBetweenWarehouses  =67         # from enum BoRcptInvTypes
	it_WorkInstructions           =68         # from enum BoRcptInvTypes
	rAccount                      =1          # from enum BoRcptTypes
	rCustomer                     =0          # from enum BoRcptTypes
	rSupplier                     =2          # from enum BoRcptTypes
	rcpt_In                       =0          # from enum BoRecCommParamTypes
	rcpt_Out                      =1          # from enum BoRecCommParamTypes
	reu_Days                      =0          # from enum BoRemindUnits
	reu_Month                     =2          # from enum BoRemindUnits
	reu_Weeks                     =1          # from enum BoRemindUnits
	rlitEndOfReport               =5          # from enum BoReportLayoutItemTypeEnum
	rlitPageFooter                =6          # from enum BoReportLayoutItemTypeEnum
	rlitPageHeader                =0          # from enum BoReportLayoutItemTypeEnum
	rlitPictureField              =8          # from enum BoReportLayoutItemTypeEnum
	rlitRepetitiveArea            =3          # from enum BoReportLayoutItemTypeEnum
	rlitRepetitiveAreaFooter      =4          # from enum BoReportLayoutItemTypeEnum
	rlitRepetitiveAreaHeader      =2          # from enum BoReportLayoutItemTypeEnum
	rlitStartOfReport             =1          # from enum BoReportLayoutItemTypeEnum
	rlitTextField                 =7          # from enum BoReportLayoutItemTypeEnum
	rlitUserField                 =9          # from enum BoReportLayoutItemTypeEnum
	rsu_Days                      =0          # from enum BoResolutionUnits
	rsu_Hours                     =1          # from enum BoResolutionUnits
	boru_Day                      =1          # from enum BoResponseUnit
	boru_Hour                     =0          # from enum BoResponseUnit
	borit_Leader                  =1          # from enum BoRoleInTeam
	borit_Member                  =0          # from enum BoRoleInTeam
	borm_NoRounding               =0          # from enum BoRoundingMethod
	borm_RoundToFullAmount        =2          # from enum BoRoundingMethod
	borm_RoundToFullDecAmount     =1          # from enum BoRoundingMethod
	borm_RoundToFullTensAmount    =3          # from enum BoRoundingMethod
	scu_Biweekly                  =6          # from enum BoSalaryCostUnits
	scu_Day                       =1          # from enum BoSalaryCostUnits
	scu_Hour                      =0          # from enum BoSalaryCostUnits
	scu_Month                     =3          # from enum BoSalaryCostUnits
	scu_Semimonthly               =5          # from enum BoSalaryCostUnits
	scu_Week                      =2          # from enum BoSalaryCostUnits
	scu_Year                      =4          # from enum BoSalaryCostUnits
	sns_Active                    =0          # from enum BoSerialNumberStatus
	sns_InLab                     =4          # from enum BoSerialNumberStatus
	sns_Loaned                    =3          # from enum BoSerialNumberStatus
	sns_Returned                  =1          # from enum BoSerialNumberStatus
	sns_Terminated                =2          # from enum BoSerialNumberStatus
	sg_Group1                     =1          # from enum BoSeriesGroupEnum
	sg_Group10                    =10         # from enum BoSeriesGroupEnum
	sg_Group2                     =2          # from enum BoSeriesGroupEnum
	sg_Group3                     =3          # from enum BoSeriesGroupEnum
	sg_Group4                     =4          # from enum BoSeriesGroupEnum
	sg_Group5                     =5          # from enum BoSeriesGroupEnum
	sg_Group6                     =6          # from enum BoSeriesGroupEnum
	sg_Group7                     =7          # from enum BoSeriesGroupEnum
	sg_Group8                     =8          # from enum BoSeriesGroupEnum
	sg_Group9                     =9          # from enum BoSeriesGroupEnum
	stBusinessPartner             =1          # from enum BoSeriesTypeEnum
	stDocument                    =0          # from enum BoSeriesTypeEnum
	stItem                        =2          # from enum BoSeriesTypeEnum
	bst_Regular                   =0          # from enum BoServiceTypes
	bst_Warranty                  =1          # from enum BoServiceTypes
	sos_Days                      =2          # from enum BoSoClosedInTypes
	sos_Months                    =0          # from enum BoSoClosedInTypes
	sos_Weeks                     =1          # from enum BoSoClosedInTypes
	sos_Missed                    =1          # from enum BoSoOsStatus
	sos_Open                      =0          # from enum BoSoOsStatus
	sos_Sold                      =2          # from enum BoSoOsStatus
	so_Closed                     =1          # from enum BoSoStatus
	so_Open                       =0          # from enum BoSoStatus
	rlstAlpha                     =0          # from enum BoSortTypeEnum
	rlstDate                      =3          # from enum BoSortTypeEnum
	rlstMoney                     =2          # from enum BoSortTypeEnum
	rlstNumeric                   =1          # from enum BoSortTypeEnum
	bost_Close                    =1          # from enum BoStatus
	bost_Delivered                =3          # from enum BoStatus
	bost_Open                     =0          # from enum BoStatus
	bost_Paid                     =2          # from enum BoStatus
	bos_TransferFromTechnician    =1          # from enum BoStckTrnDir
	bos_TransferToTechnician      =0          # from enum BoStckTrnDir
	spt_Days                      =3          # from enum BoSubPeriodTypeEnum
	spt_Months                    =2          # from enum BoSubPeriodTypeEnum
	spt_Quarters                  =1          # from enum BoSubPeriodTypeEnum
	spt_Year                      =0          # from enum BoSubPeriodTypeEnum
	ln_Arabic                     =32         # from enum BoSuppLangs
	ln_Chinese                    =15         # from enum BoSuppLangs
	ln_Czech_Cz                   =26         # from enum BoSuppLangs
	ln_Danish                     =11         # from enum BoSuppLangs
	ln_Dutch                      =16         # from enum BoSuppLangs
	ln_English                    =3          # from enum BoSuppLangs
	ln_English_Cy                 =21         # from enum BoSuppLangs
	ln_English_Gb                 =8          # from enum BoSuppLangs
	ln_English_Sg                 =6          # from enum BoSuppLangs
	ln_Finnish                    =17         # from enum BoSuppLangs
	ln_French                     =22         # from enum BoSuppLangs
	ln_German                     =9          # from enum BoSuppLangs
	ln_Greek                      =18         # from enum BoSuppLangs
	ln_Hebrew                     =1          # from enum BoSuppLangs
	ln_Hungarian                  =14         # from enum BoSuppLangs
	ln_Italian                    =13         # from enum BoSuppLangs
	ln_Japanese_Jp                =30         # from enum BoSuppLangs
	ln_Korean_Kr                  =28         # from enum BoSuppLangs
	ln_Norwegian                  =12         # from enum BoSuppLangs
	ln_Polish                     =5          # from enum BoSuppLangs
	ln_Portuguese                 =19         # from enum BoSuppLangs
	ln_Portuguese_Br              =29         # from enum BoSuppLangs
	ln_Russian                    =24         # from enum BoSuppLangs
	ln_Serbian                    =10         # from enum BoSuppLangs
	ln_Slovak_Sk                  =27         # from enum BoSuppLangs
	ln_Spanish                    =23         # from enum BoSuppLangs
	ln_Spanish_Ar                 =2          # from enum BoSuppLangs
	ln_Spanish_La                 =25         # from enum BoSuppLangs
	ln_Spanish_Pa                 =7          # from enum BoSuppLangs
	ln_Swedish                    =20         # from enum BoSuppLangs
	ln_TrdtnlChinese_Hk           =35         # from enum BoSuppLangs
	ln_Turkish_Tr                 =31         # from enum BoSuppLangs
	scp_High                      =2          # from enum BoSvcCallPriorities
	scp_Low                       =0          # from enum BoSvcCallPriorities
	scp_Medium                    =1          # from enum BoSvcCallPriorities
	scs_Approved                  =0          # from enum BoSvcContractStatus
	scs_Draft                     =2          # from enum BoSvcContractStatus
	scs_Frozen                    =1          # from enum BoSvcContractStatus
	scs_Terminated                =3          # from enum BoSvcContractStatus
	edt_CreditMemo                =14         # from enum BoSvcEpxDocTypes
	edt_Delivery                  =15         # from enum BoSvcEpxDocTypes
	edt_Invoice                   =13         # from enum BoSvcEpxDocTypes
	edt_Order                     =17         # from enum BoSvcEpxDocTypes
	edt_Return                    =16         # from enum BoSvcEpxDocTypes
	edt_StockTransfer             =67         # from enum BoSvcEpxDocTypes
	sep_Inventory                 =0          # from enum BoSvcExpPartTypes
	sep_NonInventory              =1          # from enum BoSvcExpPartTypes
	tcdcBusinessPartner           =11         # from enum BoTCDConditionEnum
	tcdcCustomerEquTax            =16         # from enum BoTCDConditionEnum
	tcdcCustomerGroup             =12         # from enum BoTCDConditionEnum
	tcdcFederalTaxID              =1          # from enum BoTCDConditionEnum
	tcdcFreight                   =18         # from enum BoTCDConditionEnum
	tcdcGLAccount                 =15         # from enum BoTCDConditionEnum
	tcdcItem                      =9          # from enum BoTCDConditionEnum
	tcdcItemGroup                 =10         # from enum BoTCDConditionEnum
	tcdcNone                      =0          # from enum BoTCDConditionEnum
	tcdcShipToAddress             =2          # from enum BoTCDConditionEnum
	tcdcShipToCity                =4          # from enum BoTCDConditionEnum
	tcdcShipToCountry             =8          # from enum BoTCDConditionEnum
	tcdcShipToCounty              =6          # from enum BoTCDConditionEnum
	tcdcShipToState               =7          # from enum BoTCDConditionEnum
	tcdcShipToStreePOBox          =3          # from enum BoTCDConditionEnum
	tcdcShipToZipCode             =5          # from enum BoTCDConditionEnum
	tcdcTaxStatus                 =17         # from enum BoTCDConditionEnum
	tcdcUDF                       =19         # from enum BoTCDConditionEnum
	tcdcVendorGroup               =13         # from enum BoTCDConditionEnum
	tcdcWarehouse                 =14         # from enum BoTCDConditionEnum
	tcddtItem                     =0          # from enum BoTCDDocumentTypeEnum
	tcddtItemAndService           =2          # from enum BoTCDDocumentTypeEnum
	tcddtService                  =1          # from enum BoTCDDocumentTypeEnum
	botit_AlterationCorrectionInvoice=6          # from enum BoTaxInvoiceTypes
	botit_AlterationInvoice       =5          # from enum BoTaxInvoiceTypes
	botit_CorrectionInvoice       =3          # from enum BoTaxInvoiceTypes
	botit_DownPayment             =4          # from enum BoTaxInvoiceTypes
	botit_Invoice                 =0          # from enum BoTaxInvoiceTypes
	botit_JournalEntry            =2          # from enum BoTaxInvoiceTypes
	botit_Payment                 =1          # from enum BoTaxInvoiceTypes
	tpa_Default                   =0          # from enum BoTaxPostAccEnum
	tpa_PurchaseTaxAccount        =2          # from enum BoTaxPostAccEnum
	tpa_SalesTaxAccount           =1          # from enum BoTaxPostAccEnum
	trr_CompanyDefault            =3          # from enum BoTaxRoundingRuleTypes
	trr_RoundDown                 =0          # from enum BoTaxRoundingRuleTypes
	trr_RoundOff                  =2          # from enum BoTaxRoundingRuleTypes
	trr_RoundUp                   =1          # from enum BoTaxRoundingRuleTypes
	tt_No                         =1          # from enum BoTaxTypes
	tt_OffsetTax                  =3          # from enum BoTaxTypes
	tt_UseTax                     =2          # from enum BoTaxTypes
	tt_Yes                        =0          # from enum BoTaxTypes
	tt_12H                        =1          # from enum BoTimeTemplate
	tt_24H                        =0          # from enum BoTimeTemplate
	botrntComplete                =0          # from enum BoTransactionTypeEnum
	botrntReject                  =1          # from enum BoTransactionTypeEnum
	boud_Document                 =3          # from enum BoUDOObjType
	boud_MasterData               =1          # from enum BoUDOObjType
	bou_FullNone                  =1          # from enum BoUPTOptions
	bou_FullReadNone              =0          # from enum BoUPTOptions
	bott_Document                 =3          # from enum BoUTBTableType
	bott_DocumentLines            =4          # from enum BoUTBTableType
	bott_MasterData               =1          # from enum BoUTBTableType
	bott_MasterDataLines          =2          # from enum BoUTBTableType
	bott_NoObject                 =0          # from enum BoUTBTableType
	usn_LotNumber                 =3          # from enum BoUniqueSerialNumber
	usn_MfrSerialNumber           =1          # from enum BoUniqueSerialNumber
	usn_None                      =0          # from enum BoUniqueSerialNumber
	usn_SerialNumber              =2          # from enum BoUniqueSerialNumber
	ug_Deleted                    =1          # from enum BoUserGroup
	ug_Regular                    =0          # from enum BoUserGroup
	bovcInputTax                  =1          # from enum BoVatCategoryEnum
	bovcOutputTax                 =0          # from enum BoVatCategoryEnum
	vEC                           =2          # from enum BoVatStatus
	vExempted                     =0          # from enum BoVatStatus
	vLiable                       =1          # from enum BoVatStatus
	rlvaBottom                    =1          # from enum BoVerticalAlignmentEnum
	rlvaCentralized               =2          # from enum BoVerticalAlignmentEnum
	rlvaTop                       =0          # from enum BoVerticalAlignmentEnum
	wf_Commit                     =0          # from enum BoWfTransOpt
	wf_RollBack                   =1          # from enum BoWfTransOpt
	wk_ProductComplete            =2          # from enum BoWorkOrderStat
	wk_WorkInstruction            =1          # from enum BoWorkOrderStat
	wk_WorkOrder                  =0          # from enum BoWorkOrderStat
	xet_AllNodes                  =0          # from enum BoXmlExportTypes
	xet_ExportImportMode          =3          # from enum BoXmlExportTypes
	xet_NodesAsProperties         =2          # from enum BoXmlExportTypes
	xet_ValidNodesOnly            =1          # from enum BoXmlExportTypes
	tNO                           =0          # from enum BoYesNoEnum
	tYES                          =1          # from enum BoYesNoEnum
	bsBranch                      =0          # from enum BranchesServiceDataInterfaces
	bsBranchParams                =2          # from enum BranchesServiceDataInterfaces
	bsBranchesParams              =1          # from enum BranchesServiceDataInterfaces
	bbisBrazilBeverageIndexer     =0          # from enum BrazilBeverageIndexersServiceDataInterfaces
	bbisBrazilBeverageIndexerParams=2          # from enum BrazilBeverageIndexersServiceDataInterfaces
	bbisBrazilBeverageIndexersParams=1          # from enum BrazilBeverageIndexersServiceDataInterfaces
	bfisBrazilFuelIndexer         =0          # from enum BrazilFuelIndexersServiceDataInterfaces
	bfisBrazilFuelIndexerParams   =2          # from enum BrazilFuelIndexersServiceDataInterfaces
	bfisBrazilFuelIndexersParams  =1          # from enum BrazilFuelIndexersServiceDataInterfaces
	bitMulti                      =3          # from enum BrazilIndexerTypes
	bitNumeric                    =1          # from enum BrazilIndexerTypes
	bitString                     =2          # from enum BrazilIndexerTypes
	bitUnknown                    =0          # from enum BrazilIndexerTypes
	bmitIncomeNature              =1          # from enum BrazilMultiIndexerTypes
	bmitInvalid                   =0          # from enum BrazilMultiIndexerTypes
	bmisBrazilMultiIndexer        =0          # from enum BrazilMultiIndexersServiceDataInterfaces
	bmisBrazilMultiIndexerParams  =2          # from enum BrazilMultiIndexersServiceDataInterfaces
	bmisBrazilMultiIndexersParams =1          # from enum BrazilMultiIndexersServiceDataInterfaces
	bnitBeverageCommercialBrand   =1          # from enum BrazilNumericIndexerTypes
	bnitCompanyQualification      =7          # from enum BrazilNumericIndexerTypes
	bnitCooperativeAssociationType=5          # from enum BrazilNumericIndexerTypes
	bnitDeclarerType              =8          # from enum BrazilNumericIndexerTypes
	bnitEconomicActivityType      =4          # from enum BrazilNumericIndexerTypes
	bnitEnvironmentType           =9          # from enum BrazilNumericIndexerTypes
	bnitExportationDocumentType   =14         # from enum BrazilNumericIndexerTypes
	bnitExportationNature         =15         # from enum BrazilNumericIndexerTypes
	bnitFuelGroup                 =2          # from enum BrazilNumericIndexerTypes
	bnitIncomeNatureCode          =13         # from enum BrazilNumericIndexerTypes
	bnitIncomeNatureTable         =12         # from enum BrazilNumericIndexerTypes
	bnitInvalid                   =0          # from enum BrazilNumericIndexerTypes
	bnitLadingBillType            =16         # from enum BrazilNumericIndexerTypes
	bnitNatureOfCompany           =3          # from enum BrazilNumericIndexerTypes
	bnitProfitTaxation            =6          # from enum BrazilNumericIndexerTypes
	bnitTributaryRegimeCode       =11         # from enum BrazilNumericIndexerTypes
	bnitTributaryType             =10         # from enum BrazilNumericIndexerTypes
	bnisBrazilNumericIndexer      =0          # from enum BrazilNumericIndexersServiceDataInterfaces
	bnisBrazilNumericIndexerParams=2          # from enum BrazilNumericIndexersServiceDataInterfaces
	bnisBrazilNumericIndexersParams=1          # from enum BrazilNumericIndexersServiceDataInterfaces
	bsitBeverageGroup             =4          # from enum BrazilStringIndexerTypes
	bsitBeverageTable             =1          # from enum BrazilStringIndexerTypes
	bsitCreditContributionOrigin  =5          # from enum BrazilStringIndexerTypes
	bsitCreditOrigin              =3          # from enum BrazilStringIndexerTypes
	bsitIPIPeriod                 =6          # from enum BrazilStringIndexerTypes
	bsitImportationDocumentType   =8          # from enum BrazilStringIndexerTypes
	bsitInvalid                   =0          # from enum BrazilStringIndexerTypes
	bsitNatureOfCalculationBase   =2          # from enum BrazilStringIndexerTypes
	bsitSPEDProfile               =7          # from enum BrazilStringIndexerTypes
	bsisBrazilStringIndexer       =0          # from enum BrazilStringIndexersServiceDataInterfaces
	bsisBrazilStringIndexerParams =2          # from enum BrazilStringIndexersServiceDataInterfaces
	bsisBrazilStringIndexersParams=1          # from enum BrazilStringIndexersServiceDataInterfaces
	bppsBusinessPartnerPropertiesParams=1          # from enum BusinessPartnerPropertiesServiceDataInterfaces
	bppsBusinessPartnerProperty   =0          # from enum BusinessPartnerPropertiesServiceDataInterfaces
	bppsBusinessPartnerPropertyParams=2          # from enum BusinessPartnerPropertiesServiceDataInterfaces
	bpsdiBPCodes                  =1          # from enum BusinessPartnersServiceDataInterfaces
	bpsdiOpenningBalanceAccount   =0          # from enum BusinessPartnersServiceDataInterfaces
	cimOnOriginalSum              =1          # from enum CalculateInterestMethodEnum
	cimOnRemainingAmount          =0          # from enum CalculateInterestMethodEnum
	cmsRead                       =1          # from enum CallMessageStatusEnum
	cmsUnread                     =0          # from enum CallMessageStatusEnum
	cmtError                      =2          # from enum CallMessageTypeEnum
	cmtInformation                =0          # from enum CallMessageTypeEnum
	cmtWarning                    =1          # from enum CallMessageTypeEnum
	citItems                      =0          # from enum CampaignItemTypeEnum
	citLabel                      =1          # from enum CampaignItemTypeEnum
	citTravel                     =2          # from enum CampaignItemTypeEnum
	csCanceled                    =2          # from enum CampaignStatusEnum
	csFinished                    =1          # from enum CampaignStatusEnum
	csOpen                        =0          # from enum CampaignStatusEnum
	ctEmail                       =0          # from enum CampaignTypeEnum
	ctFax                         =2          # from enum CampaignTypeEnum
	ctMail                        =1          # from enum CampaignTypeEnum
	ctMeeting                     =4          # from enum CampaignTypeEnum
	ctOthers                      =7          # from enum CampaignTypeEnum
	ctPhoneCall                   =3          # from enum CampaignTypeEnum
	ctSMS                         =5          # from enum CampaignTypeEnum
	ctWeb                         =6          # from enum CampaignTypeEnum
	csCampaign                    =0          # from enum CampaignsServiceDataInterfaces
	csCampaignParams              =2          # from enum CampaignsServiceDataInterfaces
	csCampaignsParams             =1          # from enum CampaignsServiceDataInterfaces
	cdsCashDiscount               =0          # from enum CashDiscountsServiceDataInterfaces
	cdsCashDiscountParams         =2          # from enum CashDiscountsServiceDataInterfaces
	cdsCashDiscountsParams        =1          # from enum CashDiscountsServiceDataInterfaces
	cflisCashFlowLineItem         =0          # from enum CashFlowLineItemsServiceDataInterfaces
	cflisCashFlowLineItemParams   =2          # from enum CashFlowLineItemsServiceDataInterfaces
	cflisCashFlowLineItemsParams  =1          # from enum CashFlowLineItemsServiceDataInterfaces
	cssCertificateSeries          =0          # from enum CertificateSeriesServiceDataInterfaces
	cssCertificateSeriesParams    =2          # from enum CertificateSeriesServiceDataInterfaces
	cssCertificateSeriesParamsCollection=1          # from enum CertificateSeriesServiceDataInterfaces
	clsGetChangeLogParams         =0          # from enum ChangeLogsServiceDataInterfaces
	clsShowDifferenceParams       =1          # from enum ChangeLogsServiceDataInterfaces
	clsCheckLineParams            =1          # from enum CheckLinesServiceDataInterfaces
	clsCheckLinesParams           =0          # from enum CheckLinesServiceDataInterfaces
	coByCurrentSystemDate         =1          # from enum ClosingOptionEnum
	coByOriginalDocumentDate      =2          # from enum ClosingOptionEnum
	coBySpecifiedDate             =3          # from enum ClosingOptionEnum
	csCockpit                     =0          # from enum CockpitsServiceDataInterfaces
	csCockpitParams               =2          # from enum CockpitsServiceDataInterfaces
	csCockpitsParams              =1          # from enum CockpitsServiceDataInterfaces
	csdiAdminInfo                 =1          # from enum CompanyServiceDataInterfaces
	csdiBlob                      =7          # from enum CompanyServiceDataInterfaces
	csdiBlobParams                =8          # from enum CompanyServiceDataInterfaces
	csdiCompanyInfo               =0          # from enum CompanyServiceDataInterfaces
	csdiDecimalData               =11         # from enum CompanyServiceDataInterfaces
	csdiFinancePeriod             =4          # from enum CompanyServiceDataInterfaces
	csdiFinancePeriodParams       =6          # from enum CompanyServiceDataInterfaces
	csdiFinancePeriods            =5          # from enum CompanyServiceDataInterfaces
	csdiPathAdmin                 =9          # from enum CompanyServiceDataInterfaces
	csdiPeriodCategory            =2          # from enum CompanyServiceDataInterfaces
	csdiPeriodCategoryParams      =3          # from enum CompanyServiceDataInterfaces
	csdiUserLicenseParams         =10         # from enum CompanyServiceDataInterfaces
	cs_Monthly                    =0          # from enum ContractSequenceEnum
	cs_Quarterly                  =1          # from enum ContractSequenceEnum
	cs_SemiAnnually               =2          # from enum ContractSequenceEnum
	cs_Yearly                     =3          # from enum ContractSequenceEnum
	cctsCostCenterType            =0          # from enum CostCenterTypesServiceDataInterfaces
	cctsCostCenterTypeParams      =2          # from enum CostCenterTypesServiceDataInterfaces
	cctsCostCenterTypesParams     =1          # from enum CostCenterTypesServiceDataInterfaces
	csCountriesParams             =1          # from enum CountriesServiceDataInterfaces
	csCountry                     =0          # from enum CountriesServiceDataInterfaces
	csCountryParams               =2          # from enum CountriesServiceDataInterfaces
	cmAutomatic                   =1          # from enum CreateMethodEnum
	cmManual                      =0          # from enum CreateMethodEnum
	clsCreditLineParams           =1          # from enum CreditLinesServiceDataInterfaces
	clsCreditLinesParams          =0          # from enum CreditLinesServiceDataInterfaces
	cd1Digit                      =2          # from enum CurrenciesDecimalsEnum
	cd2Digits                     =3          # from enum CurrenciesDecimalsEnum
	cd3Digits                     =4          # from enum CurrenciesDecimalsEnum
	cd4Digits                     =5          # from enum CurrenciesDecimalsEnum
	cd5Digits                     =6          # from enum CurrenciesDecimalsEnum
	cd6Digits                     =7          # from enum CurrenciesDecimalsEnum
	cdDefault                     =0          # from enum CurrenciesDecimalsEnum
	cdWithoutDecimals             =1          # from enum CurrenciesDecimalsEnum
	cdsCustomsDeclaration         =0          # from enum CustomsDeclarationServiceDataInterfaces
	cdsCustomsDeclarationParams   =1          # from enum CustomsDeclarationServiceDataInterfaces
	dnfcssDNFCodeSetup            =0          # from enum DNFCodeSetupServiceDataInterfaces
	dnfcssDNFCodeSetupParams      =2          # from enum DNFCodeSetupServiceDataInterfaces
	dnfcssDNFCodeSetupParamsCollection=1          # from enum DNFCodeSetupServiceDataInterfaces
	dpsDashboardPackageImportParams=2          # from enum DashboardPackagesServiceDataInterfaces
	dpsDashboardPackageParams     =1          # from enum DashboardPackagesServiceDataInterfaces
	dpsDashboardPackagesParams    =0          # from enum DashboardPackagesServiceDataInterfaces
	dtsgsDeductionTaxSubGroup     =0          # from enum DeductionTaxSubGroupsServiceDataInterfaces
	dtsgsDeductionTaxSubGroupParams=2          # from enum DeductionTaxSubGroupsServiceDataInterfaces
	dtsgsDeductionTaxSubGroupsParams=1          # from enum DeductionTaxSubGroupsServiceDataInterfaces
	dsDepartment                  =0          # from enum DepartmentsServiceDataInterfaces
	dsDepartmentParams            =2          # from enum DepartmentsServiceDataInterfaces
	dsDepartmentsParams           =1          # from enum DepartmentsServiceDataInterfaces
	dsDeposit                     =0          # from enum DepositsServiceDataInterfaces
	dsDepositParams               =2          # from enum DepositsServiceDataInterfaces
	dsDepositsParams              =1          # from enum DepositsServiceDataInterfaces
	dsDimension                   =0          # from enum DimensionsServiceDataInterfaces
	dsDimensionParams             =2          # from enum DimensionsServiceDataInterfaces
	dsDimensionsParams            =1          # from enum DimensionsServiceDataInterfaces
	dgboItemGroups                =1          # from enum DiscountGroupBaseObjectEnum
	dgboItemProperties            =2          # from enum DiscountGroupBaseObjectEnum
	dgboManufacturer              =3          # from enum DiscountGroupBaseObjectEnum
	dgboNone                      =0          # from enum DiscountGroupBaseObjectEnum
	dgrAverageDiscount            =2          # from enum DiscountGroupRelationsEnum
	dgrDiscountTotals             =3          # from enum DiscountGroupRelationsEnum
	dgrHighestDiscount            =1          # from enum DiscountGroupRelationsEnum
	dgrLowestDiscount             =0          # from enum DiscountGroupRelationsEnum
	drsDistributionRule           =0          # from enum DistributionRulesServiceDataInterfaces
	drsDistributionRuleParams     =2          # from enum DistributionRulesServiceDataInterfaces
	drsDistributionRulesParams    =1          # from enum DistributionRulesServiceDataInterfaces
	dasApproved                   =2          # from enum DocumentAuthorizationStatusEnum
	dasCancelled                  =6          # from enum DocumentAuthorizationStatusEnum
	dasGenerated                  =4          # from enum DocumentAuthorizationStatusEnum
	dasGeneratedbyAuthorizer      =5          # from enum DocumentAuthorizationStatusEnum
	dasPending                    =1          # from enum DocumentAuthorizationStatusEnum
	dasRejected                   =3          # from enum DocumentAuthorizationStatusEnum
	dasWithout                    =0          # from enum DocumentAuthorizationStatusEnum
	dbavBelgium                   =1          # from enum DomesticBankAccountValidationEnum
	dbavFrance                    =3          # from enum DomesticBankAccountValidationEnum
	dbavItaly                     =4          # from enum DomesticBankAccountValidationEnum
	dbavNetherlands               =5          # from enum DomesticBankAccountValidationEnum
	dbavNone                      =0          # from enum DomesticBankAccountValidationEnum
	dbavPortugal                  =6          # from enum DomesticBankAccountValidationEnum
	dbavSpain                     =2          # from enum DomesticBankAccountValidationEnum
	dptInvoice                    =1          # from enum DownPaymentTypeEnum
	dptRequest                    =0          # from enum DownPaymentTypeEnum
	dmAll                         =3          # from enum DrawingMethodEnum
	dmNone                        =0          # from enum DrawingMethodEnum
	dmQuantity                    =1          # from enum DrawingMethodEnum
	dmTotal                       =2          # from enum DrawingMethodEnum
	ddtAfterTimePeriod            =1          # from enum DueDateTypesEnum
	ddtByDates                    =0          # from enum DueDateTypesEnum
	dltDunningALL                 =10         # from enum DunningLetterTypeEnum
	dltDunningLetter1             =0          # from enum DunningLetterTypeEnum
	dltDunningLetter10            =9          # from enum DunningLetterTypeEnum
	dltDunningLetter2             =1          # from enum DunningLetterTypeEnum
	dltDunningLetter3             =2          # from enum DunningLetterTypeEnum
	dltDunningLetter4             =3          # from enum DunningLetterTypeEnum
	dltDunningLetter5             =4          # from enum DunningLetterTypeEnum
	dltDunningLetter6             =5          # from enum DunningLetterTypeEnum
	dltDunningLetter7             =6          # from enum DunningLetterTypeEnum
	dltDunningLetter8             =7          # from enum DunningLetterTypeEnum
	dltDunningLetter9             =8          # from enum DunningLetterTypeEnum
	dtsDunningTerm                =0          # from enum DunningTermsServiceDataInterfaces
	dtsDunningTermLine            =2          # from enum DunningTermsServiceDataInterfaces
	dtsDunningTermLines           =1          # from enum DunningTermsServiceDataInterfaces
	dtsDunningTermParams          =4          # from enum DunningTermsServiceDataInterfaces
	dtsDunningTermsParams         =3          # from enum DunningTermsServiceDataInterfaces
	edocGenerate                  =0          # from enum EDocGenerationTypeEnum
	edocGenerateLater             =1          # from enum EDocGenerationTypeEnum
	edocNotRelevant               =2          # from enum EDocGenerationTypeEnum
	edoc_Error                    =3          # from enum EDocStatusEnum
	edoc_New                      =0          # from enum EDocStatusEnum
	edoc_Ok                       =4          # from enum EDocStatusEnum
	edoc_Pending                  =1          # from enum EDocStatusEnum
	edoc_Sent                     =2          # from enum EDocStatusEnum
	effsElectronicFileFormat      =1          # from enum ElectronicFileFormatsServiceDataInterfaces
	effsElectronicFileFormatParams=3          # from enum ElectronicFileFormatsServiceDataInterfaces
	effsElectronicFileFormatsParams=2          # from enum ElectronicFileFormatsServiceDataInterfaces
	effsImportFileParam           =0          # from enum ElectronicFileFormatsServiceDataInterfaces
	eeu_Daily                     =4          # from enum EmployeeExemptionUnitEnum
	eeu_Monthly                   =2          # from enum EmployeeExemptionUnitEnum
	eeu_None                      =0          # from enum EmployeeExemptionUnitEnum
	eeu_Weekly                    =3          # from enum EmployeeExemptionUnitEnum
	eeu_Yearly                    =1          # from enum EmployeeExemptionUnitEnum
	eidtsEmployeeIDType           =0          # from enum EmployeeIDTypeServiceDataInterfaces
	eidtsEmployeeIDTypeParams     =2          # from enum EmployeeIDTypeServiceDataInterfaces
	eidtsEmployeeIDTypeParamsCollection=1          # from enum EmployeeIDTypeServiceDataInterfaces
	epm_BankTransfer              =1          # from enum EmployeePaymentMethodEnum
	epm_None                      =0          # from enum EmployeePaymentMethodEnum
	erssEmployeeRoleSetup         =0          # from enum EmployeeRolesSetupServiceDataInterfaces
	erssEmployeeRoleSetupParams   =2          # from enum EmployeeRolesSetupServiceDataInterfaces
	erssEmployeeRoleSetupParamsCollection=1          # from enum EmployeeRolesSetupServiceDataInterfaces
	etps_Accepted                 =2          # from enum EmployeeTransferProcessingStatusEnum
	etps_Error                    =3          # from enum EmployeeTransferProcessingStatusEnum
	etps_New                      =0          # from enum EmployeeTransferProcessingStatusEnum
	etps_Sent                     =1          # from enum EmployeeTransferProcessingStatusEnum
	ets_Accepted                  =4          # from enum EmployeeTransferStatusEnum
	ets_Error                     =5          # from enum EmployeeTransferStatusEnum
	ets_New                       =0          # from enum EmployeeTransferStatusEnum
	ets_Processing                =1          # from enum EmployeeTransferStatusEnum
	ets_Received                  =3          # from enum EmployeeTransferStatusEnum
	ets_Sent                      =2          # from enum EmployeeTransferStatusEnum
	etsEmployeeTransfer           =0          # from enum EmployeeTransfersServiceDataInterfaces
	etsEmployeeTransferDetail     =2          # from enum EmployeeTransfersServiceDataInterfaces
	etsEmployeeTransferDetails    =1          # from enum EmployeeTransfersServiceDataInterfaces
	etsEmployeeTransferParams     =4          # from enum EmployeeTransfersServiceDataInterfaces
	etsEmployeeTransfersParams    =3          # from enum EmployeeTransfersServiceDataInterfaces
	etByCounter                   =1          # from enum EndTypeEnum
	etByDate                      =2          # from enum EndTypeEnum
	etNoEndDate                   =0          # from enum EndTypeEnum
	ierCurrentRate                =1          # from enum ExchangeRateSelectEnum
	ierFromInovice                =0          # from enum ExchangeRateSelectEnum
	etsExtendedTranslation        =0          # from enum ExtendedTranslationsServiceDataInterfaces
	etsExtendedTranslationParams  =2          # from enum ExtendedTranslationsServiceDataInterfaces
	etsExtendedTranslationsParams =1          # from enum ExtendedTranslationsServiceDataInterfaces
	ecsCompleted                  =2          # from enum ExternalCallStatusEnum
	ecsConfirmed                  =3          # from enum ExternalCallStatusEnum
	ecsFailed                     =4          # from enum ExternalCallStatusEnum
	ecsInProcess                  =1          # from enum ExternalCallStatusEnum
	ecsNew                        =0          # from enum ExternalCallStatusEnum
	ecsExternalCall               =0          # from enum ExternalCallsServiceDataInterfaces
	ecsExternalCallParams         =1          # from enum ExternalCallsServiceDataInterfaces
	fysFinancialYear              =0          # from enum FinancialYearsServiceDataInterfaces
	fysFinancialYearParams        =2          # from enum FinancialYearsServiceDataInterfaces
	fysFinancialYearsParams       =1          # from enum FinancialYearsServiceDataInterfaces
	fvtDaily                      =0          # from enum ForecastViewTypeEnum
	fvtMonthly                    =2          # from enum ForecastViewTypeEnum
	fvtWeekly                     =1          # from enum ForecastViewTypeEnum
	fpsdiColumnsPreferences       =0          # from enum FormPreferencesServiceDataInterfaces
	fpsdiColumnsPreferencesParams =1          # from enum FormPreferencesServiceDataInterfaces
	ftInsurance                   =1          # from enum FreightTypeEnum
	ftOther                       =2          # from enum FreightTypeEnum
	ftShipping                    =0          # from enum FreightTypeEnum
	gtisGTIParams                 =1          # from enum GTIsServiceDataInterfaces
	gtisGTIParamsCollection       =0          # from enum GTIsServiceDataInterfaces
	Block                         =0          # from enum GTSResponseToExceedingEnum
	Split                         =1          # from enum GTSResponseToExceedingEnum
	gsGeneralCollectionParams     =2          # from enum GeneralServiceDataInterfaces
	gsGeneralData                 =1          # from enum GeneralServiceDataInterfaces
	gsGeneralDataCollection       =0          # from enum GeneralServiceDataInterfaces
	gsGeneralDataParams           =3          # from enum GeneralServiceDataInterfaces
	gsInvokeParams                =4          # from enum GeneralServiceDataInterfaces
	gmPerBP                       =2          # from enum GroupingMethodEnum
	gmPerDunningLevel             =1          # from enum GroupingMethodEnum
	gmPerInvoice                  =0          # from enum GroupingMethodEnum
	ippCr                         =2          # from enum InstallmentPaymentsPossiblityEnum
	ippNo                         =1          # from enum InstallmentPaymentsPossiblityEnum
	ippRd                         =3          # from enum InstallmentPaymentsPossiblityEnum
	ippYes                        =0          # from enum InstallmentPaymentsPossiblityEnum
	Default                       =0          # from enum InvBaseDocTypeEnum
	Empty                         =1          # from enum InvBaseDocTypeEnum
	InventoryGeneralEntry         =3          # from enum InvBaseDocTypeEnum
	InventoryTransferRequest      =5          # from enum InvBaseDocTypeEnum
	PurchaseDeliveryNotes         =2          # from enum InvBaseDocTypeEnum
	WarehouseTransfers            =4          # from enum InvBaseDocTypeEnum
	itcMaterial                   =2          # from enum ItemClassEnum
	itcService                    =1          # from enum ItemClassEnum
	itItems                       =0          # from enum ItemTypeEnum
	itLabor                       =1          # from enum ItemTypeEnum
	itTravel                      =2          # from enum ItemTypeEnum
	jedtsJournalEntryDocumentType =0          # from enum JournalEntryDocumentTypeServiceDataInterfaces
	jedtsJournalEntryDocumentTypeParams=2          # from enum JournalEntryDocumentTypeServiceDataInterfaces
	jedtsJournalEntryDocumentTypeParamsCollection=1          # from enum JournalEntryDocumentTypeServiceDataInterfaces
	asMonthly                     =2          # from enum KPITypeEnum
	asMultiple                    =3          # from enum KPITypeEnum
	asQuarterly                   =1          # from enum KPITypeEnum
	asSingle                      =0          # from enum KPITypeEnum
	kpisKPI                       =0          # from enum KPIsServiceDataInterfaces
	kpisKPIParams                 =2          # from enum KPIsServiceDataInterfaces
	kpisKPIsParams                =1          # from enum KPIsServiceDataInterfaces
	asFixedCosts                  =0          # from enum LCCostTypeEnum
	asVariableCosts               =1          # from enum LCCostTypeEnum
	asCashValueAfterCustoms       =1          # from enum LandedCostAllocationByEnum
	asCashValueBeforeCustoms      =0          # from enum LandedCostAllocationByEnum
	asEqual                       =5          # from enum LandedCostAllocationByEnum
	asQuantity                    =2          # from enum LandedCostAllocationByEnum
	asVolume                      =4          # from enum LandedCostAllocationByEnum
	asWeight                      =3          # from enum LandedCostAllocationByEnum
	asDefault                     =0          # from enum LandedCostBaseDocumentTypeEnum
	asEmpty                       =1          # from enum LandedCostBaseDocumentTypeEnum
	asGoodsReceiptPO              =2          # from enum LandedCostBaseDocumentTypeEnum
	asLandedCosts                 =3          # from enum LandedCostBaseDocumentTypeEnum
	asPurchaseInvoice             =4          # from enum LandedCostBaseDocumentTypeEnum
	lcClosed                      =1          # from enum LandedCostDocStatusEnum
	lcOpen                        =0          # from enum LandedCostDocStatusEnum
	lcsLandedCost                 =0          # from enum LandedCostsServiceDataInterfaces
	lcsLandedCostParams           =2          # from enum LandedCostsServiceDataInterfaces
	lcsLandedCostsParams          =1          # from enum LandedCostsServiceDataInterfaces
	ldlt_DocumentTotal            =0          # from enum LegalDataLineTypeEnum
	ldlt_TaxPerLine               =1          # from enum LegalDataLineTypeEnum
	ldlt_TotalTax                 =2          # from enum LegalDataLineTypeEnum
	ldsLegalData                  =0          # from enum LegalDataServiceDataInterfaces
	ldsLegalDataParams            =2          # from enum LegalDataServiceDataInterfaces
	ldsLegalDataParamsCollection  =1          # from enum LegalDataServiceDataInterfaces
	ltB1i                         =23         # from enum LicenseTypeEnum
	ltB1iIndirect                 =22         # from enum LicenseTypeEnum
	ltIdirect                     =25         # from enum LicenseTypeEnum
	ltSOA                         =21         # from enum LicenseTypeEnum
	ltSOAIndirect                 =20         # from enum LicenseTypeEnum
	ultAssign                     =0          # from enum LicenseUpdateTypeEnum
	ultRemove                     =1          # from enum LicenseUpdateTypeEnum
	ltDocument                    =0          # from enum LineTypeEnum
	ltRounding                    =1          # from enum LineTypeEnum
	ltVat                         =2          # from enum LineTypeEnum
	ldtARInvoicesLink             =5          # from enum LinkedDocTypeEnum
	ldtDeliveriesLink             =4          # from enum LinkedDocTypeEnum
	ldtEmptyLink                  =0          # from enum LinkedDocTypeEnum
	ldtSalesOpportunitiesLink     =1          # from enum LinkedDocTypeEnum
	ldtSalesOrdersLink            =3          # from enum LinkedDocTypeEnum
	ldtSalesQuotationsLink        =2          # from enum LinkedDocTypeEnum
	mgsMaterialGroup              =0          # from enum MaterialGroupsServiceDataInterfaces
	mgsMaterialGroupParams        =2          # from enum MaterialGroupsServiceDataInterfaces
	mgsMaterialGroupsParams       =1          # from enum MaterialGroupsServiceDataInterfaces
	mrfifosLayer                  =2          # from enum MaterialRevaluationFIFOServiceDataInterfaces
	mrfifosLayers                 =1          # from enum MaterialRevaluationFIFOServiceDataInterfaces
	mrfifosMaterialRevaluationFIFO=0          # from enum MaterialRevaluationFIFOServiceDataInterfaces
	mrfifosMaterialRevaluationFIFOParams=3          # from enum MaterialRevaluationFIFOServiceDataInterfaces
	msdiMessage                   =0          # from enum MessagesServiceDataInterfaces
	ncmcssNCMCodeSetup            =0          # from enum NCMCodesSetupServiceDataInterfaces
	ncmcssNCMCodeSetupParams      =2          # from enum NCMCodesSetupServiceDataInterfaces
	ncmcssNCMCodeSetupParamsCollection=1          # from enum NCMCodesSetupServiceDataInterfaces
	nfmsNFModel                   =0          # from enum NFModelsServiceDataInterfaces
	nfmsNFModelParams             =2          # from enum NFModelsServiceDataInterfaces
	nfmsNFModelsParams            =1          # from enum NFModelsServiceDataInterfaces
	noasNatureOfAssessee          =0          # from enum NatureOfAssesseesServiceDataInterfaces
	noasNatureOfAssesseeParams    =2          # from enum NatureOfAssesseesServiceDataInterfaces
	noasNatureOfAssesseesParams   =1          # from enum NatureOfAssesseesServiceDataInterfaces
	ocsOccurenceCode              =0          # from enum OccurrenceCodesServiceDataInterfaces
	ocsOccurenceCodeParams        =2          # from enum OccurrenceCodesServiceDataInterfaces
	ocsOccurenceCodeParamsCollection=1          # from enum OccurrenceCodesServiceDataInterfaces
	ocGoodsOrServiciesAcquisitions=0          # from enum OperationCode347Enum
	ocPublicEntitiesAcquisitions  =1          # from enum OperationCode347Enum
	ocPublicSubsidies             =4          # from enum OperationCode347Enum
	ocSalesOrServicesRevenues     =3          # from enum OperationCode347Enum
	ocTravelAgenciesPurchases     =2          # from enum OperationCode347Enum
	ocTravelAgenciesSales         =5          # from enum OperationCode347Enum
	pssPartnersSetup              =0          # from enum PartnersSetupsServiceDataInterfaces
	pssPartnersSetupParams        =2          # from enum PartnersSetupsServiceDataInterfaces
	pssPartnersSetupsParams       =1          # from enum PartnersSetupsServiceDataInterfaces
	pbsPaymentBlock               =0          # from enum PaymentBlocksServiceDataInterfaces
	pbsPaymentBlockParams         =2          # from enum PaymentBlocksServiceDataInterfaces
	pbsPaymentBlocksParams        =1          # from enum PaymentBlocksServiceDataInterfaces
	pmtBankTransfer               =2          # from enum PaymentMeansTypeEnum
	pmtCash                       =3          # from enum PaymentMeansTypeEnum
	pmtChecks                     =1          # from enum PaymentMeansTypeEnum
	pmtCreditCard                 =4          # from enum PaymentMeansTypeEnum
	pmtNotAssigned                =0          # from enum PaymentMeansTypeEnum
	prtGeneral                    =0          # from enum PaymentRunExportRowTypeEnum
	prtPayOnAccount               =1          # from enum PaymentRunExportRowTypeEnum
	prtPayToAccount               =2          # from enum PaymentRunExportRowTypeEnum
	pasApproved                   =2          # from enum PaymentsAuthorizationStatusEnum
	pasCancelled                  =6          # from enum PaymentsAuthorizationStatusEnum
	pasGenerated                  =4          # from enum PaymentsAuthorizationStatusEnum
	pasGeneratedbyAuthorizer      =5          # from enum PaymentsAuthorizationStatusEnum
	pasPending                    =1          # from enum PaymentsAuthorizationStatusEnum
	pasRejected                   =3          # from enum PaymentsAuthorizationStatusEnum
	pasWithout                    =0          # from enum PaymentsAuthorizationStatusEnum
	ltLocked                      =3          # from enum PeriodStatusEnum
	ltPeriodClosing               =2          # from enum PeriodStatusEnum
	ltUnlocked                    =0          # from enum PeriodStatusEnum
	ltUnlockedExceptSales         =1          # from enum PeriodStatusEnum
	pmBussinessPartnerBankAccount =1          # from enum PostingMethodEnum
	pmExternalReconciliation      =3          # from enum PostingMethodEnum
	pmGLAccountBankAccount        =0          # from enum PostingMethodEnum
	pmIgnore                      =4          # from enum PostingMethodEnum
	pmInterimAccountBankAccount   =2          # from enum PostingMethodEnum
	ptsPredefinedText             =0          # from enum PredefinedTextsServiceDataInterfaces
	ptsPredefinedTextParams       =2          # from enum PredefinedTextsServiceDataInterfaces
	ptsPredefinedTextsParams      =1          # from enum PredefinedTextsServiceDataInterfaces
	poBlankPaper                  =0          # from enum PrintOnEnum
	poDefault                     =3          # from enum PrintOnEnum
	poOverflowBlankPaper          =2          # from enum PrintOnEnum
	poOverflowCheckStock          =1          # from enum PrintOnEnum
	psAmended                     =2          # from enum PrintStatusEnum
	psNo                          =0          # from enum PrintStatusEnum
	psYes                         =1          # from enum PrintStatusEnum
	pcsProfitCenter               =0          # from enum ProfitCentersServiceDataInterfaces
	pcsProfitCenterParams         =2          # from enum ProfitCentersServiceDataInterfaces
	pcsProfitCentersParams        =1          # from enum ProfitCentersServiceDataInterfaces
	psProject                     =0          # from enum ProjectsServiceDataInterfaces
	psProjectParams               =2          # from enum ProjectsServiceDataInterfaces
	psProjectsParams              =1          # from enum ProjectsServiceDataInterfaces
	rxmData                       =0          # from enum RecordsetXMLModeEnum
	rxmDataWithPrimaryKeys        =1          # from enum RecordsetXMLModeEnum
	rxmOnlyPrimaryKeys            =2          # from enum RecordsetXMLModeEnum
	rdowDay                       =0          # from enum RecurrenceDayOfWeekEnum
	rdowFri                       =8          # from enum RecurrenceDayOfWeekEnum
	rdowMon                       =4          # from enum RecurrenceDayOfWeekEnum
	rdowSat                       =9          # from enum RecurrenceDayOfWeekEnum
	rdowSun                       =3          # from enum RecurrenceDayOfWeekEnum
	rdowThu                       =7          # from enum RecurrenceDayOfWeekEnum
	rdowTue                       =5          # from enum RecurrenceDayOfWeekEnum
	rdowWed                       =6          # from enum RecurrenceDayOfWeekEnum
	rdowWeekDay                   =1          # from enum RecurrenceDayOfWeekEnum
	rdowWeekendDay                =2          # from enum RecurrenceDayOfWeekEnum
	rpAnnually                    =4          # from enum RecurrencePatternEnum
	rpDaily                       =1          # from enum RecurrencePatternEnum
	rpMonthly                     =3          # from enum RecurrencePatternEnum
	rpNone                        =0          # from enum RecurrencePatternEnum
	rpWeekly                      =2          # from enum RecurrencePatternEnum
	rssFirst                      =0          # from enum RecurrenceSequenceSpecifierEnum
	rssFourth                     =3          # from enum RecurrenceSequenceSpecifierEnum
	rssLast                       =4          # from enum RecurrenceSequenceSpecifierEnum
	rssSecond                     =1          # from enum RecurrenceSequenceSpecifierEnum
	rssThird                      =2          # from enum RecurrenceSequenceSpecifierEnum
	roByDate                      =0          # from enum RepeatOptionEnum
	roByWeekDay                   =1          # from enum RepeatOptionEnum
	r349cA                        =2          # from enum Report349CodeListEnum
	r349cE                        =1          # from enum Report349CodeListEnum
	r349cEmpty                    =0          # from enum Report349CodeListEnum
	r349cH                        =7          # from enum Report349CodeListEnum
	r349cI                        =5          # from enum Report349CodeListEnum
	r349cM                        =6          # from enum Report349CodeListEnum
	r349cS                        =4          # from enum Report349CodeListEnum
	r349cT                        =3          # from enum Report349CodeListEnum
	rfsdiTaxReportFilter          =0          # from enum ReportFilterServiceDataInterfaces
	rfsdiTaxReportFilterParams    =1          # from enum ReportFilterServiceDataInterfaces
	rfsdiTaxReportFiltersParams   =2          # from enum ReportFilterServiceDataInterfaces
	rlcCrystal                    =1          # from enum ReportLayoutCategoryEnum
	rlcLegalList                  =2          # from enum ReportLayoutCategoryEnum
	rlcPLD                        =0          # from enum ReportLayoutCategoryEnum
	rlcUserDefinedType            =3          # from enum ReportLayoutCategoryEnum
	rlsdiDefaultReportParams      =0          # from enum ReportLayoutsServiceDataInterfaces
	rlsdiReportLayout             =3          # from enum ReportLayoutsServiceDataInterfaces
	rlsdiReportLayoutParams       =2          # from enum ReportLayoutsServiceDataInterfaces
	rlsdiReportLayoutPrintParams  =4          # from enum ReportLayoutsServiceDataInterfaces
	rlsdiReportParams             =1          # from enum ReportLayoutsServiceDataInterfaces
	rtsReportType                 =0          # from enum ReportTypesServiceDataInterfaces
	rtsReportTypeParams           =2          # from enum ReportTypesServiceDataInterfaces
	rtsReportTypesParams          =1          # from enum ReportTypesServiceDataInterfaces
	rcsRetornoCode                =0          # from enum RetornoCodesServiceDataInterfaces
	rcsRetornoCodeParams          =2          # from enum RetornoCodesServiceDataInterfaces
	rcsRetornoCodeParamsCollection=1          # from enum RetornoCodesServiceDataInterfaces
	rt26Q                         =0          # from enum ReturnTypeEnum
	rt27Q                         =1          # from enum ReturnTypeEnum
	rcBASCode                     =25         # from enum RoundingContextEnum
	rcBudgetSum                   =16         # from enum RoundingContextEnum
	rcDocHeaderTotal              =20         # from enum RoundingContextEnum
	rcExpenseTotal                =23         # from enum RoundingContextEnum
	rcLineGrossTotal              =22         # from enum RoundingContextEnum
	rcMeasure                     =11         # from enum RoundingContextEnum
	rcPercent                     =12         # from enum RoundingContextEnum
	rcPrice                       =8          # from enum RoundingContextEnum
	rcPriceListSum                =17         # from enum RoundingContextEnum
	rcQuantity                    =10         # from enum RoundingContextEnum
	rcRate                        =9          # from enum RoundingContextEnum
	rcRealAmountInPayment         =18         # from enum RoundingContextEnum
	rcStockSumRoundUp             =19         # from enum RoundingContextEnum
	rcSum                         =7          # from enum RoundingContextEnum
	rcTax                         =13         # from enum RoundingContextEnum
	rcTaxForPrice                 =26         # from enum RoundingContextEnum
	rcTaxPerGroup                 =14         # from enum RoundingContextEnum
	rcVatReportAmount             =21         # from enum RoundingContextEnum
	rcWTax                        =24         # from enum RoundingContextEnum
	rsNoRounding                  =0          # from enum RoundingSysEnum
	rsRoundToFiveHundredth        =4          # from enum RoundingSysEnum
	rsRoundToOne                  =2          # from enum RoundingSysEnum
	rsRoundToTen                  =3          # from enum RoundingSysEnum
	rsRoundToTenHundredth         =1          # from enum RoundingSysEnum
	rt_CommercialValues           =1          # from enum RoundingTypeEnum
	rt_NoRounding                 =2          # from enum RoundingTypeEnum
	rt_TruncatedAU                =0          # from enum RoundingTypeEnum
	socssSalesOpportunityCompetitorSetup=0          # from enum SalesOpportunityCompetitorsSetupServiceDataInterfaces
	socssSalesOpportunityCompetitorSetupParams=2          # from enum SalesOpportunityCompetitorsSetupServiceDataInterfaces
	socssSalesOpportunityCompetitorSetupParamsCollection=1          # from enum SalesOpportunityCompetitorsSetupServiceDataInterfaces
	soissSalesOpportunityInterestSetup=0          # from enum SalesOpportunityInterestsSetupServiceDataInterfaces
	soissSalesOpportunityInterestSetupParams=2          # from enum SalesOpportunityInterestsSetupServiceDataInterfaces
	soissSalesOpportunityInterestSetupParamsCollection=1          # from enum SalesOpportunityInterestsSetupServiceDataInterfaces
	sorssSalesOpportunityReasonSetup=0          # from enum SalesOpportunityReasonsSetupServiceDataInterfaces
	sorssSalesOpportunityReasonSetupParams=2          # from enum SalesOpportunityReasonsSetupServiceDataInterfaces
	sorssSalesOpportunityReasonSetupParamsCollection=1          # from enum SalesOpportunityReasonsSetupServiceDataInterfaces
	sosssSalesOpportunitySourceSetup=0          # from enum SalesOpportunitySourcesSetupServiceDataInterfaces
	sosssSalesOpportunitySourceSetupParams=2          # from enum SalesOpportunitySourcesSetupServiceDataInterfaces
	sosssSalesOpportunitySourceSetupParamsCollection=1          # from enum SalesOpportunitySourcesSetupServiceDataInterfaces
	ssSection                     =0          # from enum SectionsServiceDataInterfaces
	ssSectionParams               =2          # from enum SectionsServiceDataInterfaces
	ssSectionsParams              =1          # from enum SectionsServiceDataInterfaces
	sndsSerialNumberDetail        =0          # from enum SerialNumberDetailsServiceDataInterfaces
	sndsSerialNumberDetailParams  =1          # from enum SerialNumberDetailsServiceDataInterfaces
	ssdiDefaultElectronicSeriesParams=10         # from enum SeriesServiceDataInterfaces
	ssdiDocumentChangeMenuName    =6          # from enum SeriesServiceDataInterfaces
	ssdiDocumentSeriesParams      =3          # from enum SeriesServiceDataInterfaces
	ssdiDocumentSeriesUserParams  =4          # from enum SeriesServiceDataInterfaces
	ssdiDocumentTypeParams        =5          # from enum SeriesServiceDataInterfaces
	ssdiElectronicSeries          =7          # from enum SeriesServiceDataInterfaces
	ssdiElectronicSeriesCollection=8          # from enum SeriesServiceDataInterfaces
	ssdiElectronicSeriesParams    =9          # from enum SeriesServiceDataInterfaces
	ssdiSeries                    =0          # from enum SeriesServiceDataInterfaces
	ssdiSeriesCollection          =1          # from enum SeriesServiceDataInterfaces
	ssdiSeriesParams              =2          # from enum SeriesServiceDataInterfaces
	scosServiceCallOrigin         =0          # from enum ServiceCallOriginsServiceDataInterfaces
	scosServiceCallOriginParams   =2          # from enum ServiceCallOriginsServiceDataInterfaces
	scosServiceCallOriginParamsCollection=1          # from enum ServiceCallOriginsServiceDataInterfaces
	scptsServiceCallProblemType   =0          # from enum ServiceCallProblemTypesServiceDataInterfaces
	scptsServiceCallProblemTypeParams=2          # from enum ServiceCallProblemTypesServiceDataInterfaces
	scptsServiceCallProblemTypeParamsCollection=1          # from enum ServiceCallProblemTypesServiceDataInterfaces
	scsssServiceCallSolutionStatus=0          # from enum ServiceCallSolutionStatusServiceDataInterfaces
	scsssServiceCallSolutionStatusParams=2          # from enum ServiceCallSolutionStatusServiceDataInterfaces
	scsssServiceCallSolutionStatusParamsCollection=1          # from enum ServiceCallSolutionStatusServiceDataInterfaces
	scssServiceCallStatus         =0          # from enum ServiceCallStatusServiceDataInterfaces
	scssServiceCallStatusParams   =2          # from enum ServiceCallStatusServiceDataInterfaces
	scssServiceCallStatusParamsCollection=1          # from enum ServiceCallStatusServiceDataInterfaces
	sctsServiceCallType           =0          # from enum ServiceCallTypesServiceDataInterfaces
	sctsServiceCallTypeParams     =2          # from enum ServiceCallTypesServiceDataInterfaces
	sctsServiceCallTypeParamsCollection=1          # from enum ServiceCallTypesServiceDataInterfaces
	sgsServiceGroup               =0          # from enum ServiceGroupsServiceDataInterfaces
	sgsServiceGroupParams         =2          # from enum ServiceGroupsServiceDataInterfaces
	sgsServiceGroupsParams        =1          # from enum ServiceGroupsServiceDataInterfaces
	stpsServiceTaxPostingParams   =1          # from enum ServiceTaxPostingServiceDataInterfaces
	stpsServiceTaxPostingParamsCollection=0          # from enum ServiceTaxPostingServiceDataInterfaces
	AccountCategoryService        =238        # from enum ServiceTypes
	AccountsService               =1001       # from enum ServiceTypes
	AccrualTypesService           =540000048  # from enum ServiceTypes
	ActivitiesService             =1007       # from enum ServiceTypes
	AlertManagementService        =80         # from enum ServiceTypes
	AlternativeItemsService       =107        # from enum ServiceTypes
	ApprovalRequestsService       =122        # from enum ServiceTypes
	ApprovalStagesService         =120        # from enum ServiceTypes
	ApprovalTemplatesService      =121        # from enum ServiceTypes
	BOEDocumentTypesService       =267        # from enum ServiceTypes
	BOEInstructionsService        =269        # from enum ServiceTypes
	BOELinesService               =181        # from enum ServiceTypes
	BOEPortfoliosService          =268        # from enum ServiceTypes
	BankChargesAllocationCodesService=239        # from enum ServiceTypes
	BankStatementsService         =10000003   # from enum ServiceTypes
	BatchNumberDetailsService     =10000044   # from enum ServiceTypes
	BlanketAgreementsService      =1250000025 # from enum ServiceTypes
	BranchesService               =118        # from enum ServiceTypes
	BrazilBeverageIndexersService =540000068  # from enum ServiceTypes
	BrazilFuelIndexersService     =540000067  # from enum ServiceTypes
	BrazilMultiIndexersService    =1720000001 # from enum ServiceTypes
	BrazilNumericIndexersService  =540000066  # from enum ServiceTypes
	BrazilStringIndexersService   =540000065  # from enum ServiceTypes
	BusinessPartnerPropertiesService=44         # from enum ServiceTypes
	BusinessPartnersService       =1002       # from enum ServiceTypes
	CampaignsService              =1320000012 # from enum ServiceTypes
	CashDiscountsService          =133        # from enum ServiceTypes
	CashFlowLineItemsService      =242        # from enum ServiceTypes
	CertificateSeriesService      =10000075   # from enum ServiceTypes
	ChangeLogsService             =130000000  # from enum ServiceTypes
	CheckLinesService             =27         # from enum ServiceTypes
	CockpitsService               =1210000000 # from enum ServiceTypes
	CostCenterTypesService        =540000042  # from enum ServiceTypes
	CountriesService              =129        # from enum ServiceTypes
	CreditLinesService            =72         # from enum ServiceTypes
	CustomsDeclarationService     =283        # from enum ServiceTypes
	DNFCodeSetupService           =140000041  # from enum ServiceTypes
	DashboardPackagesService      =1210000008 # from enum ServiceTypes
	DeductionTaxSubGroupsService  =530000000  # from enum ServiceTypes
	DepartmentsService            =119        # from enum ServiceTypes
	DepositsService               =25         # from enum ServiceTypes
	DimensionsService             =251        # from enum ServiceTypes
	DistributionRulesService      =62         # from enum ServiceTypes
	DunningTermsService           =196        # from enum ServiceTypes
	ElectronicFileFormatsService  =410000005  # from enum ServiceTypes
	EmployeeIDTypeService         =1560000000 # from enum ServiceTypes
	EmployeeRolesSetupService     =172        # from enum ServiceTypes
	EmployeeTransfersService      =480000001  # from enum ServiceTypes
	ExtendedTranslationsService   =1320000005 # from enum ServiceTypes
	ExternalCallsService          =10000020   # from enum ServiceTypes
	FinancialYearsService         =10000073   # from enum ServiceTypes
	FormPreferencesService        =41         # from enum ServiceTypes
	GTIsService                   =1230000004 # from enum ServiceTypes
	JournalEntryDocumentTypeService=1560000001 # from enum ServiceTypes
	KPIsService                   =1320000000 # from enum ServiceTypes
	LandedCostsService            =69         # from enum ServiceTypes
	LegalDataService              =540000073  # from enum ServiceTypes
	MaterialGroupsService         =256        # from enum ServiceTypes
	MaterialRevaluationFIFOService=1006       # from enum ServiceTypes
	MessagesService               =81         # from enum ServiceTypes
	NCMCodesSetupService          =257        # from enum ServiceTypes
	NFModelsService               =540000056  # from enum ServiceTypes
	NatureOfAssesseesService      =10000077   # from enum ServiceTypes
	OccurrenceCodesService        =1320000032 # from enum ServiceTypes
	PartnersSetupsService         =108        # from enum ServiceTypes
	PaymentBlocksService          =159        # from enum ServiceTypes
	PredefinedTextsService        =215        # from enum ServiceTypes
	ProfitCentersService          =61         # from enum ServiceTypes
	ProjectsService               =63         # from enum ServiceTypes
	ReportFilterService           =180        # from enum ServiceTypes
	ReportLayoutsService          =232        # from enum ServiceTypes
	ReportTypesService            =10000196   # from enum ServiceTypes
	RetornoCodesService           =1320000028 # from enum ServiceTypes
	SalesOpportunityCompetitorsSetupService=109        # from enum ServiceTypes
	SalesOpportunityInterestsSetupService=98         # from enum ServiceTypes
	SalesOpportunityReasonsSetupService=102        # from enum ServiceTypes
	SalesOpportunitySourcesSetupService=100        # from enum ServiceTypes
	SectionsService               =10000074   # from enum ServiceTypes
	SerialNumberDetailsService    =10000045   # from enum ServiceTypes
	SeriesService                 =35         # from enum ServiceTypes
	ServiceCallOriginsService     =192        # from enum ServiceTypes
	ServiceCallProblemTypesService=169        # from enum ServiceTypes
	ServiceCallSolutionStatusService=188        # from enum ServiceTypes
	ServiceCallStatusService      =167        # from enum ServiceTypes
	ServiceCallTypesService       =168        # from enum ServiceTypes
	ServiceGroupsService          =255        # from enum ServiceTypes
	ServiceTaxPostingService      =1520000001 # from enum ServiceTypes
	StatesService                 =130        # from enum ServiceTypes
	TargetGroupsService           =1320000002 # from enum ServiceTypes
	TaxCodeDeterminationsService  =540000005  # from enum ServiceTypes
	TaxWebSitesService            =1160000000 # from enum ServiceTypes
	TransactionCodesService       =45         # from enum ServiceTypes
	UserMenuService               =2002       # from enum ServiceTypes
	sgAgriculturalProducts        =1          # from enum ShaamGroupEnum
	sgInsuranceCommissions        =2          # from enum ShaamGroupEnum
	sgInterestExchangeRateDiffs   =4          # from enum ShaamGroupEnum
	sgServicesAndAsset            =0          # from enum ShaamGroupEnum
	sgWHTaxInstructions           =3          # from enum ShaamGroupEnum
	soAscending                   =0          # from enum SortOrderEnum
	soDescending                  =1          # from enum SortOrderEnum
	ssState                       =0          # from enum StatesServiceDataInterfaces
	ssStateParams                 =2          # from enum StatesServiceDataInterfaces
	ssStatesParams                =1          # from enum StatesServiceDataInterfaces
	sasApproved                   =2          # from enum StockTransferAuthorizationStatusEnum
	sasCancelled                  =6          # from enum StockTransferAuthorizationStatusEnum
	sasGenerated                  =4          # from enum StockTransferAuthorizationStatusEnum
	sasGeneratedbyAuthorizer      =5          # from enum StockTransferAuthorizationStatusEnum
	sasPending                    =1          # from enum StockTransferAuthorizationStatusEnum
	sasRejected                   =3          # from enum StockTransferAuthorizationStatusEnum
	sasWithout                    =0          # from enum StockTransferAuthorizationStatusEnum
	tdsActive                     =0          # from enum TargetGroupsDetailStatusEnum
	tdsInactive                   =1          # from enum TargetGroupsDetailStatusEnum
	tgsTargetGroup                =0          # from enum TargetGroupsServiceDataInterfaces
	tgsTargetGroupParams          =2          # from enum TargetGroupsServiceDataInterfaces
	tgsTargetGroupsParams         =1          # from enum TargetGroupsServiceDataInterfaces
	PreconfiguredFormula          =2          # from enum TaxCalcSysEnum
	PreconfiguredFormulaWithJurisdictionSupport=0          # from enum TaxCalcSysEnum
	UserDefinedFormula            =1          # from enum TaxCalcSysEnum
	tcdsTaxCodeDetermination      =0          # from enum TaxCodeDeterminationsServiceDataInterfaces
	tcdsTaxCodeDeterminationParams=2          # from enum TaxCodeDeterminationsServiceDataInterfaces
	tcdsTaxCodeDeterminationsParams=1          # from enum TaxCodeDeterminationsServiceDataInterfaces
	trd_DocumentDate              =1          # from enum TaxRateDeterminationEnum
	trd_PostingDate               =0          # from enum TaxRateDeterminationEnum
	trfadt_APDocuments            =0          # from enum TaxReportFilterApArDocumentType
	trfadt_ARDocuments            =1          # from enum TaxReportFilterApArDocumentType
	trfdt_Complementary           =2          # from enum TaxReportFilterDeclarationType
	trfdt_Original                =0          # from enum TaxReportFilterDeclarationType
	trfdt_Substitute              =1          # from enum TaxReportFilterDeclarationType
	trfdt_APCreditMemos           =3          # from enum TaxReportFilterDocumentType
	trfdt_APDownPayment           =10         # from enum TaxReportFilterDocumentType
	trfdt_APInvoices              =2          # from enum TaxReportFilterDocumentType
	trfdt_ARCreditMemos           =1          # from enum TaxReportFilterDocumentType
	trfdt_ARDownPayment           =9          # from enum TaxReportFilterDocumentType
	trfdt_ARInvoices              =0          # from enum TaxReportFilterDocumentType
	trfdt_ChecksforPayment        =7          # from enum TaxReportFilterDocumentType
	trfdt_IncomingPayments        =4          # from enum TaxReportFilterDocumentType
	trfdt_InventoryTransfers      =8          # from enum TaxReportFilterDocumentType
	trfdt_JournalEntries          =5          # from enum TaxReportFilterDocumentType
	trfdt_OutgoingPayments        =6          # from enum TaxReportFilterDocumentType
	trfP_Month                    =2          # from enum TaxReportFilterPeriod
	trfP_NULL                     =3          # from enum TaxReportFilterPeriod
	trfP_Quarter                  =0          # from enum TaxReportFilterPeriod
	trfP_Year                     =1          # from enum TaxReportFilterPeriod
	trfqd_Date                    =1          # from enum TaxReportFilterQuarterOrDates
	trfqd_Interval                =0          # from enum TaxReportFilterQuarterOrDates
	trfrlt_DeclarationLayout      =1          # from enum TaxReportFilterReportLayoutType
	trfrlt_RegisterBookLayout     =0          # from enum TaxReportFilterReportLayoutType
	trft_AnnualSalesReport        =10         # from enum TaxReportFilterType
	trft_AppendixOP               =9          # from enum TaxReportFilterType
	trft_BoxReport                =8          # from enum TaxReportFilterType
	trft_None                     =7          # from enum TaxReportFilterType
	trft_ReconciliationReport     =4          # from enum TaxReportFilterType
	trft_Report347                =2          # from enum TaxReportFilterType
	trft_Report349                =3          # from enum TaxReportFilterType
	trft_SalesReport              =6          # from enum TaxReportFilterType
	trft_StampTax                 =5          # from enum TaxReportFilterType
	trft_TaxReport                =0          # from enum TaxReportFilterType
	trft_VATRefundReport          =11         # from enum TaxReportFilterType
	trft_WTReport                 =1          # from enum TaxReportFilterType
	ttblExcluded                  =0          # from enum TaxTypeBlackListEnum
	ttblExempt                    =2          # from enum TaxTypeBlackListEnum
	ttblNonSubject                =4          # from enum TaxTypeBlackListEnum
	ttblNotTaxable                =3          # from enum TaxTypeBlackListEnum
	ttblTaxable                   =1          # from enum TaxTypeBlackListEnum
	twssTaxWebSite                =0          # from enum TaxWebSitesServiceDataInterfaces
	twssTaxWebSiteParams          =2          # from enum TaxWebSitesServiceDataInterfaces
	twssTaxWebSitesParams         =1          # from enum TaxWebSitesServiceDataInterfaces
	tlHigh                        =2          # from enum ThreatLevelEnum
	tlLow                         =0          # from enum ThreatLevelEnum
	tlMedium                      =1          # from enum ThreatLevelEnum
	ttAPCorrectionInvoice         =25         # from enum TransTypesEnum
	ttAPCorrectionInvoiceReversal =26         # from enum TransTypesEnum
	ttAPCreditNote                =8          # from enum TransTypesEnum
	ttAPInvoice                   =7          # from enum TransTypesEnum
	ttARCorrectionInvoice         =27         # from enum TransTypesEnum
	ttARCorrectionInvoiceReversal =28         # from enum TransTypesEnum
	ttARCredItnote                =4          # from enum TransTypesEnum
	ttARInvoice                   =3          # from enum TransTypesEnum
	ttAllTransactions             =0          # from enum TransTypesEnum
	ttBoETransaction              =29         # from enum TransTypesEnum
	ttChequesForPayment           =15         # from enum TransTypesEnum
	ttClosingBalance              =2          # from enum TransTypesEnum
	ttCorrectionInvoice           =23         # from enum TransTypesEnum
	ttDeferredDeposit             =22         # from enum TransTypesEnum
	ttDelivery                    =5          # from enum TransTypesEnum
	ttDeposit                     =12         # from enum TransTypesEnum
	ttDownPayment                 =31         # from enum TransTypesEnum
	ttGeneralReceiptToStock       =17         # from enum TransTypesEnum
	ttGeneralReleaseFromStock     =18         # from enum TransTypesEnum
	ttInternalReconciliation      =33         # from enum TransTypesEnum
	ttInventoryValuation          =24         # from enum TransTypesEnum
	ttJournalEntry                =13         # from enum TransTypesEnum
	ttLandedCosts                 =21         # from enum TransTypesEnum
	ttOpeningBalance              =1          # from enum TransTypesEnum
	ttProductionOrder             =30         # from enum TransTypesEnum
	ttPurchaseDeliveryNote        =9          # from enum TransTypesEnum
	ttPurchaseDownPayment         =32         # from enum TransTypesEnum
	ttPurchaseReturn              =10         # from enum TransTypesEnum
	ttReceipt                     =11         # from enum TransTypesEnum
	ttReturn                      =6          # from enum TransTypesEnum
	ttStockList                   =16         # from enum TransTypesEnum
	ttTransferBetweenWarehouses   =19         # from enum TransTypesEnum
	ttVendorPayment               =14         # from enum TransTypesEnum
	ttWorkInstructions            =20         # from enum TransTypesEnum
	tcsTransactionCode            =0          # from enum TransactionCodesServiceDataInterfaces
	tcsTransactionCodeParams      =2          # from enum TransactionCodesServiceDataInterfaces
	tcsTransactionCodeParamsCollection=1          # from enum TransactionCodesServiceDataInterfaces
	asCRReport                    =0          # from enum TranslationCategoryEnum
	asEFMItem                     =2          # from enum TranslationCategoryEnum
	asMenuItem                    =1          # from enum TranslationCategoryEnum
	actionChPasswd                =9          # from enum UserActionTypeEnum
	actionCreateUser              =3          # from enum UserActionTypeEnum
	actionDeselectSU              =6          # from enum UserActionTypeEnum
	actionLock                    =7          # from enum UserActionTypeEnum
	actionLogin                   =0          # from enum UserActionTypeEnum
	actionLoginFail               =1          # from enum UserActionTypeEnum
	actionLogoff                  =2          # from enum UserActionTypeEnum
	actionRemoveUser              =4          # from enum UserActionTypeEnum
	actionSelectSU                =5          # from enum UserActionTypeEnum
	actionUnlock                  =8          # from enum UserActionTypeEnum
	umitFolder                    =2          # from enum UserMenuItemTypeEnum
	umitForm                      =0          # from enum UserMenuItemTypeEnum
	umitLink                      =4          # from enum UserMenuItemTypeEnum
	umitQuery                     =1          # from enum UserMenuItemTypeEnum
	umitReport                    =3          # from enum UserMenuItemTypeEnum
	umsdiUserMenuParams           =0          # from enum UserMenuServiceDataInterfaces
	wtcbt_Gross                   =0          # from enum WithholdingTaxCodeBaseTypeEnum
	wtcbt_Net                     =1          # from enum WithholdingTaxCodeBaseTypeEnum
	wtcbt_VAT                     =2          # from enum WithholdingTaxCodeBaseTypeEnum
	wtcc_Invoice                  =0          # from enum WithholdingTaxCodeCategoryEnum
	wtcc_Payment                  =1          # from enum WithholdingTaxCodeCategoryEnum
	wt_IncomeTaxWithholding       =1          # from enum WithholdingTypeEnum
	wt_VatWithholding             =0          # from enum WithholdingTypeEnum

from win32com.client import DispatchBaseClass
class IAccountCategoriesParams(DispatchBaseClass):
	'IAccountCategoriesParams Interface'
	CLSID = IID('{AABB98FA-CCB5-4F0D-A6B6-5684708886C9}')
	coclass_clsid = IID('{F20289AA-1F5D-421F-A23A-0A50FE3BBEE7}')

	# Result is of type IAccountCategoryParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{797B09FC-E40A-42FA-9045-30B351D937F1}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IAccountCategoryParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{797B09FC-E40A-42FA-9045-30B351D937F1}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{797B09FC-E40A-42FA-9045-30B351D937F1}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{797B09FC-E40A-42FA-9045-30B351D937F1}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IAccountCategory(DispatchBaseClass):
	'IAccountCategory Interface'
	CLSID = IID('{F656351C-32B3-4FE5-9054-221B5988B7E7}')
	coclass_clsid = IID('{B4F1CCC6-85B4-48D1-9E4D-E068CE6D681B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CategoryCode": (10, 2, (3, 0), (), "CategoryCode", None),
		"CategoryName": (11, 2, (8, 0), (), "CategoryName", None),
		"CategorySource": (12, 2, (3, 0), (), "CategorySource", None),
	}
	_prop_map_put_ = {
		"CategoryName": ((11, LCID, 4, 0),()),
		"CategorySource": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAccountCategoryParams(DispatchBaseClass):
	'IAccountCategoryParams Interface'
	CLSID = IID('{797B09FC-E40A-42FA-9045-30B351D937F1}')
	coclass_clsid = IID('{449F96E1-0BA8-4C26-BD2F-DB0139B6ADBA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CategoryCode": (10, 2, (3, 0), (), "CategoryCode", None),
		"CategoryName": (11, 2, (8, 0), (), "CategoryName", None),
	}
	_prop_map_put_ = {
		"CategoryCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAccountCategoryService(DispatchBaseClass):
	'IAccountCategoryService Interface'
	CLSID = IID('{F2353C93-5EBC-4DDC-B750-717E97F41CF2}')
	coclass_clsid = IID('{D9C8E19C-6F74-4457-BEC3-332EABE6D013}')

	# Result is of type IAccountCategoryParams
	def AddCategory(self, pIAccountCategory=defaultNamedNotOptArg):
		'AddCategory'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIAccountCategory
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddCategory', '{797B09FC-E40A-42FA-9045-30B351D937F1}')
		return ret

	def DeleteCategory(self, pIAccountCategoryParams=defaultNamedNotOptArg):
		'DeleteCategory'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIAccountCategoryParams
			)

	# Result is of type IAccountCategory
	def GetCategory(self, pIAccountCategoryParams=defaultNamedNotOptArg):
		'GetCategory'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIAccountCategoryParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCategory', '{F656351C-32B3-4FE5-9054-221B5988B7E7}')
		return ret

	# Result is of type IAccountCategoriesParams
	def GetCategoryList(self):
		'GetCategoryList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCategoryList', '{AABB98FA-CCB5-4F0D-A6B6-5684708886C9}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateCategory(self, pIAccountCategory=defaultNamedNotOptArg):
		'UpdateCategory'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIAccountCategory
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAccountSegmentationCategories(DispatchBaseClass):
	'IAccountSegmentationCategories Interface'
	CLSID = IID('{2608CED7-EBD1-4F95-B41C-ECDF2CE685E4}')
	coclass_clsid = IID('{6398CC93-68AB-4886-9C3A-0EAC9F5814AA}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lSegmentId=defaultNamedNotOptArg, bstrCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1), (8, 1)),lSegmentId
			, bstrCode)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (12, 2, (8, 0), (), "Code", None),
		"Name": (13, 2, (8, 0), (), "Name", None),
		"SegmentID": (11, 2, (3, 0), (), "SegmentID", None),
		"ShortName": (14, 2, (8, 0), (), "ShortName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Code": ((12, LCID, 4, 0),()),
		"Name": ((13, LCID, 4, 0),()),
		"SegmentID": ((11, LCID, 4, 0),()),
		"ShortName": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAccountSegmentations(DispatchBaseClass):
	'IAccountSegmentations Interface'
	CLSID = IID('{7A1600FC-7942-4604-8D55-1923FF369965}')
	coclass_clsid = IID('{1688D816-29DF-4BF3-89A8-D6312DF351AB}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsID=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lAbsID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		# Method 'Categories' returns object of type 'IAcctSegmnt_Categories'
		"Categories": (14, 2, (9, 0), (), "Categories", '{414D11BE-00FC-4AF1-BEDF-C0B3308E1A40}'),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"Numerator": (10, 2, (3, 0), (), "Numerator", None),
		"Size": (12, 2, (3, 0), (), "Size", None),
		"Type": (13, 2, (3, 0), (), "Type", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((11, LCID, 4, 0),()),
		"Size": ((12, LCID, 4, 0),()),
		"Type": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAccountsService(DispatchBaseClass):
	'IAccountsService Interface'
	CLSID = IID('{43C8A942-73F5-40BE-9675-CC8946003F0A}')
	coclass_clsid = IID('{0104D235-3B56-47AF-ADEE-352BA7538035}')

	def CreateOpenBalance(self, pIOpenningBalanceAccount=defaultNamedNotOptArg, pGLAccounts=defaultNamedNotOptArg):
		'CreateOpenBalance'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((9, 1), (9, 1)),pIOpenningBalanceAccount
			, pGLAccounts)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAccrualType(DispatchBaseClass):
	'IAccrualType Interface'
	CLSID = IID('{439BEC35-EDAA-4F54-8FEF-647658D06148}')
	coclass_clsid = IID('{ED08E4CF-0DC1-40F4-9769-770663082515}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CalculationAccount": (13, 2, (8, 0), (), "CalculationAccount", None),
		"Code": (10, 2, (8, 0), (), "Code", None),
		"InterimAccount": (14, 2, (8, 0), (), "InterimAccount", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"PostingAccount": (12, 2, (8, 0), (), "PostingAccount", None),
	}
	_prop_map_put_ = {
		"CalculationAccount": ((13, LCID, 4, 0),()),
		"Code": ((10, LCID, 4, 0),()),
		"InterimAccount": ((14, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"PostingAccount": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAccrualTypeParams(DispatchBaseClass):
	'IAccrualTypeParams Interface'
	CLSID = IID('{70DC39C1-4019-4618-9D1F-7D227A68491F}')
	coclass_clsid = IID('{B1E97A7D-C850-4253-BF24-D946B20A13A3}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAccrualTypes(DispatchBaseClass):
	'IAccrualTypes Interface'
	CLSID = IID('{539EA80F-E53D-45C1-9610-C1D138699EFB}')
	coclass_clsid = IID('{03B794A4-682F-46BD-B17D-5373BEADF08D}')

	# Result is of type IAccrualType
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{439BEC35-EDAA-4F54-8FEF-647658D06148}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IAccrualType
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{439BEC35-EDAA-4F54-8FEF-647658D06148}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{439BEC35-EDAA-4F54-8FEF-647658D06148}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{439BEC35-EDAA-4F54-8FEF-647658D06148}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IAccrualTypesParams(DispatchBaseClass):
	'IAccrualTypesParams Interface'
	CLSID = IID('{046161D0-6736-48A3-A619-805A9C68F5C1}')
	coclass_clsid = IID('{6437CFC6-20AE-456A-8CD1-0F98D6F2CAF9}')

	# Result is of type IAccrualTypeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{70DC39C1-4019-4618-9D1F-7D227A68491F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IAccrualTypeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{70DC39C1-4019-4618-9D1F-7D227A68491F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{70DC39C1-4019-4618-9D1F-7D227A68491F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{70DC39C1-4019-4618-9D1F-7D227A68491F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IAccrualTypesService(DispatchBaseClass):
	'IAccrualTypesService Interface'
	CLSID = IID('{E78A5751-F0F7-4A5A-BDE0-B59BC461F57C}')
	coclass_clsid = IID('{99A581A7-0EC0-41CB-A273-D205125DB608}')

	# Result is of type IAccrualTypeParams
	def AddAccrualType(self, pIAccrualType=defaultNamedNotOptArg):
		'AddAccrualType'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIAccrualType
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddAccrualType', '{70DC39C1-4019-4618-9D1F-7D227A68491F}')
		return ret

	def DeleteAccrualType(self, pIAccrualTypeParams=defaultNamedNotOptArg):
		'DeleteAccrualType'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIAccrualTypeParams
			)

	# Result is of type IAccrualType
	def GetAccrualType(self, pIAccrualTypeParams=defaultNamedNotOptArg):
		'GetAccrualType'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIAccrualTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetAccrualType', '{439BEC35-EDAA-4F54-8FEF-647658D06148}')
		return ret

	# Result is of type IAccrualTypesParams
	def GetAccrualTypeList(self):
		'GetAccrualTypeList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetAccrualTypeList', '{046161D0-6736-48A3-A619-805A9C68F5C1}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateAccrualType(self, pIAccrualType=defaultNamedNotOptArg):
		'UpdateAccrualType'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIAccrualType
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAcctSegmnt_Categories(DispatchBaseClass):
	'IAcctSegmnt_Categories Interface'
	CLSID = IID('{414D11BE-00FC-4AF1-BEDF-C0B3308E1A40}')
	coclass_clsid = IID('{81735331-E9E5-4A93-9772-BA20A8027E7A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Code": (3, 2, (8, 0), (), "Code", None),
		"Name": (4, 2, (8, 0), (), "Name", None),
		"SegmentID": (2, 2, (3, 0), (), "SegmentID", None),
		"ShortName": (5, 2, (8, 0), (), "ShortName", None),
	}
	_prop_map_put_ = {
		"Code": ((3, LCID, 4, 0),()),
		"Name": ((4, LCID, 4, 0),()),
		"SegmentID": ((2, LCID, 4, 0),()),
		"ShortName": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivitiesParams(DispatchBaseClass):
	'IActivitiesParams Interface'
	CLSID = IID('{8289DE12-A145-459F-90F2-69A907294981}')
	coclass_clsid = IID('{0274D5B9-311A-4D13-A665-E981B9E43491}')

	# Result is of type IActivityParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IActivityParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IActivitiesService(DispatchBaseClass):
	'IActivitiesService Interface'
	CLSID = IID('{BABAB22E-0679-48A4-B7BD-BB0BF14F927F}')
	coclass_clsid = IID('{6C40800B-AFDB-4B88-947B-128F32F24EC9}')

	# Result is of type IActivityParams
	def AddActivity(self, pIActivity=defaultNamedNotOptArg):
		'AddActivity'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIActivity
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddActivity', '{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')
		return ret

	def DeleteActivity(self, pIActivityParams=defaultNamedNotOptArg):
		'DeleteActivity'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIActivityParams
			)

	def DeleteSingleInstanceFromSeries(self, pIActivityInstanceParams=defaultNamedNotOptArg):
		'DeleteSingleInstanceFromSeries'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (24, 0), ((9, 1),),pIActivityInstanceParams
			)

	# Result is of type IActivity
	def GetActivity(self, pIActivityParams=defaultNamedNotOptArg):
		'GetActivity'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIActivityParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetActivity', '{EE825513-A21F-467A-AAC5-931A7939C954}')
		return ret

	# Result is of type IActivitiesParams
	def GetActivityList(self):
		'GetActivityList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetActivityList', '{8289DE12-A145-459F-90F2-69A907294981}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IActivity
	def GetSingleInstanceFromSeries(self, pIActivityInstanceParams=defaultNamedNotOptArg):
		'GetSingleInstanceFromSeries'
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), ((9, 1),),pIActivityInstanceParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetSingleInstanceFromSeries', '{EE825513-A21F-467A-AAC5-931A7939C954}')
		return ret

	# Result is of type IActivityInstancesParams
	def GetTopNActivityInstances(self, pActivityInstancesListParams=defaultNamedNotOptArg):
		'GetTopNActivityInstances'
		ret = self._oleobj_.InvokeTypes(18, LCID, 1, (9, 0), ((9, 1),),pActivityInstancesListParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetTopNActivityInstances', '{681D8515-EF90-42C7-9463-3CE0B14E72C5}')
		return ret

	def UpdateActivity(self, pIActivity=defaultNamedNotOptArg):
		'UpdateActivity'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIActivity
			)

	# Result is of type IActivityParams
	def UpdateSingleInstanceInSeries(self, pIActivity=defaultNamedNotOptArg):
		'UpdateSingleInstanceInSeries'
		ret = self._oleobj_.InvokeTypes(16, LCID, 1, (9, 0), ((9, 1),),pIActivity
			)
		if ret is not None:
			ret = Dispatch(ret, u'UpdateSingleInstanceInSeries', '{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivity(DispatchBaseClass):
	'IActivity Interface'
	CLSID = IID('{EE825513-A21F-467A-AAC5-931A7939C954}')
	coclass_clsid = IID('{5EC86D5B-840B-4676-8D5B-6154AD738D09}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Activity": (26, 2, (3, 0), (), "Activity", None),
		"ActivityCode": (10, 2, (3, 0), (), "ActivityCode", None),
		"ActivityDate": (13, 2, (7, 0), (), "ActivityDate", None),
		"ActivityTime": (14, 2, (7, 0), (), "ActivityTime", None),
		"ActivityType": (27, 2, (3, 0), (), "ActivityType", None),
		"AddressName": (70, 2, (8, 0), (), "AddressName", None),
		"AddressType": (71, 2, (3, 0), (), "AddressType", None),
		"AttachmentEntry": (53, 2, (3, 0), (), "AttachmentEntry", None),
		"BelongedSeriesNum": (68, 2, (3, 0), (), "BelongedSeriesNum", None),
		"CardCode": (11, 2, (8, 0), (), "CardCode", None),
		"City": (39, 2, (8, 0), (), "City", None),
		"CloseDate": (17, 2, (7, 0), (), "CloseDate", None),
		"Closed": (16, 2, (3, 0), (), "Closed", None),
		"ContactPersonCode": (34, 2, (3, 0), (), "ContactPersonCode", None),
		"Country": (48, 2, (8, 0), (), "Country", None),
		"Details": (25, 2, (8, 0), (), "Details", None),
		"DocEntry": (23, 2, (8, 0), (), "DocEntry", None),
		"DocNum": (22, 2, (8, 0), (), "DocNum", None),
		"DocType": (21, 2, (8, 0), (), "DocType", None),
		"DocTypeEx": (52, 2, (8, 0), (), "DocTypeEx", None),
		"Duration": (31, 2, (5, 0), (), "Duration", None),
		"DurationType": (32, 2, (3, 0), (), "DurationType", None),
		"EndDuedate": (51, 2, (7, 0), (), "EndDuedate", None),
		"EndTime": (30, 2, (7, 0), (), "EndTime", None),
		"Fax": (19, 2, (8, 0), (), "Fax", None),
		"Friday": (65, 2, (3, 0), (), "Friday", None),
		"HandledBy": (35, 2, (3, 0), (), "HandledBy", None),
		"HandledByEmployee": (72, 2, (3, 0), (), "HandledByEmployee", None),
		"Inactiveflag": (45, 2, (3, 0), (), "Inactiveflag", None),
		"Interval": (59, 2, (3, 0), (), "Interval", None),
		"IsRemoved": (69, 2, (3, 0), (), "IsRemoved", None),
		"Location": (28, 2, (3, 0), (), "Location", None),
		"MaxOccurrence": (58, 2, (3, 0), (), "MaxOccurrence", None),
		"Monday": (61, 2, (3, 0), (), "Monday", None),
		"Notes": (12, 2, (8, 0), (), "Notes", None),
		"ParentobjectId": (42, 2, (3, 0), (), "ParentobjectId", None),
		"Parentobjecttype": (43, 2, (8, 0), (), "Parentobjecttype", None),
		"Personalflag": (40, 2, (3, 0), (), "Personalflag", None),
		"Phone": (18, 2, (8, 0), (), "Phone", None),
		"PreviousActivity": (47, 2, (3, 0), (), "PreviousActivity", None),
		"Priority": (24, 2, (3, 0), (), "Priority", None),
		"RecurrenceDayInMonth": (74, 2, (3, 0), (), "RecurrenceDayInMonth", None),
		"RecurrenceDayOfWeek": (76, 2, (3, 0), (), "RecurrenceDayOfWeek", None),
		"RecurrenceMonth": (75, 2, (3, 0), (), "RecurrenceMonth", None),
		"RecurrencePattern": (54, 2, (3, 0), (), "RecurrencePattern", None),
		"RecurrenceSequenceSpecifier": (73, 2, (3, 0), (), "RecurrenceSequenceSpecifier", None),
		"Reminder": (36, 2, (3, 0), (), "Reminder", None),
		"ReminderPeriod": (37, 2, (5, 0), (), "ReminderPeriod", None),
		"ReminderType": (38, 2, (3, 0), (), "ReminderType", None),
		"RepeatOption": (67, 2, (3, 0), (), "RepeatOption", None),
		"Room": (44, 2, (8, 0), (), "Room", None),
		"SalesEmployee": (33, 2, (3, 0), (), "SalesEmployee", None),
		"Saturday": (66, 2, (3, 0), (), "Saturday", None),
		"SeriesEndDate": (57, 2, (7, 0), (), "SeriesEndDate", None),
		"SeriesStartDate": (56, 2, (7, 0), (), "SeriesStartDate", None),
		"StartDate": (15, 2, (7, 0), (), "StartDate", None),
		"StartTime": (29, 2, (7, 0), (), "StartTime", None),
		"State": (46, 2, (8, 0), (), "State", None),
		"Status": (49, 2, (3, 0), (), "Status", None),
		"Street": (41, 2, (8, 0), (), "Street", None),
		"Subject": (20, 2, (3, 0), (), "Subject", None),
		"Sunday": (60, 2, (3, 0), (), "Sunday", None),
		"Tentativeflag": (50, 2, (3, 0), (), "Tentativeflag", None),
		"Thursday": (64, 2, (3, 0), (), "Thursday", None),
		"Tuesday": (62, 2, (3, 0), (), "Tuesday", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (77, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
		"Wednesday": (63, 2, (3, 0), (), "Wednesday", None),
		"endType": (55, 2, (3, 0), (), "endType", None),
	}
	_prop_map_put_ = {
		"Activity": ((26, LCID, 4, 0),()),
		"ActivityDate": ((13, LCID, 4, 0),()),
		"ActivityTime": ((14, LCID, 4, 0),()),
		"ActivityType": ((27, LCID, 4, 0),()),
		"AddressName": ((70, LCID, 4, 0),()),
		"AddressType": ((71, LCID, 4, 0),()),
		"AttachmentEntry": ((53, LCID, 4, 0),()),
		"CardCode": ((11, LCID, 4, 0),()),
		"City": ((39, LCID, 4, 0),()),
		"CloseDate": ((17, LCID, 4, 0),()),
		"Closed": ((16, LCID, 4, 0),()),
		"ContactPersonCode": ((34, LCID, 4, 0),()),
		"Country": ((48, LCID, 4, 0),()),
		"Details": ((25, LCID, 4, 0),()),
		"DocEntry": ((23, LCID, 4, 0),()),
		"DocType": ((21, LCID, 4, 0),()),
		"DocTypeEx": ((52, LCID, 4, 0),()),
		"Duration": ((31, LCID, 4, 0),()),
		"DurationType": ((32, LCID, 4, 0),()),
		"EndDuedate": ((51, LCID, 4, 0),()),
		"EndTime": ((30, LCID, 4, 0),()),
		"Fax": ((19, LCID, 4, 0),()),
		"Friday": ((65, LCID, 4, 0),()),
		"HandledBy": ((35, LCID, 4, 0),()),
		"HandledByEmployee": ((72, LCID, 4, 0),()),
		"Inactiveflag": ((45, LCID, 4, 0),()),
		"Interval": ((59, LCID, 4, 0),()),
		"Location": ((28, LCID, 4, 0),()),
		"MaxOccurrence": ((58, LCID, 4, 0),()),
		"Monday": ((61, LCID, 4, 0),()),
		"Notes": ((12, LCID, 4, 0),()),
		"Personalflag": ((40, LCID, 4, 0),()),
		"Phone": ((18, LCID, 4, 0),()),
		"PreviousActivity": ((47, LCID, 4, 0),()),
		"Priority": ((24, LCID, 4, 0),()),
		"RecurrenceDayInMonth": ((74, LCID, 4, 0),()),
		"RecurrenceDayOfWeek": ((76, LCID, 4, 0),()),
		"RecurrenceMonth": ((75, LCID, 4, 0),()),
		"RecurrencePattern": ((54, LCID, 4, 0),()),
		"RecurrenceSequenceSpecifier": ((73, LCID, 4, 0),()),
		"Reminder": ((36, LCID, 4, 0),()),
		"ReminderPeriod": ((37, LCID, 4, 0),()),
		"ReminderType": ((38, LCID, 4, 0),()),
		"RepeatOption": ((67, LCID, 4, 0),()),
		"Room": ((44, LCID, 4, 0),()),
		"SalesEmployee": ((33, LCID, 4, 0),()),
		"Saturday": ((66, LCID, 4, 0),()),
		"SeriesEndDate": ((57, LCID, 4, 0),()),
		"StartDate": ((15, LCID, 4, 0),()),
		"StartTime": ((29, LCID, 4, 0),()),
		"State": ((46, LCID, 4, 0),()),
		"Status": ((49, LCID, 4, 0),()),
		"Street": ((41, LCID, 4, 0),()),
		"Subject": ((20, LCID, 4, 0),()),
		"Sunday": ((60, LCID, 4, 0),()),
		"Tentativeflag": ((50, LCID, 4, 0),()),
		"Thursday": ((64, LCID, 4, 0),()),
		"Tuesday": ((62, LCID, 4, 0),()),
		"Wednesday": ((63, LCID, 4, 0),()),
		"endType": ((55, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivityInstanceParams(DispatchBaseClass):
	'IActivityInstanceParams Interface'
	CLSID = IID('{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}')
	coclass_clsid = IID('{869F134B-E012-418A-B519-FC5CBAC4E5F4}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ActivityCode": (10, 2, (3, 0), (), "ActivityCode", None),
		"InstanceDate": (11, 2, (7, 0), (), "InstanceDate", None),
	}
	_prop_map_put_ = {
		"ActivityCode": ((10, LCID, 4, 0),()),
		"InstanceDate": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivityInstancesListParams(DispatchBaseClass):
	'IActivityInstancesListParams Interface'
	CLSID = IID('{14BE1C8C-20CA-4E53-A55C-097AB57740B8}')
	coclass_clsid = IID('{8D12B6FF-AA47-441C-BA2F-C02A10890DCE}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"InstanceCount": (11, 2, (3, 0), (), "InstanceCount", None),
		"StartDate": (10, 2, (7, 0), (), "StartDate", None),
	}
	_prop_map_put_ = {
		"InstanceCount": ((11, LCID, 4, 0),()),
		"StartDate": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivityInstancesParams(DispatchBaseClass):
	'IActivityInstancesParams Interface'
	CLSID = IID('{681D8515-EF90-42C7-9463-3CE0B14E72C5}')
	coclass_clsid = IID('{90F5B36A-4621-44F8-BB72-8FC83DC756F2}')

	# Result is of type IActivityInstanceParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IActivityInstanceParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IActivityLocations(DispatchBaseClass):
	'IActivityLocations Interface'
	CLSID = IID('{0383EE76-4325-42FE-8164-91C2E8FDE242}')
	coclass_clsid = IID('{1FE6EEB5-6D21-4EE0-AC7C-8A2B181080C8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (1, 2, (3, 0), (), "Code", None),
		"Name": (2, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivityParams(DispatchBaseClass):
	'IActivityParams Interface'
	CLSID = IID('{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')
	coclass_clsid = IID('{A7420F65-B537-47B4-870C-CE7E3D98CB29}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ActivityCode": (10, 2, (3, 0), (), "ActivityCode", None),
	}
	_prop_map_put_ = {
		"ActivityCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivityStatus(DispatchBaseClass):
	'IActivityStatus Interface'
	CLSID = IID('{E985FCDC-43E0-47C4-821D-7F60D4BC9009}')
	coclass_clsid = IID('{07B255E1-6AF8-4615-BAC4-D258D316BF1B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, ActivityID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),ActivityID
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(6, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"StatusDescription": (1, 2, (8, 0), (), "StatusDescription", None),
		"StatusId": (2, 2, (3, 0), (), "StatusId", None),
		"StatusName": (3, 2, (8, 0), (), "StatusName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"StatusDescription": ((1, LCID, 4, 0),()),
		"StatusName": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IActivityTypes(DispatchBaseClass):
	'IActivityTypes Interface'
	CLSID = IID('{0C60C86B-3CB9-4E78-80D0-1AACB3C1C6F0}')
	coclass_clsid = IID('{094BA05B-B730-4D86-8BCF-91F788C16057}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (1, 2, (3, 0), (), "Code", None),
		"Name": (2, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAdditionalExpenses(DispatchBaseClass):
	'IAdditionalExpenses Interface'
	CLSID = IID('{0FCFCE88-47F3-4F05-9803-3081D83C92DC}')
	coclass_clsid = IID('{F68150E3-371A-4D4F-990C-16CDFF1A04FA}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(22, LCID, 1, (8, 0), (),)

	def GetByKey(self, ExpnsCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),ExpnsCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(23, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"DistributionMethod": (17, 2, (3, 0), (), "DistributionMethod", None),
		"DistributionRule": (26, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (32, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (33, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (34, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (35, 2, (8, 0), (), "DistributionRule5", None),
		"DrawingMethod": (27, 2, (3, 0), (), "DrawingMethod", None),
		"ExpensCode": (21, 2, (3, 0), (), "ExpensCode", None),
		"ExpenseAccount": (11, 2, (8, 0), (), "ExpenseAccount", None),
		"ExpenseExemptedAccount": (24, 2, (8, 0), (), "ExpenseExemptedAccount", None),
		"FixedAmountExpenses": (14, 2, (5, 0), (), "FixedAmountExpenses", None),
		"FixedAmountRevenues": (13, 2, (5, 0), (), "FixedAmountRevenues", None),
		"FreightOffsetAccount": (19, 2, (8, 0), (), "FreightOffsetAccount", None),
		"FreightType": (28, 2, (3, 0), (), "FreightType", None),
		"Includein1099": (18, 2, (3, 0), (), "Includein1099", None),
		"InputVATGroup": (16, 2, (8, 0), (), "InputVATGroup", None),
		"LastPurchasePrice": (30, 2, (3, 0), (), "LastPurchasePrice", None),
		"Name": (9, 2, (8, 0), (), "Name", None),
		"OutputVATGroup": (15, 2, (8, 0), (), "OutputVATGroup", None),
		"Project": (31, 2, (8, 0), (), "Project", None),
		"RevenuesAccount": (10, 2, (8, 0), (), "RevenuesAccount", None),
		"RevenuesExemptedAccount": (25, 2, (8, 0), (), "RevenuesExemptedAccount", None),
		"Stock": (29, 2, (3, 0), (), "Stock", None),
		"TaxLiable": (12, 2, (3, 0), (), "TaxLiable", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WTLiable": (20, 2, (8, 0), (), "WTLiable", None),
	}
	_prop_map_put_ = {
		"DistributionMethod": ((17, LCID, 4, 0),()),
		"DistributionRule": ((26, LCID, 4, 0),()),
		"DistributionRule2": ((32, LCID, 4, 0),()),
		"DistributionRule3": ((33, LCID, 4, 0),()),
		"DistributionRule4": ((34, LCID, 4, 0),()),
		"DistributionRule5": ((35, LCID, 4, 0),()),
		"DrawingMethod": ((27, LCID, 4, 0),()),
		"ExpenseAccount": ((11, LCID, 4, 0),()),
		"ExpenseExemptedAccount": ((24, LCID, 4, 0),()),
		"FixedAmountExpenses": ((14, LCID, 4, 0),()),
		"FixedAmountRevenues": ((13, LCID, 4, 0),()),
		"FreightOffsetAccount": ((19, LCID, 4, 0),()),
		"FreightType": ((28, LCID, 4, 0),()),
		"Includein1099": ((18, LCID, 4, 0),()),
		"InputVATGroup": ((16, LCID, 4, 0),()),
		"LastPurchasePrice": ((30, LCID, 4, 0),()),
		"Name": ((9, LCID, 4, 0),()),
		"OutputVATGroup": ((15, LCID, 4, 0),()),
		"Project": ((31, LCID, 4, 0),()),
		"RevenuesAccount": ((10, LCID, 4, 0),()),
		"RevenuesExemptedAccount": ((25, LCID, 4, 0),()),
		"Stock": ((29, LCID, 4, 0),()),
		"TaxLiable": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAddressExtension(DispatchBaseClass):
	'IAddressExtension Interface'
	CLSID = IID('{7CBD5DDC-C99C-4D73-9ECC-C8B6CDF2FB92}')
	coclass_clsid = IID('{8FDEBBA0-2EDA-4AFE-9EC1-3A45913C68DA}')

	_prop_map_get_ = {
		"BillToAddressType": (20, 2, (8, 0), (), "BillToAddressType", None),
		"BillToBlock": (13, 2, (8, 0), (), "BillToBlock", None),
		"BillToBuilding": (14, 2, (8, 0), (), "BillToBuilding", None),
		"BillToCity": (15, 2, (8, 0), (), "BillToCity", None),
		"BillToCountry": (19, 2, (8, 0), (), "BillToCountry", None),
		"BillToCounty": (17, 2, (8, 0), (), "BillToCounty", None),
		"BillToState": (18, 2, (8, 0), (), "BillToState", None),
		"BillToStreet": (11, 2, (8, 0), (), "BillToStreet", None),
		"BillToStreetNo": (12, 2, (8, 0), (), "BillToStreetNo", None),
		"BillToZipCode": (16, 2, (8, 0), (), "BillToZipCode", None),
		"ShipToAddressType": (10, 2, (8, 0), (), "ShipToAddressType", None),
		"ShipToBlock": (3, 2, (8, 0), (), "ShipToBlock", None),
		"ShipToBuilding": (4, 2, (8, 0), (), "ShipToBuilding", None),
		"ShipToCity": (5, 2, (8, 0), (), "ShipToCity", None),
		"ShipToCountry": (9, 2, (8, 0), (), "ShipToCountry", None),
		"ShipToCounty": (7, 2, (8, 0), (), "ShipToCounty", None),
		"ShipToState": (8, 2, (8, 0), (), "ShipToState", None),
		"ShipToStreet": (1, 2, (8, 0), (), "ShipToStreet", None),
		"ShipToStreetNo": (2, 2, (8, 0), (), "ShipToStreetNo", None),
		"ShipToZipCode": (6, 2, (8, 0), (), "ShipToZipCode", None),
	}
	_prop_map_put_ = {
		"BillToAddressType": ((20, LCID, 4, 0),()),
		"BillToBlock": ((13, LCID, 4, 0),()),
		"BillToBuilding": ((14, LCID, 4, 0),()),
		"BillToCity": ((15, LCID, 4, 0),()),
		"BillToCountry": ((19, LCID, 4, 0),()),
		"BillToCounty": ((17, LCID, 4, 0),()),
		"BillToState": ((18, LCID, 4, 0),()),
		"BillToStreet": ((11, LCID, 4, 0),()),
		"BillToStreetNo": ((12, LCID, 4, 0),()),
		"BillToZipCode": ((16, LCID, 4, 0),()),
		"ShipToAddressType": ((10, LCID, 4, 0),()),
		"ShipToBlock": ((3, LCID, 4, 0),()),
		"ShipToBuilding": ((4, LCID, 4, 0),()),
		"ShipToCity": ((5, LCID, 4, 0),()),
		"ShipToCountry": ((9, LCID, 4, 0),()),
		"ShipToCounty": ((7, LCID, 4, 0),()),
		"ShipToState": ((8, LCID, 4, 0),()),
		"ShipToStreet": ((1, LCID, 4, 0),()),
		"ShipToStreetNo": ((2, LCID, 4, 0),()),
		"ShipToZipCode": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAdminInfo(DispatchBaseClass):
	'IAdminInfo Interface'
	CLSID = IID('{4583DECC-E80D-46AE-B3C0-308FC33C58E9}')
	coclass_clsid = IID('{16521FC3-2B92-47B4-89E1-3145EE333649}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AccountSegmentsSeparator": (140, 2, (8, 0), (), "AccountSegmentsSeparator", None),
		"AccuracyofQuantities": (71, 2, (3, 0), (), "AccuracyofQuantities", None),
		"AdditionalIdNumber": (171, 2, (8, 0), (), "AdditionalIdNumber", None),
		"Address": (10, 2, (8, 0), (), "Address", None),
		"AddressinForeignLanguage": (76, 2, (8, 0), (), "AddressinForeignLanguage", None),
		"AdressFromWH": (151, 2, (3, 0), (), "AdressFromWH", None),
		"AdvancesonCorpIncomeTax": (34, 2, (5, 0), (), "AdvancesonCorpIncomeTax", None),
		"AlertTypeforWHStock": (55, 2, (3, 0), (), "AlertTypeforWHStock", None),
		"AlertbyWarehouse": (126, 2, (3, 0), (), "AlertbyWarehouse", None),
		"AliasName": (234, 2, (8, 0), (), "AliasName", None),
		"AllowClosedSalesQuotations": (67, 2, (3, 0), (), "AllowClosedSalesQuotations", None),
		"AllowFuturePostingDate": (170, 2, (3, 0), (), "AllowFuturePostingDate", None),
		"AllowMultipleBAOnSamePeriod": (238, 2, (3, 0), (), "AllowMultipleBAOnSamePeriod", None),
		"AltNameForApInvoice": (50, 2, (8, 0), (), "AltNameForApInvoice", None),
		"AltNameForGoodsReceipt": (52, 2, (8, 0), (), "AltNameForGoodsReceipt", None),
		"AltNameForGoodsReturn": (53, 2, (8, 0), (), "AltNameForGoodsReturn", None),
		"AltNameForPurchase": (54, 2, (8, 0), (), "AltNameForPurchase", None),
		"AltNameforCreditMemo": (51, 2, (8, 0), (), "AltNameforCreditMemo", None),
		"ApplicationOfIFRS": (214, 2, (3, 0), (), "ApplicationOfIFRS", None),
		"BPTypeCode": (136, 2, (8, 0), (), "BPTypeCode", None),
		"BankCountry": (27, 2, (8, 0), (), "BankCountry", None),
		"BankStatementInstalled": (174, 2, (3, 0), (), "BankStatementInstalled", None),
		"BaseField": (66, 2, (3, 0), (), "BaseField", None),
		"BlockBookkeeping": (105, 2, (3, 0), (), "BlockBookkeeping", None),
		"BlockBudget": (102, 2, (3, 0), (), "BlockBudget", None),
		"BlockDelNotesforPurchase": (110, 2, (3, 0), (), "BlockDelNotesforPurchase", None),
		"BlockMultipleBAOnSameAPDocument": (239, 2, (3, 0), (), "BlockMultipleBAOnSameAPDocument", None),
		"BlockMultipleBAOnSameARDocument": (240, 2, (3, 0), (), "BlockMultipleBAOnSameARDocument", None),
		"BlockPostingDateEditing": (93, 2, (3, 0), (), "BlockPostingDateEditing", None),
		"BlockPurchaseOrders": (104, 2, (3, 0), (), "BlockPurchaseOrders", None),
		"BlockSystemCurrencyEditing": (92, 2, (3, 0), (), "BlockSystemCurrencyEditing", None),
		"BlockTaxDate": (95, 2, (3, 0), (), "BlockTaxDate", None),
		"BoletoFolderPath": (241, 2, (8, 0), (), "BoletoFolderPath", None),
		"BudgetAlert": (103, 2, (3, 0), (), "BudgetAlert", None),
		"CalculateBudget": (100, 2, (3, 0), (), "CalculateBudget", None),
		"CalculateGrossProfitperTra": (61, 2, (3, 0), (), "CalculateGrossProfitperTra", None),
		"CalculateRowDiscount": (173, 2, (3, 0), (), "CalculateRowDiscount", None),
		"CalculateTaxinSalesQuotati": (65, 2, (3, 0), (), "CalculateTaxinSalesQuotati", None),
		"CertificateNo": (153, 2, (8, 0), (), "CertificateNo", None),
		"ChangeDefReconAPAccounts": (134, 2, (3, 0), (), "ChangeDefReconAPAccounts", None),
		"ChangeDefReconARAccounts": (135, 2, (3, 0), (), "ChangeDefReconARAccounts", None),
		"ChangedExistingOrders": (87, 2, (3, 0), (), "ChangedExistingOrders", None),
		"ChartofAccountsTemplate": (18, 2, (8, 0), (), "ChartofAccountsTemplate", None),
		"Code": (202, 2, (3, 0), (), "Code", None),
		"CommitmentRestriction": (41, 2, (3, 0), (), "CommitmentRestriction", None),
		"CompanyColor": (69, 2, (3, 0), (), "CompanyColor", None),
		"CompanyName": (9, 2, (8, 0), (), "CompanyName", None),
		"ConsiderDelNotesinSalesR": (46, 2, (3, 0), (), "ConsiderDelNotesinSalesR", None),
		"ConsumeForecast": (163, 2, (3, 0), (), "ConsumeForecast", None),
		"ConsumptionMethod": (164, 2, (3, 0), (), "ConsumptionMethod", None),
		"ContinuousStockManagement": (107, 2, (3, 0), (), "ContinuousStockManagement", None),
		"ContinuousStockSystem": (108, 2, (3, 0), (), "ContinuousStockSystem", None),
		"CopyExchangeRateInCopyTo": (203, 2, (3, 0), (), "CopyExchangeRateInCopyTo", None),
		"CopyOpenRowsToDelivery": (218, 2, (3, 0), (), "CopyOpenRowsToDelivery", None),
		"Country": (11, 2, (8, 0), (), "Country", None),
		"CreateAutoVATLineinJDT": (162, 2, (3, 0), (), "CreateAutoVATLineinJDT", None),
		"CreateOnlineQuotation": (217, 2, (3, 0), (), "CreateOnlineQuotation", None),
		"CreditBalancewithMinusSign": (21, 2, (3, 0), (), "CreditBalancewithMinusSign", None),
		"CreditDepositType": (47, 2, (3, 0), (), "CreditDepositType", None),
		"CreditRestriction": (42, 2, (3, 0), (), "CreditRestriction", None),
		"CustomerIdNumber": (101, 2, (8, 0), (), "CustomerIdNumber", None),
		"CustomersDeductionatSource": (37, 2, (3, 0), (), "CustomersDeductionatSource", None),
		"DateSeparator": (85, 2, (8, 0), (), "DateSeparator", None),
		"DateTemplate": (84, 2, (3, 0), (), "DateTemplate", None),
		"DaysBackward": (165, 2, (3, 0), (), "DaysBackward", None),
		"DaysForward": (166, 2, (3, 0), (), "DaysForward", None),
		"DecimalSeparator": (123, 2, (8, 0), (), "DecimalSeparator", None),
		"DeductionFileNo": (30, 2, (8, 0), (), "DeductionFileNo", None),
		"DefaultAccountCurrency": (160, 2, (3, 0), (), "DefaultAccountCurrency", None),
		"DefaultBankAccount": (114, 2, (8, 0), (), "DefaultBankAccount", None),
		"DefaultBankAccountKey": (168, 2, (3, 0), (), "DefaultBankAccountKey", None),
		"DefaultBankNo": (113, 2, (8, 0), (), "DefaultBankNo", None),
		"DefaultBranch": (115, 2, (8, 0), (), "DefaultBranch", None),
		"DefaultBudgetCostAssessMt": (106, 2, (3, 0), (), "DefaultBudgetCostAssessMt", None),
		"DefaultCustomerPaymentTerms": (59, 2, (3, 0), (), "DefaultCustomerPaymentTerms", None),
		"DefaultDunningTerm": (167, 2, (8, 0), (), "DefaultDunningTerm", None),
		"DefaultTaxCode": (77, 2, (8, 0), (), "DefaultTaxCode", None),
		"DefaultVendorPaymentTerms": (60, 2, (3, 0), (), "DefaultVendorPaymentTerms", None),
		"DefaultWarehouse": (94, 2, (8, 0), (), "DefaultWarehouse", None),
		"DefaultforBatchStatus": (130, 2, (3, 0), (), "DefaultforBatchStatus", None),
		"DeferredTax": (112, 2, (3, 0), (), "DeferredTax", None),
		"DeferredTaxforVendors": (161, 2, (3, 0), (), "DeferredTaxforVendors", None),
		"DirectIndirectRate": (24, 2, (3, 0), (), "DirectIndirectRate", None),
		"DisplayBookkeepingWindow": (141, 2, (3, 0), (), "DisplayBookkeepingWindow", None),
		"DisplayCurrencyontheRight": (125, 2, (3, 0), (), "DisplayCurrencyontheRight", None),
		"DisplayPriceforPriceOnly": (64, 2, (3, 0), (), "DisplayPriceforPriceOnly", None),
		"DisplayRoundingRemark": (90, 2, (3, 0), (), "DisplayRoundingRemark", None),
		"DocConfirmation": (129, 2, (3, 0), (), "DocConfirmation", None),
		"EmployerReference": (176, 2, (8, 0), (), "EmployerReference", None),
		"EnableApprovalProcedureInDI": (219, 2, (3, 0), (), "EnableApprovalProcedureInDI", None),
		"EnableBranches": (230, 2, (3, 0), (), "EnableBranches", None),
		"EnableCentralizedIncomingPayments": (235, 2, (3, 0), (), "EnableCentralizedIncomingPayments", None),
		"EnableCentralizedOutgoingPayments": (236, 2, (3, 0), (), "EnableCentralizedOutgoingPayments", None),
		"EnablePaymentDueDates": (232, 2, (3, 0), (), "EnablePaymentDueDates", None),
		"ExcelFolderPath": (120, 2, (8, 0), (), "ExcelFolderPath", None),
		"ExpirationDate": (154, 2, (7, 0), (), "ExpirationDate", None),
		# Method 'ExtendedAdminInfo' returns object of type 'IExtendedAdminInfo'
		"ExtendedAdminInfo": (179, 2, (9, 0), (), "ExtendedAdminInfo", '{6AAAB602-C1E1-4988-BF5D-ECE369936FC0}'),
		"FCCheckAccount": (86, 2, (3, 0), (), "FCCheckAccount", None),
		"FaxNumber": (15, 2, (8, 0), (), "FaxNumber", None),
		"FaxNumberForeignLang": (81, 2, (8, 0), (), "FaxNumberForeignLang", None),
		"FederalTaxID": (28, 2, (8, 0), (), "FederalTaxID", None),
		"FederalTaxID2": (121, 2, (8, 0), (), "FederalTaxID2", None),
		"FederalTaxID3": (122, 2, (8, 0), (), "FederalTaxID3", None),
		"FileNumberinIncomeTax": (111, 2, (8, 0), (), "FileNumberinIncomeTax", None),
		"GLMethod": (131, 2, (3, 0), (), "GLMethod", None),
		"GTSDefaultChecker": (207, 2, (3, 0), (), "GTSDefaultChecker", None),
		"GTSDefaultPayee": (208, 2, (3, 0), (), "GTSDefaultPayee", None),
		"GTSInboundFolder": (205, 2, (8, 0), (), "GTSInboundFolder", None),
		"GTSMaxAmount": (209, 2, (5, 0), (), "GTSMaxAmount", None),
		"GTSOutboundFolder": (204, 2, (8, 0), (), "GTSOutboundFolder", None),
		"GTSResponseToExceeding": (210, 2, (3, 0), (), "GTSResponseToExceeding", None),
		"GTSSeparateCode": (206, 2, (8, 0), (), "GTSSeparateCode", None),
		"GeneralManager": (182, 2, (8, 0), (), "GeneralManager", None),
		"GeneralManagerForeignLanguage": (183, 2, (8, 0), (), "GeneralManagerForeignLanguage", None),
		"GrossProfitAfterSale": (63, 2, (3, 0), (), "GrossProfitAfterSale", None),
		"GrossProfitPercentForServiceDocuments": (200, 2, (5, 0), (), "GrossProfitPercentForServiceDocuments", None),
		"HolidaysName": (148, 2, (8, 0), (), "HolidaysName", None),
		"IEMandatoryValidation": (231, 2, (3, 0), (), "IEMandatoryValidation", None),
		"ISRBillerID": (91, 2, (8, 0), (), "ISRBillerID", None),
		"ISRType": (89, 2, (3, 0), (), "ISRType", None),
		"IsPrinterConnected": (220, 2, (3, 0), (), "IsPrinterConnected", None),
		"LetterHeaderinForeignLangu": (78, 2, (8, 0), (), "LetterHeaderinForeignLangu", None),
		"LocalCurrency": (19, 2, (8, 0), (), "LocalCurrency", None),
		"ManagingDirector": (17, 2, (8, 0), (), "ManagingDirector", None),
		"ManagingDirectorForeignLan": (82, 2, (8, 0), (), "ManagingDirectorForeignLan", None),
		"MaxHistory": (133, 2, (3, 0), (), "MaxHistory", None),
		"MaximumNumberOfDaysForDueDate": (233, 2, (3, 0), (), "MaximumNumberOfDaysForDueDate", None),
		"MeasuringAccuracy": (75, 2, (3, 0), (), "MeasuringAccuracy", None),
		"MinimumAmountfor347Report": (25, 2, (5, 0), (), "MinimumAmountfor347Report", None),
		"MultiCurrencyCheck": (88, 2, (3, 0), (), "MultiCurrencyCheck", None),
		"MultiLanguageSupportEnable": (169, 2, (3, 0), (), "MultiLanguageSupportEnable", None),
		"NationalInsuranceNo": (155, 2, (8, 0), (), "NationalInsuranceNo", None),
		"OrderBlock": (149, 2, (8, 0), (), "OrderBlock", None),
		"OrderingParty": (152, 2, (8, 0), (), "OrderingParty", None),
		"OrganizationNumber": (139, 2, (8, 0), (), "OrganizationNumber", None),
		"PBSGroupNumber": (138, 2, (8, 0), (), "PBSGroupNumber", None),
		"PBSNumber": (137, 2, (8, 0), (), "PBSNumber", None),
		"PDefaultWTCode": (145, 2, (8, 0), (), "PDefaultWTCode", None),
		"PDfltITWT": (159, 2, (8, 0), (), "PDfltITWT", None),
		"ParamFolderPath": (119, 2, (8, 0), (), "ParamFolderPath", None),
		"PercentageAccuracy": (74, 2, (3, 0), (), "PercentageAccuracy", None),
		"PeriodStatusAutoChange": (177, 2, (3, 0), (), "PeriodStatusAutoChange", None),
		"PeriodStatusChangeDelay": (178, 2, (3, 0), (), "PeriodStatusChangeDelay", None),
		"PhoneNumber1": (13, 2, (8, 0), (), "PhoneNumber1", None),
		"PhoneNumber1ForeignLang": (79, 2, (8, 0), (), "PhoneNumber1ForeignLang", None),
		"PhoneNumber2": (14, 2, (8, 0), (), "PhoneNumber2", None),
		"PhoneNumber2ForeignLang": (80, 2, (8, 0), (), "PhoneNumber2ForeignLang", None),
		"PickList": (201, 2, (3, 0), (), "PickList", None),
		"PriceAccuracy": (72, 2, (3, 0), (), "PriceAccuracy", None),
		"PriceListforCostPrice": (62, 2, (3, 0), (), "PriceListforCostPrice", None),
		"PriceSystem": (127, 2, (3, 0), (), "PriceSystem", None),
		"PrintingHeader": (12, 2, (8, 0), (), "PrintingHeader", None),
		"PurchaseOrderConfirmed": (157, 2, (3, 0), (), "PurchaseOrderConfirmed", None),
		"QueryAccuracy": (181, 2, (3, 0), (), "QueryAccuracy", None),
		"RateAccuracy": (73, 2, (3, 0), (), "RateAccuracy", None),
		"ReportAccordingTo": (216, 2, (3, 0), (), "ReportAccordingTo", None),
		"RestrictDelNotesPO": (44, 2, (3, 0), (), "RestrictDelNotesPO", None),
		"RestrictOrders": (45, 2, (3, 0), (), "RestrictOrders", None),
		"RestrictSales": (43, 2, (3, 0), (), "RestrictSales", None),
		"RoundTaxAmounts": (109, 2, (3, 0), (), "RoundTaxAmounts", None),
		"RoundingMethod": (150, 2, (3, 0), (), "RoundingMethod", None),
		"SDefaultWTCode": (143, 2, (8, 0), (), "SDefaultWTCode", None),
		"SDfltITWT": (158, 2, (8, 0), (), "SDfltITWT", None),
		"SHandleWT": (142, 2, (3, 0), (), "SHandleWT", None),
		"SalesOrderConfirmed": (156, 2, (3, 0), (), "SalesOrderConfirmed", None),
		"ServiceCode": (117, 2, (8, 0), (), "ServiceCode", None),
		"ServicePassword": (118, 2, (8, 0), (), "ServicePassword", None),
		"SetCommissionbyCustomer": (56, 2, (3, 0), (), "SetCommissionbyCustomer", None),
		"SetCommissionbyItem": (57, 2, (3, 0), (), "SetCommissionbyItem", None),
		"SetCommissionbySE": (58, 2, (3, 0), (), "SetCommissionbySE", None),
		"SetItemsWarehouses": (26, 2, (3, 0), (), "SetItemsWarehouses", None),
		"SplitPO": (49, 2, (3, 0), (), "SplitPO", None),
		"StandardUnitofLength": (22, 2, (3, 0), (), "StandardUnitofLength", None),
		"StartingInFiscalYear": (215, 2, (3, 0), (), "StartingInFiscalYear", None),
		"State": (172, 2, (8, 0), (), "State", None),
		"SystemCurrency": (20, 2, (8, 0), (), "SystemCurrency", None),
		"TaxCollection": (31, 2, (3, 0), (), "TaxCollection", None),
		"TaxDefinition": (32, 2, (3, 0), (), "TaxDefinition", None),
		"TaxDefinitionforVatitem": (96, 2, (8, 0), (), "TaxDefinitionforVatitem", None),
		"TaxDefinitionforVatservice": (97, 2, (8, 0), (), "TaxDefinitionforVatservice", None),
		"TaxGroupforPurchaseItem": (98, 2, (8, 0), (), "TaxGroupforPurchaseItem", None),
		"TaxGroupforServicePurchase": (99, 2, (8, 0), (), "TaxGroupforServicePurchase", None),
		"TaxOffice": (29, 2, (8, 0), (), "TaxOffice", None),
		"TaxPercentage": (33, 2, (5, 0), (), "TaxPercentage", None),
		"TaxRateDetermination": (237, 2, (3, 0), (), "TaxRateDetermination", None),
		"ThousandsSeparator": (124, 2, (8, 0), (), "ThousandsSeparator", None),
		"TimeTemplate": (83, 2, (3, 0), (), "TimeTemplate", None),
		"TotalsAccuracy": (70, 2, (3, 0), (), "TotalsAccuracy", None),
		"UniqueSerialNo": (132, 2, (3, 0), (), "UniqueSerialNo", None),
		"UniqueTaxPayerReference": (175, 2, (8, 0), (), "UniqueTaxPayerReference", None),
		"UseNegativeAmounts": (147, 2, (3, 0), (), "UseNegativeAmounts", None),
		"UsePASystem": (116, 2, (3, 0), (), "UsePASystem", None),
		"UseProductionProfitAndLossAccount": (211, 2, (3, 0), (), "UseProductionProfitAndLossAccount", None),
		"UseTax": (48, 2, (3, 0), (), "UseTax", None),
		"UserConversionCode": (68, 2, (3, 0), (), "UserConversionCode", None),
		"WTAccumAmountAP": (212, 2, (5, 0), (), "WTAccumAmountAP", None),
		"WTAccumAmountAR": (213, 2, (5, 0), (), "WTAccumAmountAR", None),
		"WTLiableExpense": (146, 2, (3, 0), (), "WTLiableExpense", None),
		"WeightUnitDefault": (23, 2, (3, 0), (), "WeightUnitDefault", None),
		"WholdingTaxDedHierarchy": (128, 2, (3, 0), (), "WholdingTaxDedHierarchy", None),
		"WithTax": (35, 2, (5, 0), (), "WithTax", None),
		"WithholdingTaxDdctExpired": (39, 2, (7, 0), (), "WithholdingTaxDdctExpired", None),
		"WithholdingTaxDdctOffice": (40, 2, (8, 0), (), "WithholdingTaxDdctOffice", None),
		"WithholdingTaxPHandle": (144, 2, (8, 0), (), "WithholdingTaxPHandle", None),
		"WithholdingTaxTdctPercnt": (38, 2, (5, 0), (), "WithholdingTaxTdctPercnt", None),
		"WithholdingTaxVendorDdct": (36, 2, (3, 0), (), "WithholdingTaxVendorDdct", None),
		"XMLFileFolderPath": (180, 2, (8, 0), (), "XMLFileFolderPath", None),
		"eMail": (16, 2, (8, 0), (), "eMail", None),
	}
	_prop_map_put_ = {
		"AccountSegmentsSeparator": ((140, LCID, 4, 0),()),
		"AccuracyofQuantities": ((71, LCID, 4, 0),()),
		"AdditionalIdNumber": ((171, LCID, 4, 0),()),
		"AddressinForeignLanguage": ((76, LCID, 4, 0),()),
		"AdressFromWH": ((151, LCID, 4, 0),()),
		"AdvancesonCorpIncomeTax": ((34, LCID, 4, 0),()),
		"AlertTypeforWHStock": ((55, LCID, 4, 0),()),
		"AlertbyWarehouse": ((126, LCID, 4, 0),()),
		"AliasName": ((234, LCID, 4, 0),()),
		"AllowClosedSalesQuotations": ((67, LCID, 4, 0),()),
		"AllowFuturePostingDate": ((170, LCID, 4, 0),()),
		"AllowMultipleBAOnSamePeriod": ((238, LCID, 4, 0),()),
		"AltNameForApInvoice": ((50, LCID, 4, 0),()),
		"AltNameForGoodsReceipt": ((52, LCID, 4, 0),()),
		"AltNameForGoodsReturn": ((53, LCID, 4, 0),()),
		"AltNameForPurchase": ((54, LCID, 4, 0),()),
		"AltNameforCreditMemo": ((51, LCID, 4, 0),()),
		"ApplicationOfIFRS": ((214, LCID, 4, 0),()),
		"BPTypeCode": ((136, LCID, 4, 0),()),
		"BankCountry": ((27, LCID, 4, 0),()),
		"BaseField": ((66, LCID, 4, 0),()),
		"BlockBookkeeping": ((105, LCID, 4, 0),()),
		"BlockBudget": ((102, LCID, 4, 0),()),
		"BlockDelNotesforPurchase": ((110, LCID, 4, 0),()),
		"BlockMultipleBAOnSameAPDocument": ((239, LCID, 4, 0),()),
		"BlockMultipleBAOnSameARDocument": ((240, LCID, 4, 0),()),
		"BlockPostingDateEditing": ((93, LCID, 4, 0),()),
		"BlockPurchaseOrders": ((104, LCID, 4, 0),()),
		"BlockSystemCurrencyEditing": ((92, LCID, 4, 0),()),
		"BlockTaxDate": ((95, LCID, 4, 0),()),
		"BoletoFolderPath": ((241, LCID, 4, 0),()),
		"BudgetAlert": ((103, LCID, 4, 0),()),
		"CalculateBudget": ((100, LCID, 4, 0),()),
		"CalculateGrossProfitperTra": ((61, LCID, 4, 0),()),
		"CalculateRowDiscount": ((173, LCID, 4, 0),()),
		"CalculateTaxinSalesQuotati": ((65, LCID, 4, 0),()),
		"CertificateNo": ((153, LCID, 4, 0),()),
		"ChangeDefReconAPAccounts": ((134, LCID, 4, 0),()),
		"ChangeDefReconARAccounts": ((135, LCID, 4, 0),()),
		"ChangedExistingOrders": ((87, LCID, 4, 0),()),
		"ChartofAccountsTemplate": ((18, LCID, 4, 0),()),
		"CommitmentRestriction": ((41, LCID, 4, 0),()),
		"CompanyColor": ((69, LCID, 4, 0),()),
		"CompanyName": ((9, LCID, 4, 0),()),
		"ConsiderDelNotesinSalesR": ((46, LCID, 4, 0),()),
		"ConsumeForecast": ((163, LCID, 4, 0),()),
		"ConsumptionMethod": ((164, LCID, 4, 0),()),
		"ContinuousStockManagement": ((107, LCID, 4, 0),()),
		"ContinuousStockSystem": ((108, LCID, 4, 0),()),
		"CopyExchangeRateInCopyTo": ((203, LCID, 4, 0),()),
		"CopyOpenRowsToDelivery": ((218, LCID, 4, 0),()),
		"Country": ((11, LCID, 4, 0),()),
		"CreateAutoVATLineinJDT": ((162, LCID, 4, 0),()),
		"CreateOnlineQuotation": ((217, LCID, 4, 0),()),
		"CreditBalancewithMinusSign": ((21, LCID, 4, 0),()),
		"CreditDepositType": ((47, LCID, 4, 0),()),
		"CreditRestriction": ((42, LCID, 4, 0),()),
		"CustomerIdNumber": ((101, LCID, 4, 0),()),
		"CustomersDeductionatSource": ((37, LCID, 4, 0),()),
		"DateSeparator": ((85, LCID, 4, 0),()),
		"DateTemplate": ((84, LCID, 4, 0),()),
		"DaysBackward": ((165, LCID, 4, 0),()),
		"DaysForward": ((166, LCID, 4, 0),()),
		"DecimalSeparator": ((123, LCID, 4, 0),()),
		"DeductionFileNo": ((30, LCID, 4, 0),()),
		"DefaultAccountCurrency": ((160, LCID, 4, 0),()),
		"DefaultBankAccount": ((114, LCID, 4, 0),()),
		"DefaultBankAccountKey": ((168, LCID, 4, 0),()),
		"DefaultBankNo": ((113, LCID, 4, 0),()),
		"DefaultBudgetCostAssessMt": ((106, LCID, 4, 0),()),
		"DefaultCustomerPaymentTerms": ((59, LCID, 4, 0),()),
		"DefaultDunningTerm": ((167, LCID, 4, 0),()),
		"DefaultTaxCode": ((77, LCID, 4, 0),()),
		"DefaultVendorPaymentTerms": ((60, LCID, 4, 0),()),
		"DefaultWarehouse": ((94, LCID, 4, 0),()),
		"DefaultforBatchStatus": ((130, LCID, 4, 0),()),
		"DeferredTax": ((112, LCID, 4, 0),()),
		"DeferredTaxforVendors": ((161, LCID, 4, 0),()),
		"DirectIndirectRate": ((24, LCID, 4, 0),()),
		"DisplayBookkeepingWindow": ((141, LCID, 4, 0),()),
		"DisplayCurrencyontheRight": ((125, LCID, 4, 0),()),
		"DisplayPriceforPriceOnly": ((64, LCID, 4, 0),()),
		"DisplayRoundingRemark": ((90, LCID, 4, 0),()),
		"DocConfirmation": ((129, LCID, 4, 0),()),
		"EmployerReference": ((176, LCID, 4, 0),()),
		"EnableApprovalProcedureInDI": ((219, LCID, 4, 0),()),
		"EnableBranches": ((230, LCID, 4, 0),()),
		"EnableCentralizedIncomingPayments": ((235, LCID, 4, 0),()),
		"EnableCentralizedOutgoingPayments": ((236, LCID, 4, 0),()),
		"EnablePaymentDueDates": ((232, LCID, 4, 0),()),
		"ExcelFolderPath": ((120, LCID, 4, 0),()),
		"ExpirationDate": ((154, LCID, 4, 0),()),
		"FCCheckAccount": ((86, LCID, 4, 0),()),
		"FaxNumber": ((15, LCID, 4, 0),()),
		"FaxNumberForeignLang": ((81, LCID, 4, 0),()),
		"FederalTaxID": ((28, LCID, 4, 0),()),
		"FederalTaxID2": ((121, LCID, 4, 0),()),
		"FederalTaxID3": ((122, LCID, 4, 0),()),
		"FileNumberinIncomeTax": ((111, LCID, 4, 0),()),
		"GLMethod": ((131, LCID, 4, 0),()),
		"GTSDefaultChecker": ((207, LCID, 4, 0),()),
		"GTSDefaultPayee": ((208, LCID, 4, 0),()),
		"GTSInboundFolder": ((205, LCID, 4, 0),()),
		"GTSMaxAmount": ((209, LCID, 4, 0),()),
		"GTSOutboundFolder": ((204, LCID, 4, 0),()),
		"GTSResponseToExceeding": ((210, LCID, 4, 0),()),
		"GTSSeparateCode": ((206, LCID, 4, 0),()),
		"GeneralManager": ((182, LCID, 4, 0),()),
		"GeneralManagerForeignLanguage": ((183, LCID, 4, 0),()),
		"GrossProfitAfterSale": ((63, LCID, 4, 0),()),
		"GrossProfitPercentForServiceDocuments": ((200, LCID, 4, 0),()),
		"HolidaysName": ((148, LCID, 4, 0),()),
		"IEMandatoryValidation": ((231, LCID, 4, 0),()),
		"ISRBillerID": ((91, LCID, 4, 0),()),
		"ISRType": ((89, LCID, 4, 0),()),
		"IsPrinterConnected": ((220, LCID, 4, 0),()),
		"LetterHeaderinForeignLangu": ((78, LCID, 4, 0),()),
		"LocalCurrency": ((19, LCID, 4, 0),()),
		"ManagingDirector": ((17, LCID, 4, 0),()),
		"ManagingDirectorForeignLan": ((82, LCID, 4, 0),()),
		"MaxHistory": ((133, LCID, 4, 0),()),
		"MaximumNumberOfDaysForDueDate": ((233, LCID, 4, 0),()),
		"MeasuringAccuracy": ((75, LCID, 4, 0),()),
		"MinimumAmountfor347Report": ((25, LCID, 4, 0),()),
		"MultiCurrencyCheck": ((88, LCID, 4, 0),()),
		"MultiLanguageSupportEnable": ((169, LCID, 4, 0),()),
		"NationalInsuranceNo": ((155, LCID, 4, 0),()),
		"OrderBlock": ((149, LCID, 4, 0),()),
		"OrderingParty": ((152, LCID, 4, 0),()),
		"OrganizationNumber": ((139, LCID, 4, 0),()),
		"PBSGroupNumber": ((138, LCID, 4, 0),()),
		"PBSNumber": ((137, LCID, 4, 0),()),
		"PDefaultWTCode": ((145, LCID, 4, 0),()),
		"PDfltITWT": ((159, LCID, 4, 0),()),
		"ParamFolderPath": ((119, LCID, 4, 0),()),
		"PercentageAccuracy": ((74, LCID, 4, 0),()),
		"PeriodStatusAutoChange": ((177, LCID, 4, 0),()),
		"PeriodStatusChangeDelay": ((178, LCID, 4, 0),()),
		"PhoneNumber1": ((13, LCID, 4, 0),()),
		"PhoneNumber1ForeignLang": ((79, LCID, 4, 0),()),
		"PhoneNumber2": ((14, LCID, 4, 0),()),
		"PhoneNumber2ForeignLang": ((80, LCID, 4, 0),()),
		"PickList": ((201, LCID, 4, 0),()),
		"PriceAccuracy": ((72, LCID, 4, 0),()),
		"PriceListforCostPrice": ((62, LCID, 4, 0),()),
		"PriceSystem": ((127, LCID, 4, 0),()),
		"PrintingHeader": ((12, LCID, 4, 0),()),
		"PurchaseOrderConfirmed": ((157, LCID, 4, 0),()),
		"QueryAccuracy": ((181, LCID, 4, 0),()),
		"RateAccuracy": ((73, LCID, 4, 0),()),
		"ReportAccordingTo": ((216, LCID, 4, 0),()),
		"RestrictDelNotesPO": ((44, LCID, 4, 0),()),
		"RestrictOrders": ((45, LCID, 4, 0),()),
		"RestrictSales": ((43, LCID, 4, 0),()),
		"RoundTaxAmounts": ((109, LCID, 4, 0),()),
		"RoundingMethod": ((150, LCID, 4, 0),()),
		"SDefaultWTCode": ((143, LCID, 4, 0),()),
		"SDfltITWT": ((158, LCID, 4, 0),()),
		"SHandleWT": ((142, LCID, 4, 0),()),
		"SalesOrderConfirmed": ((156, LCID, 4, 0),()),
		"ServiceCode": ((117, LCID, 4, 0),()),
		"ServicePassword": ((118, LCID, 4, 0),()),
		"SetCommissionbyCustomer": ((56, LCID, 4, 0),()),
		"SetCommissionbyItem": ((57, LCID, 4, 0),()),
		"SetCommissionbySE": ((58, LCID, 4, 0),()),
		"SetItemsWarehouses": ((26, LCID, 4, 0),()),
		"SplitPO": ((49, LCID, 4, 0),()),
		"StandardUnitofLength": ((22, LCID, 4, 0),()),
		"StartingInFiscalYear": ((215, LCID, 4, 0),()),
		"State": ((172, LCID, 4, 0),()),
		"SystemCurrency": ((20, LCID, 4, 0),()),
		"TaxCollection": ((31, LCID, 4, 0),()),
		"TaxDefinition": ((32, LCID, 4, 0),()),
		"TaxDefinitionforVatitem": ((96, LCID, 4, 0),()),
		"TaxDefinitionforVatservice": ((97, LCID, 4, 0),()),
		"TaxGroupforPurchaseItem": ((98, LCID, 4, 0),()),
		"TaxGroupforServicePurchase": ((99, LCID, 4, 0),()),
		"TaxOffice": ((29, LCID, 4, 0),()),
		"TaxPercentage": ((33, LCID, 4, 0),()),
		"TaxRateDetermination": ((237, LCID, 4, 0),()),
		"ThousandsSeparator": ((124, LCID, 4, 0),()),
		"TimeTemplate": ((83, LCID, 4, 0),()),
		"TotalsAccuracy": ((70, LCID, 4, 0),()),
		"UniqueSerialNo": ((132, LCID, 4, 0),()),
		"UniqueTaxPayerReference": ((175, LCID, 4, 0),()),
		"UseNegativeAmounts": ((147, LCID, 4, 0),()),
		"UsePASystem": ((116, LCID, 4, 0),()),
		"UseProductionProfitAndLossAccount": ((211, LCID, 4, 0),()),
		"UseTax": ((48, LCID, 4, 0),()),
		"UserConversionCode": ((68, LCID, 4, 0),()),
		"WTAccumAmountAP": ((212, LCID, 4, 0),()),
		"WTAccumAmountAR": ((213, LCID, 4, 0),()),
		"WTLiableExpense": ((146, LCID, 4, 0),()),
		"WeightUnitDefault": ((23, LCID, 4, 0),()),
		"WholdingTaxDedHierarchy": ((128, LCID, 4, 0),()),
		"WithTax": ((35, LCID, 4, 0),()),
		"WithholdingTaxDdctExpired": ((39, LCID, 4, 0),()),
		"WithholdingTaxDdctOffice": ((40, LCID, 4, 0),()),
		"WithholdingTaxPHandle": ((144, LCID, 4, 0),()),
		"WithholdingTaxTdctPercnt": ((38, LCID, 4, 0),()),
		"WithholdingTaxVendorDdct": ((36, LCID, 4, 0),()),
		"XMLFileFolderPath": ((180, LCID, 4, 0),()),
		"eMail": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAlertManagement(DispatchBaseClass):
	'IAlertManagement Interface'
	CLSID = IID('{9E52D02D-16FC-4E2C-87FC-CD070F5D646A}')
	coclass_clsid = IID('{B52CCF14-E084-48A9-AE48-2E1B38CAD704}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Active": (15, 2, (3, 0), (), "Active", None),
		# Method 'AlertManagementDocuments' returns object of type 'IAlertManagementDocuments'
		"AlertManagementDocuments": (27, 2, (9, 0), (), "AlertManagementDocuments", '{A6E70E75-647C-48BF-A642-84841BD85B2C}'),
		# Method 'AlertManagementRecipients' returns object of type 'IAlertManagementRecipients'
		"AlertManagementRecipients": (26, 2, (9, 0), (), "AlertManagementRecipients", '{F675D408-2207-4E44-AE93-3BFDA7DE7CA3}'),
		"Code": (11, 2, (3, 0), (), "Code", None),
		"DayOfExecution": (19, 2, (3, 0), (), "DayOfExecution", None),
		"ExecutionTime": (20, 2, (7, 0), (), "ExecutionTime", None),
		"FrequencyInterval": (28, 2, (3, 0), (), "FrequencyInterval", None),
		"FrequencyType": (18, 2, (3, 0), (), "FrequencyType", None),
		"LastExecutionDate": (21, 2, (7, 0), (), "LastExecutionDate", None),
		"LastExecutionTime": (22, 2, (3, 0), (), "LastExecutionTime", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
		"NextExecutionDate": (23, 2, (7, 0), (), "NextExecutionDate", None),
		"NextExecutionTime": (24, 2, (7, 0), (), "NextExecutionTime", None),
		"Param": (16, 2, (8, 0), (), "Param", None),
		"Priority": (14, 2, (3, 0), (), "Priority", None),
		"QueryID": (17, 2, (3, 0), (), "QueryID", None),
		"SaveHistory": (25, 2, (3, 0), (), "SaveHistory", None),
		"Type": (13, 2, (3, 0), (), "Type", None),
	}
	_prop_map_put_ = {
		"Active": ((15, LCID, 4, 0),()),
		"DayOfExecution": ((19, LCID, 4, 0),()),
		"ExecutionTime": ((20, LCID, 4, 0),()),
		"FrequencyInterval": ((28, LCID, 4, 0),()),
		"FrequencyType": ((18, LCID, 4, 0),()),
		"Name": ((12, LCID, 4, 0),()),
		"Param": ((16, LCID, 4, 0),()),
		"Priority": ((14, LCID, 4, 0),()),
		"QueryID": ((17, LCID, 4, 0),()),
		"SaveHistory": ((25, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAlertManagementDocument(DispatchBaseClass):
	'IAlertManagementDocument Interface'
	CLSID = IID('{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}')
	coclass_clsid = IID('{2FA0FB01-DCC0-436C-8677-44654831D6E6}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Active": (12, 2, (3, 0), (), "Active", None),
		"Document": (11, 2, (3, 0), (), "Document", None),
	}
	_prop_map_put_ = {
		"Active": ((12, LCID, 4, 0),()),
		"Document": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAlertManagementDocuments(DispatchBaseClass):
	'IAlertManagementDocuments Interface'
	CLSID = IID('{A6E70E75-647C-48BF-A642-84841BD85B2C}')
	coclass_clsid = IID('{453C97AF-4491-4776-A6BA-52F8739A96D9}')

	# Result is of type IAlertManagementDocument
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IAlertManagementDocument
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IAlertManagementParams(DispatchBaseClass):
	'IAlertManagementParams Interface'
	CLSID = IID('{CC51470B-7859-4DC8-B636-E3856A52C02D}')
	coclass_clsid = IID('{6D6214D8-5ABD-4DAD-9F9C-E2F69EFEBA8D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (3, 0), (), "Code", None),
		"Name": (13, 2, (8, 0), (), "Name", None),
		"Type": (12, 2, (3, 0), (), "Type", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"Type": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAlertManagementParamsCollection(DispatchBaseClass):
	'IAlertManagementParamsCollection Interface'
	CLSID = IID('{341FC52D-5088-4DE4-8308-7085F8D950A1}')
	coclass_clsid = IID('{7DB5BDE8-AC90-4159-8B34-33A41A886FCE}')

	# Result is of type IAlertManagementParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{CC51470B-7859-4DC8-B636-E3856A52C02D}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IAlertManagementParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{CC51470B-7859-4DC8-B636-E3856A52C02D}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{CC51470B-7859-4DC8-B636-E3856A52C02D}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{CC51470B-7859-4DC8-B636-E3856A52C02D}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IAlertManagementRecipient(DispatchBaseClass):
	'IAlertManagementRecipient Interface'
	CLSID = IID('{B93946BC-D44E-4D81-8071-B56EF0830B51}')
	coclass_clsid = IID('{F59180EC-0D39-40F6-894E-3444F552732D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (3, 0), (), "Code", None),
		"SendEmail": (13, 2, (3, 0), (), "SendEmail", None),
		"SendFax": (15, 2, (3, 0), (), "SendFax", None),
		"SendInternal": (16, 2, (3, 0), (), "SendInternal", None),
		"SendSMS": (14, 2, (3, 0), (), "SendSMS", None),
		"UserCode": (12, 2, (3, 0), (), "UserCode", None),
	}
	_prop_map_put_ = {
		"SendEmail": ((13, LCID, 4, 0),()),
		"SendFax": ((15, LCID, 4, 0),()),
		"SendInternal": ((16, LCID, 4, 0),()),
		"SendSMS": ((14, LCID, 4, 0),()),
		"UserCode": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAlertManagementRecipients(DispatchBaseClass):
	'IAlertManagementRecipients Interface'
	CLSID = IID('{F675D408-2207-4E44-AE93-3BFDA7DE7CA3}')
	coclass_clsid = IID('{4701FCE6-F62A-47EC-BF1A-FA9894901984}')

	# Result is of type IAlertManagementRecipient
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{B93946BC-D44E-4D81-8071-B56EF0830B51}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IAlertManagementRecipient
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{B93946BC-D44E-4D81-8071-B56EF0830B51}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{B93946BC-D44E-4D81-8071-B56EF0830B51}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{B93946BC-D44E-4D81-8071-B56EF0830B51}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IAlertManagementService(DispatchBaseClass):
	'IAlertManagementService Interface'
	CLSID = IID('{7424993D-6DC0-48E5-AEEF-B10A3177E175}')
	coclass_clsid = IID('{4EF2A7BE-CB39-473A-977B-C2AAE73210AF}')

	# Result is of type IAlertManagementParams
	def AddAlertManagement(self, pAlertManagement=defaultNamedNotOptArg):
		'AddAlertManagement'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pAlertManagement
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddAlertManagement', '{CC51470B-7859-4DC8-B636-E3856A52C02D}')
		return ret

	# Result is of type IAlertManagement
	def GetAlertManagement(self, pAlertManagementParams=defaultNamedNotOptArg):
		'GetAlertManagement'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pAlertManagementParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetAlertManagement', '{9E52D02D-16FC-4E2C-87FC-CD070F5D646A}')
		return ret

	# Result is of type IAlertManagementParamsCollection
	def GetAlertManagementList(self, pAlertManagementParams=defaultNamedNotOptArg):
		'GetAlertManagementList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pAlertManagementParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetAlertManagementList', '{341FC52D-5088-4DE4-8308-7085F8D950A1}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateAlertManagement(self, pIAlertManagement=defaultNamedNotOptArg):
		'UpdateAlertManagement'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIAlertManagement
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAlternateCatNum(DispatchBaseClass):
	'IAlternateCatNum Interface'
	CLSID = IID('{0677DAD5-92DA-441E-A674-13DE601888FB}')
	coclass_clsid = IID('{BBC625E2-17DA-4434-83D6-56FE0401D9A6}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(12, LCID, 1, (8, 0), (),)

	def GetByKey(self, ItemCode=defaultNamedNotOptArg, CardCode=defaultNamedNotOptArg, Substitute=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (11, 0), ((8, 1), (8, 1), (8, 1)),ItemCode
			, CardCode, Substitute)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (14, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (7, 2, (8, 0), (), "CardCode", None),
		"DisplayBPCatalogNumber": (16, 2, (3, 0), (), "DisplayBPCatalogNumber", None),
		"ItemCode": (6, 2, (8, 0), (), "ItemCode", None),
		"Substitute": (8, 2, (8, 0), (), "Substitute", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (15, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CardCode": ((7, LCID, 4, 0),()),
		"DisplayBPCatalogNumber": ((16, LCID, 4, 0),()),
		"ItemCode": ((6, LCID, 4, 0),()),
		"Substitute": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAlternativeItem(DispatchBaseClass):
	'IAlternativeItem Interface'
	CLSID = IID('{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}')
	coclass_clsid = IID('{35CF9AB5-A66B-46EC-805A-E5192414BD4A}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AlternativeItemCode": (10, 2, (8, 0), (), "AlternativeItemCode", None),
		"MatchFactor": (11, 2, (5, 0), (), "MatchFactor", None),
		"Remarks": (12, 2, (8, 0), (), "Remarks", None),
	}
	_prop_map_put_ = {
		"AlternativeItemCode": ((10, LCID, 4, 0),()),
		"MatchFactor": ((11, LCID, 4, 0),()),
		"Remarks": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAlternativeItems(DispatchBaseClass):
	'IAlternativeItems Interface'
	CLSID = IID('{416CFADF-9DA6-47BD-A490-09AC890FC530}')
	coclass_clsid = IID('{FFDDAD10-AEC3-4717-B909-2C409EA9859E}')

	# Result is of type IAlternativeItem
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IAlternativeItem
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IAlternativeItemsService(DispatchBaseClass):
	'IAlternativeItemsService Interface'
	CLSID = IID('{BAEEDA1A-8CBE-4C07-B23A-CBC9BCE6AE37}')
	coclass_clsid = IID('{1CFBF8AA-ED92-4452-9DBE-4E8BCA68731C}')

	# Result is of type IOriginalItemParams
	def AddItem(self, pIOriginalItem=defaultNamedNotOptArg):
		'AddItem'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIOriginalItem
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddItem', '{BC7EF5B4-EEA5-4C83-8478-FBC484133A79}')
		return ret

	def DeleteItem(self, pIOriginalItemParams=defaultNamedNotOptArg):
		'DeleteItem'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIOriginalItemParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IOriginalItem
	def GetItem(self, pIOriginalItemParams=defaultNamedNotOptArg):
		'GetItem'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIOriginalItemParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetItem', '{4631570A-DAE1-43BB-9E4A-BA9957E593E1}')
		return ret

	def UpdateItem(self, pIOriginalItem=defaultNamedNotOptArg):
		'UpdateItem'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIOriginalItem
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalRequest(DispatchBaseClass):
	'IApprovalRequest Interface'
	CLSID = IID('{92196C1E-B89A-4F4E-8E37-A1F2FAC71C5C}')
	coclass_clsid = IID('{7F873201-71DD-4678-AFEB-8EB4D0ED45A4}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		# Method 'ApprovalRequestDecisions' returns object of type 'IApprovalRequestDecisions'
		"ApprovalRequestDecisions": (19, 2, (9, 0), (), "ApprovalRequestDecisions", '{B148F7EE-7416-4B22-B266-55321DF794D8}'),
		# Method 'ApprovalRequestLines' returns object of type 'IApprovalRequestLines'
		"ApprovalRequestLines": (18, 2, (9, 0), (), "ApprovalRequestLines", '{100612B7-46C2-4489-A406-504575577467}'),
		"Code": (10, 2, (3, 0), (), "Code", None),
		"CurrentStage": (16, 2, (3, 0), (), "CurrentStage", None),
		"IsDraft": (12, 2, (8, 0), (), "IsDraft", None),
		"ObjectEntry": (13, 2, (3, 0), (), "ObjectEntry", None),
		"ObjectType": (11, 2, (8, 0), (), "ObjectType", None),
		"OriginatorID": (17, 2, (3, 0), (), "OriginatorID", None),
		"Remarks": (15, 2, (8, 0), (), "Remarks", None),
		"Status": (14, 2, (3, 0), (), "Status", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalRequestDecision(DispatchBaseClass):
	'IApprovalRequestDecision Interface'
	CLSID = IID('{FB002972-8E0A-4819-AC30-B955B37C4772}')
	coclass_clsid = IID('{FAB3EB8B-22A5-4530-908D-9ADBBD88774D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ApproverPassword": (11, 2, (8, 0), (), "ApproverPassword", None),
		"ApproverUserName": (10, 2, (8, 0), (), "ApproverUserName", None),
		"Remarks": (13, 2, (8, 0), (), "Remarks", None),
		"Status": (12, 2, (3, 0), (), "Status", None),
	}
	_prop_map_put_ = {
		"ApproverPassword": ((11, LCID, 4, 0),()),
		"ApproverUserName": ((10, LCID, 4, 0),()),
		"Remarks": ((13, LCID, 4, 0),()),
		"Status": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalRequestDecisions(DispatchBaseClass):
	'IApprovalRequestDecisions Interface'
	CLSID = IID('{B148F7EE-7416-4B22-B266-55321DF794D8}')
	coclass_clsid = IID('{297C40ED-92B6-4DB9-9304-CF9350F3FE8C}')

	# Result is of type IApprovalRequestDecision
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{FB002972-8E0A-4819-AC30-B955B37C4772}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalRequestDecision
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{FB002972-8E0A-4819-AC30-B955B37C4772}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{FB002972-8E0A-4819-AC30-B955B37C4772}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{FB002972-8E0A-4819-AC30-B955B37C4772}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalRequestLine(DispatchBaseClass):
	'IApprovalRequestLine Interface'
	CLSID = IID('{6228C442-C4B7-4841-9275-54B459F42BCB}')
	coclass_clsid = IID('{2704D884-C30C-42FF-8D33-D1D7E3FE039A}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Remarks": (13, 2, (8, 0), (), "Remarks", None),
		"StageCode": (10, 2, (3, 0), (), "StageCode", None),
		"Status": (12, 2, (3, 0), (), "Status", None),
		"UserID": (11, 2, (3, 0), (), "UserID", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalRequestLines(DispatchBaseClass):
	'IApprovalRequestLines Interface'
	CLSID = IID('{100612B7-46C2-4489-A406-504575577467}')
	coclass_clsid = IID('{FD7AA643-4DD4-4E5C-AC36-C0B782A6A3E4}')

	# Result is of type IApprovalRequestLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{6228C442-C4B7-4841-9275-54B459F42BCB}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalRequestLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{6228C442-C4B7-4841-9275-54B459F42BCB}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{6228C442-C4B7-4841-9275-54B459F42BCB}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{6228C442-C4B7-4841-9275-54B459F42BCB}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalRequestParams(DispatchBaseClass):
	'IApprovalRequestParams Interface'
	CLSID = IID('{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}')
	coclass_clsid = IID('{BD849811-3C0D-4850-8E56-26C12823E15C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Remarks": (11, 2, (8, 0), (), "Remarks", None),
		"Status": (12, 2, (3, 0), (), "Status", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalRequestsParams(DispatchBaseClass):
	'IApprovalRequestsParams Interface'
	CLSID = IID('{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}')
	coclass_clsid = IID('{FB0CD2F1-E744-4CC6-8D1C-9A9ED9F533F1}')

	# Result is of type IApprovalRequestParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalRequestParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalRequestsService(DispatchBaseClass):
	'IApprovalRequestsService Interface'
	CLSID = IID('{285E7F1A-1AB7-45F3-9A0A-2B1AD538954B}')
	coclass_clsid = IID('{FA50FE8D-9DFF-44CD-A0D2-6FE8315B2393}')

	# Result is of type IApprovalRequestsParams
	def GetAllApprovalRequestsList(self):
		'GetAllApprovalRequestsList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetAllApprovalRequestsList', '{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}')
		return ret

	# Result is of type IApprovalRequest
	def GetApprovalRequest(self, pIApprovalRequestParams=defaultNamedNotOptArg):
		'GetApprovalRequest'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIApprovalRequestParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetApprovalRequest', '{92196C1E-B89A-4F4E-8E37-A1F2FAC71C5C}')
		return ret

	# Result is of type IApprovalRequestsParams
	def GetApprovalRequestList(self):
		'GetApprovalRequestList'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetApprovalRequestList', '{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IApprovalRequestsParams
	def GetOpenApprovalRequestList(self):
		'GetOpenApprovalRequestList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetOpenApprovalRequestList', '{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}')
		return ret

	def UpdateRequest(self, pIApprovalRequest=defaultNamedNotOptArg):
		'UpdateRequest'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((9, 1),),pIApprovalRequest
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalStage(DispatchBaseClass):
	'IApprovalStage Interface'
	CLSID = IID('{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')
	coclass_clsid = IID('{2DC337EF-DA9D-4A0B-AA09-34795D4CA674}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		# Method 'ApprovalStageApprovers' returns object of type 'IApprovalStageApprovers'
		"ApprovalStageApprovers": (15, 2, (9, 0), (), "ApprovalStageApprovers", '{D154A6C0-19F8-46CE-B66D-FFC856FC0310}'),
		"Code": (11, 2, (3, 0), (), "Code", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
		"NoOfApproversRequired": (14, 2, (3, 0), (), "NoOfApproversRequired", None),
		"Remarks": (13, 2, (8, 0), (), "Remarks", None),
	}
	_prop_map_put_ = {
		"Name": ((12, LCID, 4, 0),()),
		"NoOfApproversRequired": ((14, LCID, 4, 0),()),
		"Remarks": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalStageApprover(DispatchBaseClass):
	'IApprovalStageApprover Interface'
	CLSID = IID('{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}')
	coclass_clsid = IID('{DC399818-11FD-4FC3-A46C-B9A3F35E5CD1}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"UserID": (11, 2, (3, 0), (), "UserID", None),
	}
	_prop_map_put_ = {
		"UserID": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalStageApprovers(DispatchBaseClass):
	'IApprovalStageApprovers Interface'
	CLSID = IID('{D154A6C0-19F8-46CE-B66D-FFC856FC0310}')
	coclass_clsid = IID('{1BB54C50-66D7-4907-807C-92F58119C21D}')

	# Result is of type IApprovalStageApprover
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalStageApprover
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalStageParams(DispatchBaseClass):
	'IApprovalStageParams Interface'
	CLSID = IID('{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')
	coclass_clsid = IID('{6410A92E-B2C4-432B-B421-01FDD7835CEF}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (3, 0), (), "Code", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalStages(DispatchBaseClass):
	'IApprovalStages Interface'
	CLSID = IID('{7590979F-CE5F-480B-AEA5-2B83A04BE64B}')
	coclass_clsid = IID('{A0B0F43B-427F-4744-ABD3-0684090D3470}')

	# Result is of type IApprovalStage
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalStage
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalStagesParams(DispatchBaseClass):
	'IApprovalStagesParams Interface'
	CLSID = IID('{03664F1A-4FCF-401A-84E1-934D1F101EA4}')
	coclass_clsid = IID('{E07E71EA-0DEF-4990-A99D-C6B7407995C9}')

	# Result is of type IApprovalStageParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalStageParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalStagesService(DispatchBaseClass):
	'IApprovalStagesService Interface'
	CLSID = IID('{DA0391B0-6748-4F2D-8FEC-A077DE54FED8}')
	coclass_clsid = IID('{4DEFA778-37C3-4F67-9EF9-2675EEE468F8}')

	# Result is of type IApprovalStageParams
	def AddApprovalStage(self, pApprovalStage=defaultNamedNotOptArg):
		'AddApprovalStage'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pApprovalStage
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddApprovalStage', '{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')
		return ret

	# Result is of type IApprovalStage
	def GetApprovalStage(self, pIApprovalStageParams=defaultNamedNotOptArg):
		'GetApprovalStage'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIApprovalStageParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetApprovalStage', '{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')
		return ret

	# Result is of type IApprovalStagesParams
	def GetApprovalStageList(self):
		'GetApprovalStageList'
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetApprovalStageList', '{03664F1A-4FCF-401A-84E1-934D1F101EA4}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def RemoveApprovalStage(self, pIApprovalStageParams=defaultNamedNotOptArg):
		'RemoveApprovalStage'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((9, 1),),pIApprovalStageParams
			)

	def UpdateApprovalStage(self, pIApprovalStage=defaultNamedNotOptArg):
		'UpdateApprovalStage'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pIApprovalStage
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalTemplate(DispatchBaseClass):
	'IApprovalTemplate Interface'
	CLSID = IID('{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')
	coclass_clsid = IID('{E0718E09-A6F5-4221-84C5-EB8A28F4F741}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		# Method 'ApprovalTemplateDocuments' returns object of type 'IApprovalTemplateDocuments'
		"ApprovalTemplateDocuments": (18, 2, (9, 0), (), "ApprovalTemplateDocuments", '{216D15B1-8639-435F-8C85-4967488AD161}'),
		# Method 'ApprovalTemplateQueries' returns object of type 'IApprovalTemplateQueries'
		"ApprovalTemplateQueries": (20, 2, (9, 0), (), "ApprovalTemplateQueries", '{5C730C88-3D5F-4C01-911A-56813AD89504}'),
		# Method 'ApprovalTemplateStages' returns object of type 'IApprovalTemplateStages'
		"ApprovalTemplateStages": (17, 2, (9, 0), (), "ApprovalTemplateStages", '{02B05079-F380-48A7-A573-0BB7307A52C0}'),
		# Method 'ApprovalTemplateTerms' returns object of type 'IApprovalTemplateTerms'
		"ApprovalTemplateTerms": (19, 2, (9, 0), (), "ApprovalTemplateTerms", '{EFFD365E-5096-4B19-9187-986F83D337E0}'),
		# Method 'ApprovalTemplateUsers' returns object of type 'IApprovalTemplateUsers'
		"ApprovalTemplateUsers": (16, 2, (9, 0), (), "ApprovalTemplateUsers", '{948C7B32-1518-45ED-99A3-94AA328CD7FF}'),
		"Code": (11, 2, (3, 0), (), "Code", None),
		"IsActive": (15, 2, (3, 0), (), "IsActive", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
		"Remarks": (13, 2, (8, 0), (), "Remarks", None),
		"UseTerms": (14, 2, (3, 0), (), "UseTerms", None),
	}
	_prop_map_put_ = {
		"IsActive": ((15, LCID, 4, 0),()),
		"Name": ((12, LCID, 4, 0),()),
		"Remarks": ((13, LCID, 4, 0),()),
		"UseTerms": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalTemplateDocument(DispatchBaseClass):
	'IApprovalTemplateDocument Interface'
	CLSID = IID('{81BEC420-E567-4353-95BA-71F26FD54BCD}')
	coclass_clsid = IID('{10449DDE-FB95-4E0E-B699-D13949A808CF}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocumentType": (11, 2, (3, 0), (), "DocumentType", None),
	}
	_prop_map_put_ = {
		"DocumentType": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalTemplateDocuments(DispatchBaseClass):
	'IApprovalTemplateDocuments Interface'
	CLSID = IID('{216D15B1-8639-435F-8C85-4967488AD161}')
	coclass_clsid = IID('{F44DCA1A-C2B4-4CD3-9536-1471ADBA10E0}')

	# Result is of type IApprovalTemplateDocument
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{81BEC420-E567-4353-95BA-71F26FD54BCD}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalTemplateDocument
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{81BEC420-E567-4353-95BA-71F26FD54BCD}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{81BEC420-E567-4353-95BA-71F26FD54BCD}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{81BEC420-E567-4353-95BA-71F26FD54BCD}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalTemplateParams(DispatchBaseClass):
	'IApprovalTemplateParams Interface'
	CLSID = IID('{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')
	coclass_clsid = IID('{56AE7782-A205-4EBB-ADFD-FE4CE27B9201}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (21, 2, (3, 0), (), "Code", None),
		"Name": (23, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((21, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalTemplateQueries(DispatchBaseClass):
	'IApprovalTemplateQueries Interface'
	CLSID = IID('{5C730C88-3D5F-4C01-911A-56813AD89504}')
	coclass_clsid = IID('{3B62767B-45B8-4997-B249-F989A0C4AB8E}')

	# Result is of type IApprovalTemplateQuery
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalTemplateQuery
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalTemplateQuery(DispatchBaseClass):
	'IApprovalTemplateQuery Interface'
	CLSID = IID('{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}')
	coclass_clsid = IID('{46CBA2F6-0319-4C81-8D08-407EB184F732}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"QueryID": (11, 2, (3, 0), (), "QueryID", None),
	}
	_prop_map_put_ = {
		"QueryID": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalTemplateStage(DispatchBaseClass):
	'IApprovalTemplateStage Interface'
	CLSID = IID('{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}')
	coclass_clsid = IID('{F72514BA-4388-4D35-821A-CF58DA7F7C10}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ApprovalStageCode": (13, 2, (3, 0), (), "ApprovalStageCode", None),
		"Remarks": (12, 2, (8, 0), (), "Remarks", None),
		"SortID": (11, 2, (3, 0), (), "SortID", None),
	}
	_prop_map_put_ = {
		"ApprovalStageCode": ((13, LCID, 4, 0),()),
		"Remarks": ((12, LCID, 4, 0),()),
		"SortID": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalTemplateStages(DispatchBaseClass):
	'IApprovalTemplateStages Interface'
	CLSID = IID('{02B05079-F380-48A7-A573-0BB7307A52C0}')
	coclass_clsid = IID('{7649AEBB-4217-4944-9DC2-1426C38113C7}')

	# Result is of type IApprovalTemplateStage
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalTemplateStage
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalTemplateTerm(DispatchBaseClass):
	'IApprovalTemplateTerm Interface'
	CLSID = IID('{5691EAF4-B571-4BDA-B908-F7596767830E}')
	coclass_clsid = IID('{AA803CCD-C262-45A7-B9C6-FC034D4938CE}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ConditionType": (11, 2, (3, 0), (), "ConditionType", None),
		"OperationType": (12, 2, (3, 0), (), "OperationType", None),
		"Value": (13, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"ConditionType": ((11, LCID, 4, 0),()),
		"OperationType": ((12, LCID, 4, 0),()),
		"Value": ((13, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(13, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalTemplateTerms(DispatchBaseClass):
	'IApprovalTemplateTerms Interface'
	CLSID = IID('{EFFD365E-5096-4B19-9187-986F83D337E0}')
	coclass_clsid = IID('{B9DE72FD-C04A-4585-9850-73B6E3E58ADB}')

	# Result is of type IApprovalTemplateTerm
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{5691EAF4-B571-4BDA-B908-F7596767830E}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalTemplateTerm
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{5691EAF4-B571-4BDA-B908-F7596767830E}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{5691EAF4-B571-4BDA-B908-F7596767830E}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{5691EAF4-B571-4BDA-B908-F7596767830E}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalTemplateUser(DispatchBaseClass):
	'IApprovalTemplateUser Interface'
	CLSID = IID('{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}')
	coclass_clsid = IID('{C636E409-2B25-451B-90CE-B34F4C700180}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"UserID": (11, 2, (3, 0), (), "UserID", None),
	}
	_prop_map_put_ = {
		"UserID": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IApprovalTemplateUsers(DispatchBaseClass):
	'IApprovalTemplateUsers Interface'
	CLSID = IID('{948C7B32-1518-45ED-99A3-94AA328CD7FF}')
	coclass_clsid = IID('{EE8E76CB-5ABF-4220-B5A9-DC11A34F042F}')

	# Result is of type IApprovalTemplateUser
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalTemplateUser
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalTemplates(DispatchBaseClass):
	'IApprovalTemplates Interface'
	CLSID = IID('{7DDA3A4A-07A5-43A7-885E-B34217076D17}')
	coclass_clsid = IID('{AA5DB4F6-0C6C-4453-B5C5-EC21CBC719A7}')

	# Result is of type IApprovalTemplate
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalTemplate
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalTemplatesParams(DispatchBaseClass):
	'IApprovalTemplatesParams Interface'
	CLSID = IID('{14E8A7AE-CC48-4793-B4C6-4942E83F92BD}')
	coclass_clsid = IID('{3984330B-A277-496F-9926-EBAA43351154}')

	# Result is of type IApprovalTemplateParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IApprovalTemplateParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IApprovalTemplatesService(DispatchBaseClass):
	'IApprovalTemplatesService Interface'
	CLSID = IID('{690E65AA-B309-41D2-9697-0B6CBB58C4AF}')
	coclass_clsid = IID('{E4B8D471-9672-41D7-B340-E8DF455FE90D}')

	# Result is of type IApprovalTemplateParams
	def AddApprovalTemplate(self, pApprovalTemplate=defaultNamedNotOptArg):
		'AddApprovalTemplate'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pApprovalTemplate
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddApprovalTemplate', '{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')
		return ret

	# Result is of type IApprovalTemplate
	def GetApprovalTemplate(self, pIApprovalTemplateParams=defaultNamedNotOptArg):
		'GetApprovalTemplate'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIApprovalTemplateParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetApprovalTemplate', '{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')
		return ret

	# Result is of type IApprovalTemplatesParams
	def GetApprovalTemplateList(self):
		'GetApprovalTemplateList'
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetApprovalTemplateList', '{14E8A7AE-CC48-4793-B4C6-4942E83F92BD}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def RemoveApprovalTemplate(self, pIApprovalTemplateParams=defaultNamedNotOptArg):
		'RemoveApprovalTemplate'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((9, 1),),pIApprovalTemplateParams
			)

	def UpdateApprovalTemplate(self, pIApprovalTemplate=defaultNamedNotOptArg):
		'UpdateApprovalTemplate'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pIApprovalTemplate
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAttachment(DispatchBaseClass):
	'IAttachment Interface'
	CLSID = IID('{18B4A57B-206A-4CF7-B94B-7325AED96137}')
	coclass_clsid = IID('{054C0B23-FE27-46A4-990C-901A4906BEB5}')

	_prop_map_get_ = {
		"FileName": (1, 2, (8, 0), (), "FileName", None),
	}
	_prop_map_put_ = {
		"FileName": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAttachments(DispatchBaseClass):
	'IAttachments Interface'
	CLSID = IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')
	coclass_clsid = IID('{3C447394-4D07-46E5-8ADE-0E5973F97CF7}')

	def Add(self):
		'Add a new field.'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	# Result is of type IAttachment
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{18B4A57B-206A-4CF7-B94B-7325AED96137}')
		return ret

	def Refresh(self):
		'method Refresh'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{18B4A57B-206A-4CF7-B94B-7325AED96137}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{18B4A57B-206A-4CF7-B94B-7325AED96137}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IAttachments2(DispatchBaseClass):
	'IAttachments2 Interface'
	CLSID = IID('{EE480268-BD9E-4DD2-8BA2-BBB3C9665448}')
	coclass_clsid = IID('{3AFC5084-1838-4196-BAEF-7C16635E8068}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsoluteEntry=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lAbsoluteEntry
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AbsoluteEntry": (11, 2, (3, 0), (), "AbsoluteEntry", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		# Method 'Lines' returns object of type 'IAttachments2_Lines'
		"Lines": (12, 2, (9, 0), (), "Lines", '{F9D49CC8-76E7-4387-AA71-ED03A361F510}'),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IAttachments2_Lines(DispatchBaseClass):
	'IAttachments2_Lines Interface'
	CLSID = IID('{F9D49CC8-76E7-4387-AA71-ED03A361F510}')
	coclass_clsid = IID('{AE9073B1-59FF-423E-B562-BEFE747D2D5C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AttachmentDate": (8, 2, (7, 0), (), "AttachmentDate", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"FileExtension": (7, 2, (8, 0), (), "FileExtension", None),
		"FileName": (6, 2, (8, 0), (), "FileName", None),
		"Override": (10, 2, (3, 0), (), "Override", None),
		"SourcePath": (5, 2, (8, 0), (), "SourcePath", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserID": (9, 2, (3, 0), (), "UserID", None),
	}
	_prop_map_put_ = {
		"FileExtension": ((7, LCID, 4, 0),()),
		"FileName": ((6, LCID, 4, 0),()),
		"Override": ((10, LCID, 4, 0),()),
		"SourcePath": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBOEDocumentType(DispatchBaseClass):
	'IBOEDocumentType Interface'
	CLSID = IID('{746B0E89-0625-4B20-BD67-029DB26D074D}')
	coclass_clsid = IID('{5D08DA01-1E53-4A29-BDCC-5CE3FDFEC343}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocDescription": (12, 2, (8, 0), (), "DocDescription", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"DocType": (11, 2, (8, 0), (), "DocType", None),
	}
	_prop_map_put_ = {
		"DocDescription": ((12, LCID, 4, 0),()),
		"DocType": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOEDocumentTypeParams(DispatchBaseClass):
	'IBOEDocumentTypeParams Interface'
	CLSID = IID('{7B45A310-CED5-4D41-9A54-BED0F11B6950}')
	coclass_clsid = IID('{4B445959-4085-4FCE-8832-58AD489D81D1}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"DocType": (11, 2, (8, 0), (), "DocType", None),
	}
	_prop_map_put_ = {
		"DocEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOEDocumentTypes(DispatchBaseClass):
	'IBOEDocumentTypes Interface'
	CLSID = IID('{3BCB6516-86EB-4170-91BD-7EE4E52D6172}')
	coclass_clsid = IID('{1DB2C7ED-919B-49BA-9A7F-35E9F3262C3E}')

	# Result is of type IBOEDocumentType
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{746B0E89-0625-4B20-BD67-029DB26D074D}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBOEDocumentType
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{746B0E89-0625-4B20-BD67-029DB26D074D}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{746B0E89-0625-4B20-BD67-029DB26D074D}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{746B0E89-0625-4B20-BD67-029DB26D074D}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBOEDocumentTypesParams(DispatchBaseClass):
	'IBOEDocumentTypesParams Interface'
	CLSID = IID('{B25EF557-1E57-4CA8-BDD3-B2AF96815278}')
	coclass_clsid = IID('{F7CB66FA-3F53-4B0F-818C-259C599CFE15}')

	# Result is of type IBOEDocumentTypeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7B45A310-CED5-4D41-9A54-BED0F11B6950}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBOEDocumentTypeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{7B45A310-CED5-4D41-9A54-BED0F11B6950}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{7B45A310-CED5-4D41-9A54-BED0F11B6950}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{7B45A310-CED5-4D41-9A54-BED0F11B6950}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBOEDocumentTypesService(DispatchBaseClass):
	'IBOEDocumentTypesService Interface'
	CLSID = IID('{13792BEB-6BDC-46EC-A35F-F98DF2B98CD6}')
	coclass_clsid = IID('{302CB444-8F72-40F4-A8A7-457500892805}')

	# Result is of type IBOEDocumentTypeParams
	def AddBOEDocumentType(self, pIBOEDocumentType=defaultNamedNotOptArg):
		'AddBOEDocumentType'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBOEDocumentType
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddBOEDocumentType', '{7B45A310-CED5-4D41-9A54-BED0F11B6950}')
		return ret

	def DeleteBOEDocumentType(self, pIBOEDocumentTypeParams=defaultNamedNotOptArg):
		'DeleteBOEDocumentType'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIBOEDocumentTypeParams
			)

	# Result is of type IBOEDocumentType
	def GetBOEDocumentType(self, pIBOEDocumentTypeParams=defaultNamedNotOptArg):
		'GetBOEDocumentType'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIBOEDocumentTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBOEDocumentType', '{746B0E89-0625-4B20-BD67-029DB26D074D}')
		return ret

	# Result is of type IBOEDocumentTypesParams
	def GetBOEDocumentTypeList(self):
		'GetBOEDocumentTypeList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetBOEDocumentTypeList', '{B25EF557-1E57-4CA8-BDD3-B2AF96815278}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateBOEDocumentType(self, pIBOEDocumentType=defaultNamedNotOptArg):
		'UpdateBOEDocumentType'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBOEDocumentType
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOEInstruction(DispatchBaseClass):
	'IBOEInstruction Interface'
	CLSID = IID('{70443238-FECE-4E0B-8900-9C5D06C4E71C}')
	coclass_clsid = IID('{A3029CAF-054C-4339-ADDD-87F60B113023}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"InstructionCode": (11, 2, (8, 0), (), "InstructionCode", None),
		"InstructionDesc": (12, 2, (8, 0), (), "InstructionDesc", None),
		"InstructionEntry": (10, 2, (3, 0), (), "InstructionEntry", None),
		"IsCancelInstruction": (13, 2, (3, 0), (), "IsCancelInstruction", None),
	}
	_prop_map_put_ = {
		"InstructionCode": ((11, LCID, 4, 0),()),
		"InstructionDesc": ((12, LCID, 4, 0),()),
		"IsCancelInstruction": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOEInstructionParams(DispatchBaseClass):
	'IBOEInstructionParams Interface'
	CLSID = IID('{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')
	coclass_clsid = IID('{A9C6DFCF-1FFD-46AF-89FC-5618ECAF2441}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"InstructionCode": (11, 2, (8, 0), (), "InstructionCode", None),
		"InstructionEntry": (10, 2, (3, 0), (), "InstructionEntry", None),
	}
	_prop_map_put_ = {
		"InstructionEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOEInstructions(DispatchBaseClass):
	'IBOEInstructions Interface'
	CLSID = IID('{4B03F542-E836-450B-89AC-04E7609E6B35}')
	coclass_clsid = IID('{FD7ECEE2-5FA5-4054-9769-B86A8096D9BA}')

	# Result is of type IBOEInstruction
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{70443238-FECE-4E0B-8900-9C5D06C4E71C}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBOEInstruction
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{70443238-FECE-4E0B-8900-9C5D06C4E71C}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{70443238-FECE-4E0B-8900-9C5D06C4E71C}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{70443238-FECE-4E0B-8900-9C5D06C4E71C}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBOEInstructionsParams(DispatchBaseClass):
	'IBOEInstructionsParams Interface'
	CLSID = IID('{910426DC-C7C4-4EBC-8FB3-97BC2805C81D}')
	coclass_clsid = IID('{82C004A0-40F6-460F-8581-E34747E9CF01}')

	# Result is of type IBOEInstructionParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBOEInstructionParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBOEInstructionsService(DispatchBaseClass):
	'IBOEInstructionsService Interface'
	CLSID = IID('{E962CD81-105C-4E61-91B8-A86AFE748209}')
	coclass_clsid = IID('{EC78D9AA-6CA6-427C-9D33-38A4EAD168AB}')

	# Result is of type IBOEInstructionParams
	def AddBOEInstruction(self, pIBOEInstruction=defaultNamedNotOptArg):
		'AddBOEInstruction'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBOEInstruction
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddBOEInstruction', '{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')
		return ret

	def DeleteBOEInstruction(self, pIBOEInstructionParams=defaultNamedNotOptArg):
		'DeleteBOEInstruction'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIBOEInstructionParams
			)

	# Result is of type IBOEInstruction
	def GetBOEInstruction(self, pIBOEInstructionParams=defaultNamedNotOptArg):
		'GetBOEInstruction'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIBOEInstructionParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBOEInstruction', '{70443238-FECE-4E0B-8900-9C5D06C4E71C}')
		return ret

	# Result is of type IBOEInstructionsParams
	def GetBOEInstructionList(self):
		'GetBOEInstructionList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetBOEInstructionList', '{910426DC-C7C4-4EBC-8FB3-97BC2805C81D}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateBOEInstruction(self, pIBOEInstruction=defaultNamedNotOptArg):
		'UpdateBOEInstruction'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBOEInstruction
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOELine(DispatchBaseClass):
	'IBOELine Interface'
	CLSID = IID('{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}')
	coclass_clsid = IID('{F6E76C2D-0F98-4358-B0F3-BE632E6CC9F7}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AccountNumber": (15, 2, (8, 0), (), "AccountNumber", None),
		"BOEKey": (10, 2, (3, 0), (), "BOEKey", None),
		"BOENumber": (11, 2, (3, 0), (), "BOENumber", None),
		"BOEStatus": (17, 2, (3, 0), (), "BOEStatus", None),
		"Bank": (13, 2, (8, 0), (), "Bank", None),
		"Branch": (14, 2, (8, 0), (), "Branch", None),
		"DueDate": (12, 2, (7, 0), (), "DueDate", None),
		"Transferred": (18, 2, (3, 0), (), "Transferred", None),
		"amount": (16, 2, (5, 0), (), "amount", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOELineParams(DispatchBaseClass):
	'IBOELineParams Interface'
	CLSID = IID('{225FB23A-8178-4A0B-A9F4-88D1F33278DC}')
	coclass_clsid = IID('{F0070DD3-7081-46DD-A17E-0DCAF223D213}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"BOEKey": (10, 2, (3, 0), (), "BOEKey", None),
	}
	_prop_map_put_ = {
		"BOEKey": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOELines(DispatchBaseClass):
	'IBOELines Interface'
	CLSID = IID('{87ED882F-80FA-487D-8DA1-058E42B6BFA8}')
	coclass_clsid = IID('{969FE83E-F0A8-47E9-811E-C8B03F67253A}')

	# Result is of type IBOELine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBOELine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBOELinesParams(DispatchBaseClass):
	'IBOELinesParams Interface'
	CLSID = IID('{0DAE1D7B-419B-4573-9315-8094285CD00A}')
	coclass_clsid = IID('{2FC28FB9-7376-41BE-9CCE-50FCB69D8ECF}')

	# Result is of type IBOELineParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{225FB23A-8178-4A0B-A9F4-88D1F33278DC}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBOELineParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{225FB23A-8178-4A0B-A9F4-88D1F33278DC}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{225FB23A-8178-4A0B-A9F4-88D1F33278DC}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{225FB23A-8178-4A0B-A9F4-88D1F33278DC}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBOELinesService(DispatchBaseClass):
	'IBOELinesService Interface'
	CLSID = IID('{83E2FD00-E8D3-40D0-91E7-59166A6309DC}')
	coclass_clsid = IID('{C0E3FD16-7EC1-462F-BF9E-5524665C2E22}')

	# Result is of type IBOELine
	def GetBOELine(self, pIBOELineParams=defaultNamedNotOptArg):
		'GetBOELine'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBOELineParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBOELine', '{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOEPortfolio(DispatchBaseClass):
	'IBOEPortfolio Interface'
	CLSID = IID('{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')
	coclass_clsid = IID('{DFED3449-35B2-4A0A-B789-20EE627AE347}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"PortfolioCode": (12, 2, (8, 0), (), "PortfolioCode", None),
		"PortfolioDescription": (14, 2, (8, 0), (), "PortfolioDescription", None),
		"PortfolioEntry": (10, 2, (3, 0), (), "PortfolioEntry", None),
		"PortfolioID": (11, 2, (8, 0), (), "PortfolioID", None),
		"PortfolioNum": (13, 2, (8, 0), (), "PortfolioNum", None),
	}
	_prop_map_put_ = {
		"PortfolioCode": ((12, LCID, 4, 0),()),
		"PortfolioDescription": ((14, LCID, 4, 0),()),
		"PortfolioID": ((11, LCID, 4, 0),()),
		"PortfolioNum": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOEPortfolioParams(DispatchBaseClass):
	'IBOEPortfolioParams Interface'
	CLSID = IID('{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')
	coclass_clsid = IID('{5016BA26-6D6D-47B7-9B13-558EC0B1B916}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"PortfolioCode": (12, 2, (8, 0), (), "PortfolioCode", None),
		"PortfolioEntry": (10, 2, (3, 0), (), "PortfolioEntry", None),
		"PortfolioID": (11, 2, (8, 0), (), "PortfolioID", None),
	}
	_prop_map_put_ = {
		"PortfolioEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBOEPortfolios(DispatchBaseClass):
	'IBOEPortfolios Interface'
	CLSID = IID('{881C8CF2-FDB4-43ED-866F-4F6A4827E02C}')
	coclass_clsid = IID('{CDF64DE9-D2B8-4180-983C-457ABAA5EFB1}')

	# Result is of type IBOEPortfolio
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBOEPortfolio
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBOEPortfoliosParams(DispatchBaseClass):
	'IBOEPortfoliosParams Interface'
	CLSID = IID('{C44BDF5B-E877-4183-AC97-76D9E4921BB3}')
	coclass_clsid = IID('{2760F015-04C7-40D5-88DD-499BFD8B6CD1}')

	# Result is of type IBOEPortfolioParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBOEPortfolioParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBOEPortfoliosService(DispatchBaseClass):
	'IBOEPortfoliosService Interface'
	CLSID = IID('{6EA82155-C282-4F2D-90C4-BF6F95269228}')
	coclass_clsid = IID('{877ACA0D-FA03-41F8-8B84-E4090B053532}')

	# Result is of type IBOEPortfolioParams
	def AddBOEPortfolio(self, pIBOEPortfolio=defaultNamedNotOptArg):
		'AddBOEPortfolio'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBOEPortfolio
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddBOEPortfolio', '{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')
		return ret

	def DeleteBOEPortfolio(self, pIBOEPortfolioParams=defaultNamedNotOptArg):
		'DeleteBOEPortfolio'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIBOEPortfolioParams
			)

	# Result is of type IBOEPortfolio
	def GetBOEPortfolio(self, pIBOEPortfolioParams=defaultNamedNotOptArg):
		'GetBOEPortfolio'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIBOEPortfolioParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBOEPortfolio', '{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')
		return ret

	# Result is of type IBOEPortfoliosParams
	def GetBOEPortfolioList(self):
		'GetBOEPortfolioList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetBOEPortfolioList', '{C44BDF5B-E877-4183-AC97-76D9E4921BB3}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateBOEPortfolio(self, pIBOEPortfolio=defaultNamedNotOptArg):
		'UpdateBOEPortfolio'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBOEPortfolio
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBPAccountReceivablePayble(DispatchBaseClass):
	'IBPAccountReceivablePayble Interface'
	CLSID = IID('{4162242D-4217-47FA-BDFF-5070B6D03F30}')
	coclass_clsid = IID('{2795C6A1-A943-411B-BE58-A062A0E4711A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (5, 2, (8, 0), (), "AccountCode", None),
		"AccountType": (6, 2, (3, 0), (), "AccountType", None),
		"BPCode": (7, 2, (8, 0), (), "BPCode", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
		"AccountCode": ((5, LCID, 4, 0),()),
		"AccountType": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPAddresses(DispatchBaseClass):
	'IBPAddresses Interface'
	CLSID = IID('{02F225DD-827F-4065-BC4A-14D5F4136D28}')
	coclass_clsid = IID('{1520690D-0D25-415A-B290-66DF277561FE}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(23, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AddressName": (4, 2, (8, 0), (), "AddressName", None),
		"AddressName2": (18, 2, (8, 0), (), "AddressName2", None),
		"AddressName3": (20, 2, (8, 0), (), "AddressName3", None),
		"AddressType": (16, 2, (3, 0), (), "AddressType", None),
		"BPCode": (24, 2, (8, 0), (), "BPCode", None),
		"Block": (6, 2, (8, 0), (), "Block", None),
		"BuildingFloorRoom": (15, 2, (8, 0), (), "BuildingFloorRoom", None),
		"City": (8, 2, (8, 0), (), "City", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"Country": (10, 2, (8, 0), (), "Country", None),
		"County": (9, 2, (8, 0), (), "County", None),
		"FederalTaxID": (12, 2, (8, 0), (), "FederalTaxID", None),
		"RowNum": (25, 2, (3, 0), (), "RowNum", None),
		"State": (11, 2, (8, 0), (), "State", None),
		"Street": (5, 2, (8, 0), (), "Street", None),
		"StreetNo": (22, 2, (8, 0), (), "StreetNo", None),
		"TaxCode": (13, 2, (8, 0), (), "TaxCode", None),
		"TypeOfAddress": (21, 2, (8, 0), (), "TypeOfAddress", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (14, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"ZipCode": (7, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AddressName": ((4, LCID, 4, 0),()),
		"AddressName2": ((18, LCID, 4, 0),()),
		"AddressName3": ((20, LCID, 4, 0),()),
		"AddressType": ((16, LCID, 4, 0),()),
		"Block": ((6, LCID, 4, 0),()),
		"BuildingFloorRoom": ((15, LCID, 4, 0),()),
		"City": ((8, LCID, 4, 0),()),
		"Country": ((10, LCID, 4, 0),()),
		"County": ((9, LCID, 4, 0),()),
		"FederalTaxID": ((12, LCID, 4, 0),()),
		"State": ((11, LCID, 4, 0),()),
		"Street": ((5, LCID, 4, 0),()),
		"StreetNo": ((22, LCID, 4, 0),()),
		"TaxCode": ((13, LCID, 4, 0),()),
		"TypeOfAddress": ((21, LCID, 4, 0),()),
		"ZipCode": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPBankAccounts(DispatchBaseClass):
	'IBPBankAccounts Interface'
	CLSID = IID('{472B7A32-EB83-4D3A-9908-699D5C8DC33B}')
	coclass_clsid = IID('{0C9CE0A9-AA16-4C81-A474-9D960E735AA5}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(23, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(33, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(22, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ABARoutingNumber": (35, 2, (8, 0), (), "ABARoutingNumber", None),
		"AccountName": (26, 2, (8, 0), (), "AccountName", None),
		"AccountNo": (17, 2, (8, 0), (), "AccountNo", None),
		"BICSwiftCode": (34, 2, (8, 0), (), "BICSwiftCode", None),
		"BIK": (25, 2, (8, 0), (), "BIK", None),
		"BPCode": (3, 2, (8, 0), (), "BPCode", None),
		"BankCode": (16, 2, (8, 0), (), "BankCode", None),
		"Block": (10, 2, (8, 0), (), "Block", None),
		"Branch": (11, 2, (8, 0), (), "Branch", None),
		"BuildingFloorRoom": (20, 2, (8, 0), (), "BuildingFloorRoom", None),
		"City": (9, 2, (8, 0), (), "City", None),
		"ControlKey": (14, 2, (8, 0), (), "ControlKey", None),
		"CorrespondentAccount": (27, 2, (8, 0), (), "CorrespondentAccount", None),
		"Count": (21, 2, (3, 0), (), "Count", None),
		"Country": (12, 2, (8, 0), (), "Country", None),
		"County": (4, 2, (8, 0), (), "County", None),
		"CustomerIdNumber": (30, 2, (8, 0), (), "CustomerIdNumber", None),
		"Fax": (29, 2, (8, 0), (), "Fax", None),
		"IBAN": (7, 2, (8, 0), (), "IBAN", None),
		"ISRBillerID": (31, 2, (8, 0), (), "ISRBillerID", None),
		"ISRType": (32, 2, (3, 0), (), "ISRType", None),
		"InternalKey": (19, 2, (3, 0), (), "InternalKey", None),
		"LogInstance": (1, 2, (3, 0), (), "LogInstance", None),
		"MandateID": (36, 2, (8, 0), (), "MandateID", None),
		"Phone": (28, 2, (8, 0), (), "Phone", None),
		"SignatureDate": (37, 2, (7, 0), (), "SignatureDate", None),
		"State": (5, 2, (8, 0), (), "State", None),
		"Street": (13, 2, (8, 0), (), "Street", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (24, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserNo1": (18, 2, (8, 0), (), "UserNo1", None),
		"UserNo2": (6, 2, (8, 0), (), "UserNo2", None),
		"UserNo3": (15, 2, (8, 0), (), "UserNo3", None),
		"UserNo4": (2, 2, (8, 0), (), "UserNo4", None),
		"ZipCode": (8, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"ABARoutingNumber": ((35, LCID, 4, 0),()),
		"AccountName": ((26, LCID, 4, 0),()),
		"AccountNo": ((17, LCID, 4, 0),()),
		"BICSwiftCode": ((34, LCID, 4, 0),()),
		"BIK": ((25, LCID, 4, 0),()),
		"BPCode": ((3, LCID, 4, 0),()),
		"BankCode": ((16, LCID, 4, 0),()),
		"Block": ((10, LCID, 4, 0),()),
		"Branch": ((11, LCID, 4, 0),()),
		"BuildingFloorRoom": ((20, LCID, 4, 0),()),
		"City": ((9, LCID, 4, 0),()),
		"ControlKey": ((14, LCID, 4, 0),()),
		"CorrespondentAccount": ((27, LCID, 4, 0),()),
		"Country": ((12, LCID, 4, 0),()),
		"County": ((4, LCID, 4, 0),()),
		"CustomerIdNumber": ((30, LCID, 4, 0),()),
		"Fax": ((29, LCID, 4, 0),()),
		"IBAN": ((7, LCID, 4, 0),()),
		"ISRBillerID": ((31, LCID, 4, 0),()),
		"ISRType": ((32, LCID, 4, 0),()),
		"InternalKey": ((19, LCID, 4, 0),()),
		"LogInstance": ((1, LCID, 4, 0),()),
		"MandateID": ((36, LCID, 4, 0),()),
		"Phone": ((28, LCID, 4, 0),()),
		"SignatureDate": ((37, LCID, 4, 0),()),
		"State": ((5, LCID, 4, 0),()),
		"Street": ((13, LCID, 4, 0),()),
		"UserNo1": ((18, LCID, 4, 0),()),
		"UserNo2": ((6, LCID, 4, 0),()),
		"UserNo3": ((15, LCID, 4, 0),()),
		"UserNo4": ((2, LCID, 4, 0),()),
		"ZipCode": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(21, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPBranchAssignment(DispatchBaseClass):
	'IBPBranchAssignment Interface'
	CLSID = IID('{C65DEE24-288A-43E4-9F93-93F384B157BB}')
	coclass_clsid = IID('{FC23201F-196D-40E5-A3CA-C8DA72FC63B2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPCode": (11, 2, (8, 0), (), "BPCode", None),
		"BPLID": (12, 2, (3, 0), (), "BPLID", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
		"BPLID": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPCode(DispatchBaseClass):
	'IBPCode Interface'
	CLSID = IID('{259FA540-F962-4A5D-9BF5-E9772AF43A31}')
	coclass_clsid = IID('{3026EE2A-44C8-433C-AE19-0C9EBD1C6285}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Credit": (13, 2, (5, 0), (), "Credit", None),
		"Debit": (12, 2, (5, 0), (), "Debit", None),
		"DueDate": (11, 2, (7, 0), (), "DueDate", None),
		"ForeignCredit": (17, 2, (5, 0), (), "ForeignCredit", None),
		"ForeignCurrency": (18, 2, (8, 0), (), "ForeignCurrency", None),
		"ForeignDebit": (16, 2, (5, 0), (), "ForeignDebit", None),
		"SystemCredit": (15, 2, (5, 0), (), "SystemCredit", None),
		"SystemDebit": (14, 2, (5, 0), (), "SystemDebit", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
		"Credit": ((13, LCID, 4, 0),()),
		"Debit": ((12, LCID, 4, 0),()),
		"DueDate": ((11, LCID, 4, 0),()),
		"ForeignCredit": ((17, LCID, 4, 0),()),
		"ForeignCurrency": ((18, LCID, 4, 0),()),
		"ForeignDebit": ((16, LCID, 4, 0),()),
		"SystemCredit": ((15, LCID, 4, 0),()),
		"SystemDebit": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBPCodes(DispatchBaseClass):
	'IBPCodes Interface'
	CLSID = IID('{9B7AB6DE-2A25-4329-9423-6B175EB8BCD3}')
	coclass_clsid = IID('{CB6DE5B7-50B1-4068-A778-CD08EEA34DC4}')

	# Result is of type IBPCode
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{259FA540-F962-4A5D-9BF5-E9772AF43A31}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBPCode
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{259FA540-F962-4A5D-9BF5-E9772AF43A31}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{259FA540-F962-4A5D-9BF5-E9772AF43A31}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{259FA540-F962-4A5D-9BF5-E9772AF43A31}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPFiscalRegistryID(DispatchBaseClass):
	'IBPFiscalRegistryID Interface'
	CLSID = IID('{2C35D508-856B-43E0-A1A5-EC6BCA16E62A}')
	coclass_clsid = IID('{F2BCB557-408E-4D6C-B46D-7E5517D939B2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lGroupCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lGroupCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CNAECode": (11, 2, (8, 0), (), "CNAECode", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Numerator": (10, 2, (3, 0), (), "Numerator", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CNAECode": ((11, LCID, 4, 0),()),
		"Description": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBPFiscalTaxID(DispatchBaseClass):
	'IBPFiscalTaxID Interface'
	CLSID = IID('{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}')
	coclass_clsid = IID('{578B1918-60ED-440F-9729-7C59AEE459E8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AddrType": (25, 2, (3, 0), (), "AddrType", None),
		"Address": (10, 2, (8, 0), (), "Address", None),
		"BPCode": (24, 2, (8, 0), (), "BPCode", None),
		"CNAECode": (23, 2, (3, 0), (), "CNAECode", None),
		"Count": (4, 2, (3, 0), (), "Count", None),
		"TaxId0": (11, 2, (8, 0), (), "TaxId0", None),
		"TaxId1": (12, 2, (8, 0), (), "TaxId1", None),
		"TaxId10": (21, 2, (8, 0), (), "TaxId10", None),
		"TaxId11": (22, 2, (8, 0), (), "TaxId11", None),
		"TaxId2": (13, 2, (8, 0), (), "TaxId2", None),
		"TaxId3": (14, 2, (8, 0), (), "TaxId3", None),
		"TaxId4": (15, 2, (8, 0), (), "TaxId4", None),
		"TaxId5": (16, 2, (8, 0), (), "TaxId5", None),
		"TaxId6": (17, 2, (8, 0), (), "TaxId6", None),
		"TaxId7": (18, 2, (8, 0), (), "TaxId7", None),
		"TaxId8": (19, 2, (8, 0), (), "TaxId8", None),
		"TaxId9": (20, 2, (8, 0), (), "TaxId9", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Address": ((10, LCID, 4, 0),()),
		"CNAECode": ((23, LCID, 4, 0),()),
		"TaxId0": ((11, LCID, 4, 0),()),
		"TaxId1": ((12, LCID, 4, 0),()),
		"TaxId10": ((21, LCID, 4, 0),()),
		"TaxId11": ((22, LCID, 4, 0),()),
		"TaxId2": ((13, LCID, 4, 0),()),
		"TaxId3": ((14, LCID, 4, 0),()),
		"TaxId4": ((15, LCID, 4, 0),()),
		"TaxId5": ((16, LCID, 4, 0),()),
		"TaxId6": ((17, LCID, 4, 0),()),
		"TaxId7": ((18, LCID, 4, 0),()),
		"TaxId8": ((19, LCID, 4, 0),()),
		"TaxId9": ((20, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(4, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPPaymentDates(DispatchBaseClass):
	'IBPPaymentDates Interface'
	CLSID = IID('{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}')
	coclass_clsid = IID('{727B34C7-DD01-4B31-9213-F5B02C5E3276}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPCode": (7, 2, (8, 0), (), "BPCode", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"PaymentDate": (1, 2, (8, 0), (), "PaymentDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (2, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"PaymentDate": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPPaymentMethods(DispatchBaseClass):
	'IBPPaymentMethods Interface'
	CLSID = IID('{7D947F60-6017-44AA-AEAC-9721FF263D5E}')
	coclass_clsid = IID('{9091A78F-FCC8-4399-88F3-53E1631F100F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPCode": (7, 2, (8, 0), (), "BPCode", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"PaymentMethodCode": (1, 2, (8, 0), (), "PaymentMethodCode", None),
		"RowNumber": (6, 2, (3, 0), (), "RowNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (2, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"PaymentMethodCode": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBPPriorities(DispatchBaseClass):
	'IBPPriorities Interface'
	CLSID = IID('{36EA48A3-B828-45D8-B5E2-AE3584E54AE3}')
	coclass_clsid = IID('{3A1E1C0F-EEA6-43A5-893C-280A50D37410}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Priority": (10, 2, (3, 0), (), "Priority", None),
		"PriorityDescription": (11, 2, (8, 0), (), "PriorityDescription", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Priority": ((10, LCID, 4, 0),()),
		"PriorityDescription": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBPWithholdingTax(DispatchBaseClass):
	'IBPWithholdingTax Interface'
	CLSID = IID('{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}')
	coclass_clsid = IID('{740243E4-B946-4D50-94D9-7F7E3EC04FE9}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPCode": (6, 2, (8, 0), (), "BPCode", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (2, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WTCode": (1, 2, (8, 0), (), "WTCode", None),
	}
	_prop_map_put_ = {
		"WTCode": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBankChargesAllocationCode(DispatchBaseClass):
	'IBankChargesAllocationCode Interface'
	CLSID = IID('{95968C8C-6866-4B59-BB03-E08A96684591}')
	coclass_clsid = IID('{D7CA14AD-9A60-48D8-857B-441F3102B1AC}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Description": (11, 2, (8, 0), (), "Description", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
		"Description": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBankChargesAllocationCodeParams(DispatchBaseClass):
	'IBankChargesAllocationCodeParams Interface'
	CLSID = IID('{53062C45-E05A-4717-909C-3C3073E10DDD}')
	coclass_clsid = IID('{BACE2904-08D9-41F7-A963-FA3E550D9BF9}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Description": (11, 2, (8, 0), (), "Description", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBankChargesAllocationCodesParams(DispatchBaseClass):
	'IBankChargesAllocationCodesParams Interface'
	CLSID = IID('{46BCE59C-FCA9-4AC3-8A3D-07090C41E5F2}')
	coclass_clsid = IID('{4B310591-7DB5-48EE-BB34-A2F954D41897}')

	# Result is of type IBankChargesAllocationCodeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{53062C45-E05A-4717-909C-3C3073E10DDD}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBankChargesAllocationCodeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{53062C45-E05A-4717-909C-3C3073E10DDD}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{53062C45-E05A-4717-909C-3C3073E10DDD}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{53062C45-E05A-4717-909C-3C3073E10DDD}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBankChargesAllocationCodesService(DispatchBaseClass):
	'IBankChargesAllocationCodesService Interface'
	CLSID = IID('{E73F2CD8-14C2-4BDD-AEB2-7D7DCFF21571}')
	coclass_clsid = IID('{1CBABC7A-347F-48EA-A6F6-FCA17C04A159}')

	# Result is of type IBankChargesAllocationCodeParams
	def AddBankChargesAllocationCode(self, pIBankChargesAllocationCode=defaultNamedNotOptArg):
		'AddBankChargesAllocationCode'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBankChargesAllocationCode
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddBankChargesAllocationCode', '{53062C45-E05A-4717-909C-3C3073E10DDD}')
		return ret

	def DeleteBankChargesAllocationCode(self, pIBankChargesAllocationCodeParams=defaultNamedNotOptArg):
		'DeleteBankChargesAllocationCode'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIBankChargesAllocationCodeParams
			)

	# Result is of type IBankChargesAllocationCode
	def GetBankChargesAllocationCode(self, pIBankChargesAllocationCodeParams=defaultNamedNotOptArg):
		'GetBankChargesAllocationCode'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIBankChargesAllocationCodeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBankChargesAllocationCode', '{95968C8C-6866-4B59-BB03-E08A96684591}')
		return ret

	# Result is of type IBankChargesAllocationCodesParams
	def GetBankChargesAllocationCodeList(self):
		'GetBankChargesAllocationCodeList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetBankChargesAllocationCodeList', '{46BCE59C-FCA9-4AC3-8A3D-07090C41E5F2}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def SetDefaultBankChargesAllocationCode(self, pIBankChargesAllocationCodeParams=defaultNamedNotOptArg):
		'SetDefaultBankChargesAllocationCode'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((9, 1),),pIBankChargesAllocationCodeParams
			)

	def UpdateBankChargesAllocationCode(self, pIBankChargesAllocationCode=defaultNamedNotOptArg):
		'UpdateBankChargesAllocationCode'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBankChargesAllocationCode
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBankPages(DispatchBaseClass):
	'IBankPages Interface'
	CLSID = IID('{5BB202A1-E560-4E34-ACB3-2ECA52FFB274}')
	coclass_clsid = IID('{842BE793-D5A4-4C52-B7C1-99E189D39B8D}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(27, LCID, 1, (8, 0), (),)

	def GetByKey(self, AccountCode=defaultNamedNotOptArg, Sequence=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((8, 1), (3, 1)),AccountCode
			, Sequence)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(28, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AccountCode": (6, 2, (8, 0), (), "AccountCode", None),
		"AccountName": (8, 2, (8, 0), (), "AccountName", None),
		"BICSwiftCode": (31, 2, (8, 0), (), "BICSwiftCode", None),
		"BankMatch": (14, 2, (3, 0), (), "BankMatch", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (29, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (18, 2, (8, 0), (), "CardCode", None),
		"CardName": (19, 2, (8, 0), (), "CardName", None),
		"CreditAmount": (13, 2, (5, 0), (), "CreditAmount", None),
		"DataSource": (15, 2, (8, 0), (), "DataSource", None),
		"DebitAmount": (12, 2, (5, 0), (), "DebitAmount", None),
		"DocNumberType": (24, 2, (3, 0), (), "DocNumberType", None),
		"DueDate": (10, 2, (7, 0), (), "DueDate", None),
		"ExternalCode": (17, 2, (8, 0), (), "ExternalCode", None),
		"InvoiceNumber": (21, 2, (3, 0), (), "InvoiceNumber", None),
		"InvoiceNumberEx": (26, 2, (8, 0), (), "InvoiceNumberEx", None),
		"Memo": (11, 2, (8, 0), (), "Memo", None),
		"PaymentCreated": (22, 2, (3, 0), (), "PaymentCreated", None),
		"PaymentReference": (25, 2, (8, 0), (), "PaymentReference", None),
		"Reference": (9, 2, (8, 0), (), "Reference", None),
		"Sequence": (7, 2, (3, 0), (), "Sequence", None),
		"StatementNumber": (20, 2, (3, 0), (), "StatementNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (30, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (16, 2, (3, 0), (), "UserSignature", None),
		"VisualOrder": (23, 2, (3, 0), (), "VisualOrder", None),
	}
	_prop_map_put_ = {
		"AccountCode": ((6, LCID, 4, 0),()),
		"BICSwiftCode": ((31, LCID, 4, 0),()),
		"CardCode": ((18, LCID, 4, 0),()),
		"CardName": ((19, LCID, 4, 0),()),
		"CreditAmount": ((13, LCID, 4, 0),()),
		"DebitAmount": ((12, LCID, 4, 0),()),
		"DocNumberType": ((24, LCID, 4, 0),()),
		"DueDate": ((10, LCID, 4, 0),()),
		"ExternalCode": ((17, LCID, 4, 0),()),
		"InvoiceNumber": ((21, LCID, 4, 0),()),
		"InvoiceNumberEx": ((26, LCID, 4, 0),()),
		"Memo": ((11, LCID, 4, 0),()),
		"PaymentCreated": ((22, LCID, 4, 0),()),
		"PaymentReference": ((25, LCID, 4, 0),()),
		"Reference": ((9, LCID, 4, 0),()),
		"StatementNumber": ((20, LCID, 4, 0),()),
		"VisualOrder": ((23, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBankStatement(DispatchBaseClass):
	'IBankStatement Interface'
	CLSID = IID('{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')
	coclass_clsid = IID('{D68B336E-19AF-4033-8308-BA6A03D3C535}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"BankAccountKey": (11, 2, (3, 0), (), "BankAccountKey", None),
		"BankStatementFileHash": (22, 2, (8, 0), (), "BankStatementFileHash", None),
		"BankStatementGUID": (23, 2, (8, 0), (), "BankStatementGUID", None),
		# Method 'BankStatementRows' returns object of type 'IBankStatementRows'
		"BankStatementRows": (21, 2, (9, 0), (), "BankStatementRows", '{7E9C6F20-F9A1-470C-B50D-D1EA112B030A}'),
		"Currency": (18, 2, (8, 0), (), "Currency", None),
		"EndingBalanceF": (17, 2, (5, 0), (), "EndingBalanceF", None),
		"EndingBalanceL": (20, 2, (5, 0), (), "EndingBalanceL", None),
		"Imported": (15, 2, (3, 0), (), "Imported", None),
		"InternalNumber": (10, 2, (3, 0), (), "InternalNumber", None),
		"StartingBalanceF": (16, 2, (5, 0), (), "StartingBalanceF", None),
		"StartingBalanceL": (19, 2, (5, 0), (), "StartingBalanceL", None),
		"StatementDate": (13, 2, (7, 0), (), "StatementDate", None),
		"StatementNumber": (12, 2, (8, 0), (), "StatementNumber", None),
		"Status": (14, 2, (3, 0), (), "Status", None),
	}
	_prop_map_put_ = {
		"BankAccountKey": ((11, LCID, 4, 0),()),
		"BankStatementFileHash": ((22, LCID, 4, 0),()),
		"BankStatementGUID": ((23, LCID, 4, 0),()),
		"Currency": ((18, LCID, 4, 0),()),
		"EndingBalanceF": ((17, LCID, 4, 0),()),
		"EndingBalanceL": ((20, LCID, 4, 0),()),
		"StartingBalanceF": ((16, LCID, 4, 0),()),
		"StartingBalanceL": ((19, LCID, 4, 0),()),
		"StatementDate": ((13, LCID, 4, 0),()),
		"StatementNumber": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBankStatementParams(DispatchBaseClass):
	'IBankStatementParams Interface'
	CLSID = IID('{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')
	coclass_clsid = IID('{DAB0264E-58F1-4024-BA03-EE55FE4BB12E}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"BankAccountKey": (11, 2, (3, 0), (), "BankAccountKey", None),
		"Currency": (18, 2, (8, 0), (), "Currency", None),
		"EndingBalanceF": (17, 2, (5, 0), (), "EndingBalanceF", None),
		"EndingBalanceL": (20, 2, (5, 0), (), "EndingBalanceL", None),
		"Imported": (15, 2, (3, 0), (), "Imported", None),
		"InternalNumber": (10, 2, (3, 0), (), "InternalNumber", None),
		"StartingBalanceF": (16, 2, (5, 0), (), "StartingBalanceF", None),
		"StartingBalanceL": (19, 2, (5, 0), (), "StartingBalanceL", None),
		"StatementDate": (13, 2, (7, 0), (), "StatementDate", None),
		"StatementNumber": (12, 2, (8, 0), (), "StatementNumber", None),
		"Status": (14, 2, (3, 0), (), "Status", None),
	}
	_prop_map_put_ = {
		"InternalNumber": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBankStatementRow(DispatchBaseClass):
	'IBankStatementRow Interface'
	CLSID = IID('{2647D070-305A-43E8-89AE-B4D2C41E5168}')
	coclass_clsid = IID('{5BD5C9AB-52F6-411E-992F-1D507D70F6C1}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AccountName": (13, 2, (8, 0), (), "AccountName", None),
		"AccountNumber": (11, 2, (8, 0), (), "AccountNumber", None),
		"BPBICSwiftCode": (57, 2, (8, 0), (), "BPBICSwiftCode", None),
		"BPBankAccount": (35, 2, (8, 0), (), "BPBankAccount", None),
		"BPBankCode": (51, 2, (8, 0), (), "BPBankCode", None),
		"BPCode": (23, 2, (8, 0), (), "BPCode", None),
		"BPName": (24, 2, (8, 0), (), "BPName", None),
		"Balance": (20, 2, (5, 0), (), "Balance", None),
		"BankStmtDueDate": (33, 2, (7, 0), (), "BankStmtDueDate", None),
		"BankStmtLineDate": (32, 2, (7, 0), (), "BankStmtLineDate", None),
		"CreateMethod": (31, 2, (3, 0), (), "CreateMethod", None),
		"CreditAmountFC": (18, 2, (5, 0), (), "CreditAmountFC", None),
		"CreditAmountLC": (37, 2, (5, 0), (), "CreditAmountLC", None),
		"CreditCurrency": (19, 2, (8, 0), (), "CreditCurrency", None),
		"DebitAmountFC": (17, 2, (5, 0), (), "DebitAmountFC", None),
		"DebitAmountLC": (36, 2, (5, 0), (), "DebitAmountLC", None),
		"Details": (16, 2, (8, 0), (), "Details", None),
		"Details2": (29, 2, (8, 0), (), "Details2", None),
		"DocNumType": (28, 2, (3, 0), (), "DocNumType", None),
		"DocumentType": (45, 2, (3, 0), (), "DocumentType", None),
		"DueDate": (15, 2, (7, 0), (), "DueDate", None),
		"ExchangeRate": (38, 2, (5, 0), (), "ExchangeRate", None),
		"ExternalBankStatementNo": (10, 2, (3, 0), (), "ExternalBankStatementNo", None),
		"ExternalCode": (22, 2, (8, 0), (), "ExternalCode", None),
		"FeeDistributionRule": (52, 2, (8, 0), (), "FeeDistributionRule", None),
		"FeeDistributionRule2": (53, 2, (8, 0), (), "FeeDistributionRule2", None),
		"FeeDistributionRule3": (54, 2, (8, 0), (), "FeeDistributionRule3", None),
		"FeeDistributionRule4": (55, 2, (8, 0), (), "FeeDistributionRule4", None),
		"FeeDistributionRule5": (56, 2, (8, 0), (), "FeeDistributionRule5", None),
		"FeeOnTheLine": (40, 2, (5, 0), (), "FeeOnTheLine", None),
		"FeeProfitCenter": (48, 2, (8, 0), (), "FeeProfitCenter", None),
		"FeeProject": (49, 2, (8, 0), (), "FeeProject", None),
		"GLAccountforFee": (47, 2, (8, 0), (), "GLAccountforFee", None),
		"IBANofBPBankAccount": (39, 2, (8, 0), (), "IBANofBPBankAccount", None),
		"InternalBankOpCode": (34, 2, (3, 0), (), "InternalBankOpCode", None),
		"JournalEntryID": (43, 2, (3, 0), (), "JournalEntryID", None),
		# Method 'MultiplePayments' returns object of type 'IMultiplePayments'
		"MultiplePayments": (50, 2, (9, 0), (), "MultiplePayments", '{4207538F-AAC0-4EDD-9002-6F710410D5C6}'),
		"PaymentID": (44, 2, (3, 0), (), "PaymentID", None),
		"PaymentReferenceNo": (30, 2, (8, 0), (), "PaymentReferenceNo", None),
		"PostingMethod": (46, 2, (3, 0), (), "PostingMethod", None),
		"ReconciliationNo": (21, 2, (3, 0), (), "ReconciliationNo", None),
		"Reference": (14, 2, (8, 0), (), "Reference", None),
		"RowStatus": (26, 2, (8, 0), (), "RowStatus", None),
		"SequenceNo": (12, 2, (3, 0), (), "SequenceNo", None),
		"Source": (58, 2, (3, 0), (), "Source", None),
		"StatementNumber": (25, 2, (3, 0), (), "StatementNumber", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (59, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
		"VATAmountFC": (42, 2, (5, 0), (), "VATAmountFC", None),
		"VATAmountLC": (41, 2, (5, 0), (), "VATAmountLC", None),
		"VisualOrder": (27, 2, (3, 0), (), "VisualOrder", None),
	}
	_prop_map_put_ = {
		"AccountName": ((13, LCID, 4, 0),()),
		"BPBICSwiftCode": ((57, LCID, 4, 0),()),
		"BPBankAccount": ((35, LCID, 4, 0),()),
		"BPBankCode": ((51, LCID, 4, 0),()),
		"BPCode": ((23, LCID, 4, 0),()),
		"BPName": ((24, LCID, 4, 0),()),
		"Balance": ((20, LCID, 4, 0),()),
		"BankStmtDueDate": ((33, LCID, 4, 0),()),
		"BankStmtLineDate": ((32, LCID, 4, 0),()),
		"CreditAmountFC": ((18, LCID, 4, 0),()),
		"CreditAmountLC": ((37, LCID, 4, 0),()),
		"CreditCurrency": ((19, LCID, 4, 0),()),
		"DebitAmountFC": ((17, LCID, 4, 0),()),
		"DebitAmountLC": ((36, LCID, 4, 0),()),
		"Details": ((16, LCID, 4, 0),()),
		"Details2": ((29, LCID, 4, 0),()),
		"DocNumType": ((28, LCID, 4, 0),()),
		"DueDate": ((15, LCID, 4, 0),()),
		"ExchangeRate": ((38, LCID, 4, 0),()),
		"ExternalCode": ((22, LCID, 4, 0),()),
		"FeeDistributionRule": ((52, LCID, 4, 0),()),
		"FeeDistributionRule2": ((53, LCID, 4, 0),()),
		"FeeDistributionRule3": ((54, LCID, 4, 0),()),
		"FeeDistributionRule4": ((55, LCID, 4, 0),()),
		"FeeDistributionRule5": ((56, LCID, 4, 0),()),
		"FeeOnTheLine": ((40, LCID, 4, 0),()),
		"IBANofBPBankAccount": ((39, LCID, 4, 0),()),
		"PaymentReferenceNo": ((30, LCID, 4, 0),()),
		"Reference": ((14, LCID, 4, 0),()),
		"VATAmountFC": ((42, LCID, 4, 0),()),
		"VATAmountLC": ((41, LCID, 4, 0),()),
		"VisualOrder": ((27, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBankStatementRows(DispatchBaseClass):
	'IBankStatementRows Interface'
	CLSID = IID('{7E9C6F20-F9A1-470C-B50D-D1EA112B030A}')
	coclass_clsid = IID('{19A76A7C-7D0A-43FB-B70C-2338FCAA6453}')

	# Result is of type IBankStatementRow
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{2647D070-305A-43E8-89AE-B4D2C41E5168}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBankStatementRow
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{2647D070-305A-43E8-89AE-B4D2C41E5168}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{2647D070-305A-43E8-89AE-B4D2C41E5168}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{2647D070-305A-43E8-89AE-B4D2C41E5168}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBankStatements(DispatchBaseClass):
	'IBankStatements Interface'
	CLSID = IID('{57803F71-402E-40E7-94A1-A479207BD227}')
	coclass_clsid = IID('{1D2BD23C-C2FC-447C-B63E-4D4A321ECEED}')

	# Result is of type IBankStatement
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBankStatement
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBankStatementsFilter(DispatchBaseClass):
	'IBankStatementsFilter Interface'
	CLSID = IID('{9A4EDA67-F390-4901-80F3-0D85F73994B7}')
	coclass_clsid = IID('{B6D42A3B-BAEB-4A65-BA49-E5A89BC8EAFA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Account": (12, 2, (8, 0), (), "Account", None),
		"Bank": (11, 2, (8, 0), (), "Bank", None),
		"Country": (10, 2, (8, 0), (), "Country", None),
	}
	_prop_map_put_ = {
		"Account": ((12, LCID, 4, 0),()),
		"Bank": ((11, LCID, 4, 0),()),
		"Country": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBankStatementsImportFile(DispatchBaseClass):
	'IBankStatementsImportFile Interface'
	CLSID = IID('{7DCD3C0C-6B56-4572-8015-8E4CC744A095}')
	coclass_clsid = IID('{24323C3C-1853-425E-96F9-1D441B2D462F}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Account": (13, 2, (8, 0), (), "Account", None),
		"Bank": (12, 2, (8, 0), (), "Bank", None),
		"Country": (11, 2, (8, 0), (), "Country", None),
		"FileName": (10, 2, (8, 0), (), "FileName", None),
	}
	_prop_map_put_ = {
		"Account": ((13, LCID, 4, 0),()),
		"Bank": ((12, LCID, 4, 0),()),
		"Country": ((11, LCID, 4, 0),()),
		"FileName": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBankStatementsParams(DispatchBaseClass):
	'IBankStatementsParams Interface'
	CLSID = IID('{2C841DE4-014D-44C4-9D48-6A9B7BCD789A}')
	coclass_clsid = IID('{02FD29A2-2B9E-4D9E-936C-5DE5A115C180}')

	# Result is of type IBankStatementParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBankStatementParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBankStatementsService(DispatchBaseClass):
	'IBankStatementsService Interface'
	CLSID = IID('{C90D9F7D-14B6-465B-BE3B-48FABA68CF75}')
	coclass_clsid = IID('{8EBC49BF-EDA5-4B08-B93A-5B4A81045176}')

	# Result is of type IBankStatementParams
	def AddBankStatement(self, pIBankStatement=defaultNamedNotOptArg):
		'AddBankStatement'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBankStatement
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddBankStatement', '{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')
		return ret

	def DeleteBankStatement(self, pIBankStatementParams=defaultNamedNotOptArg):
		'DeleteBankStatement'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIBankStatementParams
			)

	# Result is of type IBankStatement
	def GetBankStatement(self, pIBankStatementParams=defaultNamedNotOptArg):
		'GetBankStatement'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIBankStatementParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBankStatement', '{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')
		return ret

	# Result is of type IBankStatementsParams
	def GetBankStatementList(self, pIBankStatementsFilter=defaultNamedNotOptArg):
		'GetBankStatementList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((9, 1),),pIBankStatementsFilter
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBankStatementList', '{2C841DE4-014D-44C4-9D48-6A9B7BCD789A}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateBankStatement(self, pIBankStatement=defaultNamedNotOptArg):
		'UpdateBankStatement'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBankStatement
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBanks(DispatchBaseClass):
	'IBanks Interface'
	CLSID = IID('{7A4DE818-7DD3-4035-97F8-6696A65651BF}')
	coclass_clsid = IID('{24AD49CD-DD3F-42CB-B745-5D6329BD0EDA}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsEntry=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lAbsEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AbsoluteEntry": (19, 2, (3, 0), (), "AbsoluteEntry", None),
		"AccountforOutgoingChecks": (12, 2, (8, 0), (), "AccountforOutgoingChecks", None),
		"BankCode": (10, 2, (8, 0), (), "BankCode", None),
		"BankName": (11, 2, (8, 0), (), "BankName", None),
		"BranchforOutgoingChecks": (13, 2, (8, 0), (), "BranchforOutgoingChecks", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CountryCode": (17, 2, (8, 0), (), "CountryCode", None),
		"DefaultBankAccountKey": (20, 2, (3, 0), (), "DefaultBankAccountKey", None),
		"IBAN": (16, 2, (8, 0), (), "IBAN", None),
		"NextCheckNumber": (14, 2, (3, 0), (), "NextCheckNumber", None),
		"PostOffice": (18, 2, (3, 0), (), "PostOffice", None),
		"SwiftNo": (15, 2, (8, 0), (), "SwiftNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BankCode": ((10, LCID, 4, 0),()),
		"BankName": ((11, LCID, 4, 0),()),
		"CountryCode": ((17, LCID, 4, 0),()),
		"DefaultBankAccountKey": ((20, LCID, 4, 0),()),
		"IBAN": ((16, LCID, 4, 0),()),
		"PostOffice": ((18, LCID, 4, 0),()),
		"SwiftNo": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBatchNumberDetail(DispatchBaseClass):
	'IBatchNumberDetail Interface'
	CLSID = IID('{A302DDF1-F725-46B9-8CC4-19E5766CEAC0}')
	coclass_clsid = IID('{D8FB6CAE-94FF-49EB-9B87-0FDDAAA8C165}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AdmissionDate": (17, 2, (7, 0), (), "AdmissionDate", None),
		"Batch": (14, 2, (8, 0), (), "Batch", None),
		"BatchAttribute1": (15, 2, (8, 0), (), "BatchAttribute1", None),
		"BatchAttribute2": (16, 2, (8, 0), (), "BatchAttribute2", None),
		"Details": (20, 2, (8, 0), (), "Details", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"ExpirationDate": (19, 2, (7, 0), (), "ExpirationDate", None),
		"ItemCode": (11, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (12, 2, (8, 0), (), "ItemDescription", None),
		"ManufacturingDate": (18, 2, (7, 0), (), "ManufacturingDate", None),
		"Status": (13, 2, (3, 0), (), "Status", None),
		"SystemNumber": (21, 2, (3, 0), (), "SystemNumber", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (22, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
	}
	_prop_map_put_ = {
		"AdmissionDate": ((17, LCID, 4, 0),()),
		"BatchAttribute1": ((15, LCID, 4, 0),()),
		"BatchAttribute2": ((16, LCID, 4, 0),()),
		"Details": ((20, LCID, 4, 0),()),
		"ExpirationDate": ((19, LCID, 4, 0),()),
		"ManufacturingDate": ((18, LCID, 4, 0),()),
		"Status": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBatchNumberDetailParams(DispatchBaseClass):
	'IBatchNumberDetailParams Interface'
	CLSID = IID('{CF02E105-3575-467B-9AD6-5BF719C9BC8B}')
	coclass_clsid = IID('{0362FE87-4255-455E-A6C8-A356C252767B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
	}
	_prop_map_put_ = {
		"DocEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBatchNumberDetailsService(DispatchBaseClass):
	'IBatchNumberDetailsService Interface'
	CLSID = IID('{3B0A3979-DE99-4162-8B2F-A8D4C9737B71}')
	coclass_clsid = IID('{60469EFE-3F0E-4B28-B387-6F6ADFB367DF}')

	# Result is of type IBatchNumberDetail
	def Get(self, pIBatchNumberDetailParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIBatchNumberDetailParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{A302DDF1-F725-46B9-8CC4-19E5766CEAC0}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def Update(self, pIBatchNumberDetail=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((9, 1),),pIBatchNumberDetail
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBatchNumbers(DispatchBaseClass):
	'IBatchNumbers Interface'
	CLSID = IID('{1FEF5698-93E1-4167-AEA0-4BB151792623}')
	coclass_clsid = IID('{41172218-C619-4E35-9D03-59EAF1E0F300}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AddmisionDate": (10, 2, (7, 0), (), "AddmisionDate", None),
		"BaseLineNumber": (15, 2, (3, 0), (), "BaseLineNumber", None),
		"BatchNumber": (5, 2, (8, 0), (), "BatchNumber", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"ExpiryDate": (8, 2, (7, 0), (), "ExpiryDate", None),
		"InternalSerialNumber": (7, 2, (8, 0), (), "InternalSerialNumber", None),
		"Location": (11, 2, (8, 0), (), "Location", None),
		"ManufacturerSerialNumber": (6, 2, (8, 0), (), "ManufacturerSerialNumber", None),
		"ManufacturingDate": (9, 2, (7, 0), (), "ManufacturingDate", None),
		"Notes": (12, 2, (8, 0), (), "Notes", None),
		"Quantity": (14, 2, (5, 0), (), "Quantity", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (16, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AddmisionDate": ((10, LCID, 4, 0),()),
		"BaseLineNumber": ((15, LCID, 4, 0),()),
		"BatchNumber": ((5, LCID, 4, 0),()),
		"ExpiryDate": ((8, LCID, 4, 0),()),
		"InternalSerialNumber": ((7, LCID, 4, 0),()),
		"Location": ((11, LCID, 4, 0),()),
		"ManufacturerSerialNumber": ((6, LCID, 4, 0),()),
		"ManufacturingDate": ((9, LCID, 4, 0),()),
		"Notes": ((12, LCID, 4, 0),()),
		"Quantity": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBillOfExchange(DispatchBaseClass):
	'IBillOfExchange Interface'
	CLSID = IID('{741AA803-AB33-4FD7-B664-63116291D6CE}')
	coclass_clsid = IID('{EA7AF142-F7C4-4E1A-BA6A-B5DBFCB71C3C}')

	_prop_map_get_ = {
		"BPBankAct": (22, 2, (8, 0), (), "BPBankAct", None),
		"BPBankCode": (21, 2, (8, 0), (), "BPBankCode", None),
		"BPBankCountry": (23, 2, (8, 0), (), "BPBankCountry", None),
		"BillOfExchangeDueDate": (12, 2, (7, 0), (), "BillOfExchangeDueDate", None),
		"BillOfExchangeNo": (10, 2, (8, 0), (), "BillOfExchangeNo", None),
		"ControlKey": (24, 2, (8, 0), (), "ControlKey", None),
		"Details": (13, 2, (8, 0), (), "Details", None),
		"DiscountAmount": (34, 2, (5, 0), (), "DiscountAmount", None),
		"DiscountDate": (37, 2, (7, 0), (), "DiscountDate", None),
		"FineAmount": (35, 2, (5, 0), (), "FineAmount", None),
		"FineDate": (38, 2, (7, 0), (), "FineDate", None),
		"FolioNumber": (31, 2, (3, 0), (), "FolioNumber", None),
		"FolioPrefixString": (32, 2, (8, 0), (), "FolioPrefixString", None),
		"IOFAmount": (39, 2, (5, 0), (), "IOFAmount", None),
		"InterestAmount": (33, 2, (5, 0), (), "InterestAmount", None),
		"InterestDate": (36, 2, (7, 0), (), "InterestDate", None),
		"OtherExpensesAmount": (41, 2, (5, 0), (), "OtherExpensesAmount", None),
		"OtherIncomesAmount": (42, 2, (5, 0), (), "OtherIncomesAmount", None),
		"PaymentEngineStatus1": (25, 2, (8, 0), (), "PaymentEngineStatus1", None),
		"PaymentEngineStatus2": (26, 2, (8, 0), (), "PaymentEngineStatus2", None),
		"PaymentEngineStatus3": (27, 2, (8, 0), (), "PaymentEngineStatus3", None),
		"PaymentMethodCode": (20, 2, (8, 0), (), "PaymentMethodCode", None),
		"ReferenceNo": (14, 2, (8, 0), (), "ReferenceNo", None),
		"Remarks": (19, 2, (8, 0), (), "Remarks", None),
		"ServiceFeeAmount": (40, 2, (5, 0), (), "ServiceFeeAmount", None),
		"StampTaxAmount": (30, 2, (5, 0), (), "StampTaxAmount", None),
		"StampTaxCode": (29, 2, (8, 0), (), "StampTaxCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (28, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BPBankAct": ((22, LCID, 4, 0),()),
		"BPBankCode": ((21, LCID, 4, 0),()),
		"BPBankCountry": ((23, LCID, 4, 0),()),
		"BillOfExchangeDueDate": ((12, LCID, 4, 0),()),
		"BillOfExchangeNo": ((10, LCID, 4, 0),()),
		"Details": ((13, LCID, 4, 0),()),
		"DiscountAmount": ((34, LCID, 4, 0),()),
		"DiscountDate": ((37, LCID, 4, 0),()),
		"FineAmount": ((35, LCID, 4, 0),()),
		"FineDate": ((38, LCID, 4, 0),()),
		"FolioNumber": ((31, LCID, 4, 0),()),
		"FolioPrefixString": ((32, LCID, 4, 0),()),
		"IOFAmount": ((39, LCID, 4, 0),()),
		"InterestAmount": ((33, LCID, 4, 0),()),
		"InterestDate": ((36, LCID, 4, 0),()),
		"OtherExpensesAmount": ((41, LCID, 4, 0),()),
		"OtherIncomesAmount": ((42, LCID, 4, 0),()),
		"PaymentEngineStatus1": ((25, LCID, 4, 0),()),
		"PaymentEngineStatus2": ((26, LCID, 4, 0),()),
		"PaymentEngineStatus3": ((27, LCID, 4, 0),()),
		"PaymentMethodCode": ((20, LCID, 4, 0),()),
		"ReferenceNo": ((14, LCID, 4, 0),()),
		"Remarks": ((19, LCID, 4, 0),()),
		"ServiceFeeAmount": ((40, LCID, 4, 0),()),
		"StampTaxAmount": ((30, LCID, 4, 0),()),
		"StampTaxCode": ((29, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBillOfExchangeTrans_BankPages(DispatchBaseClass):
	'IBillOfExchangeTrans_BankPages Interface'
	CLSID = IID('{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}')
	coclass_clsid = IID('{C057A0F5-A755-4C5E-A410-D4C4D1379487}')

	_prop_map_get_ = {
		"AccountCode": (4, 2, (8, 0), (), "AccountCode", None),
		"Sequence": (5, 2, (3, 0), (), "Sequence", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AccountCode": ((4, LCID, 4, 0),()),
		"Sequence": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBillOfExchangeTrans_Deposits(DispatchBaseClass):
	'IBillOfExchangeTrans_Deposits Interface'
	CLSID = IID('{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}')
	coclass_clsid = IID('{94DA073B-4599-4BC9-A22B-87D912159247}')

	_prop_map_get_ = {
		"BankAccount": (4, 2, (8, 0), (), "BankAccount", None),
		"BankBranch": (6, 2, (8, 0), (), "BankBranch", None),
		"BankCountry": (3, 2, (8, 0), (), "BankCountry", None),
		"BankDepositAccount": (5, 2, (8, 0), (), "BankDepositAccount", None),
		"DepositNorm": (1, 2, (8, 0), (), "DepositNorm", None),
		"PostingType": (2, 2, (3, 0), (), "PostingType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (7, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BankAccount": ((4, LCID, 4, 0),()),
		"BankBranch": ((6, LCID, 4, 0),()),
		"BankCountry": ((3, LCID, 4, 0),()),
		"BankDepositAccount": ((5, LCID, 4, 0),()),
		"DepositNorm": ((1, LCID, 4, 0),()),
		"PostingType": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBillOfExchangeTransaction(DispatchBaseClass):
	'IBillOfExchangeTransaction Interface'
	CLSID = IID('{DB038EC5-97EC-4D04-8E6A-AF01A5C05900}')
	coclass_clsid = IID('{CFAA1E6C-53D8-4C8E-A7DE-78ABE1601F30}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(19, LCID, 1, (8, 0), (),)

	def GetByKey(self, InternalKey=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),InternalKey
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		"BOETransactionkey": (18, 2, (3, 0), (), "BOETransactionkey", None),
		# Method 'BankPages' returns object of type 'IBillOfExchangeTrans_BankPages'
		"BankPages": (16, 2, (9, 0), (), "BankPages", '{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (21, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		# Method 'Deposits' returns object of type 'IBillOfExchangeTrans_Deposits'
		"Deposits": (15, 2, (9, 0), (), "Deposits", '{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}'),
		"IsBoeReconciled": (10, 2, (3, 0), (), "IsBoeReconciled", None),
		# Method 'Lines' returns object of type 'IBillOfExchangeTransaction_Lines'
		"Lines": (14, 2, (9, 0), (), "Lines", '{2DBFED56-4DB4-455A-9C22-E2C01C052D39}'),
		"PostingDate": (12, 2, (7, 0), (), "PostingDate", None),
		"StatusFrom": (6, 2, (3, 0), (), "StatusFrom", None),
		"StatusTo": (7, 2, (3, 0), (), "StatusTo", None),
		"TaxDate": (13, 2, (7, 0), (), "TaxDate", None),
		"TransactionDate": (8, 2, (7, 0), (), "TransactionDate", None),
		"TransactionNumber": (11, 2, (3, 0), (), "TransactionNumber", None),
		"TransactionTime": (9, 2, (7, 0), (), "TransactionTime", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (17, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"IsBoeReconciled": ((10, LCID, 4, 0),()),
		"PostingDate": ((12, LCID, 4, 0),()),
		"StatusFrom": ((6, LCID, 4, 0),()),
		"StatusTo": ((7, LCID, 4, 0),()),
		"TaxDate": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBillOfExchangeTransaction_Lines(DispatchBaseClass):
	'IBillOfExchangeTransaction_Lines Interface'
	CLSID = IID('{2DBFED56-4DB4-455A-9C22-E2C01C052D39}')
	coclass_clsid = IID('{A8A658F8-0A8A-4CEF-B5F4-481C3D4652FA}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BillOfExchangeDueDate": (7, 2, (7, 0), (), "BillOfExchangeDueDate", None),
		"BillOfExchangeNo": (5, 2, (3, 0), (), "BillOfExchangeNo", None),
		"BillOfExchangeType": (6, 2, (3, 0), (), "BillOfExchangeType", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BillOfExchangeNo": ((5, LCID, 4, 0),()),
		"BillOfExchangeType": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBlanketAgreement(DispatchBaseClass):
	'IBlanketAgreement Interface'
	CLSID = IID('{14F49B88-4722-45AC-993A-AD7680142769}')
	coclass_clsid = IID('{FB23BF90-F362-4CE6-AD2B-B5F45DE7EAC2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AgreementMethod": (30, 2, (3, 0), (), "AgreementMethod", None),
		"AgreementNo": (10, 2, (3, 0), (), "AgreementNo", None),
		"AgreementType": (18, 2, (3, 0), (), "AgreementType", None),
		"AmendmentTo": (34, 2, (3, 0), (), "AmendmentTo", None),
		"AttachmentEntry": (26, 2, (3, 0), (), "AttachmentEntry", None),
		"BPCode": (11, 2, (8, 0), (), "BPCode", None),
		"BPName": (12, 2, (8, 0), (), "BPName", None),
		# Method 'BlanketAgreements_ItemsLines' returns object of type 'IBlanketAgreements_ItemsLines'
		"BlanketAgreements_ItemsLines": (27, 2, (9, 0), (), "BlanketAgreements_ItemsLines", '{FECE5DF5-E254-43C1-BDD9-5C82097B9B9D}'),
		"ContactPersonCode": (13, 2, (3, 0), (), "ContactPersonCode", None),
		"Description": (17, 2, (8, 0), (), "Description", None),
		"EndDate": (15, 2, (7, 0), (), "EndDate", None),
		"IgnorePricesInAgreement": (21, 2, (3, 0), (), "IgnorePricesInAgreement", None),
		"Owner": (20, 2, (3, 0), (), "Owner", None),
		"PaymentTerms": (31, 2, (3, 0), (), "PaymentTerms", None),
		"PriceList": (32, 2, (3, 0), (), "PriceList", None),
		"Remarks": (25, 2, (8, 0), (), "Remarks", None),
		"RemindTime": (24, 2, (3, 0), (), "RemindTime", None),
		"RemindUnit": (23, 2, (3, 0), (), "RemindUnit", None),
		"Renewal": (22, 2, (3, 0), (), "Renewal", None),
		"SettlementProbability": (28, 2, (5, 0), (), "SettlementProbability", None),
		"SigningDate": (33, 2, (7, 0), (), "SigningDate", None),
		"StartDate": (14, 2, (7, 0), (), "StartDate", None),
		"Status": (19, 2, (3, 0), (), "Status", None),
		"TerminateDate": (16, 2, (7, 0), (), "TerminateDate", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (29, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
	}
	_prop_map_put_ = {
		"AgreementMethod": ((30, LCID, 4, 0),()),
		"AgreementType": ((18, LCID, 4, 0),()),
		"AmendmentTo": ((34, LCID, 4, 0),()),
		"AttachmentEntry": ((26, LCID, 4, 0),()),
		"BPCode": ((11, LCID, 4, 0),()),
		"ContactPersonCode": ((13, LCID, 4, 0),()),
		"Description": ((17, LCID, 4, 0),()),
		"EndDate": ((15, LCID, 4, 0),()),
		"Owner": ((20, LCID, 4, 0),()),
		"PaymentTerms": ((31, LCID, 4, 0),()),
		"PriceList": ((32, LCID, 4, 0),()),
		"Remarks": ((25, LCID, 4, 0),()),
		"RemindTime": ((24, LCID, 4, 0),()),
		"RemindUnit": ((23, LCID, 4, 0),()),
		"Renewal": ((22, LCID, 4, 0),()),
		"SettlementProbability": ((28, LCID, 4, 0),()),
		"SigningDate": ((33, LCID, 4, 0),()),
		"StartDate": ((14, LCID, 4, 0),()),
		"Status": ((19, LCID, 4, 0),()),
		"TerminateDate": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBlanketAgreementParams(DispatchBaseClass):
	'IBlanketAgreementParams Interface'
	CLSID = IID('{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')
	coclass_clsid = IID('{1A4FDB5D-78F8-4BC7-BBDD-3854B3B374BF}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AgreementNo": (10, 2, (3, 0), (), "AgreementNo", None),
	}
	_prop_map_put_ = {
		"AgreementNo": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBlanketAgreementsDocument(DispatchBaseClass):
	'IBlanketAgreementsDocument Interface'
	CLSID = IID('{14AF3328-811A-4FE5-A55A-C17BECE10062}')
	coclass_clsid = IID('{5D02917C-8423-418A-8BC7-7D1631742444}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AgreementRowNumber": (11, 2, (3, 0), (), "AgreementRowNumber", None),
		"Discount": (22, 2, (5, 0), (), "Discount", None),
		"DocumentDate": (15, 2, (7, 0), (), "DocumentDate", None),
		"DocumentNo": (13, 2, (3, 0), (), "DocumentNo", None),
		"DocumentRowNumber": (14, 2, (3, 0), (), "DocumentRowNumber", None),
		"DocumentType": (12, 2, (3, 0), (), "DocumentType", None),
		"ItemDescription": (17, 2, (8, 0), (), "ItemDescription", None),
		"ItemNo": (16, 2, (8, 0), (), "ItemNo", None),
		"Quantity": (19, 2, (5, 0), (), "Quantity", None),
		"RowStatus": (21, 2, (3, 0), (), "RowStatus", None),
		"UnitPrice": (18, 2, (5, 0), (), "UnitPrice", None),
		"UoM": (20, 2, (8, 0), (), "UoM", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBlanketAgreementsDocuments(DispatchBaseClass):
	'IBlanketAgreementsDocuments Interface'
	CLSID = IID('{EFA05C0F-B878-48E4-AA66-4E266FA5CC1A}')
	coclass_clsid = IID('{4B0217F3-1748-4E90-B442-C83DF84BF4B5}')

	# Result is of type IBlanketAgreementsDocument
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{14AF3328-811A-4FE5-A55A-C17BECE10062}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBlanketAgreementsDocument
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{14AF3328-811A-4FE5-A55A-C17BECE10062}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{14AF3328-811A-4FE5-A55A-C17BECE10062}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{14AF3328-811A-4FE5-A55A-C17BECE10062}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBlanketAgreementsParams(DispatchBaseClass):
	'IBlanketAgreementsParams Interface'
	CLSID = IID('{C1751C9B-F39D-4401-87D9-2C0C6B2DD2D2}')
	coclass_clsid = IID('{8BC443FC-F05C-40F1-A27E-BCCB4A568CB2}')

	# Result is of type IBlanketAgreementParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBlanketAgreementParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBlanketAgreementsService(DispatchBaseClass):
	'IBlanketAgreementsService Interface'
	CLSID = IID('{E22659B2-7CEA-4351-96C4-80160CFAADE7}')
	coclass_clsid = IID('{B9614205-7D1D-4EEC-9E2E-B1F6F1ACE50F}')

	# Result is of type IBlanketAgreementParams
	def AddBlanketAgreement(self, pIBlanketAgreement=defaultNamedNotOptArg):
		'AddBlanketAgreement'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBlanketAgreement
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddBlanketAgreement', '{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')
		return ret

	def CancelBlanketAgreement(self, pIBlanketAgreementParams=defaultNamedNotOptArg):
		'CancelBlanketAgreement'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((9, 1),),pIBlanketAgreementParams
			)

	# Result is of type IBlanketAgreement
	def GetBlanketAgreement(self, pIBlanketAgreementParams=defaultNamedNotOptArg):
		'GetBlanketAgreement'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIBlanketAgreementParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBlanketAgreement', '{14F49B88-4722-45AC-993A-AD7680142769}')
		return ret

	# Result is of type IBlanketAgreementsParams
	def GetBlanketAgreementList(self):
		'GetBlanketAgreementList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetBlanketAgreementList', '{C1751C9B-F39D-4401-87D9-2C0C6B2DD2D2}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IBlanketAgreementsDocuments
	def GetRelatedDocuments(self, pIBlanketAgreementParams=defaultNamedNotOptArg):
		'GetRelatedDocuments'
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), ((9, 1),),pIBlanketAgreementParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetRelatedDocuments', '{EFA05C0F-B878-48E4-AA66-4E266FA5CC1A}')
		return ret

	def UpdateBlanketAgreement(self, pIBlanketAgreement=defaultNamedNotOptArg):
		'UpdateBlanketAgreement'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBlanketAgreement
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBlanketAgreements_DetailsLine(DispatchBaseClass):
	'IBlanketAgreements_DetailsLine Interface'
	CLSID = IID('{E21D5CB9-5B51-4598-8989-75A702DFC29E}')
	coclass_clsid = IID('{B4BD2994-B72F-4AEE-8A80-8B94E2E34E4A}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AgreementEffectiveRowNumber": (12, 2, (3, 0), (), "AgreementEffectiveRowNumber", None),
		"AgreementNo": (10, 2, (3, 0), (), "AgreementNo", None),
		"AgreementRowNumber": (11, 2, (3, 0), (), "AgreementRowNumber", None),
		"ConsumeSalesForecast": (20, 2, (3, 0), (), "ConsumeSalesForecast", None),
		"FreeText": (19, 2, (8, 0), (), "FreeText", None),
		"Frequency": (13, 2, (3, 0), (), "Frequency", None),
		"From": (14, 2, (7, 0), (), "From", None),
		"PlannedAmountFC": (23, 2, (5, 0), (), "PlannedAmountFC", None),
		"PlannedAmountLC": (22, 2, (5, 0), (), "PlannedAmountLC", None),
		"Quantity": (17, 2, (5, 0), (), "Quantity", None),
		"ReleaseInformation": (16, 2, (8, 0), (), "ReleaseInformation", None),
		"To": (15, 2, (7, 0), (), "To", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (21, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
		"Warehouse": (18, 2, (8, 0), (), "Warehouse", None),
	}
	_prop_map_put_ = {
		"ConsumeSalesForecast": ((20, LCID, 4, 0),()),
		"FreeText": ((19, LCID, 4, 0),()),
		"Frequency": ((13, LCID, 4, 0),()),
		"From": ((14, LCID, 4, 0),()),
		"PlannedAmountFC": ((23, LCID, 4, 0),()),
		"PlannedAmountLC": ((22, LCID, 4, 0),()),
		"Quantity": ((17, LCID, 4, 0),()),
		"ReleaseInformation": ((16, LCID, 4, 0),()),
		"To": ((15, LCID, 4, 0),()),
		"Warehouse": ((18, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBlanketAgreements_DetailsLines(DispatchBaseClass):
	'IBlanketAgreements_DetailsLines Interface'
	CLSID = IID('{EB66D894-270C-4DF1-B76A-AB91ABE88D03}')
	coclass_clsid = IID('{066F2531-FDDC-46CF-9795-BD09D7E3A4C9}')

	# Result is of type IBlanketAgreements_DetailsLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{E21D5CB9-5B51-4598-8989-75A702DFC29E}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBlanketAgreements_DetailsLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{E21D5CB9-5B51-4598-8989-75A702DFC29E}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{E21D5CB9-5B51-4598-8989-75A702DFC29E}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{E21D5CB9-5B51-4598-8989-75A702DFC29E}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBlanketAgreements_ItemsLine(DispatchBaseClass):
	'IBlanketAgreements_ItemsLine Interface'
	CLSID = IID('{C083AAA6-1496-4E5F-82B0-201194FD8651}')
	coclass_clsid = IID('{1C485004-89C3-4E4F-A043-697986E0D571}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AgreementNo": (10, 2, (3, 0), (), "AgreementNo", None),
		"AgreementRowNumber": (11, 2, (3, 0), (), "AgreementRowNumber", None),
		# Method 'BlanketAgreements_DetailsLines' returns object of type 'IBlanketAgreements_DetailsLines'
		"BlanketAgreements_DetailsLines": (23, 2, (9, 0), (), "BlanketAgreements_DetailsLines", '{EB66D894-270C-4DF1-B76A-AB91ABE88D03}'),
		"CumulativeAmountFC": (20, 2, (5, 0), (), "CumulativeAmountFC", None),
		"CumulativeAmountLC": (19, 2, (5, 0), (), "CumulativeAmountLC", None),
		"CumulativeQuantity": (18, 2, (5, 0), (), "CumulativeQuantity", None),
		"EndOfWarranty": (25, 2, (7, 0), (), "EndOfWarranty", None),
		"FreeText": (21, 2, (8, 0), (), "FreeText", None),
		"InventoryUOM": (22, 2, (8, 0), (), "InventoryUOM", None),
		"ItemDescription": (13, 2, (8, 0), (), "ItemDescription", None),
		"ItemGroup": (14, 2, (3, 0), (), "ItemGroup", None),
		"ItemNo": (12, 2, (8, 0), (), "ItemNo", None),
		"LineDiscount": (29, 2, (5, 0), (), "LineDiscount", None),
		"PlannedAmountFC": (28, 2, (5, 0), (), "PlannedAmountFC", None),
		"PlannedAmountLC": (27, 2, (5, 0), (), "PlannedAmountLC", None),
		"PlannedQuantity": (15, 2, (5, 0), (), "PlannedQuantity", None),
		"PortionOfReturns": (24, 2, (5, 0), (), "PortionOfReturns", None),
		"PriceCurrency": (17, 2, (8, 0), (), "PriceCurrency", None),
		"UnitPrice": (16, 2, (5, 0), (), "UnitPrice", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (26, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
	}
	_prop_map_put_ = {
		"EndOfWarranty": ((25, LCID, 4, 0),()),
		"FreeText": ((21, LCID, 4, 0),()),
		"ItemDescription": ((13, LCID, 4, 0),()),
		"ItemNo": ((12, LCID, 4, 0),()),
		"LineDiscount": ((29, LCID, 4, 0),()),
		"PlannedAmountFC": ((28, LCID, 4, 0),()),
		"PlannedAmountLC": ((27, LCID, 4, 0),()),
		"PlannedQuantity": ((15, LCID, 4, 0),()),
		"PortionOfReturns": ((24, LCID, 4, 0),()),
		"PriceCurrency": ((17, LCID, 4, 0),()),
		"UnitPrice": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBlanketAgreements_ItemsLines(DispatchBaseClass):
	'IBlanketAgreements_ItemsLines Interface'
	CLSID = IID('{FECE5DF5-E254-43C1-BDD9-5C82097B9B9D}')
	coclass_clsid = IID('{B139E51C-5D68-4216-969D-7511566847B2}')

	# Result is of type IBlanketAgreements_ItemsLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{C083AAA6-1496-4E5F-82B0-201194FD8651}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBlanketAgreements_ItemsLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{C083AAA6-1496-4E5F-82B0-201194FD8651}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{C083AAA6-1496-4E5F-82B0-201194FD8651}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{C083AAA6-1496-4E5F-82B0-201194FD8651}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBlob(DispatchBaseClass):
	'IBlob Interface'
	CLSID = IID('{E7838784-BDDC-4EC2-A812-C96B19D169C5}')
	coclass_clsid = IID('{4E7D63F0-1341-4517-8F19-2EBC03A2D875}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Content": (10, 2, (8, 0), (), "Content", None),
	}
	_prop_map_put_ = {
		"Content": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBlobParams(DispatchBaseClass):
	'IBlobParams Interface'
	CLSID = IID('{6625CFCF-AADC-4D47-A83E-C1C786666117}')
	coclass_clsid = IID('{3C0844B7-EFC9-4F84-99C7-EE736EDF6A89}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		# Method 'BlobTableKeySegments' returns object of type 'IBlobTableKeySegments'
		"BlobTableKeySegments": (10, 2, (9, 0), (), "BlobTableKeySegments", '{86FB8743-E265-47A1-BE6C-7A5E9FEEAAAB}'),
		"Field": (12, 2, (8, 0), (), "Field", None),
		"FileName": (13, 2, (8, 0), (), "FileName", None),
		"Table": (11, 2, (8, 0), (), "Table", None),
	}
	_prop_map_put_ = {
		"Field": ((12, LCID, 4, 0),()),
		"FileName": ((13, LCID, 4, 0),()),
		"Table": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBlobTableKeySegment(DispatchBaseClass):
	'IBlobTableKeySegment Interface'
	CLSID = IID('{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}')
	coclass_clsid = IID('{52065704-057D-4B2B-A301-40F252371DA3}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Name": (10, 2, (8, 0), (), "Name", None),
		"Value": (11, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Name": ((10, LCID, 4, 0),()),
		"Value": ((11, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(11, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBlobTableKeySegments(DispatchBaseClass):
	'IBlobTableKeySegments Interface'
	CLSID = IID('{86FB8743-E265-47A1-BE6C-7A5E9FEEAAAB}')
	coclass_clsid = IID('{AB946B33-0679-4E78-92EE-BAFFC4DAA9AE}')

	# Result is of type IBlobTableKeySegment
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBlobTableKeySegment
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBoxes1099(DispatchBaseClass):
	'IBoxes1099 Interface'
	CLSID = IID('{1C7661BB-2694-4ECF-94EF-588ECB0CB8AD}')
	coclass_clsid = IID('{7444C348-853B-4932-924E-14D1314F9D32}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Box1099": (6, 2, (8, 0), (), "Box1099", None),
		"BoxDescription": (7, 2, (8, 0), (), "BoxDescription", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"FormCode": (5, 2, (3, 0), (), "FormCode", None),
		"Minimum1099Amount": (8, 2, (5, 0), (), "Minimum1099Amount", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Box1099": ((6, LCID, 4, 0),()),
		"BoxDescription": ((7, LCID, 4, 0),()),
		"Minimum1099Amount": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBranch(DispatchBaseClass):
	'IBranch Interface'
	CLSID = IID('{DC24341F-4CD3-4608-9ED4-745882053E6A}')
	coclass_clsid = IID('{84AA649E-44F2-4988-8CDF-53FFD270933C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBranchParams(DispatchBaseClass):
	'IBranchParams Interface'
	CLSID = IID('{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')
	coclass_clsid = IID('{171C2811-0B09-46D2-B716-50A0FF4CB5AE}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBranchesParams(DispatchBaseClass):
	'IBranchesParams Interface'
	CLSID = IID('{3CA31A48-0CEE-436B-9447-E14D8D27C546}')
	coclass_clsid = IID('{303AD037-92AA-4508-8FD3-08C4A6D4CFAF}')

	# Result is of type IBranchParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBranchParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBranchesService(DispatchBaseClass):
	'IBranchesService Interface'
	CLSID = IID('{0577F672-2A66-452A-9597-5008904A3940}')
	coclass_clsid = IID('{26C5C696-EC20-43DC-BCD9-010F00F40843}')

	# Result is of type IBranchParams
	def AddBranch(self, pIBranch=defaultNamedNotOptArg):
		'AddBranch'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBranch
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddBranch', '{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')
		return ret

	def DeleteBranch(self, pIBranchParams=defaultNamedNotOptArg):
		'DeleteBranch'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIBranchParams
			)

	# Result is of type IBranch
	def GetBranch(self, pIBranchParams=defaultNamedNotOptArg):
		'GetBranch'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIBranchParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBranch', '{DC24341F-4CD3-4608-9ED4-745882053E6A}')
		return ret

	# Result is of type IBranchesParams
	def GetBranchList(self):
		'GetBranchList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetBranchList', '{3CA31A48-0CEE-436B-9447-E14D8D27C546}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateBranch(self, pIBranch=defaultNamedNotOptArg):
		'UpdateBranch'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBranch
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilBeverageIndexer(DispatchBaseClass):
	'IBrazilBeverageIndexer Interface'
	CLSID = IID('{F17A759E-0E4E-448D-BA57-E6EF3760A591}')
	coclass_clsid = IID('{EEC2D22B-97A3-4AC4-9823-7DBC2A9A1C53}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"BeverageCommercialBrandCode": (12, 2, (3, 0), (), "BeverageCommercialBrandCode", None),
		"BeverageGroupCode": (10, 2, (8, 0), (), "BeverageGroupCode", None),
		"BeverageID": (13, 2, (3, 0), (), "BeverageID", None),
		"BeverageTableCode": (11, 2, (8, 0), (), "BeverageTableCode", None),
	}
	_prop_map_put_ = {
		"BeverageCommercialBrandCode": ((12, LCID, 4, 0),()),
		"BeverageGroupCode": ((10, LCID, 4, 0),()),
		"BeverageTableCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilBeverageIndexerParams(DispatchBaseClass):
	'IBrazilBeverageIndexerParams Interface'
	CLSID = IID('{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')
	coclass_clsid = IID('{C7678A96-E53C-402A-B298-8104D810EDE5}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"BeverageCommercialBrandCode": (12, 2, (3, 0), (), "BeverageCommercialBrandCode", None),
		"BeverageGroupCode": (10, 2, (8, 0), (), "BeverageGroupCode", None),
		"BeverageTableCode": (11, 2, (8, 0), (), "BeverageTableCode", None),
	}
	_prop_map_put_ = {
		"BeverageCommercialBrandCode": ((12, LCID, 4, 0),()),
		"BeverageGroupCode": ((10, LCID, 4, 0),()),
		"BeverageTableCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilBeverageIndexersParams(DispatchBaseClass):
	'IBrazilBeverageIndexersParams Interface'
	CLSID = IID('{C9C4DE1F-9409-446D-AC6A-0FAD12624939}')
	coclass_clsid = IID('{FD5860AF-4409-4BE0-87A2-51FB438E08BF}')

	# Result is of type IBrazilBeverageIndexerParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBrazilBeverageIndexerParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBrazilBeverageIndexersService(DispatchBaseClass):
	'IBrazilBeverageIndexersService Interface'
	CLSID = IID('{80E28887-F468-4172-9043-D442BCAB1F55}')
	coclass_clsid = IID('{83EEB8EC-F354-45A8-A55B-4C2EF2511F9C}')

	# Result is of type IBrazilBeverageIndexerParams
	def Add(self, pIBrazilBeverageIndexer=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBrazilBeverageIndexer
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')
		return ret

	def Delete(self, pIBrazilBeverageIndexerParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBrazilBeverageIndexerParams
			)

	# Result is of type IBrazilBeverageIndexer
	def Get(self, pIBrazilBeverageIndexerParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIBrazilBeverageIndexerParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{F17A759E-0E4E-448D-BA57-E6EF3760A591}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IBrazilBeverageIndexersParams
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{C9C4DE1F-9409-446D-AC6A-0FAD12624939}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilFuelIndexer(DispatchBaseClass):
	'IBrazilFuelIndexer Interface'
	CLSID = IID('{45CD0988-1275-4D2C-BF2C-5D04CB984489}')
	coclass_clsid = IID('{3BDD39A5-7A7A-4DD1-963A-5C3500A6B262}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (13, 2, (8, 0), (), "Description", None),
		"FuelCode": (12, 2, (8, 0), (), "FuelCode", None),
		"FuelGroupCode": (11, 2, (3, 0), (), "FuelGroupCode", None),
		"FuelID": (10, 2, (3, 0), (), "FuelID", None),
	}
	_prop_map_put_ = {
		"Description": ((13, LCID, 4, 0),()),
		"FuelCode": ((12, LCID, 4, 0),()),
		"FuelGroupCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilFuelIndexerParams(DispatchBaseClass):
	'IBrazilFuelIndexerParams Interface'
	CLSID = IID('{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')
	coclass_clsid = IID('{819AD6EF-E5DB-4FBA-8387-17863BEFE018}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (13, 2, (8, 0), (), "Description", None),
		"FuelCode": (12, 2, (8, 0), (), "FuelCode", None),
		"FuelGroupCode": (11, 2, (3, 0), (), "FuelGroupCode", None),
		"FuelID": (10, 2, (3, 0), (), "FuelID", None),
	}
	_prop_map_put_ = {
		"FuelID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilFuelIndexersParams(DispatchBaseClass):
	'IBrazilFuelIndexersParams Interface'
	CLSID = IID('{C7037B05-9DF8-47CA-8819-4D9460F03794}')
	coclass_clsid = IID('{6D9D8D62-8831-45B0-814A-BF7EB5AA63DD}')

	# Result is of type IBrazilFuelIndexerParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBrazilFuelIndexerParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBrazilFuelIndexersService(DispatchBaseClass):
	'IBrazilFuelIndexersService Interface'
	CLSID = IID('{40BA4F6D-54E1-41DD-A912-C9D3A4C5EA28}')
	coclass_clsid = IID('{77166E02-41E6-47C8-9EBE-66348C1C9D9E}')

	# Result is of type IBrazilFuelIndexerParams
	def Add(self, pIBrazilFuelIndexer=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBrazilFuelIndexer
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')
		return ret

	def Delete(self, pIBrazilFuelIndexerParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBrazilFuelIndexerParams
			)

	# Result is of type IBrazilFuelIndexer
	def Get(self, pIBrazilFuelIndexerParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIBrazilFuelIndexerParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{45CD0988-1275-4D2C-BF2C-5D04CB984489}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IBrazilFuelIndexersParams
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{C7037B05-9DF8-47CA-8819-4D9460F03794}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilMultiIndexer(DispatchBaseClass):
	'IBrazilMultiIndexer Interface'
	CLSID = IID('{EB892090-5B7A-48F1-849C-5F4A0048B2DA}')
	coclass_clsid = IID('{03811867-1D7D-4ED8-B42B-040839C0EC4C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetReferencedIndexerType(self, referenceIndex=defaultNamedNotOptArg, penumRsltType=pythoncom.Missing, plRsltValue=pythoncom.Missing):
		'method GetReferencedIndexerType'
		return self._ApplyTypes_(17, 1, (11, 0), ((3, 1), (16387, 2), (16387, 2)), u'GetReferencedIndexerType', None,referenceIndex
			, penumRsltType, plRsltValue)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (12, 2, (8, 0), (), "Code", None),
		"Description": (13, 2, (8, 0), (), "Description", None),
		"FirstRefIndexerCode": (14, 2, (8, 0), (), "FirstRefIndexerCode", None),
		"ID": (10, 2, (3, 0), (), "ID", None),
		"IndexerType": (11, 2, (3, 0), (), "IndexerType", None),
		"SecondRefIndexerCode": (15, 2, (8, 0), (), "SecondRefIndexerCode", None),
		"ThirdRefIndexerCode": (16, 2, (8, 0), (), "ThirdRefIndexerCode", None),
	}
	_prop_map_put_ = {
		"Code": ((12, LCID, 4, 0),()),
		"Description": ((13, LCID, 4, 0),()),
		"FirstRefIndexerCode": ((14, LCID, 4, 0),()),
		"IndexerType": ((11, LCID, 4, 0),()),
		"SecondRefIndexerCode": ((15, LCID, 4, 0),()),
		"ThirdRefIndexerCode": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilMultiIndexerParams(DispatchBaseClass):
	'IBrazilMultiIndexerParams Interface'
	CLSID = IID('{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')
	coclass_clsid = IID('{58FCDC2F-A0BF-4211-A2F9-D21C0E13AEDF}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"FirstRefIndexerCode": (13, 2, (8, 0), (), "FirstRefIndexerCode", None),
		"IndexerType": (10, 2, (3, 0), (), "IndexerType", None),
		"SecondRefIndexerCode": (14, 2, (8, 0), (), "SecondRefIndexerCode", None),
		"ThirdRefIndexerCode": (15, 2, (8, 0), (), "ThirdRefIndexerCode", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"IndexerType": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilMultiIndexersParams(DispatchBaseClass):
	'IBrazilMultiIndexersParams Interface'
	CLSID = IID('{292717A3-9E69-4C34-BE56-A61A52CA8AA2}')
	coclass_clsid = IID('{F69530F1-7AD5-4496-807B-6911ED2E5363}')

	# Result is of type IBrazilMultiIndexerParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBrazilMultiIndexerParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBrazilMultiIndexersService(DispatchBaseClass):
	'IBrazilMultiIndexersService Interface'
	CLSID = IID('{207685C7-0E68-4A17-AD6C-7C2635B60316}')
	coclass_clsid = IID('{6AD3FECD-43C9-4993-B8F5-0340C8299AEE}')

	# Result is of type IBrazilMultiIndexerParams
	def Add(self, pIBrazilMultiIndexer=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBrazilMultiIndexer
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')
		return ret

	def Delete(self, pIBrazilMultiIndexerParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBrazilMultiIndexerParams
			)

	# Result is of type IBrazilMultiIndexer
	def Get(self, pIBrazilMultiIndexerParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIBrazilMultiIndexerParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{EB892090-5B7A-48F1-849C-5F4A0048B2DA}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IBrazilMultiIndexersParams
	def GetIndexerTypeList(self, pIBrazilMultiIndexerParams=defaultNamedNotOptArg):
		'GetIndexerTypeList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIBrazilMultiIndexerParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetIndexerTypeList', '{292717A3-9E69-4C34-BE56-A61A52CA8AA2}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilNumericIndexer(DispatchBaseClass):
	'IBrazilNumericIndexer Interface'
	CLSID = IID('{69B00574-A904-4416-AC73-94E84B7882CA}')
	coclass_clsid = IID('{3CFFABA9-A29B-4D64-8344-17073542C395}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (3, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"ID": (13, 2, (3, 0), (), "ID", None),
		"IndexerType": (10, 2, (3, 0), (), "IndexerType", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"Description": ((12, LCID, 4, 0),()),
		"IndexerType": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilNumericIndexerParams(DispatchBaseClass):
	'IBrazilNumericIndexerParams Interface'
	CLSID = IID('{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')
	coclass_clsid = IID('{9E538356-9693-4627-A806-D01D07823616}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (3, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"IndexerType": (10, 2, (3, 0), (), "IndexerType", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"IndexerType": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilNumericIndexersParams(DispatchBaseClass):
	'IBrazilNumericIndexersParams Interface'
	CLSID = IID('{12696EFB-62EF-4BD0-9B7B-456F3999DAEF}')
	coclass_clsid = IID('{3F0B1146-0F25-4198-A84C-BBA0CEB0FACF}')

	# Result is of type IBrazilNumericIndexerParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBrazilNumericIndexerParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBrazilNumericIndexersService(DispatchBaseClass):
	'IBrazilNumericIndexersService Interface'
	CLSID = IID('{DA13FA15-615B-4F4D-9E61-120A803D3F32}')
	coclass_clsid = IID('{B65E1962-E1A8-4BD0-83D6-6F159503C18E}')

	# Result is of type IBrazilNumericIndexerParams
	def Add(self, pIBrazilNumericIndexer=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBrazilNumericIndexer
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')
		return ret

	def Delete(self, pIBrazilNumericIndexerParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBrazilNumericIndexerParams
			)

	# Result is of type IBrazilNumericIndexer
	def Get(self, pIBrazilNumericIndexerParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIBrazilNumericIndexerParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{69B00574-A904-4416-AC73-94E84B7882CA}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IBrazilNumericIndexersParams
	def GetIndexerTypeList(self, pIBrazilNumericIndexerParams=defaultNamedNotOptArg):
		'GetIndexerTypeList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIBrazilNumericIndexerParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetIndexerTypeList', '{12696EFB-62EF-4BD0-9B7B-456F3999DAEF}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilStringIndexer(DispatchBaseClass):
	'IBrazilStringIndexer Interface'
	CLSID = IID('{BCE76DC7-889C-4A7A-B77F-842FC7D0684E}')
	coclass_clsid = IID('{E8DA612B-3A4E-4186-B127-DAF785480B47}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"ID": (13, 2, (3, 0), (), "ID", None),
		"IndexerType": (10, 2, (3, 0), (), "IndexerType", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"Description": ((12, LCID, 4, 0),()),
		"IndexerType": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilStringIndexerParams(DispatchBaseClass):
	'IBrazilStringIndexerParams Interface'
	CLSID = IID('{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')
	coclass_clsid = IID('{638D8662-F163-4574-B69D-11B5C6696733}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"IndexerType": (10, 2, (3, 0), (), "IndexerType", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"IndexerType": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBrazilStringIndexersParams(DispatchBaseClass):
	'IBrazilStringIndexersParams Interface'
	CLSID = IID('{F2A7926C-BDB1-4151-8FEC-5A58C2BCC600}')
	coclass_clsid = IID('{DC66A989-A072-41C9-959F-B9525E8AFC1B}')

	# Result is of type IBrazilStringIndexerParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBrazilStringIndexerParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBrazilStringIndexersService(DispatchBaseClass):
	'IBrazilStringIndexersService Interface'
	CLSID = IID('{4735E037-68A6-474D-AEC5-F5D9BD3B09A6}')
	coclass_clsid = IID('{BD51601F-CF1B-4F4E-A99A-A8642C241815}')

	# Result is of type IBrazilStringIndexerParams
	def Add(self, pIBrazilStringIndexer=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIBrazilStringIndexer
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')
		return ret

	def Delete(self, pIBrazilStringIndexerParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIBrazilStringIndexerParams
			)

	# Result is of type IBrazilStringIndexer
	def Get(self, pIBrazilStringIndexerParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIBrazilStringIndexerParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{BCE76DC7-889C-4A7A-B77F-842FC7D0684E}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IBrazilStringIndexersParams
	def GetIndexerTypeList(self, pIBrazilStringIndexerParams=defaultNamedNotOptArg):
		'GetIndexerTypeList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIBrazilStringIndexerParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetIndexerTypeList', '{F2A7926C-BDB1-4151-8FEC-5A58C2BCC600}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBudget(DispatchBaseClass):
	'IBudget Interface'
	CLSID = IID('{C1F83FBE-3A3F-4A81-8B0B-B5485DC6ADF9}')
	coclass_clsid = IID('{11067A79-5484-43A2-945C-7408CDCF01E6}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(33, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((3, 1),),Key
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(34, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AccountCode": (27, 2, (8, 0), (), "AccountCode", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (31, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BudgetBalanceCreditLoc": (25, 2, (5, 0), (), "BudgetBalanceCreditLoc", None),
		"BudgetBalanceCreditSys": (24, 2, (5, 0), (), "BudgetBalanceCreditSys", None),
		"BudgetBalanceDebitLoc": (20, 2, (5, 0), (), "BudgetBalanceDebitLoc", None),
		"BudgetBalanceDebitSys": (19, 2, (5, 0), (), "BudgetBalanceDebitSys", None),
		"BudgetScenario": (32, 2, (3, 0), (), "BudgetScenario", None),
		# Method 'CostAccountingLines' returns object of type 'IBudgetCostAccounting_Lines'
		"CostAccountingLines": (35, 2, (9, 0), (), "CostAccountingLines", '{F1E88ED4-1F91-4FE5-B4EB-13B48CB46F52}'),
		"DivisionCode": (26, 2, (3, 0), (), "DivisionCode", None),
		"FutureAnnualExpensesCreditLoc": (8, 2, (5, 0), (), "FutureAnnualExpensesCreditLoc", None),
		"FutureAnnualExpensesCreditSys": (7, 2, (5, 0), (), "FutureAnnualExpensesCreditSys", None),
		"FutureAnnualExpensesDebitLoc": (10, 2, (5, 0), (), "FutureAnnualExpensesDebitLoc", None),
		"FutureAnnualExpensesDebitSys": (9, 2, (5, 0), (), "FutureAnnualExpensesDebitSys", None),
		"FutureAnnualRevenuesCredit": (11, 2, (5, 0), (), "FutureAnnualRevenuesCredit", None),
		"FutureAnnualRevenuesDebit": (12, 2, (5, 0), (), "FutureAnnualRevenuesDebit", None),
		"FutureRevenuesDebitLoc": (14, 2, (5, 0), (), "FutureRevenuesDebitLoc", None),
		"FutureRevenuesDebitSys": (13, 2, (5, 0), (), "FutureRevenuesDebitSys", None),
		# Method 'Lines' returns object of type 'IBudget_Lines'
		"Lines": (29, 2, (9, 0), (), "Lines", '{D2BAB599-C7C6-4301-B925-B6BB51092A79}'),
		"Numerator": (28, 2, (3, 0), (), "Numerator", None),
		"ParentAccPercent": (15, 2, (5, 0), (), "ParentAccPercent", None),
		"ParentAccountKey": (17, 2, (8, 0), (), "ParentAccountKey", None),
		"StartofFiscalYear": (16, 2, (7, 0), (), "StartofFiscalYear", None),
		"TotalAnnualBudgetCreditLoc": (23, 2, (5, 0), (), "TotalAnnualBudgetCreditLoc", None),
		"TotalAnnualBudgetCreditSys": (22, 2, (5, 0), (), "TotalAnnualBudgetCreditSys", None),
		"TotalAnnualBudgetDebitLoc": (21, 2, (5, 0), (), "TotalAnnualBudgetDebitLoc", None),
		"TotalAnnualBudgetDebitSys": (18, 2, (5, 0), (), "TotalAnnualBudgetDebitSys", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (30, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AccountCode": ((27, LCID, 4, 0),()),
		"BudgetScenario": ((32, LCID, 4, 0),()),
		"DivisionCode": ((26, LCID, 4, 0),()),
		"ParentAccPercent": ((15, LCID, 4, 0),()),
		"ParentAccountKey": ((17, LCID, 4, 0),()),
		"TotalAnnualBudgetCreditLoc": ((23, LCID, 4, 0),()),
		"TotalAnnualBudgetCreditSys": ((22, LCID, 4, 0),()),
		"TotalAnnualBudgetDebitLoc": ((21, LCID, 4, 0),()),
		"TotalAnnualBudgetDebitSys": ((18, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBudgetCostAccounting_Lines(DispatchBaseClass):
	'IBudgetCostAccounting_Lines Interface'
	CLSID = IID('{F1E88ED4-1F91-4FE5-B4EB-13B48CB46F52}')
	coclass_clsid = IID('{E8AB066D-E193-4433-AD85-0E1AA6F490A3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (4, 2, (3, 0), (), "Count", None),
		"Dimension": (7, 2, (3, 0), (), "Dimension", None),
		"DistrRuleCode": (6, 2, (8, 0), (), "DistrRuleCode", None),
		"DistrRuleCreditLC": (10, 2, (5, 0), (), "DistrRuleCreditLC", None),
		"DistrRuleCreditSC": (11, 2, (5, 0), (), "DistrRuleCreditSC", None),
		"DistrRuleDebitLC": (8, 2, (5, 0), (), "DistrRuleDebitLC", None),
		"DistrRuleDebitSC": (9, 2, (5, 0), (), "DistrRuleDebitSC", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Dimension": ((7, LCID, 4, 0),()),
		"DistrRuleCode": ((6, LCID, 4, 0),()),
		"DistrRuleCreditLC": ((10, LCID, 4, 0),()),
		"DistrRuleCreditSC": ((11, LCID, 4, 0),()),
		"DistrRuleDebitLC": ((8, LCID, 4, 0),()),
		"DistrRuleDebitSC": ((9, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(4, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBudgetDistribution(DispatchBaseClass):
	'IBudgetDistribution Interface'
	CLSID = IID('{0CFCFE82-D222-486A-9E49-0FBE58FDD534}')
	coclass_clsid = IID('{16F466DA-6A22-46AE-A5B2-5934A0194D7A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(23, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(24, LCID, 1, (8, 0), (),)

	def GetByKey(self, lBgdCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (11, 0), ((3, 1),),lBgdCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(25, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(20, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"April": (6, 2, (5, 0), (), "April", None),
		"August": (2, 2, (5, 0), (), "August", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (22, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BudgetAmount": (13, 2, (5, 0), (), "BudgetAmount", None),
		"December": (9, 2, (5, 0), (), "December", None),
		"Description": (14, 2, (8, 0), (), "Description", None),
		"DivisionCode": (15, 2, (3, 0), (), "DivisionCode", None),
		"February": (8, 2, (5, 0), (), "February", None),
		"January": (12, 2, (5, 0), (), "January", None),
		"July": (3, 2, (5, 0), (), "July", None),
		"June": (4, 2, (5, 0), (), "June", None),
		"March": (7, 2, (5, 0), (), "March", None),
		"May": (5, 2, (5, 0), (), "May", None),
		"November": (10, 2, (5, 0), (), "November", None),
		"October": (11, 2, (5, 0), (), "October", None),
		"September": (1, 2, (5, 0), (), "September", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (21, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"April": ((6, LCID, 4, 0),()),
		"August": ((2, LCID, 4, 0),()),
		"BudgetAmount": ((13, LCID, 4, 0),()),
		"December": ((9, LCID, 4, 0),()),
		"Description": ((14, LCID, 4, 0),()),
		"February": ((8, LCID, 4, 0),()),
		"January": ((12, LCID, 4, 0),()),
		"July": ((3, LCID, 4, 0),()),
		"June": ((4, LCID, 4, 0),()),
		"March": ((7, LCID, 4, 0),()),
		"May": ((5, LCID, 4, 0),()),
		"November": ((10, LCID, 4, 0),()),
		"October": ((11, LCID, 4, 0),()),
		"September": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBudgetScenarios(DispatchBaseClass):
	'IBudgetScenarios Interface'
	CLSID = IID('{5D48514C-4B40-4C2A-9FC9-8CC2518B0F8E}')
	coclass_clsid = IID('{8DCD076F-BF30-45C6-822A-B23FDA1B37F5}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(15, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((3, 1),),lAbsID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(16, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(10, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"BasicBudget": (4, 2, (3, 0), (), "BasicBudget", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (12, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"DistributionRule": (18, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (19, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (20, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (21, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (22, 2, (8, 0), (), "DistributionRule5", None),
		"InitialRatioPercentage": (2, 2, (5, 0), (), "InitialRatioPercentage", None),
		"Name": (1, 2, (8, 0), (), "Name", None),
		"Numerator": (5, 2, (3, 0), (), "Numerator", None),
		"Project": (17, 2, (8, 0), (), "Project", None),
		"RoundingMethod": (14, 2, (3, 0), (), "RoundingMethod", None),
		"StartofFiscalYear": (3, 2, (7, 0), (), "StartofFiscalYear", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (11, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BasicBudget": ((4, LCID, 4, 0),()),
		"DistributionRule": ((18, LCID, 4, 0),()),
		"DistributionRule2": ((19, LCID, 4, 0),()),
		"DistributionRule3": ((20, LCID, 4, 0),()),
		"DistributionRule4": ((21, LCID, 4, 0),()),
		"DistributionRule5": ((22, LCID, 4, 0),()),
		"InitialRatioPercentage": ((2, LCID, 4, 0),()),
		"Name": ((1, LCID, 4, 0),()),
		"Project": ((17, LCID, 4, 0),()),
		"RoundingMethod": ((14, LCID, 4, 0),()),
		"StartofFiscalYear": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBudget_Lines(DispatchBaseClass):
	'IBudget_Lines Interface'
	CLSID = IID('{D2BAB599-C7C6-4301-B925-B6BB51092A79}')
	coclass_clsid = IID('{F105494C-B48F-4E8A-B6E7-C1947194E835}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(25, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(24, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (21, 2, (8, 0), (), "AccountCode", None),
		"BalSysTotCredit": (18, 2, (5, 0), (), "BalSysTotCredit", None),
		"BalSysTotDebit": (13, 2, (5, 0), (), "BalSysTotDebit", None),
		"BalTotCredit": (19, 2, (5, 0), (), "BalTotCredit", None),
		"BalTotDebit": (14, 2, (5, 0), (), "BalTotDebit", None),
		"BudgetKey": (20, 2, (3, 0), (), "BudgetKey", None),
		"BudgetSysTotCredit": (16, 2, (5, 0), (), "BudgetSysTotCredit", None),
		"BudgetSysTotDebit": (12, 2, (5, 0), (), "BudgetSysTotDebit", None),
		"BudgetTotCredit": (15, 2, (5, 0), (), "BudgetTotCredit", None),
		"BudgetTotDebit": (17, 2, (5, 0), (), "BudgetTotDebit", None),
		"Count": (23, 2, (3, 0), (), "Count", None),
		"FutExpenCredit": (7, 2, (5, 0), (), "FutExpenCredit", None),
		"FutExpenDebit": (5, 2, (5, 0), (), "FutExpenDebit", None),
		"FutExpenSysCredit": (6, 2, (5, 0), (), "FutExpenSysCredit", None),
		"FutExpenSysDebit": (4, 2, (5, 0), (), "FutExpenSysDebit", None),
		"FutIncomesCredit": (11, 2, (5, 0), (), "FutIncomesCredit", None),
		"FutIncomesSysCredit": (9, 2, (5, 0), (), "FutIncomesSysCredit", None),
		"FutIncomesSysDebit": (10, 2, (5, 0), (), "FutIncomesSysDebit", None),
		"FutureIncomeDeb": (26, 2, (5, 0), (), "FutureIncomeDeb", None),
		"PrecentOfAnnualBudgetAmount": (1, 2, (5, 0), (), "PrecentOfAnnualBudgetAmount", None),
		"RowDetails": (2, 2, (8, 0), (), "RowDetails", None),
		"RowNumber": (3, 2, (3, 0), (), "RowNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (22, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BudgetSysTotCredit": ((16, LCID, 4, 0),()),
		"BudgetSysTotDebit": ((12, LCID, 4, 0),()),
		"BudgetTotCredit": ((15, LCID, 4, 0),()),
		"BudgetTotDebit": ((17, LCID, 4, 0),()),
		"RowDetails": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(23, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBusinessPartnerGroups(DispatchBaseClass):
	'IBusinessPartnerGroups Interface'
	CLSID = IID('{9147FC50-6FF2-40EC-B59B-2F9302B4A31D}')
	coclass_clsid = IID('{A3C87BAE-49A3-4A53-A50B-D20716733709}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lGroupCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lGroupCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"Type": (12, 2, (3, 0), (), "Type", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((11, LCID, 4, 0),()),
		"Type": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBusinessPartnerPropertiesParams(DispatchBaseClass):
	'IBusinessPartnerPropertiesParams Interface'
	CLSID = IID('{00C7246F-BD54-4E8B-8CE0-39F9C6568F68}')
	coclass_clsid = IID('{AC817068-3E5F-49B3-A301-189558534ED5}')

	# Result is of type IBusinessPartnerPropertyParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{B7546EA2-0DE7-4F28-8596-ACCD323F584E}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IBusinessPartnerPropertyParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{B7546EA2-0DE7-4F28-8596-ACCD323F584E}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{B7546EA2-0DE7-4F28-8596-ACCD323F584E}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{B7546EA2-0DE7-4F28-8596-ACCD323F584E}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBusinessPartnerPropertiesService(DispatchBaseClass):
	'IBusinessPartnerPropertiesService Interface'
	CLSID = IID('{0ED256A5-4119-4245-A961-A01AD0134E4E}')
	coclass_clsid = IID('{38038B4E-6B7A-441F-81C6-9B699CC4DE6A}')

	# Result is of type IBusinessPartnerProperty
	def GetBusinessPartnerProperty(self, pIBusinessPartnerPropertyParams=defaultNamedNotOptArg):
		'GetBusinessPartnerProperty'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIBusinessPartnerPropertyParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBusinessPartnerProperty', '{38DA089C-BF1E-457E-B486-F1E35293F5F1}')
		return ret

	# Result is of type IBusinessPartnerPropertiesParams
	def GetBusinessPartnerPropertyList(self):
		'GetBusinessPartnerPropertyList'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetBusinessPartnerPropertyList', '{00C7246F-BD54-4E8B-8CE0-39F9C6568F68}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateBusinessPartnerProperty(self, pIBusinessPartnerProperty=defaultNamedNotOptArg):
		'UpdateBusinessPartnerProperty'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((9, 1),),pIBusinessPartnerProperty
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBusinessPartnerProperty(DispatchBaseClass):
	'IBusinessPartnerProperty Interface'
	CLSID = IID('{38DA089C-BF1E-457E-B486-F1E35293F5F1}')
	coclass_clsid = IID('{3329D652-8FFF-4076-B051-A4B503878986}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"PropertyCode": (10, 2, (3, 0), (), "PropertyCode", None),
		"PropertyName": (11, 2, (8, 0), (), "PropertyName", None),
	}
	_prop_map_put_ = {
		"PropertyName": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBusinessPartnerPropertyParams(DispatchBaseClass):
	'IBusinessPartnerPropertyParams Interface'
	CLSID = IID('{B7546EA2-0DE7-4F28-8596-ACCD323F584E}')
	coclass_clsid = IID('{51090998-B57D-4A0B-A634-4664FE76FA57}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"PropertyCode": (10, 2, (3, 0), (), "PropertyCode", None),
		"PropertyName": (11, 2, (8, 0), (), "PropertyName", None),
	}
	_prop_map_put_ = {
		"PropertyCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBusinessPartners(DispatchBaseClass):
	'IBusinessPartners Interface'
	CLSID = IID('{9DF321C2-6A1D-446B-AE8A-F7C33987D792}')
	coclass_clsid = IID('{4A1DF035-9612-4CCC-B9B8-C58511D0D705}')

	def Add(self):
		'Use this function to add the card to the system.'
		return self._oleobj_.InvokeTypes(50, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(75, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(76, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(145, LCID, 1, (8, 0), (),)

	def GetByKey(self, CardCode=defaultNamedNotOptArg):
		"Get a card object by it's key (string value)."
		return self._oleobj_.InvokeTypes(57, LCID, 1, (11, 0), ((8, 0),),CardCode
			)

	# The method Properties is actually a property, but must be used as a method to correctly pass the arguments
	def Properties(self, GroupNum=defaultNamedNotOptArg):
		'You use card characteristics for cross-sections and an additional sort of the customer and supplier cards.'
		return self._oleobj_.InvokeTypes(52, LCID, 2, (3, 0), ((3, 0),),GroupNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(74, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(146, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save the objects data in xml format.'
		return self._ApplyTypes_(59, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	# The method SetProperties is actually a property, but must be used as a method to correctly pass the arguments
	def SetProperties(self, GroupNum=defaultNamedNotOptArg, arg1=defaultUnnamedArg):
		'You use card characteristics for cross-sections and an additional sort of the customer and supplier cards.'
		return self._oleobj_.InvokeTypes(52, LCID, 4, (24, 0), ((3, 0), (3, 1)),GroupNum
			, arg1)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(60, LCID, 1, (3, 0), (),)

	def UpdateFromXML(self, FileName=defaultNamedNotOptArg):
		'method UpdateFromXML'
		return self._oleobj_.InvokeTypes(191, LCID, 1, (3, 0), ((8, 1),),FileName
			)

	_prop_map_get_ = {
		# Method 'AccountRecivablePayables' returns object of type 'IBPAccountReceivablePayble'
		"AccountRecivablePayables": (119, 2, (9, 0), (), "AccountRecivablePayables", '{4162242D-4217-47FA-BDFF-5070B6D03F30}'),
		"AccrualCriteria": (127, 2, (3, 0), (), "AccrualCriteria", None),
		"AdditionalID": (46, 2, (8, 0), (), "AdditionalID", None),
		"Address": (7, 2, (8, 0), (), "Address", None),
		# Method 'Addresses' returns object of type 'IBPAddresses'
		"Addresses": (87, 2, (9, 0), (), "Addresses", '{02F225DD-827F-4065-BC4A-14D5F4136D28}'),
		"Affiliate": (176, 2, (3, 0), (), "Affiliate", None),
		"AliasName": (202, 2, (8, 0), (), "AliasName", None),
		"AutomaticPosting": (187, 2, (3, 0), (), "AutomaticPosting", None),
		"AvarageLate": (34, 2, (3, 0), (), "AvarageLate", None),
		# Method 'BPBankAccounts' returns object of type 'IBPBankAccounts'
		"BPBankAccounts": (142, 2, (9, 0), (), "BPBankAccounts", '{472B7A32-EB83-4D3A-9908-699D5C8DC33B}'),
		# Method 'BPBranchAssignment' returns object of type 'IBPBranchAssignment'
		"BPBranchAssignment": (201, 2, (9, 0), (), "BPBranchAssignment", '{C65DEE24-288A-43E4-9F93-93F384B157BB}'),
		# Method 'BPPaymentDates' returns object of type 'IBPPaymentDates'
		"BPPaymentDates": (141, 2, (9, 0), (), "BPPaymentDates", '{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}'),
		# Method 'BPPaymentMethods' returns object of type 'IBPPaymentMethods'
		"BPPaymentMethods": (139, 2, (9, 0), (), "BPPaymentMethods", '{7D947F60-6017-44AA-AEAC-9721FF263D5E}'),
		# Method 'BPWithholdingTax' returns object of type 'IBPWithholdingTax'
		"BPWithholdingTax": (140, 2, (9, 0), (), "BPWithholdingTax", '{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}'),
		"BackOrder": (95, 2, (3, 0), (), "BackOrder", None),
		"BankChargesAllocationCode": (157, 2, (8, 0), (), "BankChargesAllocationCode", None),
		"BankCountry": (98, 2, (8, 0), (), "BankCountry", None),
		"BillToBuildingFloorRoom": (130, 2, (8, 0), (), "BillToBuildingFloorRoom", None),
		"BillToState": (89, 2, (8, 0), (), "BillToState", None),
		"BillofExchangeonCollection": (152, 2, (8, 0), (), "BillofExchangeonCollection", None),
		"BilltoDefault": (134, 2, (8, 0), (), "BilltoDefault", None),
		"Block": (88, 2, (8, 0), (), "Block", None),
		"BlockDunning": (97, 2, (3, 0), (), "BlockDunning", None),
		"BookkeepingCertified": (174, 2, (3, 0), (), "BookkeepingCertified", None),
		"Box1099": (93, 2, (8, 0), (), "Box1099", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (86, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BusinessType": (195, 2, (8, 0), (), "BusinessType", None),
		"CampaignNumber": (190, 2, (3, 0), (), "CampaignNumber", None),
		"CardCode": (1, 2, (8, 0), (), "CardCode", None),
		"CardForeignName": (49, 2, (8, 0), (), "CardForeignName", None),
		"CardName": (4, 2, (8, 0), (), "CardName", None),
		"CardType": (3, 2, (3, 0), (), "CardType", None),
		"Cellular": (33, 2, (8, 0), (), "Cellular", None),
		"CertificateNumber": (124, 2, (8, 0), (), "CertificateNumber", None),
		"ChannelBP": (132, 2, (8, 0), (), "ChannelBP", None),
		"City": (35, 2, (8, 0), (), "City", None),
		"ClosingDateProcedureNumber": (150, 2, (3, 0), (), "ClosingDateProcedureNumber", None),
		"CollectionAuthorization": (105, 2, (3, 0), (), "CollectionAuthorization", None),
		"CommissionGroupCode": (28, 2, (3, 0), (), "CommissionGroupCode", None),
		"CommissionPercent": (27, 2, (5, 0), (), "CommissionPercent", None),
		"CompanyPrivate": (153, 2, (3, 0), (), "CompanyPrivate", None),
		"CompanyRegistrationNumber": (160, 2, (8, 0), (), "CompanyRegistrationNumber", None),
		# Method 'ContactEmployees' returns object of type 'IContactEmployees'
		"ContactEmployees": (64, 2, (9, 0), (), "ContactEmployees", '{52C8673B-CA79-4476-9F2E-28109AE17545}'),
		"ContactPerson": (14, 2, (8, 0), (), "ContactPerson", None),
		"Country": (37, 2, (8, 0), (), "Country", None),
		"County": (36, 2, (8, 0), (), "County", None),
		"CreditCardCode": (70, 2, (3, 0), (), "CreditCardCode", None),
		"CreditCardExpiration": (72, 2, (7, 0), (), "CreditCardExpiration", None),
		"CreditCardNum": (71, 2, (8, 0), (), "CreditCardNum", None),
		"CreditLimit": (17, 2, (5, 0), (), "CreditLimit", None),
		"Currency": (31, 2, (8, 0), (), "Currency", None),
		"CurrentAccountBalance": (61, 2, (5, 0), (), "CurrentAccountBalance", None),
		"CustomerBillofExchangDisc": (135, 2, (8, 0), (), "CustomerBillofExchangDisc", None),
		"CustomerBillofExchangPres": (138, 2, (8, 0), (), "CustomerBillofExchangPres", None),
		"DME": (106, 2, (8, 0), (), "DME", None),
		"DatevAccount": (179, 2, (3, 0), (), "DatevAccount", None),
		"DatevFirstDataEntry": (180, 2, (3, 0), (), "DatevFirstDataEntry", None),
		"DebitorAccount": (73, 2, (8, 0), (), "DebitorAccount", None),
		"DeductibleAtSource": (22, 2, (3, 0), (), "DeductibleAtSource", None),
		"DeductionOffice": (53, 2, (8, 0), (), "DeductionOffice", None),
		"DeductionPercent": (23, 2, (5, 0), (), "DeductionPercent", None),
		"DeductionValidUntil": (24, 2, (7, 0), (), "DeductionValidUntil", None),
		"DefaultAccount": (43, 2, (8, 0), (), "DefaultAccount", None),
		"DefaultBankCode": (45, 2, (8, 0), (), "DefaultBankCode", None),
		"DefaultBlanketAgreementNumber": (203, 2, (3, 0), (), "DefaultBlanketAgreementNumber", None),
		"DefaultBranch": (44, 2, (8, 0), (), "DefaultBranch", None),
		"DefaultTechnician": (133, 2, (3, 0), (), "DefaultTechnician", None),
		"DeferredTax": (129, 2, (3, 0), (), "DeferredTax", None),
		"DiscountBaseObject": (164, 2, (3, 0), (), "DiscountBaseObject", None),
		# Method 'DiscountGroups' returns object of type 'IDiscountGroups'
		"DiscountGroups": (166, 2, (9, 0), (), "DiscountGroups", '{7B78B94A-9F54-4A05-9A64-0A1E89484ECB}'),
		"DiscountPercent": (19, 2, (5, 0), (), "DiscountPercent", None),
		"DiscountRelations": (165, 2, (3, 0), (), "DiscountRelations", None),
		"DownPaymentClearAct": (131, 2, (8, 0), (), "DownPaymentClearAct", None),
		"DownPaymentInterimAccount": (170, 2, (8, 0), (), "DownPaymentInterimAccount", None),
		"DunningDate": (104, 2, (7, 0), (), "DunningDate", None),
		"DunningLevel": (103, 2, (3, 0), (), "DunningLevel", None),
		"DunningTerm": (147, 2, (8, 0), (), "DunningTerm", None),
		"ETaxWebSite": (184, 2, (3, 0), (), "ETaxWebSite", None),
		"EmailAddress": (41, 2, (8, 0), (), "EmailAddress", None),
		"Equalization": (122, 2, (3, 0), (), "Equalization", None),
		"ExemptNum": (90, 2, (8, 0), (), "ExemptNum", None),
		"ExemptionValidityDateFrom": (117, 2, (7, 0), (), "ExemptionValidityDateFrom", None),
		"ExemptionValidityDateTo": (118, 2, (7, 0), (), "ExemptionValidityDateTo", None),
		"ExpirationDate": (125, 2, (7, 0), (), "ExpirationDate", None),
		"ExportCode": (54, 2, (8, 0), (), "ExportCode", None),
		"FatherCard": (48, 2, (8, 0), (), "FatherCard", None),
		"FatherType": (51, 2, (3, 0), (), "FatherType", None),
		"Fax": (13, 2, (8, 0), (), "Fax", None),
		"FederalTaxID": (21, 2, (8, 0), (), "FederalTaxID", None),
		"FeeAccount": (189, 2, (8, 0), (), "FeeAccount", None),
		# Method 'FiscalTaxID' returns object of type 'IBPFiscalTaxID'
		"FiscalTaxID": (158, 2, (9, 0), (), "FiscalTaxID", '{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}'),
		"FormCode1099": (92, 2, (3, 0), (), "FormCode1099", None),
		"FreeText": (29, 2, (8, 0), (), "FreeText", None),
		"Frozen": (82, 2, (3, 0), (), "Frozen", None),
		"FrozenFrom": (83, 2, (7, 0), (), "FrozenFrom", None),
		"FrozenRemarks": (85, 2, (8, 0), (), "FrozenRemarks", None),
		"FrozenTo": (84, 2, (7, 0), (), "FrozenTo", None),
		"GTSBankAccountNo": (182, 2, (8, 0), (), "GTSBankAccountNo", None),
		"GTSBillingAddrTel": (183, 2, (8, 0), (), "GTSBillingAddrTel", None),
		"GTSRegNo": (181, 2, (8, 0), (), "GTSRegNo", None),
		"GroupCode": (5, 2, (3, 0), (), "GroupCode", None),
		"HierarchicalDeduction": (171, 2, (3, 0), (), "HierarchicalDeduction", None),
		"HouseBank": (99, 2, (8, 0), (), "HouseBank", None),
		"HouseBankAccount": (101, 2, (8, 0), (), "HouseBankAccount", None),
		"HouseBankBranch": (112, 2, (8, 0), (), "HouseBankBranch", None),
		"HouseBankCountry": (100, 2, (8, 0), (), "HouseBankCountry", None),
		"HouseBankIBAN": (185, 2, (8, 0), (), "HouseBankIBAN", None),
		"IBAN": (69, 2, (8, 0), (), "IBAN", None),
		"ISRBillerID": (109, 2, (8, 0), (), "ISRBillerID", None),
		"Indicator": (68, 2, (8, 0), (), "Indicator", None),
		"Industry": (177, 2, (3, 0), (), "Industry", None),
		"IndustryType": (194, 2, (8, 0), (), "IndustryType", None),
		"InstructionKey": (107, 2, (8, 0), (), "InstructionKey", None),
		"InsuranceOperation347": (163, 2, (3, 0), (), "InsuranceOperation347", None),
		"InterestAccount": (188, 2, (8, 0), (), "InterestAccount", None),
		"IntrestRatePercent": (26, 2, (5, 0), (), "IntrestRatePercent", None),
		"LanguageCode": (154, 2, (3, 0), (), "LanguageCode", None),
		"LastMultiReconciliationNum": (121, 2, (3, 0), (), "LastMultiReconciliationNum", None),
		"LinkedBusinessPartner": (120, 2, (8, 0), (), "LinkedBusinessPartner", None),
		"MailAddress": (9, 2, (8, 0), (), "MailAddress", None),
		"MailCity": (38, 2, (8, 0), (), "MailCity", None),
		"MailCountry": (40, 2, (8, 0), (), "MailCountry", None),
		"MailCounty": (39, 2, (8, 0), (), "MailCounty", None),
		"MailZipCode": (10, 2, (8, 0), (), "MailZipCode", None),
		"MaxAmountOfExemption": (116, 2, (5, 0), (), "MaxAmountOfExemption", None),
		"MaxCommitment": (18, 2, (5, 0), (), "MaxCommitment", None),
		"MinIntrest": (55, 2, (5, 0), (), "MinIntrest", None),
		"NationalInsuranceNum": (126, 2, (8, 0), (), "NationalInsuranceNum", None),
		"Notes": (15, 2, (8, 0), (), "Notes", None),
		"OpenDeliveryNotesBalance": (62, 2, (5, 0), (), "OpenDeliveryNotesBalance", None),
		"OpenOpportunities": (77, 2, (3, 0), (), "OpenOpportunities", None),
		"OpenOrdersBalance": (63, 2, (5, 0), (), "OpenOrdersBalance", None),
		"OperationCode347": (162, 2, (3, 0), (), "OperationCode347", None),
		"OtherReceivablePayable": (149, 2, (8, 0), (), "OtherReceivablePayable", None),
		"OwnerIDNumber": (113, 2, (8, 0), (), "OwnerIDNumber", None),
		"Pager": (47, 2, (8, 0), (), "Pager", None),
		"PartialDelivery": (96, 2, (3, 0), (), "PartialDelivery", None),
		"Password": (67, 2, (8, 0), (), "Password", None),
		"PayTermsGrpCode": (16, 2, (3, 0), (), "PayTermsGrpCode", None),
		"PaymentBlock": (110, 2, (3, 0), (), "PaymentBlock", None),
		"PaymentBlockDescription": (114, 2, (3, 0), (), "PaymentBlockDescription", None),
		"PeymentMethodCode": (94, 2, (8, 0), (), "PeymentMethodCode", None),
		"Phone1": (11, 2, (8, 0), (), "Phone1", None),
		"Phone2": (12, 2, (8, 0), (), "Phone2", None),
		"Picture": (42, 2, (8, 0), (), "Picture", None),
		"PlanningGroup": (175, 2, (8, 0), (), "PlanningGroup", None),
		"PriceListNum": (25, 2, (3, 0), (), "PriceListNum", None),
		"Priority": (91, 2, (3, 0), (), "Priority", None),
		"Profession": (151, 2, (8, 0), (), "Profession", None),
		"ProjectCode": (143, 2, (8, 0), (), "ProjectCode", None),
		"RateDiffAccount": (32, 2, (8, 0), (), "RateDiffAccount", None),
		"ReferenceDetails": (111, 2, (8, 0), (), "ReferenceDetails", None),
		"RepresentativeName": (193, 2, (8, 0), (), "RepresentativeName", None),
		"SalesPersonCode": (30, 2, (3, 0), (), "SalesPersonCode", None),
		"Series": (186, 2, (3, 0), (), "Series", None),
		"ShaamGroup": (172, 2, (3, 0), (), "ShaamGroup", None),
		"ShipToBuildingFloorRoom": (137, 2, (8, 0), (), "ShipToBuildingFloorRoom", None),
		"ShipToDefault": (102, 2, (8, 0), (), "ShipToDefault", None),
		"ShippingType": (66, 2, (3, 0), (), "ShippingType", None),
		"SinglePayment": (108, 2, (3, 0), (), "SinglePayment", None),
		"SubjectToWithholdingTax": (123, 2, (3, 0), (), "SubjectToWithholdingTax", None),
		"SurchargeOverlook": (169, 2, (3, 0), (), "SurchargeOverlook", None),
		"TaxExemptionLetterNum": (115, 2, (8, 0), (), "TaxExemptionLetterNum", None),
		"TaxRoundingRule": (159, 2, (3, 0), (), "TaxRoundingRule", None),
		"Territory": (136, 2, (3, 0), (), "Territory", None),
		"ThresholdOverlook": (168, 2, (3, 0), (), "ThresholdOverlook", None),
		"TypeReport": (167, 2, (3, 0), (), "TypeReport", None),
		"UnpaidBillofExchange": (155, 2, (8, 0), (), "UnpaidBillofExchange", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (58, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATRegistrationNumber": (192, 2, (8, 0), (), "VATRegistrationNumber", None),
		"Valid": (78, 2, (3, 0), (), "Valid", None),
		"ValidFrom": (79, 2, (7, 0), (), "ValidFrom", None),
		"ValidRemarks": (81, 2, (8, 0), (), "ValidRemarks", None),
		"ValidTo": (80, 2, (7, 0), (), "ValidTo", None),
		"VatGroup": (65, 2, (8, 0), (), "VatGroup", None),
		"VatGroupLatinAmerica": (144, 2, (8, 0), (), "VatGroupLatinAmerica", None),
		"VatIDNum": (178, 2, (8, 0), (), "VatIDNum", None),
		"VatLiable": (20, 2, (3, 0), (), "VatLiable", None),
		"VerificationNumber": (161, 2, (8, 0), (), "VerificationNumber", None),
		"WTCode": (128, 2, (8, 0), (), "WTCode", None),
		"Website": (148, 2, (8, 0), (), "Website", None),
		"WithholdingTaxCertified": (173, 2, (3, 0), (), "WithholdingTaxCertified", None),
		"WithholdingTaxDeductionGroup": (156, 2, (3, 0), (), "WithholdingTaxDeductionGroup", None),
		"ZipCode": (8, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AccrualCriteria": ((127, LCID, 4, 0),()),
		"AdditionalID": ((46, LCID, 4, 0),()),
		"Address": ((7, LCID, 4, 0),()),
		"Affiliate": ((176, LCID, 4, 0),()),
		"AliasName": ((202, LCID, 4, 0),()),
		"AutomaticPosting": ((187, LCID, 4, 0),()),
		"AvarageLate": ((34, LCID, 4, 0),()),
		"BackOrder": ((95, LCID, 4, 0),()),
		"BankChargesAllocationCode": ((157, LCID, 4, 0),()),
		"BankCountry": ((98, LCID, 4, 0),()),
		"BillToBuildingFloorRoom": ((130, LCID, 4, 0),()),
		"BillToState": ((89, LCID, 4, 0),()),
		"BillofExchangeonCollection": ((152, LCID, 4, 0),()),
		"BilltoDefault": ((134, LCID, 4, 0),()),
		"Block": ((88, LCID, 4, 0),()),
		"BlockDunning": ((97, LCID, 4, 0),()),
		"BookkeepingCertified": ((174, LCID, 4, 0),()),
		"Box1099": ((93, LCID, 4, 0),()),
		"BusinessType": ((195, LCID, 4, 0),()),
		"CampaignNumber": ((190, LCID, 4, 0),()),
		"CardCode": ((1, LCID, 4, 0),()),
		"CardForeignName": ((49, LCID, 4, 0),()),
		"CardName": ((4, LCID, 4, 0),()),
		"CardType": ((3, LCID, 4, 0),()),
		"Cellular": ((33, LCID, 4, 0),()),
		"CertificateNumber": ((124, LCID, 4, 0),()),
		"ChannelBP": ((132, LCID, 4, 0),()),
		"City": ((35, LCID, 4, 0),()),
		"ClosingDateProcedureNumber": ((150, LCID, 4, 0),()),
		"CollectionAuthorization": ((105, LCID, 4, 0),()),
		"CommissionGroupCode": ((28, LCID, 4, 0),()),
		"CommissionPercent": ((27, LCID, 4, 0),()),
		"CompanyPrivate": ((153, LCID, 4, 0),()),
		"CompanyRegistrationNumber": ((160, LCID, 4, 0),()),
		"ContactPerson": ((14, LCID, 4, 0),()),
		"Country": ((37, LCID, 4, 0),()),
		"County": ((36, LCID, 4, 0),()),
		"CreditCardCode": ((70, LCID, 4, 0),()),
		"CreditCardExpiration": ((72, LCID, 4, 0),()),
		"CreditCardNum": ((71, LCID, 4, 0),()),
		"CreditLimit": ((17, LCID, 4, 0),()),
		"Currency": ((31, LCID, 4, 0),()),
		"CustomerBillofExchangDisc": ((135, LCID, 4, 0),()),
		"CustomerBillofExchangPres": ((138, LCID, 4, 0),()),
		"DME": ((106, LCID, 4, 0),()),
		"DatevAccount": ((179, LCID, 4, 0),()),
		"DatevFirstDataEntry": ((180, LCID, 4, 0),()),
		"DebitorAccount": ((73, LCID, 4, 0),()),
		"DeductibleAtSource": ((22, LCID, 4, 0),()),
		"DeductionOffice": ((53, LCID, 4, 0),()),
		"DeductionPercent": ((23, LCID, 4, 0),()),
		"DeductionValidUntil": ((24, LCID, 4, 0),()),
		"DefaultAccount": ((43, LCID, 4, 0),()),
		"DefaultBankCode": ((45, LCID, 4, 0),()),
		"DefaultBlanketAgreementNumber": ((203, LCID, 4, 0),()),
		"DefaultBranch": ((44, LCID, 4, 0),()),
		"DefaultTechnician": ((133, LCID, 4, 0),()),
		"DeferredTax": ((129, LCID, 4, 0),()),
		"DiscountBaseObject": ((164, LCID, 4, 0),()),
		"DiscountPercent": ((19, LCID, 4, 0),()),
		"DiscountRelations": ((165, LCID, 4, 0),()),
		"DownPaymentClearAct": ((131, LCID, 4, 0),()),
		"DownPaymentInterimAccount": ((170, LCID, 4, 0),()),
		"DunningTerm": ((147, LCID, 4, 0),()),
		"ETaxWebSite": ((184, LCID, 4, 0),()),
		"EmailAddress": ((41, LCID, 4, 0),()),
		"Equalization": ((122, LCID, 4, 0),()),
		"ExemptNum": ((90, LCID, 4, 0),()),
		"ExemptionValidityDateFrom": ((117, LCID, 4, 0),()),
		"ExemptionValidityDateTo": ((118, LCID, 4, 0),()),
		"ExpirationDate": ((125, LCID, 4, 0),()),
		"ExportCode": ((54, LCID, 4, 0),()),
		"FatherCard": ((48, LCID, 4, 0),()),
		"FatherType": ((51, LCID, 4, 0),()),
		"Fax": ((13, LCID, 4, 0),()),
		"FederalTaxID": ((21, LCID, 4, 0),()),
		"FeeAccount": ((189, LCID, 4, 0),()),
		"FormCode1099": ((92, LCID, 4, 0),()),
		"FreeText": ((29, LCID, 4, 0),()),
		"Frozen": ((82, LCID, 4, 0),()),
		"FrozenFrom": ((83, LCID, 4, 0),()),
		"FrozenRemarks": ((85, LCID, 4, 0),()),
		"FrozenTo": ((84, LCID, 4, 0),()),
		"GTSBankAccountNo": ((182, LCID, 4, 0),()),
		"GTSBillingAddrTel": ((183, LCID, 4, 0),()),
		"GTSRegNo": ((181, LCID, 4, 0),()),
		"GroupCode": ((5, LCID, 4, 0),()),
		"HierarchicalDeduction": ((171, LCID, 4, 0),()),
		"HouseBank": ((99, LCID, 4, 0),()),
		"HouseBankAccount": ((101, LCID, 4, 0),()),
		"HouseBankBranch": ((112, LCID, 4, 0),()),
		"HouseBankCountry": ((100, LCID, 4, 0),()),
		"IBAN": ((69, LCID, 4, 0),()),
		"ISRBillerID": ((109, LCID, 4, 0),()),
		"Indicator": ((68, LCID, 4, 0),()),
		"Industry": ((177, LCID, 4, 0),()),
		"IndustryType": ((194, LCID, 4, 0),()),
		"InstructionKey": ((107, LCID, 4, 0),()),
		"InsuranceOperation347": ((163, LCID, 4, 0),()),
		"InterestAccount": ((188, LCID, 4, 0),()),
		"IntrestRatePercent": ((26, LCID, 4, 0),()),
		"LanguageCode": ((154, LCID, 4, 0),()),
		"LastMultiReconciliationNum": ((121, LCID, 4, 0),()),
		"LinkedBusinessPartner": ((120, LCID, 4, 0),()),
		"MailAddress": ((9, LCID, 4, 0),()),
		"MailCity": ((38, LCID, 4, 0),()),
		"MailCountry": ((40, LCID, 4, 0),()),
		"MailCounty": ((39, LCID, 4, 0),()),
		"MailZipCode": ((10, LCID, 4, 0),()),
		"MaxAmountOfExemption": ((116, LCID, 4, 0),()),
		"MaxCommitment": ((18, LCID, 4, 0),()),
		"MinIntrest": ((55, LCID, 4, 0),()),
		"NationalInsuranceNum": ((126, LCID, 4, 0),()),
		"Notes": ((15, LCID, 4, 0),()),
		"OperationCode347": ((162, LCID, 4, 0),()),
		"OtherReceivablePayable": ((149, LCID, 4, 0),()),
		"OwnerIDNumber": ((113, LCID, 4, 0),()),
		"Pager": ((47, LCID, 4, 0),()),
		"PartialDelivery": ((96, LCID, 4, 0),()),
		"Password": ((67, LCID, 4, 0),()),
		"PayTermsGrpCode": ((16, LCID, 4, 0),()),
		"PaymentBlock": ((110, LCID, 4, 0),()),
		"PaymentBlockDescription": ((114, LCID, 4, 0),()),
		"PeymentMethodCode": ((94, LCID, 4, 0),()),
		"Phone1": ((11, LCID, 4, 0),()),
		"Phone2": ((12, LCID, 4, 0),()),
		"Picture": ((42, LCID, 4, 0),()),
		"PlanningGroup": ((175, LCID, 4, 0),()),
		"PriceListNum": ((25, LCID, 4, 0),()),
		"Priority": ((91, LCID, 4, 0),()),
		"Profession": ((151, LCID, 4, 0),()),
		"ProjectCode": ((143, LCID, 4, 0),()),
		"RateDiffAccount": ((32, LCID, 4, 0),()),
		"ReferenceDetails": ((111, LCID, 4, 0),()),
		"RepresentativeName": ((193, LCID, 4, 0),()),
		"SalesPersonCode": ((30, LCID, 4, 0),()),
		"Series": ((186, LCID, 4, 0),()),
		"ShaamGroup": ((172, LCID, 4, 0),()),
		"ShipToBuildingFloorRoom": ((137, LCID, 4, 0),()),
		"ShipToDefault": ((102, LCID, 4, 0),()),
		"ShippingType": ((66, LCID, 4, 0),()),
		"SinglePayment": ((108, LCID, 4, 0),()),
		"SubjectToWithholdingTax": ((123, LCID, 4, 0),()),
		"SurchargeOverlook": ((169, LCID, 4, 0),()),
		"TaxExemptionLetterNum": ((115, LCID, 4, 0),()),
		"TaxRoundingRule": ((159, LCID, 4, 0),()),
		"Territory": ((136, LCID, 4, 0),()),
		"ThresholdOverlook": ((168, LCID, 4, 0),()),
		"TypeReport": ((167, LCID, 4, 0),()),
		"UnpaidBillofExchange": ((155, LCID, 4, 0),()),
		"VATRegistrationNumber": ((192, LCID, 4, 0),()),
		"Valid": ((78, LCID, 4, 0),()),
		"ValidFrom": ((79, LCID, 4, 0),()),
		"ValidRemarks": ((81, LCID, 4, 0),()),
		"ValidTo": ((80, LCID, 4, 0),()),
		"VatGroup": ((65, LCID, 4, 0),()),
		"VatGroupLatinAmerica": ((144, LCID, 4, 0),()),
		"VatIDNum": ((178, LCID, 4, 0),()),
		"VatLiable": ((20, LCID, 4, 0),()),
		"VerificationNumber": ((161, LCID, 4, 0),()),
		"WTCode": ((128, LCID, 4, 0),()),
		"Website": ((148, LCID, 4, 0),()),
		"WithholdingTaxCertified": ((173, LCID, 4, 0),()),
		"WithholdingTaxDeductionGroup": ((156, LCID, 4, 0),()),
		"ZipCode": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBusinessPartnersService(DispatchBaseClass):
	'IBusinessPartnersService Interface'
	CLSID = IID('{DF517030-9004-4965-96A3-CFE398A79DDC}')
	coclass_clsid = IID('{EEA5B4B4-F1E5-4CC2-9514-C80EE92DF9C2}')

	def CreateOpenBalance(self, pIOpenningBalanceAccount=defaultNamedNotOptArg, pBPCodes=defaultNamedNotOptArg):
		'CreateOpenBalance'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((9, 1), (9, 1)),pIOpenningBalanceAccount
			, pBPCodes)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IBusinessPlaceIENumbers(DispatchBaseClass):
	'IBusinessPlaceIENumbers Interface'
	CLSID = IID('{EC280F9D-83C0-4324-9B19-18CB128A7021}')
	coclass_clsid = IID('{EF78E12B-50D7-424C-9314-1275E4EEAF23}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPLID": (9, 2, (3, 0), (), "BPLID", None),
		"Count": (7, 2, (3, 0), (), "Count", None),
		"IENumber": (11, 2, (8, 0), (), "IENumber", None),
		"State": (10, 2, (8, 0), (), "State", None),
	}
	_prop_map_put_ = {
		"IENumber": ((11, LCID, 4, 0),()),
		"State": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(7, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBusinessPlaceTributaryInfos(DispatchBaseClass):
	'IBusinessPlaceTributaryInfos Inteface'
	CLSID = IID('{C1BF990C-0774-48F2-901C-84E414D881C6}')
	coclass_clsid = IID('{08F4BA3C-A72A-4612-B5D4-F3E1C120004E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNumber=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNumber
			)

	_prop_map_get_ = {
		"BPLID": (9, 2, (3, 0), (), "BPLID", None),
		"Count": (7, 2, (3, 0), (), "Count", None),
		"TRCEndDate": (16, 2, (7, 0), (), "TRCEndDate", None),
		"TRCStartDate": (15, 2, (7, 0), (), "TRCStartDate", None),
		"TTEndDate": (13, 2, (7, 0), (), "TTEndDate", None),
		"TTStartDate": (12, 2, (7, 0), (), "TTStartDate", None),
		"TributaryID": (10, 2, (3, 0), (), "TributaryID", None),
		"TributaryRegimeCode": (14, 2, (3, 0), (), "TributaryRegimeCode", None),
		"TributaryType": (11, 2, (3, 0), (), "TributaryType", None),
	}
	_prop_map_put_ = {
		"TRCEndDate": ((16, LCID, 4, 0),()),
		"TRCStartDate": ((15, LCID, 4, 0),()),
		"TTEndDate": ((13, LCID, 4, 0),()),
		"TTStartDate": ((12, LCID, 4, 0),()),
		"TributaryRegimeCode": ((14, LCID, 4, 0),()),
		"TributaryType": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(7, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IBusinessPlaces(DispatchBaseClass):
	'IBusinessPlaces Interface'
	CLSID = IID('{6C92660E-0507-4C90-8DDB-1C5B61AB41AA}')
	coclass_clsid = IID('{ADDFFAB7-1BA1-4C06-8229-D3CE76605700}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(45, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lBplId=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lBplId
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(46, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'Method Update'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AdditionalIdNumber": (39, 2, (8, 0), (), "AdditionalIdNumber", None),
		"Address": (14, 2, (8, 0), (), "Address", None),
		"AddressType": (51, 2, (8, 0), (), "AddressType", None),
		"Addressforeign": (15, 2, (8, 0), (), "Addressforeign", None),
		"AliasName": (61, 2, (8, 0), (), "AliasName", None),
		"BPLID": (7, 2, (3, 0), (), "BPLID", None),
		"BPLName": (8, 2, (8, 0), (), "BPLName", None),
		"BPLNameForeign": (9, 2, (8, 0), (), "BPLNameForeign", None),
		"Block": (56, 2, (8, 0), (), "Block", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Building": (54, 2, (8, 0), (), "Building", None),
		"Business": (13, 2, (8, 0), (), "Business", None),
		"City": (57, 2, (8, 0), (), "City", None),
		"CommercialRegister": (62, 2, (8, 0), (), "CommercialRegister", None),
		"CompanyQualificationCode": (48, 2, (3, 0), (), "CompanyQualificationCode", None),
		"CooperativeAssociationTypeCode": (44, 2, (3, 0), (), "CooperativeAssociationTypeCode", None),
		"Country": (60, 2, (8, 0), (), "Country", None),
		"County": (59, 2, (8, 0), (), "County", None),
		"CreditContributionOriginCode": (42, 2, (8, 0), (), "CreditContributionOriginCode", None),
		"DateOfIncorporation": (63, 2, (7, 0), (), "DateOfIncorporation", None),
		"DeclarerTypeCode": (49, 2, (3, 0), (), "DeclarerTypeCode", None),
		"DefaultCustomerID": (31, 2, (8, 0), (), "DefaultCustomerID", None),
		"DefaultTaxCode": (34, 2, (8, 0), (), "DefaultTaxCode", None),
		"DefaultVendorID": (32, 2, (8, 0), (), "DefaultVendorID", None),
		"DefaultWarehouseID": (33, 2, (8, 0), (), "DefaultWarehouseID", None),
		"Disabled": (18, 2, (3, 0), (), "Disabled", None),
		"EconomicActivityTypeCode": (41, 2, (3, 0), (), "EconomicActivityTypeCode", None),
		"EnvironmentType": (65, 2, (3, 0), (), "EnvironmentType", None),
		"FederalTaxID": (36, 2, (8, 0), (), "FederalTaxID", None),
		"FederalTaxID2": (37, 2, (8, 0), (), "FederalTaxID2", None),
		"FederalTaxID3": (38, 2, (8, 0), (), "FederalTaxID3", None),
		# Method 'IENumbers' returns object of type 'IBusinessPlaceIENumbers'
		"IENumbers": (19, 2, (9, 0), (), "IENumbers", '{EC280F9D-83C0-4324-9B19-18CB128A7021}'),
		"IPIPeriodCode": (43, 2, (8, 0), (), "IPIPeriodCode", None),
		"Industry": (12, 2, (8, 0), (), "Industry", None),
		"MainBPL": (16, 2, (3, 0), (), "MainBPL", None),
		"NatureOfCompanyCode": (40, 2, (3, 0), (), "NatureOfCompanyCode", None),
		"Opting4ICMS": (66, 2, (3, 0), (), "Opting4ICMS", None),
		"PaymentClearingAccount": (68, 2, (8, 0), (), "PaymentClearingAccount", None),
		"PreferredStateCode": (50, 2, (8, 0), (), "PreferredStateCode", None),
		"ProfitTaxationCode": (47, 2, (3, 0), (), "ProfitTaxationCode", None),
		"RepName": (11, 2, (8, 0), (), "RepName", None),
		"SPEDProfile": (64, 2, (8, 0), (), "SPEDProfile", None),
		"State": (58, 2, (8, 0), (), "State", None),
		"Street": (52, 2, (8, 0), (), "Street", None),
		"StreetNo": (53, 2, (8, 0), (), "StreetNo", None),
		"TaxOffice": (35, 2, (8, 0), (), "TaxOffice", None),
		"TaxOfficeNo": (17, 2, (8, 0), (), "TaxOfficeNo", None),
		# Method 'TributaryInfos' returns object of type 'IBusinessPlaceTributaryInfos'
		"TributaryInfos": (67, 2, (9, 0), (), "TributaryInfos", '{C1BF990C-0774-48F2-901C-84E414D881C6}'),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATRegNum": (10, 2, (8, 0), (), "VATRegNum", None),
		"ZipCode": (55, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AdditionalIdNumber": ((39, LCID, 4, 0),()),
		"Address": ((14, LCID, 4, 0),()),
		"AddressType": ((51, LCID, 4, 0),()),
		"Addressforeign": ((15, LCID, 4, 0),()),
		"AliasName": ((61, LCID, 4, 0),()),
		"BPLName": ((8, LCID, 4, 0),()),
		"BPLNameForeign": ((9, LCID, 4, 0),()),
		"Block": ((56, LCID, 4, 0),()),
		"Building": ((54, LCID, 4, 0),()),
		"Business": ((13, LCID, 4, 0),()),
		"City": ((57, LCID, 4, 0),()),
		"CommercialRegister": ((62, LCID, 4, 0),()),
		"CompanyQualificationCode": ((48, LCID, 4, 0),()),
		"CooperativeAssociationTypeCode": ((44, LCID, 4, 0),()),
		"Country": ((60, LCID, 4, 0),()),
		"County": ((59, LCID, 4, 0),()),
		"CreditContributionOriginCode": ((42, LCID, 4, 0),()),
		"DateOfIncorporation": ((63, LCID, 4, 0),()),
		"DeclarerTypeCode": ((49, LCID, 4, 0),()),
		"DefaultCustomerID": ((31, LCID, 4, 0),()),
		"DefaultTaxCode": ((34, LCID, 4, 0),()),
		"DefaultVendorID": ((32, LCID, 4, 0),()),
		"DefaultWarehouseID": ((33, LCID, 4, 0),()),
		"Disabled": ((18, LCID, 4, 0),()),
		"EconomicActivityTypeCode": ((41, LCID, 4, 0),()),
		"EnvironmentType": ((65, LCID, 4, 0),()),
		"FederalTaxID": ((36, LCID, 4, 0),()),
		"FederalTaxID2": ((37, LCID, 4, 0),()),
		"FederalTaxID3": ((38, LCID, 4, 0),()),
		"IPIPeriodCode": ((43, LCID, 4, 0),()),
		"Industry": ((12, LCID, 4, 0),()),
		"MainBPL": ((16, LCID, 4, 0),()),
		"NatureOfCompanyCode": ((40, LCID, 4, 0),()),
		"Opting4ICMS": ((66, LCID, 4, 0),()),
		"PaymentClearingAccount": ((68, LCID, 4, 0),()),
		"PreferredStateCode": ((50, LCID, 4, 0),()),
		"ProfitTaxationCode": ((47, LCID, 4, 0),()),
		"RepName": ((11, LCID, 4, 0),()),
		"SPEDProfile": ((64, LCID, 4, 0),()),
		"State": ((58, LCID, 4, 0),()),
		"Street": ((52, LCID, 4, 0),()),
		"StreetNo": ((53, LCID, 4, 0),()),
		"TaxOffice": ((35, LCID, 4, 0),()),
		"TaxOfficeNo": ((17, LCID, 4, 0),()),
		"VATRegNum": ((10, LCID, 4, 0),()),
		"ZipCode": ((55, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICallArgument(DispatchBaseClass):
	'ICallArgument Interface'
	CLSID = IID('{CB6D5BD6-878B-4966-9E6B-8599949B657F}')
	coclass_clsid = IID('{4DC221EF-0E47-4EB3-A14C-A92F31E956DD}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Name": (10, 2, (8, 0), (), "Name", None),
		"Value": (11, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Name": ((10, LCID, 4, 0),()),
		"Value": ((11, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(11, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICallArguments(DispatchBaseClass):
	'ICallArguments Interface'
	CLSID = IID('{EBBCE4C7-AE00-46A4-A0BA-851F42E7CADF}')
	coclass_clsid = IID('{C8A713C7-A32D-46CC-87FC-EF65827B1E49}')

	# Result is of type ICallArgument
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{CB6D5BD6-878B-4966-9E6B-8599949B657F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICallArgument
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{CB6D5BD6-878B-4966-9E6B-8599949B657F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{CB6D5BD6-878B-4966-9E6B-8599949B657F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{CB6D5BD6-878B-4966-9E6B-8599949B657F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICallMessage(DispatchBaseClass):
	'ICallMessage Interface'
	CLSID = IID('{297DB996-8B05-4D4A-BD2D-333A643F7303}')
	coclass_clsid = IID('{9028E41B-53F3-4D7F-8A0E-FFD5F9923664}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		# Method 'CallMessageArguments' returns object of type 'ICallMessageArguments'
		"CallMessageArguments": (17, 2, (9, 0), (), "CallMessageArguments", '{7DE64B38-CB91-46C2-B1F2-B016D3CBD61D}'),
		"CreationDate": (15, 2, (7, 0), (), "CreationDate", None),
		"CreationTime": (16, 2, (3, 0), (), "CreationTime", None),
		"ErrorCode": (12, 2, (8, 0), (), "ErrorCode", None),
		"ID": (10, 2, (3, 0), (), "ID", None),
		"MessageBody": (13, 2, (8, 0), (), "MessageBody", None),
		"Status": (14, 2, (3, 0), (), "Status", None),
		"Type": (11, 2, (3, 0), (), "Type", None),
	}
	_prop_map_put_ = {
		"CreationDate": ((15, LCID, 4, 0),()),
		"CreationTime": ((16, LCID, 4, 0),()),
		"ErrorCode": ((12, LCID, 4, 0),()),
		"MessageBody": ((13, LCID, 4, 0),()),
		"Type": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICallMessageArgument(DispatchBaseClass):
	'ICallMessageArgument Interface'
	CLSID = IID('{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}')
	coclass_clsid = IID('{0278D428-E7EE-4F0D-ACE4-1CBADAE17BC2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Name": (10, 2, (8, 0), (), "Name", None),
		"Value": (11, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Name": ((10, LCID, 4, 0),()),
		"Value": ((11, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(11, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICallMessageArguments(DispatchBaseClass):
	'ICallMessageArguments Interface'
	CLSID = IID('{7DE64B38-CB91-46C2-B1F2-B016D3CBD61D}')
	coclass_clsid = IID('{5AB3CD70-9DFD-4904-A6FC-AE99578C58BF}')

	# Result is of type ICallMessageArgument
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICallMessageArgument
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICallMessages(DispatchBaseClass):
	'ICallMessages Interface'
	CLSID = IID('{1B562911-6C93-4858-B003-D2586E02BA48}')
	coclass_clsid = IID('{914845C0-9411-4A9C-9D0D-DC85177ACFA9}')

	# Result is of type ICallMessage
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{297DB996-8B05-4D4A-BD2D-333A643F7303}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICallMessage
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{297DB996-8B05-4D4A-BD2D-333A643F7303}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{297DB996-8B05-4D4A-BD2D-333A643F7303}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{297DB996-8B05-4D4A-BD2D-333A643F7303}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICampaign(DispatchBaseClass):
	'ICampaign Interface'
	CLSID = IID('{87B9E57D-866B-4AE6-9C1D-571888134690}')
	coclass_clsid = IID('{7918DE8E-296C-4D36-9BB5-AE66DC9A466D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AttachementsEntry": (20, 2, (3, 0), (), "AttachementsEntry", None),
		# Method 'CampaignBusinessPartners' returns object of type 'ICampaignBusinessPartners'
		"CampaignBusinessPartners": (21, 2, (9, 0), (), "CampaignBusinessPartners", '{05167588-6D3A-4C0E-AEFA-284CFDA23B7E}'),
		# Method 'CampaignItems' returns object of type 'ICampaignItems'
		"CampaignItems": (22, 2, (9, 0), (), "CampaignItems", '{317E97C8-89A1-45FB-BDD3-8AB420DDF340}'),
		"CampaignName": (11, 2, (8, 0), (), "CampaignName", None),
		"CampaignNumber": (10, 2, (3, 0), (), "CampaignNumber", None),
		# Method 'CampaignPartners' returns object of type 'ICampaignPartners'
		"CampaignPartners": (23, 2, (9, 0), (), "CampaignPartners", '{40BEDE06-EB4F-4914-BCDF-71018C6FE98C}'),
		"CampaignType": (12, 2, (3, 0), (), "CampaignType", None),
		"FinishDate": (17, 2, (7, 0), (), "FinishDate", None),
		"GeneratedByWizard": (19, 2, (3, 0), (), "GeneratedByWizard", None),
		"Owner": (14, 2, (3, 0), (), "Owner", None),
		"Remarks": (18, 2, (8, 0), (), "Remarks", None),
		"StartDate": (16, 2, (7, 0), (), "StartDate", None),
		"Status": (15, 2, (3, 0), (), "Status", None),
		"TargetGroup": (13, 2, (8, 0), (), "TargetGroup", None),
	}
	_prop_map_put_ = {
		"AttachementsEntry": ((20, LCID, 4, 0),()),
		"CampaignName": ((11, LCID, 4, 0),()),
		"CampaignType": ((12, LCID, 4, 0),()),
		"FinishDate": ((17, LCID, 4, 0),()),
		"GeneratedByWizard": ((19, LCID, 4, 0),()),
		"Owner": ((14, LCID, 4, 0),()),
		"Remarks": ((18, LCID, 4, 0),()),
		"StartDate": ((16, LCID, 4, 0),()),
		"Status": ((15, LCID, 4, 0),()),
		"TargetGroup": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICampaignBusinessPartner(DispatchBaseClass):
	'ICampaignBusinessPartner Interface'
	CLSID = IID('{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}')
	coclass_clsid = IID('{E41626ED-6A4E-4C2A-8E60-7010C443F3F9}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"BPCode": (12, 2, (8, 0), (), "BPCode", None),
		"BPGroupName": (14, 2, (8, 0), (), "BPGroupName", None),
		"BPIndustryName": (15, 2, (8, 0), (), "BPIndustryName", None),
		"BPName": (13, 2, (8, 0), (), "BPName", None),
		"BPStatus": (16, 2, (8, 0), (), "BPStatus", None),
		"Block": (28, 2, (8, 0), (), "Block", None),
		"Building": (34, 2, (8, 0), (), "Building", None),
		"CampaignLineNumber": (11, 2, (3, 0), (), "CampaignLineNumber", None),
		"CampaignNumber": (10, 2, (3, 0), (), "CampaignNumber", None),
		"City": (29, 2, (8, 0), (), "City", None),
		"ContactAddress": (24, 2, (8, 0), (), "ContactAddress", None),
		"ContactCode": (17, 2, (8, 0), (), "ContactCode", None),
		"ContactEmail": (20, 2, (8, 0), (), "ContactEmail", None),
		"ContactFax": (23, 2, (8, 0), (), "ContactFax", None),
		"ContactMobile": (22, 2, (8, 0), (), "ContactMobile", None),
		"ContactPosition": (19, 2, (8, 0), (), "ContactPosition", None),
		"ContactTelephone": (21, 2, (8, 0), (), "ContactTelephone", None),
		"ContactTitle": (18, 2, (8, 0), (), "ContactTitle", None),
		"Country": (33, 2, (8, 0), (), "Country", None),
		"County": (31, 2, (8, 0), (), "County", None),
		"DocEntry": (38, 2, (3, 0), (), "DocEntry", None),
		"DocNumber": (37, 2, (3, 0), (), "DocNumber", None),
		"DocType": (35, 2, (3, 0), (), "DocType", None),
		"IsShowLinkedDoc": (36, 2, (3, 0), (), "IsShowLinkedDoc", None),
		"RelatedSalesOpportunity": (26, 2, (3, 0), (), "RelatedSalesOpportunity", None),
		"Response": (25, 2, (3, 0), (), "Response", None),
		"State": (32, 2, (8, 0), (), "State", None),
		"Street": (27, 2, (8, 0), (), "Street", None),
		"ZipCode": (30, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"BPCode": ((12, LCID, 4, 0),()),
		"BPName": ((13, LCID, 4, 0),()),
		"Block": ((28, LCID, 4, 0),()),
		"Building": ((34, LCID, 4, 0),()),
		"City": ((29, LCID, 4, 0),()),
		"ContactAddress": ((24, LCID, 4, 0),()),
		"ContactCode": ((17, LCID, 4, 0),()),
		"ContactEmail": ((20, LCID, 4, 0),()),
		"ContactFax": ((23, LCID, 4, 0),()),
		"ContactMobile": ((22, LCID, 4, 0),()),
		"ContactPosition": ((19, LCID, 4, 0),()),
		"ContactTelephone": ((21, LCID, 4, 0),()),
		"ContactTitle": ((18, LCID, 4, 0),()),
		"Country": ((33, LCID, 4, 0),()),
		"County": ((31, LCID, 4, 0),()),
		"DocEntry": ((38, LCID, 4, 0),()),
		"DocType": ((35, LCID, 4, 0),()),
		"IsShowLinkedDoc": ((36, LCID, 4, 0),()),
		"RelatedSalesOpportunity": ((26, LCID, 4, 0),()),
		"Response": ((25, LCID, 4, 0),()),
		"State": ((32, LCID, 4, 0),()),
		"Street": ((27, LCID, 4, 0),()),
		"ZipCode": ((30, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICampaignBusinessPartners(DispatchBaseClass):
	'ICampaignBusinessPartners Interface'
	CLSID = IID('{05167588-6D3A-4C0E-AEFA-284CFDA23B7E}')
	coclass_clsid = IID('{F9528D0C-E227-4693-B99E-E481C2B90BB7}')

	# Result is of type ICampaignBusinessPartner
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICampaignBusinessPartner
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICampaignItem(DispatchBaseClass):
	'ICampaignItem Interface'
	CLSID = IID('{F68C8591-8115-4DC6-B1EF-5071C5CEB367}')
	coclass_clsid = IID('{66F66F95-FC79-49B3-8B71-F80CFC73EAD0}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CampaignLineNumber": (11, 2, (3, 0), (), "CampaignLineNumber", None),
		"CampaignNumber": (10, 2, (3, 0), (), "CampaignNumber", None),
		"ItemCode": (12, 2, (8, 0), (), "ItemCode", None),
		"ItemGroup": (15, 2, (8, 0), (), "ItemGroup", None),
		"ItemName": (13, 2, (8, 0), (), "ItemName", None),
		"ItemType": (14, 2, (3, 0), (), "ItemType", None),
	}
	_prop_map_put_ = {
		"ItemCode": ((12, LCID, 4, 0),()),
		"ItemName": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICampaignItems(DispatchBaseClass):
	'ICampaignItems Interface'
	CLSID = IID('{317E97C8-89A1-45FB-BDD3-8AB420DDF340}')
	coclass_clsid = IID('{DCC7C980-6F3B-4823-872C-5DAD0BBA3A42}')

	# Result is of type ICampaignItem
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{F68C8591-8115-4DC6-B1EF-5071C5CEB367}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICampaignItem
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{F68C8591-8115-4DC6-B1EF-5071C5CEB367}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{F68C8591-8115-4DC6-B1EF-5071C5CEB367}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{F68C8591-8115-4DC6-B1EF-5071C5CEB367}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICampaignParams(DispatchBaseClass):
	'ICampaignParams Interface'
	CLSID = IID('{E47E4050-E7A6-4FD5-8F38-A8066213559A}')
	coclass_clsid = IID('{E04751E5-F944-4A94-B580-320744878FDA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CampaignName": (11, 2, (8, 0), (), "CampaignName", None),
		"CampaignNumber": (10, 2, (3, 0), (), "CampaignNumber", None),
	}
	_prop_map_put_ = {
		"CampaignName": ((11, LCID, 4, 0),()),
		"CampaignNumber": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICampaignPartner(DispatchBaseClass):
	'ICampaignPartner Interface'
	CLSID = IID('{A93138D1-7360-49C9-8F1C-EC5239C494B0}')
	coclass_clsid = IID('{2167C74B-B692-4B1C-AE1E-721CA61EA8A1}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CampaignLineNumber": (11, 2, (3, 0), (), "CampaignLineNumber", None),
		"CampaignNumber": (10, 2, (3, 0), (), "CampaignNumber", None),
		"Details": (15, 2, (8, 0), (), "Details", None),
		"PartnerID": (12, 2, (3, 0), (), "PartnerID", None),
		"RelatedBP": (14, 2, (8, 0), (), "RelatedBP", None),
		"RelationshipCode": (13, 2, (3, 0), (), "RelationshipCode", None),
	}
	_prop_map_put_ = {
		"Details": ((15, LCID, 4, 0),()),
		"PartnerID": ((12, LCID, 4, 0),()),
		"RelatedBP": ((14, LCID, 4, 0),()),
		"RelationshipCode": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICampaignPartners(DispatchBaseClass):
	'ICampaignPartners Interface'
	CLSID = IID('{40BEDE06-EB4F-4914-BCDF-71018C6FE98C}')
	coclass_clsid = IID('{91155E58-DB6A-4817-ABA0-657B09C05471}')

	# Result is of type ICampaignPartner
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A93138D1-7360-49C9-8F1C-EC5239C494B0}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICampaignPartner
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{A93138D1-7360-49C9-8F1C-EC5239C494B0}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{A93138D1-7360-49C9-8F1C-EC5239C494B0}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{A93138D1-7360-49C9-8F1C-EC5239C494B0}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICampaignsParams(DispatchBaseClass):
	'ICampaignsParams Interface'
	CLSID = IID('{EF865450-BA41-490B-B580-3D566BA3681A}')
	coclass_clsid = IID('{215A5610-7BBC-4D8A-B41F-33EF4BFBEF9F}')

	# Result is of type ICampaignParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{E47E4050-E7A6-4FD5-8F38-A8066213559A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICampaignParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{E47E4050-E7A6-4FD5-8F38-A8066213559A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{E47E4050-E7A6-4FD5-8F38-A8066213559A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{E47E4050-E7A6-4FD5-8F38-A8066213559A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICampaignsService(DispatchBaseClass):
	'ICampaignsService Interface'
	CLSID = IID('{FCF196BC-2669-4A6D-92C8-33896FD2D3B1}')
	coclass_clsid = IID('{3288D1F6-6EA4-4FA3-82E5-53943D2DA511}')

	# Result is of type ICampaignParams
	def Add(self, pICampaign=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICampaign
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{E47E4050-E7A6-4FD5-8F38-A8066213559A}')
		return ret

	def Cancel(self, pICampaignParams=defaultNamedNotOptArg):
		'Cancel'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((9, 1),),pICampaignParams
			)

	def Delete(self, pICampaignParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pICampaignParams
			)

	# Result is of type ICampaign
	def Get(self, pICampaignParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pICampaignParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{87B9E57D-866B-4AE6-9C1D-571888134690}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ICampaignsParams
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{EF865450-BA41-490B-B580-3D566BA3681A}')
		return ret

	def Update(self, pICampaign=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pICampaign
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICashDiscount(DispatchBaseClass):
	'ICashDiscount Interface'
	CLSID = IID('{A46D71C0-8C65-4B7E-BBA7-F6228CA0FE76}')
	coclass_clsid = IID('{91D09078-1DA3-4320-BDAF-AFCD977F7E83}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ByDate": (12, 2, (3, 0), (), "ByDate", None),
		"Code": (10, 2, (8, 0), (), "Code", None),
		# Method 'DiscountLines' returns object of type 'IDiscountLines'
		"DiscountLines": (15, 2, (9, 0), (), "DiscountLines", '{E14BAC45-1772-407F-B255-178FF23F91E3}'),
		"Freight": (13, 2, (3, 0), (), "Freight", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"Tax": (14, 2, (3, 0), (), "Tax", None),
	}
	_prop_map_put_ = {
		"ByDate": ((12, LCID, 4, 0),()),
		"Code": ((10, LCID, 4, 0),()),
		"Freight": ((13, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"Tax": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICashDiscountParams(DispatchBaseClass):
	'ICashDiscountParams Interface'
	CLSID = IID('{60288E22-2FC1-402B-80FE-04D66413E1A0}')
	coclass_clsid = IID('{4600E0D8-E8C5-4CC3-93CB-68DB78774B44}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICashDiscountsParams(DispatchBaseClass):
	'ICashDiscountsParams Interface'
	CLSID = IID('{38B3A4C7-93BE-4A6C-A060-C54D34979E1C}')
	coclass_clsid = IID('{04A588AD-9FA8-4238-8044-D70C1988BFD2}')

	# Result is of type ICashDiscountParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{60288E22-2FC1-402B-80FE-04D66413E1A0}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICashDiscountParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{60288E22-2FC1-402B-80FE-04D66413E1A0}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{60288E22-2FC1-402B-80FE-04D66413E1A0}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{60288E22-2FC1-402B-80FE-04D66413E1A0}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICashDiscountsService(DispatchBaseClass):
	'ICashDiscountsService Interface'
	CLSID = IID('{1FA65DB2-F84E-4C7C-A48D-E4043BCF6557}')
	coclass_clsid = IID('{A46D497B-B625-4043-B6E6-988E544336BE}')

	# Result is of type ICashDiscountParams
	def AddCashDiscount(self, pICashDiscount=defaultNamedNotOptArg):
		'AddCashDiscount'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICashDiscount
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddCashDiscount', '{60288E22-2FC1-402B-80FE-04D66413E1A0}')
		return ret

	def DeleteCashDiscount(self, pICashDiscountParams=defaultNamedNotOptArg):
		'DeleteCashDiscount'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pICashDiscountParams
			)

	# Result is of type ICashDiscount
	def GetCashDiscount(self, pICashDiscountParams=defaultNamedNotOptArg):
		'GetCashDiscount'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pICashDiscountParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCashDiscount', '{A46D71C0-8C65-4B7E-BBA7-F6228CA0FE76}')
		return ret

	# Result is of type ICashDiscountsParams
	def GetCashDiscountList(self):
		'GetCashDiscountList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCashDiscountList', '{38B3A4C7-93BE-4A6C-A060-C54D34979E1C}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateCashDiscount(self, pICashDiscount=defaultNamedNotOptArg):
		'UpdateCashDiscount'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pICashDiscount
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICashFlowAssignments(DispatchBaseClass):
	'ICashFlowAssignments Interface'
	CLSID = IID('{A0307CBF-64B1-49E8-B60D-38803E20D107}')
	coclass_clsid = IID('{920385DA-2BF3-41E5-BB01-EFDE51C104E6}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AmountFC": (11, 2, (5, 0), (), "AmountFC", None),
		"AmountLC": (10, 2, (5, 0), (), "AmountLC", None),
		"CashFlowAssignmentsID": (5, 2, (3, 0), (), "CashFlowAssignmentsID", None),
		"CashFlowLineItemID": (7, 2, (3, 0), (), "CashFlowLineItemID", None),
		"CheckNumber": (9, 2, (8, 0), (), "CheckNumber", None),
		"Count": (1, 2, (3, 0), (), "Count", None),
		"PaymentMeans": (8, 2, (3, 0), (), "PaymentMeans", None),
	}
	_prop_map_put_ = {
		"AmountFC": ((11, LCID, 4, 0),()),
		"AmountLC": ((10, LCID, 4, 0),()),
		"CashFlowLineItemID": ((7, LCID, 4, 0),()),
		"CheckNumber": ((9, LCID, 4, 0),()),
		"PaymentMeans": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICashFlowLineItem(DispatchBaseClass):
	'ICashFlowLineItem Interface'
	CLSID = IID('{D2EDF723-F433-4A0A-A4A9-5D8E628CC3E3}')
	coclass_clsid = IID('{3B3E22F6-114F-4F15-9864-319ABBEF75EB}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ActiveLineItem": (12, 2, (3, 0), (), "ActiveLineItem", None),
		"Drawer": (15, 2, (3, 0), (), "Drawer", None),
		"Level": (14, 2, (3, 0), (), "Level", None),
		"LineItemID": (10, 2, (3, 0), (), "LineItemID", None),
		"LineItemName": (11, 2, (8, 0), (), "LineItemName", None),
		"ParentArticle": (13, 2, (3, 0), (), "ParentArticle", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICashFlowLineItemParams(DispatchBaseClass):
	'ICashFlowLineItemParams Interface'
	CLSID = IID('{A6EE3F95-9556-4409-9BCB-9DC06E009E22}')
	coclass_clsid = IID('{65CA8D95-BE2F-4E7E-9E56-42BA0FE0FB49}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"LineItemID": (10, 2, (3, 0), (), "LineItemID", None),
		"LineItemName": (11, 2, (8, 0), (), "LineItemName", None),
	}
	_prop_map_put_ = {
		"LineItemID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICashFlowLineItemsParams(DispatchBaseClass):
	'ICashFlowLineItemsParams Interface'
	CLSID = IID('{7B677F06-BB36-462B-BABF-99676A90BC70}')
	coclass_clsid = IID('{78A66A76-1B6F-44EC-B0FD-5C5CDC2752F4}')

	# Result is of type ICashFlowLineItemParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A6EE3F95-9556-4409-9BCB-9DC06E009E22}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICashFlowLineItemParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{A6EE3F95-9556-4409-9BCB-9DC06E009E22}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{A6EE3F95-9556-4409-9BCB-9DC06E009E22}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{A6EE3F95-9556-4409-9BCB-9DC06E009E22}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICashFlowLineItemsService(DispatchBaseClass):
	'ICashFlowLineItemsService Interface'
	CLSID = IID('{724DEACC-3DDF-46DC-A884-A69751E80603}')
	coclass_clsid = IID('{F0DA88A7-72BE-4DF7-9A0A-05600C784DE8}')

	# Result is of type ICashFlowLineItem
	def GetCashFlowLineItem(self, pICashFlowLineItemParams=defaultNamedNotOptArg):
		'GetCashFlowLineItem'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICashFlowLineItemParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCashFlowLineItem', '{D2EDF723-F433-4A0A-A4A9-5D8E628CC3E3}')
		return ret

	# Result is of type ICashFlowLineItemsParams
	def GetCashFlowLineItemList(self):
		'GetCashFlowLineItemList'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCashFlowLineItemList', '{7B677F06-BB36-462B-BABF-99676A90BC70}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICertificateSeries(DispatchBaseClass):
	'ICertificateSeries Interface'
	CLSID = IID('{56F2B212-48C0-453C-9298-380C6F7350F2}')
	coclass_clsid = IID('{2BDDDD4B-2399-48E0-A9E1-7BC3DE1324A0}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"DefaultSeries": (14, 2, (3, 0), (), "DefaultSeries", None),
		"Location": (13, 2, (3, 0), (), "Location", None),
		"Section": (12, 2, (3, 0), (), "Section", None),
		# Method 'SeriesLines' returns object of type 'ISeriesLines'
		"SeriesLines": (15, 2, (9, 0), (), "SeriesLines", '{D5B65908-18C4-493A-B1F3-BC7987AF01DD}'),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"DefaultSeries": ((14, LCID, 4, 0),()),
		"Location": ((13, LCID, 4, 0),()),
		"Section": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICertificateSeriesParams(DispatchBaseClass):
	'ICertificateSeriesParams Interface'
	CLSID = IID('{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')
	coclass_clsid = IID('{6C88DC52-9869-4BB8-8DBB-C2F536138943}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Location": (13, 2, (3, 0), (), "Location", None),
		"Section": (12, 2, (3, 0), (), "Section", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICertificateSeriesParamsCollection(DispatchBaseClass):
	'ICertificateSeriesParamsCollection Interface'
	CLSID = IID('{731625D2-901C-40C1-A06C-C6A72FC00D8C}')
	coclass_clsid = IID('{E097B000-F885-401A-A265-5E46F074A5F4}')

	# Result is of type ICertificateSeriesParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICertificateSeriesParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICertificateSeriesService(DispatchBaseClass):
	'ICertificateSeriesService Interface'
	CLSID = IID('{9A96D2E9-0308-433A-AE8B-417FE4AD66D3}')
	coclass_clsid = IID('{C4E7259B-2770-4451-9C0F-0757F5BE9FD7}')

	# Result is of type ICertificateSeriesParams
	def AddCertificateSeries(self, pICertificateSeries=defaultNamedNotOptArg):
		'AddCertificateSeries'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICertificateSeries
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddCertificateSeries', '{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')
		return ret

	def DeleteCertificateSeries(self, pICertificateSeriesParams=defaultNamedNotOptArg):
		'DeleteCertificateSeries'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pICertificateSeriesParams
			)

	# Result is of type ICertificateSeries
	def GetCertificateSeries(self, pICertificateSeriesParams=defaultNamedNotOptArg):
		'GetCertificateSeries'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pICertificateSeriesParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCertificateSeries', '{56F2B212-48C0-453C-9298-380C6F7350F2}')
		return ret

	# Result is of type ICertificateSeriesParamsCollection
	def GetCertificateSeriesList(self):
		'GetCertificateSeriesList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCertificateSeriesList', '{731625D2-901C-40C1-A06C-C6A72FC00D8C}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateCertificateSeries(self, pICertificateSeries=defaultNamedNotOptArg):
		'UpdateCertificateSeries'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pICertificateSeries
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChangeLogDifferenceParams(DispatchBaseClass):
	'IChangeLogDifferenceParams Interface'
	CLSID = IID('{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}')
	coclass_clsid = IID('{43A684B0-5463-4FD9-9F52-A2E57909EAF2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ArrayOffset": (15, 2, (3, 0), (), "ArrayOffset", None),
		"ChangedField": (11, 2, (8, 0), (), "ChangedField", None),
		"Date": (10, 2, (7, 0), (), "Date", None),
		"LineNumber": (16, 2, (8, 0), (), "LineNumber", None),
		"NewValue": (13, 2, (8, 0), (), "NewValue", None),
		"OldValue": (12, 2, (8, 0), (), "OldValue", None),
		"UserName": (14, 2, (8, 0), (), "UserName", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChangeLogDifferencesParams(DispatchBaseClass):
	'IChangeLogDifferencesParams Interface'
	CLSID = IID('{FA06709C-FEAA-4E4B-85F1-063578C32965}')
	coclass_clsid = IID('{45B16468-2569-43A8-A330-D6E7F5275CAD}')

	# Result is of type IChangeLogDifferenceParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IChangeLogDifferenceParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IChangeLogParams(DispatchBaseClass):
	'IChangeLogParams Interface'
	CLSID = IID('{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}')
	coclass_clsid = IID('{7C51D9D4-DDBA-4057-BC03-AEE13B22CD64}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"LogInstance": (10, 2, (3, 0), (), "LogInstance", None),
		"ObjectCode": (13, 2, (8, 0), (), "ObjectCode", None),
		"UpdatedDate": (11, 2, (7, 0), (), "UpdatedDate", None),
		"UserName": (12, 2, (8, 0), (), "UserName", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChangeLogsParams(DispatchBaseClass):
	'IChangeLogsParams Interface'
	CLSID = IID('{D2FE59A3-5DA7-403C-9EAB-EF2C8CD8EFEA}')
	coclass_clsid = IID('{AE08D2F8-6EBB-42BA-9226-FD68AC457294}')

	# Result is of type IChangeLogParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IChangeLogParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IChangeLogsService(DispatchBaseClass):
	'IChangeLogsService Interface'
	CLSID = IID('{6C62EE4B-B4A6-4BD1-B0E3-D81EEB7888CA}')
	coclass_clsid = IID('{5751679D-4E34-4E74-B169-03D440F1F9D1}')

	# Result is of type IChangeLogsParams
	def GetChangeLog(self, pIGetChangeLogParams=defaultNamedNotOptArg):
		'GetChangeLog'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIGetChangeLogParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetChangeLog', '{D2FE59A3-5DA7-403C-9EAB-EF2C8CD8EFEA}')
		return ret

	# Result is of type IChangeLogDifferencesParams
	def GetChangeLogDifferences(self, pIShowDifferenceParams=defaultNamedNotOptArg):
		'GetChangeLogDifferences'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIShowDifferenceParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetChangeLogDifferences', '{FA06709C-FEAA-4E4B-85F1-063578C32965}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChartOfAccounts(DispatchBaseClass):
	'IChartOfAccounts Interface'
	CLSID = IID('{2CF2E472-CA6D-4D8E-8B80-046D28E75C40}')
	coclass_clsid = IID('{85EBDF2E-252D-4489-9E2F-FE17C36ACE86}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(41, LCID, 1, (8, 0), (),)

	def GetByKey(self, AccountCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (11, 0), ((8, 0),),AccountCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(42, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AccountLevel": (15, 2, (3, 0), (), "AccountLevel", None),
		"AccountType": (25, 2, (3, 0), (), "AccountType", None),
		"AcctCurrency": (26, 2, (8, 0), (), "AcctCurrency", None),
		"ActiveAccount": (13, 2, (3, 0), (), "ActiveAccount", None),
		"AllowChangeVatGroup": (43, 2, (3, 0), (), "AllowChangeVatGroup", None),
		"AllowMultipleLinking": (71, 2, (3, 0), (), "AllowMultipleLinking", None),
		"BPLID": (91, 2, (3, 0), (), "BPLID", None),
		"BPLName": (92, 2, (8, 0), (), "BPLName", None),
		"Balance": (9, 2, (5, 0), (), "Balance", None),
		"Balance_FrgnCurr": (29, 2, (5, 0), (), "Balance_FrgnCurr", None),
		"Balance_syscurr": (28, 2, (5, 0), (), "Balance_syscurr", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (6, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BudgetAccount": (11, 2, (3, 0), (), "BudgetAccount", None),
		"CashAccount": (10, 2, (3, 0), (), "CashAccount", None),
		"Category": (45, 2, (3, 0), (), "Category", None),
		"Code": (7, 2, (8, 0), (), "Code", None),
		"DataExportCode": (16, 2, (8, 0), (), "DataExportCode", None),
		"DatevAccount": (54, 2, (3, 0), (), "DatevAccount", None),
		"DatevAutoAccount": (55, 2, (3, 0), (), "DatevAutoAccount", None),
		"DatevFirstDataEntry": (56, 2, (3, 0), (), "DatevFirstDataEntry", None),
		"DefaultVatGroup": (44, 2, (8, 0), (), "DefaultVatGroup", None),
		"Details": (34, 2, (8, 0), (), "Details", None),
		"DistributionRule2Relevant": (74, 2, (3, 0), (), "DistributionRule2Relevant", None),
		"DistributionRule3Relevant": (75, 2, (3, 0), (), "DistributionRule3Relevant", None),
		"DistributionRule4Relevant": (76, 2, (3, 0), (), "DistributionRule4Relevant", None),
		"DistributionRule5Relevant": (77, 2, (3, 0), (), "DistributionRule5Relevant", None),
		"DistributionRuleRelevant": (73, 2, (3, 0), (), "DistributionRuleRelevant", None),
		"ExternalCode": (18, 2, (8, 0), (), "ExternalCode", None),
		"ExternalReconNo": (23, 2, (3, 0), (), "ExternalReconNo", None),
		"FatherAccountKey": (17, 2, (8, 0), (), "FatherAccountKey", None),
		"ForeignName": (33, 2, (8, 0), (), "ForeignName", None),
		"FormatCode": (39, 2, (8, 0), (), "FormatCode", None),
		"InternalReconNo": (24, 2, (3, 0), (), "InternalReconNo", None),
		"LiableForAdvances": (32, 2, (3, 0), (), "LiableForAdvances", None),
		"LoadingFactorCode": (48, 2, (8, 0), (), "LoadingFactorCode", None),
		"LoadingFactorCode2": (49, 2, (8, 0), (), "LoadingFactorCode2", None),
		"LoadingFactorCode3": (50, 2, (8, 0), (), "LoadingFactorCode3", None),
		"LoadingFactorCode4": (51, 2, (8, 0), (), "LoadingFactorCode4", None),
		"LoadingFactorCode5": (52, 2, (8, 0), (), "LoadingFactorCode5", None),
		"LoadingType": (47, 2, (3, 0), (), "LoadingType", None),
		"LockManualTransaction": (38, 2, (3, 0), (), "LockManualTransaction", None),
		"Name": (8, 2, (8, 0), (), "Name", None),
		"PlanningLevel": (53, 2, (8, 0), (), "PlanningLevel", None),
		"PrimaryAccount": (14, 2, (3, 0), (), "PrimaryAccount", None),
		"ProjectCode": (35, 2, (8, 0), (), "ProjectCode", None),
		"ProjectRelevant": (72, 2, (3, 0), (), "ProjectRelevant", None),
		"Protected": (30, 2, (3, 0), (), "Protected", None),
		"RateConversion": (20, 2, (3, 0), (), "RateConversion", None),
		"ReconciledAccount": (31, 2, (3, 0), (), "ReconciledAccount", None),
		"RevaluationCoordinated": (36, 2, (3, 0), (), "RevaluationCoordinated", None),
		"TaxExemptAccount": (22, 2, (3, 0), (), "TaxExemptAccount", None),
		"TaxLiableAccount": (21, 2, (3, 0), (), "TaxLiableAccount", None),
		"TransactionCode": (46, 2, (8, 0), (), "TransactionCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (40, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATRegNum": (93, 2, (8, 0), (), "VATRegNum", None),
	}
	_prop_map_put_ = {
		"AccountType": ((25, LCID, 4, 0),()),
		"AcctCurrency": ((26, LCID, 4, 0),()),
		"ActiveAccount": ((13, LCID, 4, 0),()),
		"AllowChangeVatGroup": ((43, LCID, 4, 0),()),
		"AllowMultipleLinking": ((71, LCID, 4, 0),()),
		"BPLID": ((91, LCID, 4, 0),()),
		"BudgetAccount": ((11, LCID, 4, 0),()),
		"CashAccount": ((10, LCID, 4, 0),()),
		"Category": ((45, LCID, 4, 0),()),
		"Code": ((7, LCID, 4, 0),()),
		"DataExportCode": ((16, LCID, 4, 0),()),
		"DatevAccount": ((54, LCID, 4, 0),()),
		"DatevAutoAccount": ((55, LCID, 4, 0),()),
		"DatevFirstDataEntry": ((56, LCID, 4, 0),()),
		"DefaultVatGroup": ((44, LCID, 4, 0),()),
		"Details": ((34, LCID, 4, 0),()),
		"DistributionRule2Relevant": ((74, LCID, 4, 0),()),
		"DistributionRule3Relevant": ((75, LCID, 4, 0),()),
		"DistributionRule4Relevant": ((76, LCID, 4, 0),()),
		"DistributionRule5Relevant": ((77, LCID, 4, 0),()),
		"DistributionRuleRelevant": ((73, LCID, 4, 0),()),
		"ExternalCode": ((18, LCID, 4, 0),()),
		"FatherAccountKey": ((17, LCID, 4, 0),()),
		"ForeignName": ((33, LCID, 4, 0),()),
		"FormatCode": ((39, LCID, 4, 0),()),
		"LiableForAdvances": ((32, LCID, 4, 0),()),
		"LoadingFactorCode": ((48, LCID, 4, 0),()),
		"LoadingFactorCode2": ((49, LCID, 4, 0),()),
		"LoadingFactorCode3": ((50, LCID, 4, 0),()),
		"LoadingFactorCode4": ((51, LCID, 4, 0),()),
		"LoadingFactorCode5": ((52, LCID, 4, 0),()),
		"LoadingType": ((47, LCID, 4, 0),()),
		"LockManualTransaction": ((38, LCID, 4, 0),()),
		"Name": ((8, LCID, 4, 0),()),
		"PlanningLevel": ((53, LCID, 4, 0),()),
		"ProjectCode": ((35, LCID, 4, 0),()),
		"ProjectRelevant": ((72, LCID, 4, 0),()),
		"Protected": ((30, LCID, 4, 0),()),
		"RateConversion": ((20, LCID, 4, 0),()),
		"ReconciledAccount": ((31, LCID, 4, 0),()),
		"RevaluationCoordinated": ((36, LCID, 4, 0),()),
		"TaxExemptAccount": ((22, LCID, 4, 0),()),
		"TaxLiableAccount": ((21, LCID, 4, 0),()),
		"TransactionCode": ((46, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICheckLine(DispatchBaseClass):
	'ICheckLine Interface'
	CLSID = IID('{900A8956-ACED-4E66-B254-78EB55F7089F}')
	coclass_clsid = IID('{5F9B7943-CA8C-482F-A5EB-B412ADB51007}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AccountNumber": (20, 2, (8, 0), (), "AccountNumber", None),
		"Bank": (12, 2, (8, 0), (), "Bank", None),
		"Branch": (13, 2, (8, 0), (), "Branch", None),
		"CashCheck": (14, 2, (8, 0), (), "CashCheck", None),
		"CheckAmount": (17, 2, (5, 0), (), "CheckAmount", None),
		"CheckCurrency": (21, 2, (8, 0), (), "CheckCurrency", None),
		"CheckDate": (15, 2, (7, 0), (), "CheckDate", None),
		"CheckKey": (10, 2, (3, 0), (), "CheckKey", None),
		"CheckNumber": (11, 2, (3, 0), (), "CheckNumber", None),
		"Customer": (16, 2, (8, 0), (), "Customer", None),
		"Deposited": (18, 2, (3, 0), (), "Deposited", None),
		"Transferred": (19, 2, (3, 0), (), "Transferred", None),
	}
	_prop_map_put_ = {
		"CheckKey": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICheckLineParams(DispatchBaseClass):
	'ICheckLineParams Interface'
	CLSID = IID('{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}')
	coclass_clsid = IID('{A0324965-FF3F-43FA-BE6B-63DE64C9991F}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CheckKey": (10, 2, (3, 0), (), "CheckKey", None),
	}
	_prop_map_put_ = {
		"CheckKey": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICheckLines(DispatchBaseClass):
	'ICheckLines Interface'
	CLSID = IID('{4DA92EEC-3781-4B5B-B466-4001E7B6F439}')
	coclass_clsid = IID('{6719EA66-D6B5-4509-ABC0-E16BDC730623}')

	# Result is of type ICheckLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{900A8956-ACED-4E66-B254-78EB55F7089F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICheckLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{900A8956-ACED-4E66-B254-78EB55F7089F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{900A8956-ACED-4E66-B254-78EB55F7089F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{900A8956-ACED-4E66-B254-78EB55F7089F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICheckLinesParams(DispatchBaseClass):
	'ICheckLinesParams Interface'
	CLSID = IID('{FFA181B4-6482-45B5-901D-525B13F491EA}')
	coclass_clsid = IID('{81460BB2-567C-447B-9606-1C70FCF4F204}')

	# Result is of type ICheckLineParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICheckLineParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICheckLinesService(DispatchBaseClass):
	'ICheckLinesService Interface'
	CLSID = IID('{ABDA119B-E21C-44A5-8DA3-CA870D0D9486}')
	coclass_clsid = IID('{3F5CE8F3-380C-4E97-A303-342EF66DE0DC}')

	# Result is of type ICheckLine
	def GetCheckLine(self, pICheckLineParams=defaultNamedNotOptArg):
		'GetCheckLine'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICheckLineParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCheckLine', '{900A8956-ACED-4E66-B254-78EB55F7089F}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ICheckLinesParams
	def GetValidCheckLineList(self):
		'GetValidCheckLineList'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetValidCheckLineList', '{FFA181B4-6482-45B5-901D-525B13F491EA}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChecksforPayment(DispatchBaseClass):
	'IChecksforPayment Interface'
	CLSID = IID('{5E6A92D1-9BAB-4BB4-A379-2428006247C3}')
	coclass_clsid = IID('{31341DF9-0A1F-4B75-BBAB-50B96478E579}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(44, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(46, LCID, 1, (8, 0), (),)

	def GetByKey(self, CheckKey=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),CheckKey
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(47, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AccountNumber": (17, 2, (8, 0), (), "AccountNumber", None),
		"Address": (33, 2, (8, 0), (), "Address", None),
		"AddressName": (45, 2, (8, 0), (), "AddressName", None),
		"BankCode": (11, 2, (8, 0), (), "BankCode", None),
		"BankName": (13, 2, (8, 0), (), "BankName", None),
		"Branch": (12, 2, (8, 0), (), "Branch", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Canceled": (26, 2, (3, 0), (), "Canceled", None),
		"CardOrAccount": (27, 2, (3, 0), (), "CardOrAccount", None),
		"CheckAmount": (22, 2, (5, 0), (), "CheckAmount", None),
		"CheckCurrency": (25, 2, (8, 0), (), "CheckCurrency", None),
		"CheckDate": (14, 2, (7, 0), (), "CheckDate", None),
		"CheckKey": (9, 2, (3, 0), (), "CheckKey", None),
		"CheckNumber": (10, 2, (3, 0), (), "CheckNumber", None),
		"CountryCode": (41, 2, (8, 0), (), "CountryCode", None),
		"CreateJournalEntry": (34, 2, (3, 0), (), "CreateJournalEntry", None),
		"CreationDate": (36, 2, (7, 0), (), "CreationDate", None),
		"CustomerAccountCode": (31, 2, (8, 0), (), "CustomerAccountCode", None),
		"DeductionRefundAmount": (39, 2, (5, 0), (), "DeductionRefundAmount", None),
		"Details": (18, 2, (8, 0), (), "Details", None),
		"JournalEntryReference": (19, 2, (8, 0), (), "JournalEntryReference", None),
		# Method 'Lines' returns object of type 'IChecksforPaymentLines'
		"Lines": (43, 2, (9, 0), (), "Lines", '{A6DB2CDA-3A42-4A70-918C-53595D6091C9}'),
		"ManualCheck": (48, 2, (3, 0), (), "ManualCheck", None),
		"PaymentDate": (20, 2, (7, 0), (), "PaymentDate", None),
		"PaymentNo": (21, 2, (3, 0), (), "PaymentNo", None),
		"Printed": (28, 2, (3, 0), (), "Printed", None),
		"PrintedBy": (40, 2, (3, 0), (), "PrintedBy", None),
		"Signature": (30, 2, (8, 0), (), "Signature", None),
		"TaxDate": (38, 2, (7, 0), (), "TaxDate", None),
		"TaxTotal": (37, 2, (5, 0), (), "TaxTotal", None),
		"TotalinWords": (42, 2, (8, 0), (), "TotalinWords", None),
		"TransactionNumber": (32, 2, (3, 0), (), "TransactionNumber", None),
		"Transferable": (23, 2, (3, 0), (), "Transferable", None),
		"UpdateDate": (35, 2, (7, 0), (), "UpdateDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VendorCode": (24, 2, (8, 0), (), "VendorCode", None),
		"VendorName": (29, 2, (8, 0), (), "VendorName", None),
	}
	_prop_map_put_ = {
		"AccountNumber": ((17, LCID, 4, 0),()),
		"Address": ((33, LCID, 4, 0),()),
		"AddressName": ((45, LCID, 4, 0),()),
		"BankCode": ((11, LCID, 4, 0),()),
		"Branch": ((12, LCID, 4, 0),()),
		"CardOrAccount": ((27, LCID, 4, 0),()),
		"CheckDate": ((14, LCID, 4, 0),()),
		"CheckNumber": ((10, LCID, 4, 0),()),
		"CountryCode": ((41, LCID, 4, 0),()),
		"CreateJournalEntry": ((34, LCID, 4, 0),()),
		"CustomerAccountCode": ((31, LCID, 4, 0),()),
		"DeductionRefundAmount": ((39, LCID, 4, 0),()),
		"Details": ((18, LCID, 4, 0),()),
		"JournalEntryReference": ((19, LCID, 4, 0),()),
		"ManualCheck": ((48, LCID, 4, 0),()),
		"PaymentDate": ((20, LCID, 4, 0),()),
		"Signature": ((30, LCID, 4, 0),()),
		"TotalinWords": ((42, LCID, 4, 0),()),
		"Transferable": ((23, LCID, 4, 0),()),
		"VendorCode": ((24, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChecksforPaymentLines(DispatchBaseClass):
	'IChecksforPaymentLines Interface'
	CLSID = IID('{A6DB2CDA-3A42-4A70-918C-53595D6091C9}')
	coclass_clsid = IID('{36360587-E2A6-4BF4-BFED-92F2CEDDF03D}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"CreditedAccount": (12, 2, (8, 0), (), "CreditedAccount", None),
		"LineTotal": (13, 2, (5, 0), (), "LineTotal", None),
		"RowCurrency": (8, 2, (8, 0), (), "RowCurrency", None),
		"RowDetails": (6, 2, (8, 0), (), "RowDetails", None),
		"RowNumber": (5, 2, (3, 0), (), "RowNumber", None),
		"RowTotal": (7, 2, (5, 0), (), "RowTotal", None),
		"TaxDefinition": (10, 2, (8, 0), (), "TaxDefinition", None),
		"TaxPercent": (11, 2, (5, 0), (), "TaxPercent", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CreditedAccount": ((12, LCID, 4, 0),()),
		"RowCurrency": ((8, LCID, 4, 0),()),
		"RowDetails": ((6, LCID, 4, 0),()),
		"RowTotal": ((7, LCID, 4, 0),()),
		"TaxDefinition": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IChooseFromList(DispatchBaseClass):
	'IChooseFromList Interface'
	CLSID = IID('{F183C834-5321-46B5-96B6-0BC50D1726E8}')
	coclass_clsid = IID('{3D623D04-749A-46B6-B0A2-AAC17B3FAEC8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrObjectName=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),bstrObjectName
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		# Method 'ChooseFromList_Lines' returns object of type 'IChooseFromList_Lines'
		"ChooseFromList_Lines": (11, 2, (9, 0), (), "ChooseFromList_Lines", '{2E9D54CC-66FD-4688-9DA0-6AEE9C263D7E}'),
		"ObjectName": (10, 2, (8, 0), (), "ObjectName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ObjectName": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IChooseFromList_Lines(DispatchBaseClass):
	'IChooseFromList_Lines Interface'
	CLSID = IID('{2E9D54CC-66FD-4688-9DA0-6AEE9C263D7E}')
	coclass_clsid = IID('{53651CC7-0892-4713-AE45-FE246FCA0F07}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (3, 2, (3, 0), (), "Count", None),
		"DisplayedName": (6, 2, (8, 0), (), "DisplayedName", None),
		"FieldNo": (5, 2, (8, 0), (), "FieldNo", None),
		"GroupBy": (7, 2, (3, 0), (), "GroupBy", None),
		"ShowType": (9, 2, (3, 0), (), "ShowType", None),
		"SortOrder": (10, 2, (3, 0), (), "SortOrder", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"Visible": (8, 2, (3, 0), (), "Visible", None),
		"VisualIndex": (11, 2, (3, 0), (), "VisualIndex", None),
	}
	_prop_map_put_ = {
		"DisplayedName": ((6, LCID, 4, 0),()),
		"FieldNo": ((5, LCID, 4, 0),()),
		"GroupBy": ((7, LCID, 4, 0),()),
		"ShowType": ((9, LCID, 4, 0),()),
		"SortOrder": ((10, LCID, 4, 0),()),
		"Visible": ((8, LCID, 4, 0),()),
		"VisualIndex": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IClosingDateProcedure(DispatchBaseClass):
	'IClosingDateProcedure Interface'
	CLSID = IID('{910FEA90-B652-4099-9817-3AA0CF635963}')
	coclass_clsid = IID('{B50BD947-38AC-4ACE-97F4-8EA9ECD9AB77}')

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, ClosingDateNum=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((3, 0),),ClosingDateNum
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(11, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		"BaselineDate": (4, 2, (3, 0), (), "BaselineDate", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (8, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ClosingDateCode": (3, 2, (8, 0), (), "ClosingDateCode", None),
		"ClosingDateNum": (2, 2, (3, 0), (), "ClosingDateNum", None),
		"DueMonth": (5, 2, (3, 0), (), "DueMonth", None),
		"ExtraDay": (7, 2, (3, 0), (), "ExtraDay", None),
		"ExtraMonth": (6, 2, (3, 0), (), "ExtraMonth", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICockpit(DispatchBaseClass):
	'ICockpit Interface'
	CLSID = IID('{30EB7C61-BD42-4AAF-877E-DB6253066688}')
	coclass_clsid = IID('{594B9D4F-6946-40E7-9E69-2DC0F506A823}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"CockpitType": (19, 2, (3, 0), (), "CockpitType", None),
		"Code": (11, 2, (3, 0), (), "Code", None),
		"Date": (15, 2, (7, 0), (), "Date", None),
		"Description": (13, 2, (8, 0), (), "Description", None),
		"Manufacturer": (17, 2, (8, 0), (), "Manufacturer", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
		"Publisher": (18, 2, (8, 0), (), "Publisher", None),
		"Time": (16, 2, (7, 0), (), "Time", None),
		"UserSignature": (14, 2, (3, 0), (), "UserSignature", None),
	}
	_prop_map_put_ = {
		"Description": ((13, LCID, 4, 0),()),
		"Manufacturer": ((17, LCID, 4, 0),()),
		"Name": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICockpitParams(DispatchBaseClass):
	'ICockpitParams Interface'
	CLSID = IID('{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')
	coclass_clsid = IID('{50A5CCB1-6509-462A-8A81-B9A11DA1C4DA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"CockpitType": (11, 2, (3, 0), (), "CockpitType", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICockpitsParams(DispatchBaseClass):
	'ICockpitsParams Interface'
	CLSID = IID('{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}')
	coclass_clsid = IID('{EE92D21D-B6D8-4BD2-B481-EF2FE7C6E731}')

	# Result is of type ICockpitParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICockpitParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICockpitsService(DispatchBaseClass):
	'ICockpitsService Interface'
	CLSID = IID('{907E9130-6B06-4C32-91E2-453846193486}')
	coclass_clsid = IID('{D0DD241B-FDFC-4D57-ACD0-CBCB01611BF9}')

	# Result is of type ICockpitParams
	def AddCockpit(self, pICockpit=defaultNamedNotOptArg):
		'AddCockpit'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pICockpit
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddCockpit', '{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')
		return ret

	def DeleteCockpit(self, pICockpitParams=defaultNamedNotOptArg):
		'DeleteCockpit'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pICockpitParams
			)

	# Result is of type ICockpit
	def GetCockpit(self, pICockpitParams=defaultNamedNotOptArg):
		'GetCockpit'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICockpitParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCockpit', '{30EB7C61-BD42-4AAF-877E-DB6253066688}')
		return ret

	# Result is of type ICockpitsParams
	def GetCockpitList(self):
		'GetCockpitList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCockpitList', '{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ICockpitsParams
	def GetTemplateCockpitList(self):
		'GetTemplateCockpitList'
		ret = self._oleobj_.InvokeTypes(17, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetTemplateCockpitList', '{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}')
		return ret

	# Result is of type ICockpitsParams
	def GetUserCockpitList(self):
		'GetUserCockpitList'
		ret = self._oleobj_.InvokeTypes(16, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetUserCockpitList', '{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}')
		return ret

	def PublishCockpit(self, pICockpit=defaultNamedNotOptArg):
		'PublishCockpit'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((9, 1),),pICockpit
			)

	def UpdateCockpit(self, pICockpit=defaultNamedNotOptArg):
		'UpdateCockpit'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pICockpit
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IColumnPreferences(DispatchBaseClass):
	'IColumnPreferences Interface'
	CLSID = IID('{E498C4B2-E919-48EA-B512-79DE65B1F5CE}')
	coclass_clsid = IID('{5E97458D-A97E-4369-B747-9AFD1A04A0D9}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Column": (13, 2, (8, 0), (), "Column", None),
		"EditableInExpanded": (20, 2, (3, 0), (), "EditableInExpanded", None),
		"EditableInForm": (17, 2, (3, 0), (), "EditableInForm", None),
		"ExpandedIndex": (19, 2, (3, 0), (), "ExpandedIndex", None),
		"FormID": (11, 2, (8, 0), (), "FormID", None),
		"ItemNumber": (12, 2, (8, 0), (), "ItemNumber", None),
		"TabsLayout": (16, 2, (3, 0), (), "TabsLayout", None),
		"User": (21, 2, (3, 0), (), "User", None),
		"VisibleInExpanded": (18, 2, (3, 0), (), "VisibleInExpanded", None),
		"VisibleInForm": (15, 2, (3, 0), (), "VisibleInForm", None),
		"Width": (14, 2, (3, 0), (), "Width", None),
	}
	_prop_map_put_ = {
		"Column": ((13, LCID, 4, 0),()),
		"EditableInExpanded": ((20, LCID, 4, 0),()),
		"EditableInForm": ((17, LCID, 4, 0),()),
		"ExpandedIndex": ((19, LCID, 4, 0),()),
		"FormID": ((11, LCID, 4, 0),()),
		"ItemNumber": ((12, LCID, 4, 0),()),
		"TabsLayout": ((16, LCID, 4, 0),()),
		"User": ((21, LCID, 4, 0),()),
		"VisibleInExpanded": ((18, LCID, 4, 0),()),
		"VisibleInForm": ((15, LCID, 4, 0),()),
		"Width": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IColumnsPreferences(DispatchBaseClass):
	'IColumnsPreferences Interface'
	CLSID = IID('{5079035B-D0E5-4D0E-AFB1-6CB1FBAB11AE}')
	coclass_clsid = IID('{6751B54D-0896-4E23-9511-D4BE79AB78B4}')

	# Result is of type IColumnPreferences
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{E498C4B2-E919-48EA-B512-79DE65B1F5CE}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IColumnPreferences
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{E498C4B2-E919-48EA-B512-79DE65B1F5CE}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{E498C4B2-E919-48EA-B512-79DE65B1F5CE}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{E498C4B2-E919-48EA-B512-79DE65B1F5CE}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IColumnsPreferencesParams(DispatchBaseClass):
	'IColumnsPreferencesParams Interface'
	CLSID = IID('{3D83A354-89D4-46AF-841A-D659A0C2678E}')
	coclass_clsid = IID('{FD65E5A4-2232-452B-8541-5BC1EC3FF9C6}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"FormID": (12, 2, (8, 0), (), "FormID", None),
		"User": (11, 2, (3, 0), (), "User", None),
	}
	_prop_map_put_ = {
		"FormID": ((12, LCID, 4, 0),()),
		"User": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICommand(DispatchBaseClass):
	'ICommand Interface'
	CLSID = IID('{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}')
	coclass_clsid = IID('{15BD344C-48ED-4A6A-8A31-AFBD7A2ED57B}')

	def Execute(self):
		'method Execute'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	_prop_map_get_ = {
		"Name": (1, 2, (8, 0), (), "Name", None),
		# Method 'Parameters' returns object of type 'ICommandParams'
		"Parameters": (2, 2, (9, 0), (), "Parameters", '{93CF87D1-95CB-459C-A906-729819461CA1}'),
	}
	_prop_map_put_ = {
		"Name": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICommandParam(DispatchBaseClass):
	'ICommandParam Interface'
	CLSID = IID('{8CA91808-D098-4416-8368-E426484BA8DB}')
	coclass_clsid = IID('{13CC4089-F2FA-4B28-9BD9-75F6DC0E44B3}')

	_prop_map_get_ = {
		"Direction": (4, 2, (3, 0), (), "Direction", None),
		"Name": (1, 2, (8, 0), (), "Name", None),
		"Type": (3, 2, (3, 0), (), "Type", None),
		"Value": (2, 2, (12, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Value": ((2, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(2, 2, (12, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICommandParams(DispatchBaseClass):
	'ICommandParams Interface'
	CLSID = IID('{93CF87D1-95CB-459C-A906-729819461CA1}')
	coclass_clsid = IID('{9C536750-5FC9-45DF-AF6E-62DB9ACCAEA8}')

	# Result is of type ICommandParam
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{8CA91808-D098-4416-8368-E426484BA8DB}')
		return ret

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{8CA91808-D098-4416-8368-E426484BA8DB}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{8CA91808-D098-4416-8368-E426484BA8DB}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICommissionGroups(DispatchBaseClass):
	'ICommissionGroups Interface'
	CLSID = IID('{5E23BA23-D431-4212-BD7F-D5CB7E263494}')
	coclass_clsid = IID('{661FDCA5-1B1D-4EBA-8DC9-EB75F2E506AD}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lGroupCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lGroupCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CommissionGroupCode": (10, 2, (3, 0), (), "CommissionGroupCode", None),
		"CommissionGroupName": (11, 2, (8, 0), (), "CommissionGroupName", None),
		"CommissionPercentage": (12, 2, (5, 0), (), "CommissionPercentage", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CommissionGroupName": ((11, LCID, 4, 0),()),
		"CommissionPercentage": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICompany(DispatchBaseClass):
	'ICompany Interface'
	CLSID = IID('{3BA8DAED-5B33-4CE4-A4B8-B4308D86E524}')
	coclass_clsid = IID('{632F4591-AA62-4219-8FB6-22BCF5F60088}')

	def AuthenticateUser(self, bstrUserName=defaultNamedNotOptArg, bstrPassword=defaultNamedNotOptArg):
		'method AuthenticateUser'
		return self._oleobj_.InvokeTypes(51, LCID, 1, (3, 0), ((8, 1), (8, 1)),bstrUserName
			, bstrPassword)

	def ChangePassword(self, NewPassword=defaultNamedNotOptArg):
		'ChangePassword'
		return self._oleobj_.InvokeTypes(47, LCID, 1, (3, 0), ((8, 1),),NewPassword
			)

	def Connect(self):
		'Use this function for establishing connection to the database.'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Disconnect(self):
		'Use this function to dissconnect from the server'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (24, 0), (),)

	def EndTransaction(self, endType=defaultNamedNotOptArg):
		'method EndTransaction'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (24, 0), ((3, 0),),endType
			)

	def GetBusinessObject(self, Object=defaultNamedNotOptArg):
		'Get a new initialized business object.'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((3, 0),),Object
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBusinessObject', None)
		return ret

	def GetBusinessObjectFromXML(self, FileName=defaultNamedNotOptArg, Index=defaultNamedNotOptArg):
		'Get a saved business object.'
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), ((8, 1), (3, 1)),FileName
			, Index)
		if ret is not None:
			ret = Dispatch(ret, u'GetBusinessObjectFromXML', None)
		return ret

	def GetBusinessObjectXmlSchema(self, Object=defaultNamedNotOptArg):
		'method GetBusinessObjectXmlSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(29, LCID, 1, (8, 0), ((3, 1),),Object
			)

	def GetCompanyDate(self):
		'Get Company DATE'
		return self._oleobj_.InvokeTypes(54, LCID, 1, (7, 0), (),)

	# Result is of type IRecordset
	def GetCompanyList(self):
		'method GetCompanyList'
		ret = self._oleobj_.InvokeTypes(24, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCompanyList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type ICompanyService
	def GetCompanyService(self):
		'GetCompanyService'
		ret = self._oleobj_.InvokeTypes(46, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCompanyService', '{9D202A0D-3D49-47E0-AC0D-90333C553E85}')
		return ret

	def GetCompanyTime(self):
		'Get Company Time'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(53, LCID, 1, (8, 0), (),)

	def GetContextCookie(self):
		'method GetContextCookie'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(34, LCID, 1, (8, 0), (),)

	def GetLastError(self, errCode=pythoncom.Missing, errMsg=pythoncom.Missing):
		'Use this function for establishing connection to the database.'
		return self._ApplyTypes_(19, 1, (24, 0), ((16387, 2), (16392, 2)), u'GetLastError', None,errCode
			, errMsg)

	def GetLastErrorCode(self):
		'method GetLastErrorCode'
		return self._oleobj_.InvokeTypes(40, LCID, 1, (3, 0), (),)

	def GetLastErrorDescription(self):
		'method GetLastErrorDescription'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(39, LCID, 1, (8, 0), (),)

	def GetNewObjectCode(self, ObjectCode=pythoncom.Missing):
		'method GetNewObjectCode'
		return self._ApplyTypes_(22, 1, (24, 0), ((16392, 2),), u'GetNewObjectCode', None,ObjectCode
			)

	def GetNewObjectKey(self):
		'method GetNewObjectKey'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(41, LCID, 1, (8, 0), (),)

	def GetNewObjectType(self):
		'method GetNewObjectType'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(52, LCID, 1, (8, 0), (),)

	# Result is of type IRecordset
	def GetRegisteredServersList(self):
		'method GetRegisteredServersList'
		ret = self._oleobj_.InvokeTypes(50, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetRegisteredServersList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	def GetXMLelementCount(self, FileName=defaultNamedNotOptArg):
		'method GetXMLelementCount'
		return self._oleobj_.InvokeTypes(26, LCID, 1, (3, 0), ((8, 1),),FileName
			)

	def GetXMLobjectType(self, FileName=defaultNamedNotOptArg, Index=defaultNamedNotOptArg):
		'method GetXMLobjectType'
		return self._oleobj_.InvokeTypes(25, LCID, 1, (3, 0), ((8, 1), (3, 1)),FileName
			, Index)

	def InvalidateCache(self, TableName=defaultNamedNotOptArg):
		'InvalidateCache'
		return self._oleobj_.InvokeTypes(48, LCID, 1, (3, 0), ((8, 1),),TableName
			)

	def IsDTCTransactionObjectSet(self):
		'IsDTCTransactionObjectSet'
		return self._oleobj_.InvokeTypes(45, LCID, 1, (11, 0), (),)

	def SetSboLoginContext(self, conStr=defaultNamedNotOptArg):
		'method SetSboLoginContext'
		return self._oleobj_.InvokeTypes(35, LCID, 1, (3, 0), ((8, 1),),conStr
			)

	def StartTransaction(self):
		'method StartTransaction'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), (),)

	_prop_map_get_ = {
		"AddonIdentifier": (37, 2, (8, 0), (), "AddonIdentifier", None),
		"AttachMentPath": (13, 2, (8, 0), (), "AttachMentPath", None),
		"BitMapPath": (8, 2, (8, 0), (), "BitMapPath", None),
		"CompanyDB": (4, 2, (8, 0), (), "CompanyDB", None),
		"CompanyName": (6, 2, (8, 0), (), "CompanyName", None),
		"Connected": (12, 2, (11, 0), (), "Connected", None),
		"DTCTransactionObject": (44, 2, (13, 0), (), "DTCTransactionObject", None),
		"DbPassword": (33, 2, (8, 0), (), "DbPassword", None),
		"DbServerType": (36, 2, (3, 0), (), "DbServerType", None),
		"DbUserName": (32, 2, (8, 0), (), "DbUserName", None),
		"ExcelDocsPath": (9, 2, (8, 0), (), "ExcelDocsPath", None),
		"InTransaction": (31, 2, (11, 0), (), "InTransaction", None),
		"LicenseServer": (38, 2, (8, 0), (), "LicenseServer", None),
		"MinimalSupportedVersion": (43, 2, (3, 0), (), "MinimalSupportedVersion", None),
		"Password": (11, 2, (8, 0), (), "Password", None),
		"Server": (2, 2, (8, 0), (), "Server", None),
		"UseTrusted": (23, 2, (11, 0), (), "UseTrusted", None),
		"UserName": (10, 2, (8, 0), (), "UserName", None),
		"UserSignature": (5, 2, (3, 0), (), "UserSignature", None),
		# Method 'UserTables' returns object of type 'IUserTables'
		"UserTables": (27, 2, (9, 0), (), "UserTables", '{625162C1-3894-460F-94EC-72D6AFEA34D2}'),
		"Version": (42, 2, (3, 0), (), "Version", None),
		"WordDocsPath": (7, 2, (8, 0), (), "WordDocsPath", None),
		"XMLAsString": (28, 2, (11, 0), (), "XMLAsString", None),
		"XmlExportType": (30, 2, (3, 0), (), "XmlExportType", None),
		"language": (18, 2, (3, 0), (), "language", None),
	}
	_prop_map_put_ = {
		"AddonIdentifier": ((37, LCID, 4, 0),()),
		"Application": ((49, LCID, 4, 0),()),
		"CompanyDB": ((4, LCID, 4, 0),()),
		"DTCTransactionObject": ((44, LCID, 4, 0),()),
		"DbPassword": ((33, LCID, 4, 0),()),
		"DbServerType": ((36, LCID, 4, 0),()),
		"DbUserName": ((32, LCID, 4, 0),()),
		"LicenseServer": ((38, LCID, 4, 0),()),
		"Password": ((11, LCID, 4, 0),()),
		"Server": ((2, LCID, 4, 0),()),
		"UseTrusted": ((23, LCID, 4, 0),()),
		"UserName": ((10, LCID, 4, 0),()),
		"XMLAsString": ((28, LCID, 4, 0),()),
		"XmlExportType": ((30, LCID, 4, 0),()),
		"language": ((18, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICompanyInfo(DispatchBaseClass):
	'ICompanyInfo Interface'
	CLSID = IID('{97F84FDF-0E1F-4C2A-9FC2-B779411EC1EB}')
	coclass_clsid = IID('{930EBAD5-80E3-46B6-9DCB-BB6F73541C5D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AutoCreateCustomerEqCard": (34, 2, (3, 0), (), "AutoCreateCustomerEqCard", None),
		"AutoSRICreationOnReceipt": (23, 2, (3, 0), (), "AutoSRICreationOnReceipt", None),
		"BISRBankAccount": (18, 2, (8, 0), (), "BISRBankAccount", None),
		"BISRBankActKey": (15, 2, (3, 0), (), "BISRBankActKey", None),
		"BISRBankCountry": (16, 2, (8, 0), (), "BISRBankCountry", None),
		"BISRBankNo": (17, 2, (8, 0), (), "BISRBankNo", None),
		"BISRBranch": (19, 2, (8, 0), (), "BISRBranch", None),
		"BaseDateForExchangeRate": (14, 2, (3, 0), (), "BaseDateForExchangeRate", None),
		"BlockStockNegativeQuantity": (33, 2, (3, 0), (), "BlockStockNegativeQuantity", None),
		"CompanyName": (38, 2, (8, 0), (), "CompanyName", None),
		"DataOwnershipIndication": (28, 2, (3, 0), (), "DataOwnershipIndication", None),
		"DefaultDaysForOrdCanc": (25, 2, (3, 0), (), "DefaultDaysForOrdCanc", None),
		"DefaultStampTax": (31, 2, (8, 0), (), "DefaultStampTax", None),
		"DisplayTransactionsByDflt": (30, 2, (3, 0), (), "DisplayTransactionsByDflt", None),
		"EnableAccountSegmentation": (12, 2, (3, 0), (), "EnableAccountSegmentation", None),
		"EnableBillOfExchange": (13, 2, (3, 0), (), "EnableBillOfExchange", None),
		"EnableCheckQuantityInRDR": (21, 2, (3, 0), (), "EnableCheckQuantityInRDR", None),
		"EnableExpensesManagement": (11, 2, (3, 0), (), "EnableExpensesManagement", None),
		"EnableStockRelNoCostPrice": (36, 2, (3, 0), (), "EnableStockRelNoCostPrice", None),
		"EnableTransactionNotification": (41, 2, (3, 0), (), "EnableTransactionNotification", None),
		"GroupLinesInVATCalculation": (39, 2, (3, 0), (), "GroupLinesInVATCalculation", None),
		"IEPSPayer": (24, 2, (3, 0), (), "IEPSPayer", None),
		"MaxNumberOfDocumentsInPmt": (35, 2, (3, 0), (), "MaxNumberOfDocumentsInPmt", None),
		"MaxRecordsInChooseFromList": (20, 2, (3, 0), (), "MaxRecordsInChooseFromList", None),
		"MinimumAmountForAnnualList": (32, 2, (5, 0), (), "MinimumAmountForAnnualList", None),
		"MinimumAmountForAppndixOP": (29, 2, (5, 0), (), "MinimumAmountForAppndixOP", None),
		"MinimumBaseAmountPerDoc": (27, 2, (5, 0), (), "MinimumBaseAmountPerDoc", None),
		"PercentOfTotalAcquisition": (26, 2, (5, 0), (), "PercentOfTotalAcquisition", None),
		"SRIManagementSystem": (22, 2, (3, 0), (), "SRIManagementSystem", None),
		"TaxCalculationSystem": (40, 2, (3, 0), (), "TaxCalculationSystem", None),
		"Version": (37, 2, (3, 0), (), "Version", None),
	}
	_prop_map_put_ = {
		"AutoCreateCustomerEqCard": ((34, LCID, 4, 0),()),
		"AutoSRICreationOnReceipt": ((23, LCID, 4, 0),()),
		"BISRBankActKey": ((15, LCID, 4, 0),()),
		"BaseDateForExchangeRate": ((14, LCID, 4, 0),()),
		"BlockStockNegativeQuantity": ((33, LCID, 4, 0),()),
		"DataOwnershipIndication": ((28, LCID, 4, 0),()),
		"DefaultDaysForOrdCanc": ((25, LCID, 4, 0),()),
		"DefaultStampTax": ((31, LCID, 4, 0),()),
		"DisplayTransactionsByDflt": ((30, LCID, 4, 0),()),
		"EnableAccountSegmentation": ((12, LCID, 4, 0),()),
		"EnableBillOfExchange": ((13, LCID, 4, 0),()),
		"EnableCheckQuantityInRDR": ((21, LCID, 4, 0),()),
		"EnableExpensesManagement": ((11, LCID, 4, 0),()),
		"EnableStockRelNoCostPrice": ((36, LCID, 4, 0),()),
		"EnableTransactionNotification": ((41, LCID, 4, 0),()),
		"IEPSPayer": ((24, LCID, 4, 0),()),
		"MaxNumberOfDocumentsInPmt": ((35, LCID, 4, 0),()),
		"MaxRecordsInChooseFromList": ((20, LCID, 4, 0),()),
		"MinimumAmountForAnnualList": ((32, LCID, 4, 0),()),
		"MinimumAmountForAppndixOP": ((29, LCID, 4, 0),()),
		"MinimumBaseAmountPerDoc": ((27, LCID, 4, 0),()),
		"PercentOfTotalAcquisition": ((26, LCID, 4, 0),()),
		"SRIManagementSystem": ((22, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICompanyService(DispatchBaseClass):
	'ICompanyService Interface'
	CLSID = IID('{9D202A0D-3D49-47E0-AC0D-90333C553E85}')
	coclass_clsid = IID('{99074C83-3748-491D-AD31-7EDE65691225}')

	# Result is of type IPeriodCategoryParams
	def CreatePeriod(self, pIPeriodCategory=defaultNamedNotOptArg):
		'CreatePeriod'
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), ((9, 1),),pIPeriodCategory
			)
		if ret is not None:
			ret = Dispatch(ret, u'CreatePeriod', '{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')
		return ret

	# Result is of type IPeriodCategoryParams
	def CreatePeriodWithFinanceParams(self, pIPeriodCategory=defaultNamedNotOptArg, pIFinancePeriodParams=defaultNamedNotOptArg):
		'CreatePeriodWithFinanceParams'
		ret = self._oleobj_.InvokeTypes(22, LCID, 1, (9, 0), ((9, 1), (9, 1)),pIPeriodCategory
			, pIFinancePeriodParams)
		if ret is not None:
			ret = Dispatch(ret, u'CreatePeriodWithFinanceParams', '{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')
		return ret

	# Result is of type IAdminInfo
	def GetAdminInfo(self):
		'GetAdminInfo'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetAdminInfo', '{4583DECC-E80D-46AE-B3C0-308FC33C58E9}')
		return ret

	# Result is of type IBlob
	def GetBlob(self, pIBlobParams=defaultNamedNotOptArg):
		'GetBlob'
		ret = self._oleobj_.InvokeTypes(24, LCID, 1, (9, 0), ((9, 1),),pIBlobParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBlob', '{E7838784-BDDC-4EC2-A812-C96B19D169C5}')
		return ret

	def GetBusinessService(self, enumServiceType=defaultNamedNotOptArg):
		'GetBusinessService'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((3, 1),),enumServiceType
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBusinessService', None)
		return ret

	# Result is of type ICompanyInfo
	def GetCompanyInfo(self):
		'GetCompanyInfo'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCompanyInfo', '{97F84FDF-0E1F-4C2A-9FC2-B779411EC1EB}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IFeatureStatusCollection
	def GetFeaturesStatus(self):
		'GetFeaturesStatus'
		ret = self._oleobj_.InvokeTypes(23, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetFeaturesStatus', '{CB4596BC-49AF-40FF-AF45-DC92A9C75C97}')
		return ret

	# Result is of type IFinancePeriod
	def GetFinancePeriod(self, pIFinancePeriodParams=defaultNamedNotOptArg):
		'GetFinancePeriod'
		ret = self._oleobj_.InvokeTypes(20, LCID, 1, (9, 0), ((9, 1),),pIFinancePeriodParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetFinancePeriod', '{39DAE3AB-708D-4123-BC50-CC57F05D734E}')
		return ret

	# Result is of type IFinancePeriods
	def GetFinancePeriods(self, pIPeriodCategoryParams=defaultNamedNotOptArg):
		'GetFinancePeriods'
		ret = self._oleobj_.InvokeTypes(19, LCID, 1, (9, 0), ((9, 1),),pIPeriodCategoryParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetFinancePeriods', '{4CA3F302-7EC4-4514-9F07-CB688C56A2ED}')
		return ret

	# Result is of type IGeneralService
	def GetGeneralService(self, sServiceCode=defaultNamedNotOptArg):
		'GetGeneralService'
		ret = self._oleobj_.InvokeTypes(28, LCID, 1, (9, 0), ((8, 1),),sServiceCode
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetGeneralService', '{31DE5655-438F-420E-83D0-016C88203706}')
		return ret

	# Result is of type IPathAdmin
	def GetPathAdmin(self):
		'GetPathAdmin'
		ret = self._oleobj_.InvokeTypes(26, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetPathAdmin', '{029D7691-D339-4790-9D8A-652C86A30458}')
		return ret

	# Result is of type IPeriodCategory
	def GetPeriod(self, pIPeriodCategoryParams=defaultNamedNotOptArg):
		'GetPeriod'
		ret = self._oleobj_.InvokeTypes(17, LCID, 1, (9, 0), ((9, 1),),pIPeriodCategoryParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetPeriod', '{1C764D4F-63DA-46FE-BD81-56548EEDB2F6}')
		return ret

	# Result is of type IPeriodCategoryParamsCollection
	def GetPeriods(self):
		'GetPeriods'
		ret = self._oleobj_.InvokeTypes(16, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetPeriods', '{A31EC6FB-9B3A-439E-828D-C95CB0646555}')
		return ret

	def GetServiceMetaData(self, ServiceCode=defaultNamedNotOptArg):
		'GetServiceMetaData'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(33, LCID, 1, (8, 0), ((3, 1),),ServiceCode
			)

	def IsUserLicensed(self, bstrUserName=defaultNamedNotOptArg, bstrLicType=defaultNamedNotOptArg):
		'IsUserLicensed'
		return self._oleobj_.InvokeTypes(32, LCID, 1, (11, 0), ((8, 1), (8, 1)),bstrUserName
			, bstrLicType)

	def LoadBlobFromFile(self, pIBlobParams=defaultNamedNotOptArg):
		'LoadBlobFromFile'
		return self._oleobj_.InvokeTypes(30, LCID, 1, (24, 0), ((9, 1),),pIBlobParams
			)

	# Result is of type IRoundedData
	def RoundDecimal(self, pIDecimalData=defaultNamedNotOptArg):
		'RoundDecimal'
		ret = self._oleobj_.InvokeTypes(34, LCID, 1, (9, 0), ((9, 1),),pIDecimalData
			)
		if ret is not None:
			ret = Dispatch(ret, u'RoundDecimal', '{EF86275D-924A-4AC9-9461-E9AAF80894B6}')
		return ret

	def SaveBlobToFile(self, pIBlobParams=defaultNamedNotOptArg):
		'SaveBlobToFile'
		return self._oleobj_.InvokeTypes(31, LCID, 1, (24, 0), ((9, 1),),pIBlobParams
			)

	def SetBlob(self, pIBlobParams=defaultNamedNotOptArg, pIBlob=defaultNamedNotOptArg):
		'SetBlob'
		return self._oleobj_.InvokeTypes(25, LCID, 1, (24, 0), ((9, 1), (9, 1)),pIBlobParams
			, pIBlob)

	def UpdateAdminInfo(self, pIAdminInfo=defaultNamedNotOptArg):
		'UpdateAdminInfo'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((9, 1),),pIAdminInfo
			)

	def UpdateCompanyInfo(self, pICompanyInfo=defaultNamedNotOptArg):
		'UpdateCompanyInfo'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pICompanyInfo
			)

	def UpdateFinancePeriod(self, pIFinancePeriod=defaultNamedNotOptArg):
		'UpdateFinancePeriod'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (24, 0), ((9, 1),),pIFinancePeriod
			)

	def UpdatePathAdmin(self, pIPathAdmin=defaultNamedNotOptArg):
		'UpdatePathAdmin'
		return self._oleobj_.InvokeTypes(27, LCID, 1, (24, 0), ((9, 1),),pIPathAdmin
			)

	def UpdatePeriod(self, pIPeriodCategory=defaultNamedNotOptArg):
		'UpdatePeriod'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (24, 0), ((9, 1),),pIPeriodCategory
			)

	def UpdateUserLicense(self, pIUserLicenseParams=defaultNamedNotOptArg):
		'UpdateUserLicense'
		return self._oleobj_.InvokeTypes(29, LCID, 1, (24, 0), ((9, 1),),pIUserLicenseParams
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IContactEmployees(DispatchBaseClass):
	'IContactEmployees Interface'
	CLSID = IID('{52C8673B-CA79-4476-9F2E-28109AE17545}')
	coclass_clsid = IID('{22DCA799-2F7B-4B31-ABB6-74F3C07CB367}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(26, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Active": (27, 2, (3, 0), (), "Active", None),
		"Address": (3, 2, (8, 0), (), "Address", None),
		"CardCode": (23, 2, (8, 0), (), "CardCode", None),
		"CityOfBirth": (25, 2, (8, 0), (), "CityOfBirth", None),
		"Count": (13, 2, (3, 0), (), "Count", None),
		"DateOfBirth": (20, 2, (7, 0), (), "DateOfBirth", None),
		"E_Mail": (8, 2, (8, 0), (), "E_Mail", None),
		"Fax": (7, 2, (8, 0), (), "Fax", None),
		"FirstName": (28, 2, (8, 0), (), "FirstName", None),
		"Gender": (21, 2, (3, 0), (), "Gender", None),
		"InternalCode": (18, 2, (3, 0), (), "InternalCode", None),
		"LastName": (30, 2, (8, 0), (), "LastName", None),
		"MiddleName": (29, 2, (8, 0), (), "MiddleName", None),
		"MobilePhone": (6, 2, (8, 0), (), "MobilePhone", None),
		"Name": (16, 2, (8, 0), (), "Name", None),
		"Pager": (9, 2, (8, 0), (), "Pager", None),
		"Password": (12, 2, (8, 0), (), "Password", None),
		"Phone1": (4, 2, (8, 0), (), "Phone1", None),
		"Phone2": (5, 2, (8, 0), (), "Phone2", None),
		"PlaceOfBirth": (19, 2, (8, 0), (), "PlaceOfBirth", None),
		"Position": (2, 2, (8, 0), (), "Position", None),
		"Profession": (22, 2, (8, 0), (), "Profession", None),
		"Remarks1": (10, 2, (8, 0), (), "Remarks1", None),
		"Remarks2": (11, 2, (8, 0), (), "Remarks2", None),
		"Title": (24, 2, (8, 0), (), "Title", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (17, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Active": ((27, LCID, 4, 0),()),
		"Address": ((3, LCID, 4, 0),()),
		"CityOfBirth": ((25, LCID, 4, 0),()),
		"DateOfBirth": ((20, LCID, 4, 0),()),
		"E_Mail": ((8, LCID, 4, 0),()),
		"Fax": ((7, LCID, 4, 0),()),
		"FirstName": ((28, LCID, 4, 0),()),
		"Gender": ((21, LCID, 4, 0),()),
		"LastName": ((30, LCID, 4, 0),()),
		"MiddleName": ((29, LCID, 4, 0),()),
		"MobilePhone": ((6, LCID, 4, 0),()),
		"Name": ((16, LCID, 4, 0),()),
		"Pager": ((9, LCID, 4, 0),()),
		"Password": ((12, LCID, 4, 0),()),
		"Phone1": ((4, LCID, 4, 0),()),
		"Phone2": ((5, LCID, 4, 0),()),
		"PlaceOfBirth": ((19, LCID, 4, 0),()),
		"Position": ((2, LCID, 4, 0),()),
		"Profession": ((22, LCID, 4, 0),()),
		"Remarks1": ((10, LCID, 4, 0),()),
		"Remarks2": ((11, LCID, 4, 0),()),
		"Title": ((24, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(13, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IContacts(DispatchBaseClass):
	'IContacts Interface'
	CLSID = IID('{96D7BBA9-27E7-4893-BC78-CC4313BE0DD1}')
	coclass_clsid = IID('{161C44B9-9DAC-4D31-AB92-EED776B8C745}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(52, LCID, 1, (8, 0), (),)

	def GetByKey(self, ContactCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((3, 0),),ContactCode
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(53, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(4, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Activity": (24, 2, (3, 0), (), "Activity", None),
		"ActivityType": (25, 2, (3, 0), (), "ActivityType", None),
		"AttachmentEntry": (55, 2, (3, 0), (), "AttachmentEntry", None),
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (19, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (20, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (5, 2, (8, 0), (), "CardCode", None),
		"City": (38, 2, (8, 0), (), "City", None),
		"CloseDate": (11, 2, (7, 0), (), "CloseDate", None),
		"Closed": (10, 2, (3, 0), (), "Closed", None),
		"ContactCode": (21, 2, (3, 0), (), "ContactCode", None),
		"ContactDate": (7, 2, (7, 0), (), "ContactDate", None),
		"ContactPersonCode": (32, 2, (3, 0), (), "ContactPersonCode", None),
		"ContactTime": (8, 2, (7, 0), (), "ContactTime", None),
		"Country": (47, 2, (8, 0), (), "Country", None),
		"Details": (23, 2, (8, 0), (), "Details", None),
		"DocEntry": (18, 2, (8, 0), (), "DocEntry", None),
		"DocNum": (17, 2, (8, 0), (), "DocNum", None),
		"DocType": (16, 2, (3, 0), (), "DocType", None),
		"DocTypeEx": (51, 2, (8, 0), (), "DocTypeEx", None),
		"Duration": (29, 2, (5, 0), (), "Duration", None),
		"DurationType": (30, 2, (3, 0), (), "DurationType", None),
		"EndDuedate": (50, 2, (7, 0), (), "EndDuedate", None),
		"EndTime": (28, 2, (7, 0), (), "EndTime", None),
		"Fax": (14, 2, (8, 0), (), "Fax", None),
		"HandledBy": (33, 2, (3, 0), (), "HandledBy", None),
		"Inactiveflag": (44, 2, (3, 0), (), "Inactiveflag", None),
		"Location": (26, 2, (3, 0), (), "Location", None),
		"Notes": (6, 2, (8, 0), (), "Notes", None),
		"ParentobjectId": (41, 2, (3, 0), (), "ParentobjectId", None),
		"Parentobjecttype": (42, 2, (8, 0), (), "Parentobjecttype", None),
		"Personalflag": (39, 2, (3, 0), (), "Personalflag", None),
		"Phone": (13, 2, (8, 0), (), "Phone", None),
		"PreviousActivity": (46, 2, (3, 0), (), "PreviousActivity", None),
		"Priority": (22, 2, (3, 0), (), "Priority", None),
		"Recontact": (9, 2, (7, 0), (), "Recontact", None),
		"Reminder": (35, 2, (3, 0), (), "Reminder", None),
		"ReminderPeriod": (36, 2, (5, 0), (), "ReminderPeriod", None),
		"ReminderType": (37, 2, (3, 0), (), "ReminderType", None),
		"Room": (43, 2, (8, 0), (), "Room", None),
		"SalesEmployee": (31, 2, (3, 0), (), "SalesEmployee", None),
		"StartDate": (56, 2, (7, 0), (), "StartDate", None),
		"StartTime": (27, 2, (7, 0), (), "StartTime", None),
		"State": (45, 2, (8, 0), (), "State", None),
		"Status": (48, 2, (3, 0), (), "Status", None),
		"Street": (40, 2, (8, 0), (), "Street", None),
		"Subject": (15, 2, (8, 0), (), "Subject", None),
		"Tentativeflag": (49, 2, (3, 0), (), "Tentativeflag", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (34, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Activity": ((24, LCID, 4, 0),()),
		"ActivityType": ((25, LCID, 4, 0),()),
		"AttachmentEntry": ((55, LCID, 4, 0),()),
		"CardCode": ((5, LCID, 4, 0),()),
		"City": ((38, LCID, 4, 0),()),
		"CloseDate": ((11, LCID, 4, 0),()),
		"Closed": ((10, LCID, 4, 0),()),
		"ContactDate": ((7, LCID, 4, 0),()),
		"ContactPersonCode": ((32, LCID, 4, 0),()),
		"ContactTime": ((8, LCID, 4, 0),()),
		"Country": ((47, LCID, 4, 0),()),
		"Details": ((23, LCID, 4, 0),()),
		"DocEntry": ((18, LCID, 4, 0),()),
		"DocType": ((16, LCID, 4, 0),()),
		"DocTypeEx": ((51, LCID, 4, 0),()),
		"Duration": ((29, LCID, 4, 0),()),
		"DurationType": ((30, LCID, 4, 0),()),
		"EndDuedate": ((50, LCID, 4, 0),()),
		"EndTime": ((28, LCID, 4, 0),()),
		"Fax": ((14, LCID, 4, 0),()),
		"HandledBy": ((33, LCID, 4, 0),()),
		"Inactiveflag": ((44, LCID, 4, 0),()),
		"Location": ((26, LCID, 4, 0),()),
		"Notes": ((6, LCID, 4, 0),()),
		"Personalflag": ((39, LCID, 4, 0),()),
		"Phone": ((13, LCID, 4, 0),()),
		"PreviousActivity": ((46, LCID, 4, 0),()),
		"Priority": ((22, LCID, 4, 0),()),
		"Recontact": ((9, LCID, 4, 0),()),
		"Reminder": ((35, LCID, 4, 0),()),
		"ReminderPeriod": ((36, LCID, 4, 0),()),
		"ReminderType": ((37, LCID, 4, 0),()),
		"Room": ((43, LCID, 4, 0),()),
		"SalesEmployee": ((31, LCID, 4, 0),()),
		"StartDate": ((56, LCID, 4, 0),()),
		"StartTime": ((27, LCID, 4, 0),()),
		"State": ((45, LCID, 4, 0),()),
		"Status": ((48, LCID, 4, 0),()),
		"Street": ((40, LCID, 4, 0),()),
		"Subject": ((15, LCID, 4, 0),()),
		"Tentativeflag": ((49, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IContractTemplates(DispatchBaseClass):
	'IContractTemplates Interface'
	CLSID = IID('{9EB0E81A-9442-4C9A-B096-93C6134E684D}')
	coclass_clsid = IID('{835F6104-3A36-4122-8AE8-C4E1D7B15453}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(46, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(50, LCID, 1, (8, 0), (),)

	def GetByKey(self, TemplateName=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((8, 1),),TemplateName
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(51, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AttachmentEntry": (52, 2, (3, 0), (), "AttachmentEntry", None),
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (41, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (45, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ContractType": (16, 2, (3, 0), (), "ContractType", None),
		"Description": (14, 2, (8, 0), (), "Description", None),
		"DurationOfCoverage": (11, 2, (3, 0), (), "DurationOfCoverage", None),
		"FridayEnabled": (21, 2, (3, 0), (), "FridayEnabled", None),
		"FridayEnd": (33, 2, (7, 0), (), "FridayEnd", None),
		"FridayStart": (32, 2, (7, 0), (), "FridayStart", None),
		"IncludeHolidays": (47, 2, (3, 0), (), "IncludeHolidays", None),
		"IncludeLabor": (39, 2, (3, 0), (), "IncludeLabor", None),
		"IncludeParts": (38, 2, (3, 0), (), "IncludeParts", None),
		"IncludeTravel": (40, 2, (3, 0), (), "IncludeTravel", None),
		"MondayEnabled": (17, 2, (3, 0), (), "MondayEnabled", None),
		"MondayEnd": (25, 2, (7, 0), (), "MondayEnd", None),
		"MondayStart": (24, 2, (7, 0), (), "MondayStart", None),
		"Remarks": (43, 2, (8, 0), (), "Remarks", None),
		"RemindBeforeRenewal": (9, 2, (3, 0), (), "RemindBeforeRenewal", None),
		"RemindUnit": (10, 2, (3, 0), (), "RemindUnit", None),
		"ResolutionTime": (49, 2, (3, 0), (), "ResolutionTime", None),
		"ResolutionUnit": (13, 2, (3, 0), (), "ResolutionUnit", None),
		"ResponseUnit": (48, 2, (3, 0), (), "ResponseUnit", None),
		"ResponseValue": (12, 2, (3, 0), (), "ResponseValue", None),
		"SaturdayEnabled": (22, 2, (3, 0), (), "SaturdayEnabled", None),
		"SaturdayEnd": (35, 2, (7, 0), (), "SaturdayEnd", None),
		"SaturdayStart": (34, 2, (7, 0), (), "SaturdayStart", None),
		"SundayEnabled": (23, 2, (3, 0), (), "SundayEnabled", None),
		"SundayEnd": (37, 2, (7, 0), (), "SundayEnd", None),
		"SundayStart": (36, 2, (7, 0), (), "SundayStart", None),
		"TemplateIsDeleted": (7, 2, (3, 0), (), "TemplateIsDeleted", None),
		"TemplateIsRenewal": (8, 2, (3, 0), (), "TemplateIsRenewal", None),
		"TemplateName": (6, 2, (8, 0), (), "TemplateName", None),
		"ThursdayEnabled": (20, 2, (3, 0), (), "ThursdayEnabled", None),
		"ThursdayEnd": (31, 2, (7, 0), (), "ThursdayEnd", None),
		"ThursdayStart": (30, 2, (7, 0), (), "ThursdayStart", None),
		"TuesdayEnabled": (18, 2, (3, 0), (), "TuesdayEnabled", None),
		"TuesdayEnd": (27, 2, (7, 0), (), "TuesdayEnd", None),
		"TuesdayStart": (26, 2, (7, 0), (), "TuesdayStart", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (44, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WednesdayEnabled": (19, 2, (3, 0), (), "WednesdayEnabled", None),
		"WednesdayEnd": (29, 2, (7, 0), (), "WednesdayEnd", None),
		"WednesdayStart": (28, 2, (7, 0), (), "WednesdayStart", None),
	}
	_prop_map_put_ = {
		"AttachmentEntry": ((52, LCID, 4, 0),()),
		"ContractType": ((16, LCID, 4, 0),()),
		"Description": ((14, LCID, 4, 0),()),
		"DurationOfCoverage": ((11, LCID, 4, 0),()),
		"FridayEnabled": ((21, LCID, 4, 0),()),
		"FridayEnd": ((33, LCID, 4, 0),()),
		"FridayStart": ((32, LCID, 4, 0),()),
		"IncludeHolidays": ((47, LCID, 4, 0),()),
		"IncludeLabor": ((39, LCID, 4, 0),()),
		"IncludeParts": ((38, LCID, 4, 0),()),
		"IncludeTravel": ((40, LCID, 4, 0),()),
		"MondayEnabled": ((17, LCID, 4, 0),()),
		"MondayEnd": ((25, LCID, 4, 0),()),
		"MondayStart": ((24, LCID, 4, 0),()),
		"Remarks": ((43, LCID, 4, 0),()),
		"RemindBeforeRenewal": ((9, LCID, 4, 0),()),
		"RemindUnit": ((10, LCID, 4, 0),()),
		"ResolutionTime": ((49, LCID, 4, 0),()),
		"ResolutionUnit": ((13, LCID, 4, 0),()),
		"ResponseUnit": ((48, LCID, 4, 0),()),
		"ResponseValue": ((12, LCID, 4, 0),()),
		"SaturdayEnabled": ((22, LCID, 4, 0),()),
		"SaturdayEnd": ((35, LCID, 4, 0),()),
		"SaturdayStart": ((34, LCID, 4, 0),()),
		"SundayEnabled": ((23, LCID, 4, 0),()),
		"SundayEnd": ((37, LCID, 4, 0),()),
		"SundayStart": ((36, LCID, 4, 0),()),
		"TemplateIsDeleted": ((7, LCID, 4, 0),()),
		"TemplateIsRenewal": ((8, LCID, 4, 0),()),
		"TemplateName": ((6, LCID, 4, 0),()),
		"ThursdayEnabled": ((20, LCID, 4, 0),()),
		"ThursdayEnd": ((31, LCID, 4, 0),()),
		"ThursdayStart": ((30, LCID, 4, 0),()),
		"TuesdayEnabled": ((18, LCID, 4, 0),()),
		"TuesdayEnd": ((27, LCID, 4, 0),()),
		"TuesdayStart": ((26, LCID, 4, 0),()),
		"WednesdayEnabled": ((19, LCID, 4, 0),()),
		"WednesdayEnd": ((29, LCID, 4, 0),()),
		"WednesdayStart": ((28, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICostCenterType(DispatchBaseClass):
	'ICostCenterType Interface'
	CLSID = IID('{B7334829-8658-48D1-9FF6-056E90AEB07D}')
	coclass_clsid = IID('{AECE9766-707E-4C6C-86BA-FD9ABE43B67A}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CostCenterTypeCode": (10, 2, (8, 0), (), "CostCenterTypeCode", None),
		"CostCenterTypeName": (11, 2, (8, 0), (), "CostCenterTypeName", None),
	}
	_prop_map_put_ = {
		"CostCenterTypeCode": ((10, LCID, 4, 0),()),
		"CostCenterTypeName": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICostCenterTypeParams(DispatchBaseClass):
	'ICostCenterTypeParams Interface'
	CLSID = IID('{C8D6687E-6A96-4458-AF54-B052F20C26B3}')
	coclass_clsid = IID('{C81FD047-A4A2-4EF6-9538-65D9F381CB03}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CostCenterTypeCode": (10, 2, (8, 0), (), "CostCenterTypeCode", None),
	}
	_prop_map_put_ = {
		"CostCenterTypeCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICostCenterTypes(DispatchBaseClass):
	'ICostCenterTypes Interface'
	CLSID = IID('{FACA7A4B-46DF-4875-8591-A5A0C3D9761F}')
	coclass_clsid = IID('{9B732959-2A6C-46D0-B082-DF0FD03D7EE0}')

	# Result is of type ICostCenterType
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{B7334829-8658-48D1-9FF6-056E90AEB07D}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICostCenterType
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{B7334829-8658-48D1-9FF6-056E90AEB07D}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{B7334829-8658-48D1-9FF6-056E90AEB07D}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{B7334829-8658-48D1-9FF6-056E90AEB07D}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICostCenterTypesParams(DispatchBaseClass):
	'ICostCenterTypesParams Interface'
	CLSID = IID('{C09C1DAE-49E3-43CF-AA54-D2EDDCAAE9DB}')
	coclass_clsid = IID('{F018FAC9-48EF-435B-9D4A-0EFE1337EABB}')

	# Result is of type ICostCenterTypeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{C8D6687E-6A96-4458-AF54-B052F20C26B3}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICostCenterTypeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{C8D6687E-6A96-4458-AF54-B052F20C26B3}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{C8D6687E-6A96-4458-AF54-B052F20C26B3}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{C8D6687E-6A96-4458-AF54-B052F20C26B3}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICostCenterTypesService(DispatchBaseClass):
	'ICostCenterTypesService Interface'
	CLSID = IID('{687B84CE-D196-49C9-A617-C6FC57BB2204}')
	coclass_clsid = IID('{E00CB643-DBC7-492C-8D65-FE84540E425A}')

	# Result is of type ICostCenterTypeParams
	def AddCostCenterType(self, pICostCenterType=defaultNamedNotOptArg):
		'AddCostCenterType'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICostCenterType
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddCostCenterType', '{C8D6687E-6A96-4458-AF54-B052F20C26B3}')
		return ret

	def DeleteCostCenterType(self, pICostCenterTypeParams=defaultNamedNotOptArg):
		'DeleteCostCenterType'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pICostCenterTypeParams
			)

	# Result is of type ICostCenterType
	def GetCostCenterType(self, pICostCenterTypeParams=defaultNamedNotOptArg):
		'GetCostCenterType'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pICostCenterTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCostCenterType', '{B7334829-8658-48D1-9FF6-056E90AEB07D}')
		return ret

	# Result is of type ICostCenterTypesParams
	def GetCostCenterTypeList(self):
		'GetCostCenterTypeList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCostCenterTypeList', '{C09C1DAE-49E3-43CF-AA54-D2EDDCAAE9DB}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateCostCenterType(self, pICostCenterType=defaultNamedNotOptArg):
		'UpdateCostCenterType'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pICostCenterType
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICountriesParams(DispatchBaseClass):
	'ICountriesParams Interface'
	CLSID = IID('{420B8379-83B3-4AE9-B7B8-4DDF73D3085D}')
	coclass_clsid = IID('{A9030345-42BE-4206-8236-DF97C0B60529}')

	# Result is of type ICountryParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICountryParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICountriesService(DispatchBaseClass):
	'ICountriesService Interface'
	CLSID = IID('{12980E2B-036E-4D5D-90F9-44383341DF63}')
	coclass_clsid = IID('{174DC159-9A9A-46AC-9A78-EAA35119F267}')

	# Result is of type ICountryParams
	def AddCountry(self, pICountry=defaultNamedNotOptArg):
		'AddCountry'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICountry
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddCountry', '{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')
		return ret

	def DeleteCountry(self, pICountryParams=defaultNamedNotOptArg):
		'DeleteCountry'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pICountryParams
			)

	# Result is of type ICountry
	def GetCountry(self, pICountryParams=defaultNamedNotOptArg):
		'GetCountry'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((9, 1),),pICountryParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCountry', '{8A1D0D45-C379-4714-87A6-F81EA6284EEB}')
		return ret

	# Result is of type ICountriesParams
	def GetCountryList(self):
		'GetCountryList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCountryList', '{420B8379-83B3-4AE9-B7B8-4DDF73D3085D}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateCountry(self, pICountry=defaultNamedNotOptArg):
		'UpdateCountry'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pICountry
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICountry(DispatchBaseClass):
	'ICountry Interface'
	CLSID = IID('{8A1D0D45-C379-4714-87A6-F81EA6284EEB}')
	coclass_clsid = IID('{C2920491-21F1-4CB6-B7FF-C638324F1234}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AddressFormat": (13, 2, (3, 0), (), "AddressFormat", None),
		"BankAccountDigits": (18, 2, (3, 0), (), "BankAccountDigits", None),
		"BankBranchDigits": (17, 2, (3, 0), (), "BankBranchDigits", None),
		"BankCodeDigits": (16, 2, (3, 0), (), "BankCodeDigits", None),
		"BankControlKeyDigits": (19, 2, (3, 0), (), "BankControlKeyDigits", None),
		"Blacklisted": (22, 2, (3, 0), (), "Blacklisted", None),
		"Code": (10, 2, (8, 0), (), "Code", None),
		"CodeForReports": (12, 2, (8, 0), (), "CodeForReports", None),
		"DomesticAccountValidation": (20, 2, (3, 0), (), "DomesticAccountValidation", None),
		"EU": (14, 2, (3, 0), (), "EU", None),
		"IbanValidation": (21, 2, (3, 0), (), "IbanValidation", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"NumberOfDigitsForTaxID": (15, 2, (3, 0), (), "NumberOfDigitsForTaxID", None),
		"UICCountryCode": (23, 2, (8, 0), (), "UICCountryCode", None),
	}
	_prop_map_put_ = {
		"AddressFormat": ((13, LCID, 4, 0),()),
		"BankAccountDigits": ((18, LCID, 4, 0),()),
		"BankBranchDigits": ((17, LCID, 4, 0),()),
		"BankCodeDigits": ((16, LCID, 4, 0),()),
		"BankControlKeyDigits": ((19, LCID, 4, 0),()),
		"Blacklisted": ((22, LCID, 4, 0),()),
		"Code": ((10, LCID, 4, 0),()),
		"CodeForReports": ((12, LCID, 4, 0),()),
		"DomesticAccountValidation": ((20, LCID, 4, 0),()),
		"EU": ((14, LCID, 4, 0),()),
		"IbanValidation": ((21, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"NumberOfDigitsForTaxID": ((15, LCID, 4, 0),()),
		"UICCountryCode": ((23, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICountryParams(DispatchBaseClass):
	'ICountryParams Interface'
	CLSID = IID('{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')
	coclass_clsid = IID('{EA66002F-549F-4B15-BD0E-7AB565D29B5F}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICreditCardPayments(DispatchBaseClass):
	'ICreditCardPayments Interface'
	CLSID = IID('{874D0559-C968-49F1-9562-E57E493A47AB}')
	coclass_clsid = IID('{EC857C0B-EFEB-43D5-92CF-8EFAC1D138F7}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),bstrCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"DueDateCode": (12, 2, (8, 0), (), "DueDateCode", None),
		"DueDateName": (13, 2, (8, 0), (), "DueDateName", None),
		"DueDatesType": (14, 2, (3, 0), (), "DueDatesType", None),
		"FromDay1": (17, 2, (3, 0), (), "FromDay1", None),
		"FromDay2": (21, 2, (3, 0), (), "FromDay2", None),
		"FromDay3": (25, 2, (3, 0), (), "FromDay3", None),
		"FromDay4": (29, 2, (3, 0), (), "FromDay4", None),
		"NoOfMonths1": (20, 2, (3, 0), (), "NoOfMonths1", None),
		"NoOfMonths2": (24, 2, (3, 0), (), "NoOfMonths2", None),
		"NoOfMonths3": (28, 2, (3, 0), (), "NoOfMonths3", None),
		"NoOfMonths4": (32, 2, (3, 0), (), "NoOfMonths4", None),
		"PaymentAfterDays": (15, 2, (3, 0), (), "PaymentAfterDays", None),
		"PaymentAfterMonths": (16, 2, (3, 0), (), "PaymentAfterMonths", None),
		"PaymentDay1": (19, 2, (3, 0), (), "PaymentDay1", None),
		"PaymentDay2": (23, 2, (3, 0), (), "PaymentDay2", None),
		"PaymentDay3": (27, 2, (3, 0), (), "PaymentDay3", None),
		"PaymentDay4": (31, 2, (3, 0), (), "PaymentDay4", None),
		"ToDay1": (18, 2, (3, 0), (), "ToDay1", None),
		"ToDay2": (22, 2, (3, 0), (), "ToDay2", None),
		"ToDay3": (26, 2, (3, 0), (), "ToDay3", None),
		"ToDay4": (30, 2, (3, 0), (), "ToDay4", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"DueDateCode": ((12, LCID, 4, 0),()),
		"DueDateName": ((13, LCID, 4, 0),()),
		"DueDatesType": ((14, LCID, 4, 0),()),
		"FromDay1": ((17, LCID, 4, 0),()),
		"FromDay2": ((21, LCID, 4, 0),()),
		"FromDay3": ((25, LCID, 4, 0),()),
		"FromDay4": ((29, LCID, 4, 0),()),
		"NoOfMonths1": ((20, LCID, 4, 0),()),
		"NoOfMonths2": ((24, LCID, 4, 0),()),
		"NoOfMonths3": ((28, LCID, 4, 0),()),
		"NoOfMonths4": ((32, LCID, 4, 0),()),
		"PaymentAfterDays": ((15, LCID, 4, 0),()),
		"PaymentAfterMonths": ((16, LCID, 4, 0),()),
		"PaymentDay1": ((19, LCID, 4, 0),()),
		"PaymentDay2": ((23, LCID, 4, 0),()),
		"PaymentDay3": ((27, LCID, 4, 0),()),
		"PaymentDay4": ((31, LCID, 4, 0),()),
		"ToDay1": ((18, LCID, 4, 0),()),
		"ToDay2": ((22, LCID, 4, 0),()),
		"ToDay3": ((26, LCID, 4, 0),()),
		"ToDay4": ((30, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICreditCards(DispatchBaseClass):
	'ICreditCards Interface'
	CLSID = IID('{49593AE6-FB7B-4B31-9029-F84067559E54}')
	coclass_clsid = IID('{F31F3841-559A-4CF2-B26C-17AA566FA21F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCardCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCardCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CompanyID": (13, 2, (8, 0), (), "CompanyID", None),
		"CountryCode": (14, 2, (8, 0), (), "CountryCode", None),
		"CreditCardCode": (9, 2, (3, 0), (), "CreditCardCode", None),
		"CreditCardName": (10, 2, (8, 0), (), "CreditCardName", None),
		"GLAccount": (11, 2, (8, 0), (), "GLAccount", None),
		"Telephone": (12, 2, (8, 0), (), "Telephone", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CompanyID": ((13, LCID, 4, 0),()),
		"CountryCode": ((14, LCID, 4, 0),()),
		"CreditCardName": ((10, LCID, 4, 0),()),
		"GLAccount": ((11, LCID, 4, 0),()),
		"Telephone": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICreditLine(DispatchBaseClass):
	'ICreditLine Interface'
	CLSID = IID('{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}')
	coclass_clsid = IID('{2B38E868-B135-40FE-9174-5C258F8638DB}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsId": (10, 2, (3, 0), (), "AbsId", None),
		"CreditCard": (11, 2, (3, 0), (), "CreditCard", None),
		"CreditCurrency": (21, 2, (8, 0), (), "CreditCurrency", None),
		"Customer": (17, 2, (8, 0), (), "Customer", None),
		"Deposited": (15, 2, (3, 0), (), "Deposited", None),
		"NumOfPayments": (16, 2, (3, 0), (), "NumOfPayments", None),
		"PayDate": (14, 2, (7, 0), (), "PayDate", None),
		"PaymentMethodCode": (13, 2, (3, 0), (), "PaymentMethodCode", None),
		"Reference": (18, 2, (8, 0), (), "Reference", None),
		"Total": (20, 2, (5, 0), (), "Total", None),
		"Transferred": (19, 2, (3, 0), (), "Transferred", None),
		"VoucherNumber": (12, 2, (8, 0), (), "VoucherNumber", None),
	}
	_prop_map_put_ = {
		"AbsId": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICreditLineParams(DispatchBaseClass):
	'ICreditLineParams Interface'
	CLSID = IID('{B0338FF7-542D-4AEA-A097-A51DECA7E671}')
	coclass_clsid = IID('{45D4B1C7-FB50-4628-94F5-78006AD1EFAC}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsId": (10, 2, (3, 0), (), "AbsId", None),
	}
	_prop_map_put_ = {
		"AbsId": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICreditLines(DispatchBaseClass):
	'ICreditLines Interface'
	CLSID = IID('{0219BFB4-6A47-47F5-942F-8B05389A05FB}')
	coclass_clsid = IID('{1442D59A-3803-4A00-B991-1652819C0E7E}')

	# Result is of type ICreditLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICreditLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICreditLinesParams(DispatchBaseClass):
	'ICreditLinesParams Interface'
	CLSID = IID('{60836D85-E0A0-435F-B237-4A1E79D7D670}')
	coclass_clsid = IID('{3B27BECB-507C-43E6-8FDF-080EC3810C1E}')

	# Result is of type ICreditLineParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{B0338FF7-542D-4AEA-A097-A51DECA7E671}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ICreditLineParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{B0338FF7-542D-4AEA-A097-A51DECA7E671}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{B0338FF7-542D-4AEA-A097-A51DECA7E671}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{B0338FF7-542D-4AEA-A097-A51DECA7E671}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICreditLinesService(DispatchBaseClass):
	'ICreditLinesService Interface'
	CLSID = IID('{CCCB8B97-63C1-461E-957F-858EADAE1E04}')
	coclass_clsid = IID('{D110EAAC-B59D-499D-9936-67F70B616026}')

	# Result is of type ICreditLine
	def GetCreditLine(self, pICreditLineParams=defaultNamedNotOptArg):
		'GetCreditLine'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICreditLineParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCreditLine', '{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ICreditLinesParams
	def GetValidCreditLineList(self):
		'GetValidCreditLineList'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetValidCreditLineList', '{60836D85-E0A0-435F-B237-4A1E79D7D670}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICreditPaymentMethods(DispatchBaseClass):
	'ICreditPaymentMethods Interface'
	CLSID = IID('{7B951C46-49D0-4E0C-8832-48B62F4EF0BD}')
	coclass_clsid = IID('{ED5A21FE-3751-472D-B058-198D6E2FEB9F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AssignedtoCreditCard": (12, 2, (3, 0), (), "AssignedtoCreditCard", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"InstallmentPaymentsPossible": (17, 2, (3, 0), (), "InstallmentPaymentsPossible", None),
		"MaxQtyWithoutApproval": (16, 2, (5, 0), (), "MaxQtyWithoutApproval", None),
		"MinimumCreditAmount": (14, 2, (5, 0), (), "MinimumCreditAmount", None),
		"MinimumPaymentAmount": (15, 2, (5, 0), (), "MinimumPaymentAmount", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"PaymentCode": (13, 2, (8, 0), (), "PaymentCode", None),
		"PaymentMethodCode": (10, 2, (3, 0), (), "PaymentMethodCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AssignedtoCreditCard": ((12, LCID, 4, 0),()),
		"InstallmentPaymentsPossible": ((17, LCID, 4, 0),()),
		"MaxQtyWithoutApproval": ((16, LCID, 4, 0),()),
		"MinimumCreditAmount": ((14, LCID, 4, 0),()),
		"MinimumPaymentAmount": ((15, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"PaymentCode": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICurrencies(DispatchBaseClass):
	'ICurrencies Interface'
	CLSID = IID('{596CFFFE-E95F-472D-8243-37094A850DCF}')
	coclass_clsid = IID('{12788346-93BB-4D1C-8649-A3266A413D3F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(9, LCID, 1, (8, 0), (),)

	def GetByKey(self, Currency=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (11, 0), ((8, 0),),Currency
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (11, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (6, 2, (8, 0), (), "Code", None),
		"Decimals": (21, 2, (3, 0), (), "Decimals", None),
		"DocumentsCode": (8, 2, (8, 0), (), "DocumentsCode", None),
		"EnglishHundredthName": (16, 2, (8, 0), (), "EnglishHundredthName", None),
		"EnglishName": (15, 2, (8, 0), (), "EnglishName", None),
		"HundredthName": (14, 2, (8, 0), (), "HundredthName", None),
		"InternationalDescription": (13, 2, (8, 0), (), "InternationalDescription", None),
		"MaxIncomingAmtDiff": (24, 2, (5, 0), (), "MaxIncomingAmtDiff", None),
		"MaxIncomingAmtDiffPercent": (26, 2, (5, 0), (), "MaxIncomingAmtDiffPercent", None),
		"MaxOutgoingAmtDiff": (25, 2, (5, 0), (), "MaxOutgoingAmtDiff", None),
		"MaxOutgoingAmtDiffPercent": (27, 2, (5, 0), (), "MaxOutgoingAmtDiffPercent", None),
		"Name": (7, 2, (8, 0), (), "Name", None),
		"PluralEnglishHundredthName": (20, 2, (8, 0), (), "PluralEnglishHundredthName", None),
		"PluralEnglishName": (19, 2, (8, 0), (), "PluralEnglishName", None),
		"PluralHundredthName": (18, 2, (8, 0), (), "PluralHundredthName", None),
		"PluralInternationalDescription": (17, 2, (8, 0), (), "PluralInternationalDescription", None),
		"Rounding": (22, 2, (3, 0), (), "Rounding", None),
		"RoundingInPayment": (23, 2, (3, 0), (), "RoundingInPayment", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (12, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Code": ((6, LCID, 4, 0),()),
		"Decimals": ((21, LCID, 4, 0),()),
		"DocumentsCode": ((8, LCID, 4, 0),()),
		"EnglishHundredthName": ((16, LCID, 4, 0),()),
		"EnglishName": ((15, LCID, 4, 0),()),
		"HundredthName": ((14, LCID, 4, 0),()),
		"InternationalDescription": ((13, LCID, 4, 0),()),
		"MaxIncomingAmtDiff": ((24, LCID, 4, 0),()),
		"MaxIncomingAmtDiffPercent": ((26, LCID, 4, 0),()),
		"MaxOutgoingAmtDiff": ((25, LCID, 4, 0),()),
		"MaxOutgoingAmtDiffPercent": ((27, LCID, 4, 0),()),
		"Name": ((7, LCID, 4, 0),()),
		"PluralEnglishHundredthName": ((20, LCID, 4, 0),()),
		"PluralEnglishName": ((19, LCID, 4, 0),()),
		"PluralHundredthName": ((18, LCID, 4, 0),()),
		"PluralInternationalDescription": ((17, LCID, 4, 0),()),
		"Rounding": ((22, LCID, 4, 0),()),
		"RoundingInPayment": ((23, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICurrencyRestrictions(DispatchBaseClass):
	'ICurrencyRestrictions Interface'
	CLSID = IID('{E6144A85-69CC-4178-A0B2-BDC8BED4930E}')
	coclass_clsid = IID('{C02B3449-252C-42AD-A6AA-05513188EA84}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Choose": (8, 2, (3, 0), (), "Choose", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"CurrencyCode": (6, 2, (8, 0), (), "CurrencyCode", None),
		"CurrencyName": (7, 2, (8, 0), (), "CurrencyName", None),
		"PaymentMethodCode": (5, 2, (8, 0), (), "PaymentMethodCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Choose": ((8, LCID, 4, 0),()),
		"CurrencyCode": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ICustomerEquipmentCards(DispatchBaseClass):
	'ICustomerEquipmentCards Interface'
	CLSID = IID('{D8BCB8BC-6DD1-4D3A-ABBF-FA7A18396B2C}')
	coclass_clsid = IID('{6EF2D0B5-8580-41AD-B879-42738445BE03}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(47, LCID, 1, (8, 0), (),)

	def GetByKey(self, EquipmentCardNum=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),EquipmentCardNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(48, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AttachmentEntry": (50, 2, (3, 0), (), "AttachmentEntry", None),
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (39, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		"Block": (29, 2, (8, 0), (), "Block", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BuildingFloorRoom": (49, 2, (8, 0), (), "BuildingFloorRoom", None),
		"City": (31, 2, (8, 0), (), "City", None),
		"ContactEmployeeCode": (12, 2, (3, 0), (), "ContactEmployeeCode", None),
		"ContactPhone": (27, 2, (8, 0), (), "ContactPhone", None),
		"CountryCode": (33, 2, (8, 0), (), "CountryCode", None),
		"County": (32, 2, (8, 0), (), "County", None),
		"CustomerCode": (10, 2, (8, 0), (), "CustomerCode", None),
		"CustomerName": (11, 2, (8, 0), (), "CustomerName", None),
		"DefaultTechnician": (44, 2, (3, 0), (), "DefaultTechnician", None),
		"Defaultterritory": (46, 2, (3, 0), (), "Defaultterritory", None),
		"DeliveryCode": (40, 2, (3, 0), (), "DeliveryCode", None),
		"DeliveryDate": (26, 2, (7, 0), (), "DeliveryDate", None),
		"DeliveryNumber": (41, 2, (3, 0), (), "DeliveryNumber", None),
		"DirectCustomerCode": (13, 2, (8, 0), (), "DirectCustomerCode", None),
		"DirectCustomerName": (14, 2, (8, 0), (), "DirectCustomerName", None),
		"EquipmentCardNum": (9, 2, (3, 0), (), "EquipmentCardNum", None),
		"InstallLocation": (35, 2, (8, 0), (), "InstallLocation", None),
		"InternalSerialNum": (16, 2, (8, 0), (), "InternalSerialNum", None),
		"InvoiceCode": (24, 2, (3, 0), (), "InvoiceCode", None),
		"InvoiceNumber": (25, 2, (3, 0), (), "InvoiceNumber", None),
		"ItemCode": (22, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (23, 2, (8, 0), (), "ItemDescription", None),
		"ManufacturerSerialNum": (15, 2, (8, 0), (), "ManufacturerSerialNum", None),
		"ReplaceSN": (43, 2, (3, 0), (), "ReplaceSN", None),
		"ReplacedBySN": (45, 2, (3, 0), (), "ReplacedBySN", None),
		"StateCode": (34, 2, (8, 0), (), "StateCode", None),
		"StatusOfSerialNumber": (42, 2, (3, 0), (), "StatusOfSerialNumber", None),
		"Street": (28, 2, (8, 0), (), "Street", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"ZipCode": (30, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AttachmentEntry": ((50, LCID, 4, 0),()),
		"Block": ((29, LCID, 4, 0),()),
		"BuildingFloorRoom": ((49, LCID, 4, 0),()),
		"City": ((31, LCID, 4, 0),()),
		"ContactEmployeeCode": ((12, LCID, 4, 0),()),
		"CountryCode": ((33, LCID, 4, 0),()),
		"County": ((32, LCID, 4, 0),()),
		"CustomerCode": ((10, LCID, 4, 0),()),
		"CustomerName": ((11, LCID, 4, 0),()),
		"DefaultTechnician": ((44, LCID, 4, 0),()),
		"Defaultterritory": ((46, LCID, 4, 0),()),
		"DeliveryCode": ((40, LCID, 4, 0),()),
		"DirectCustomerCode": ((13, LCID, 4, 0),()),
		"DirectCustomerName": ((14, LCID, 4, 0),()),
		"InstallLocation": ((35, LCID, 4, 0),()),
		"InternalSerialNum": ((16, LCID, 4, 0),()),
		"InvoiceCode": ((24, LCID, 4, 0),()),
		"ItemCode": ((22, LCID, 4, 0),()),
		"ItemDescription": ((23, LCID, 4, 0),()),
		"ManufacturerSerialNum": ((15, LCID, 4, 0),()),
		"ReplaceSN": ((43, LCID, 4, 0),()),
		"ReplacedBySN": ((45, LCID, 4, 0),()),
		"StateCode": ((34, LCID, 4, 0),()),
		"StatusOfSerialNumber": ((42, LCID, 4, 0),()),
		"Street": ((28, LCID, 4, 0),()),
		"ZipCode": ((30, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICustomsDeclaration(DispatchBaseClass):
	'ICustomsDeclaration Interface'
	CLSID = IID('{812BAA6F-715C-42E4-811F-287EF23E05A2}')
	coclass_clsid = IID('{B476320F-636F-42C4-9BA9-2D6CE71D3CBC}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CCDNum": (10, 2, (8, 0), (), "CCDNum", None),
		"CustomsBroker": (12, 2, (8, 0), (), "CustomsBroker", None),
		"CustomsTerminal": (17, 2, (8, 0), (), "CustomsTerminal", None),
		"Date": (11, 2, (7, 0), (), "Date", None),
		"DocDate": (14, 2, (7, 0), (), "DocDate", None),
		"DocNum": (13, 2, (8, 0), (), "DocNum", None),
		"PaymentKey": (18, 2, (8, 0), (), "PaymentKey", None),
		"SupplyDate": (16, 2, (7, 0), (), "SupplyDate", None),
		"SupplyNum": (15, 2, (8, 0), (), "SupplyNum", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (19, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
	}
	_prop_map_put_ = {
		"CCDNum": ((10, LCID, 4, 0),()),
		"CustomsBroker": ((12, LCID, 4, 0),()),
		"CustomsTerminal": ((17, LCID, 4, 0),()),
		"Date": ((11, LCID, 4, 0),()),
		"DocDate": ((14, LCID, 4, 0),()),
		"DocNum": ((13, LCID, 4, 0),()),
		"PaymentKey": ((18, LCID, 4, 0),()),
		"SupplyDate": ((16, LCID, 4, 0),()),
		"SupplyNum": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICustomsDeclarationParams(DispatchBaseClass):
	'ICustomsDeclarationParams Interface'
	CLSID = IID('{3D7A2391-5E52-45DE-80DB-A09ECADBD5A3}')
	coclass_clsid = IID('{C49DD31B-4B54-43B9-9E44-119635A4759A}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CCDNum": (10, 2, (8, 0), (), "CCDNum", None),
	}
	_prop_map_put_ = {
		"CCDNum": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICustomsDeclarationService(DispatchBaseClass):
	'ICustomsDeclarationService Interface'
	CLSID = IID('{13B5A261-F351-4DB5-8D4A-5A6C9083CF19}')
	coclass_clsid = IID('{9992E219-AAB5-48C8-B749-9D13289B4111}')

	# Result is of type ICustomsDeclarationParams
	def AddCustomsDeclaration(self, pICustomsDeclaration=defaultNamedNotOptArg):
		'AddCustomsDeclaration'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pICustomsDeclaration
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddCustomsDeclaration', '{3D7A2391-5E52-45DE-80DB-A09ECADBD5A3}')
		return ret

	def DeleteCustomsDeclaration(self, pICustomsDeclarationParams=defaultNamedNotOptArg):
		'DeleteCustomsDeclaration'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pICustomsDeclarationParams
			)

	# Result is of type ICustomsDeclaration
	def GetCustomsDeclaration(self, pICustomsDeclarationParams=defaultNamedNotOptArg):
		'GetCustomsDeclaration'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pICustomsDeclarationParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCustomsDeclaration', '{812BAA6F-715C-42E4-811F-287EF23E05A2}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateCustomsDeclaration(self, pICustomsDeclaration=defaultNamedNotOptArg):
		'UpdateCustomsDeclaration'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pICustomsDeclaration
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ICustomsGroups(DispatchBaseClass):
	'ICustomsGroups Interface'
	CLSID = IID('{842F5C3F-67A6-42B4-8181-98EFB9520A5F}')
	coclass_clsid = IID('{C7224CA0-BA56-4141-84AA-9E45D75208EF}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lGroupCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lGroupCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Customs": (13, 2, (5, 0), (), "Customs", None),
		"CustomsAllocationAccount": (19, 2, (8, 0), (), "CustomsAllocationAccount", None),
		"CustomsExpenseAccount": (20, 2, (8, 0), (), "CustomsExpenseAccount", None),
		"Locked": (17, 2, (3, 0), (), "Locked", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"Number": (12, 2, (8, 0), (), "Number", None),
		"Other": (15, 2, (5, 0), (), "Other", None),
		"PortAddress": (21, 2, (8, 0), (), "PortAddress", None),
		"PortState": (22, 2, (8, 0), (), "PortState", None),
		"Purchase": (14, 2, (5, 0), (), "Purchase", None),
		"Total": (16, 2, (5, 0), (), "Total", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Customs": ((13, LCID, 4, 0),()),
		"CustomsAllocationAccount": ((19, LCID, 4, 0),()),
		"CustomsExpenseAccount": ((20, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"Number": ((12, LCID, 4, 0),()),
		"Other": ((15, LCID, 4, 0),()),
		"PortAddress": ((21, LCID, 4, 0),()),
		"PortState": ((22, LCID, 4, 0),()),
		"Purchase": ((14, LCID, 4, 0),()),
		"Total": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDNFCodeSetup(DispatchBaseClass):
	'IDNFCodeSetup Interface'
	CLSID = IID('{F8E64A61-69DC-439B-82C9-0D7B1BD5E4B1}')
	coclass_clsid = IID('{24242AF5-F1A3-4688-9AB3-6CC76EB08D78}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"DNFCode": (12, 2, (8, 0), (), "DNFCode", None),
		"Factor": (14, 2, (5, 0), (), "Factor", None),
		"NCMCode": (11, 2, (3, 0), (), "NCMCode", None),
		"UoM": (13, 2, (8, 0), (), "UoM", None),
	}
	_prop_map_put_ = {
		"DNFCode": ((12, LCID, 4, 0),()),
		"Factor": ((14, LCID, 4, 0),()),
		"NCMCode": ((11, LCID, 4, 0),()),
		"UoM": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDNFCodeSetupParams(DispatchBaseClass):
	'IDNFCodeSetupParams Interface'
	CLSID = IID('{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')
	coclass_clsid = IID('{F4B554B0-CBF3-4258-89E5-F94FB08E463C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"DNFCode": (12, 2, (8, 0), (), "DNFCode", None),
		"NCMCode": (11, 2, (3, 0), (), "NCMCode", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDNFCodeSetupParamsCollection(DispatchBaseClass):
	'IDNFCodeSetupParamsCollection Interface'
	CLSID = IID('{80B626C7-6F5E-4C42-BBD0-36A311400BAE}')
	coclass_clsid = IID('{6A7BB82D-309D-4A45-818A-6FAB750C449C}')

	# Result is of type IDNFCodeSetupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDNFCodeSetupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDNFCodeSetupService(DispatchBaseClass):
	'IDNFCodeSetupService Interface'
	CLSID = IID('{CFD28E0F-8394-4B7D-87A0-52D3AD73254E}')
	coclass_clsid = IID('{0B0ADBC6-6CCA-48DF-92A9-2D0633AED84B}')

	# Result is of type IDNFCodeSetupParams
	def AddDNFCodeSetup(self, pIDNFCodeSetup=defaultNamedNotOptArg):
		'AddDNFCodeSetup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIDNFCodeSetup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddDNFCodeSetup', '{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')
		return ret

	def DeleteDNFCodeSetup(self, pIDNFCodeSetupParams=defaultNamedNotOptArg):
		'DeleteDNFCodeSetup'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIDNFCodeSetupParams
			)

	# Result is of type IDNFCodeSetup
	def GetDNFCodeSetup(self, pIDNFCodeSetupParams=defaultNamedNotOptArg):
		'GetDNFCodeSetup'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIDNFCodeSetupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDNFCodeSetup', '{F8E64A61-69DC-439B-82C9-0D7B1BD5E4B1}')
		return ret

	# Result is of type IDNFCodeSetupParamsCollection
	def GetDNFCodeSetupList(self):
		'GetDNFCodeSetupList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetDNFCodeSetupList', '{80B626C7-6F5E-4C42-BBD0-36A311400BAE}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateDNFCodeSetup(self, pIDNFCodeSetup=defaultNamedNotOptArg):
		'UpdateDNFCodeSetup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIDNFCodeSetup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDashboardPackageImportParams(DispatchBaseClass):
	'IDashboardPackageImportParams Interface'
	CLSID = IID('{D0D6E022-B36B-44E9-BD9A-24E3169AD532}')
	coclass_clsid = IID('{F563A16D-0B24-4D00-A668-C12DF72F6EE9}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ForceOverwritePackage": (11, 2, (3, 0), (), "ForceOverwritePackage", None),
		"ForceOverwriteQuery": (13, 2, (3, 0), (), "ForceOverwriteQuery", None),
		"ImportQueries": (12, 2, (3, 0), (), "ImportQueries", None),
		"PackageFilePath": (10, 2, (8, 0), (), "PackageFilePath", None),
	}
	_prop_map_put_ = {
		"ForceOverwritePackage": ((11, LCID, 4, 0),()),
		"ForceOverwriteQuery": ((13, LCID, 4, 0),()),
		"ImportQueries": ((12, LCID, 4, 0),()),
		"PackageFilePath": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDashboardPackageParams(DispatchBaseClass):
	'IDashboardPackageParams Interface'
	CLSID = IID('{006B6314-B29C-407F-A8F8-11717E779A2A}')
	coclass_clsid = IID('{B18C2498-6343-4620-87B9-6C298AE9BFD9}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDashboardPackagesParams(DispatchBaseClass):
	'IDashboardPackagesParams Interface'
	CLSID = IID('{F7BC21C9-ACB8-4B44-8488-5BE5D15BADEA}')
	coclass_clsid = IID('{20971C52-C8A9-4B34-B882-A2B3D0826E32}')

	# Result is of type IDashboardPackageParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{006B6314-B29C-407F-A8F8-11717E779A2A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDashboardPackageParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{006B6314-B29C-407F-A8F8-11717E779A2A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{006B6314-B29C-407F-A8F8-11717E779A2A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{006B6314-B29C-407F-A8F8-11717E779A2A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDashboardPackagesService(DispatchBaseClass):
	'IDashboardPackagesService Interface'
	CLSID = IID('{5077C7F7-E950-40A4-9A0E-71CF776AE79F}')
	coclass_clsid = IID('{DB836AB0-9F22-422C-BA3A-873208689C81}')

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IDashboardPackageParams
	def ImportDashboardPackage(self, pIDashboardPackageImportParams=defaultNamedNotOptArg):
		'ImportDashboardPackage'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIDashboardPackageImportParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'ImportDashboardPackage', '{006B6314-B29C-407F-A8F8-11717E779A2A}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDataBrowser(DispatchBaseClass):
	'IDataBrowser Interface'
	CLSID = IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')
	coclass_clsid = IID('{0D5D4022-6FCC-49A4-AB69-7F4304B47EC9}')

	def GetByKeys(self, keysStr=defaultNamedNotOptArg):
		'method GetByKeys'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (11, 0), ((8, 1),),keysStr
			)

	def MoveFirst(self):
		'method MoveFirst'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def MoveLast(self):
		'method MoveLast'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), (),)

	def MoveNext(self):
		'method MoveNext'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def MovePrevious(self):
		'method MovePrevious'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def ReadXml(self, XmlFileStr=defaultNamedNotOptArg, Index=defaultNamedNotOptArg):
		'method ReadXml'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1), (3, 1)),XmlFileStr
			, Index)

	def Refresh(self):
		'method Refresh'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (24, 0), (),)

	_prop_map_get_ = {
		"BoF": (7, 2, (11, 0), (), "BoF", None),
		"EoF": (8, 2, (11, 0), (), "EoF", None),
		"RecordCount": (2, 2, (3, 0), (), "RecordCount", None),
	}
	_prop_map_put_ = {
		"Recordset": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDecimalData(DispatchBaseClass):
	'IDecimalData Interface'
	CLSID = IID('{FF79D2D4-A79B-4DCF-A3BB-14A8B01A5FDC}')
	coclass_clsid = IID('{748FD7AC-AA7D-4D4D-A206-8E5898BDF94F}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Context": (11, 2, (3, 0), (), "Context", None),
		"Currency": (12, 2, (8, 0), (), "Currency", None),
		"Value": (10, 2, (5, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Context": ((11, LCID, 4, 0),()),
		"Currency": ((12, LCID, 4, 0),()),
		"Value": ((10, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(10, 2, (5, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDeductionTaxGroups(DispatchBaseClass):
	'IDeductionTaxGroups Interface'
	CLSID = IID('{7C3BB8E9-B896-4556-859F-FCAC93473C04}')
	coclass_clsid = IID('{2D582F5D-2BE6-408A-A03A-ED37F5C30491}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lGroupKey=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lGroupKey
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"GroupCode": (11, 2, (3, 0), (), "GroupCode", None),
		"GroupExtendedCode": (14, 2, (8, 0), (), "GroupExtendedCode", None),
		"GroupKey": (10, 2, (3, 0), (), "GroupKey", None),
		"GroupName": (12, 2, (8, 0), (), "GroupName", None),
		"MaxRedin": (13, 2, (5, 0), (), "MaxRedin", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"GroupCode": ((11, LCID, 4, 0),()),
		"GroupExtendedCode": ((14, LCID, 4, 0),()),
		"GroupName": ((12, LCID, 4, 0),()),
		"MaxRedin": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDeductionTaxHierarchies(DispatchBaseClass):
	'IDeductionTaxHierarchies Interface'
	CLSID = IID('{33DDE1AB-5C1F-454E-840A-884CF62A6747}')
	coclass_clsid = IID('{57DED1E0-70C3-46C1-97BC-69B0F683D66C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsEntry=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lAbsEntry
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"BPCode": (11, 2, (8, 0), (), "BPCode", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"DeductionPercent": (17, 2, (5, 0), (), "DeductionPercent", None),
		"HierarchyCode": (12, 2, (8, 0), (), "HierarchyCode", None),
		"HierarchyName": (13, 2, (8, 0), (), "HierarchyName", None),
		"LastUpdated": (19, 2, (7, 0), (), "LastUpdated", None),
		# Method 'Lines' returns object of type 'IDeductionTaxHierarchies_Lines'
		"Lines": (16, 2, (9, 0), (), "Lines", '{27A32FF4-4CC4-4D4A-860F-83E81EC52F3A}'),
		"MaximumTotal": (18, 2, (5, 0), (), "MaximumTotal", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"ValidFrom": (14, 2, (7, 0), (), "ValidFrom", None),
		"ValidUntil": (15, 2, (7, 0), (), "ValidUntil", None),
	}
	_prop_map_put_ = {
		"BPCode": ((11, LCID, 4, 0),()),
		"DeductionPercent": ((17, LCID, 4, 0),()),
		"HierarchyCode": ((12, LCID, 4, 0),()),
		"HierarchyName": ((13, LCID, 4, 0),()),
		"MaximumTotal": ((18, LCID, 4, 0),()),
		"ValidFrom": ((14, LCID, 4, 0),()),
		"ValidUntil": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDeductionTaxHierarchies_Lines(DispatchBaseClass):
	'IDeductionTaxHierarchies_Lines Interface'
	CLSID = IID('{27A32FF4-4CC4-4D4A-860F-83E81EC52F3A}')
	coclass_clsid = IID('{20C0F904-66E3-4784-965E-65FC991D8FE8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (3, 2, (3, 0), (), "Count", None),
		"DeductionPercent": (6, 2, (3, 0), (), "DeductionPercent", None),
		"MaximumTotal": (7, 2, (5, 0), (), "MaximumTotal", None),
		"RowNumber": (5, 2, (3, 0), (), "RowNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"DeductionPercent": ((6, LCID, 4, 0),()),
		"MaximumTotal": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDeductionTaxSubGroup(DispatchBaseClass):
	'IDeductionTaxSubGroup Interface'
	CLSID = IID('{16403B63-EB90-4781-9C89-05EF77769731}')
	coclass_clsid = IID('{FEC7996F-BF4C-4850-9576-FF3B3AF66851}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"GroupCode": (10, 2, (8, 0), (), "GroupCode", None),
		"GroupName": (11, 2, (8, 0), (), "GroupName", None),
	}
	_prop_map_put_ = {
		"GroupCode": ((10, LCID, 4, 0),()),
		"GroupName": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDeductionTaxSubGroupParams(DispatchBaseClass):
	'IDeductionTaxSubGroupParams Interface'
	CLSID = IID('{2165070A-0BA0-4409-AC85-52A47508F236}')
	coclass_clsid = IID('{975B187C-4395-4FE4-ABEB-B347B279215B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"GroupCode": (10, 2, (8, 0), (), "GroupCode", None),
		"GroupName": (11, 2, (8, 0), (), "GroupName", None),
	}
	_prop_map_put_ = {
		"GroupCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDeductionTaxSubGroupsParams(DispatchBaseClass):
	'IDeductionTaxSubGroupsParams Interface'
	CLSID = IID('{9766B024-E4F6-4116-98AC-DE54D618BFFA}')
	coclass_clsid = IID('{AF74F44A-F8C1-4A3E-B390-01D61430ED8A}')

	# Result is of type IDeductionTaxSubGroupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{2165070A-0BA0-4409-AC85-52A47508F236}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDeductionTaxSubGroupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{2165070A-0BA0-4409-AC85-52A47508F236}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{2165070A-0BA0-4409-AC85-52A47508F236}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{2165070A-0BA0-4409-AC85-52A47508F236}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDeductionTaxSubGroupsService(DispatchBaseClass):
	'IDeductionTaxSubGroupsService Interface'
	CLSID = IID('{389082B5-04A7-4CB6-A0FB-EEC065715703}')
	coclass_clsid = IID('{F63CDC3F-A87E-4BEF-99DD-8F1540BD524D}')

	# Result is of type IDeductionTaxSubGroupParams
	def AddDeductionTaxSubGroup(self, pIDeductionTaxSubGroup=defaultNamedNotOptArg):
		'AddDeductionTaxSubGroup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIDeductionTaxSubGroup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddDeductionTaxSubGroup', '{2165070A-0BA0-4409-AC85-52A47508F236}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IDeductionTaxSubGroup
	def GetDeductionTaxSubGroup(self, pIDeductionTaxSubGroupParams=defaultNamedNotOptArg):
		'GetDeductionTaxSubGroup'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIDeductionTaxSubGroupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDeductionTaxSubGroup', '{16403B63-EB90-4781-9C89-05EF77769731}')
		return ret

	# Result is of type IDeductionTaxSubGroupsParams
	def GetDeductionTaxSubGroupList(self):
		'GetDeductionTaxSubGroupList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetDeductionTaxSubGroupList', '{9766B024-E4F6-4116-98AC-DE54D618BFFA}')
		return ret

	def UpdateDeductionTaxSubGroup(self, pIDeductionTaxSubGroup=defaultNamedNotOptArg):
		'UpdateDeductionTaxSubGroup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIDeductionTaxSubGroup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDefaultCreditCards(DispatchBaseClass):
	'IDefaultCreditCards Interface'
	CLSID = IID('{5923A153-B41F-4676-A5B6-1FAD645FDD7B}')
	coclass_clsid = IID('{BE8AA2E1-EFFD-4AD5-AC95-47CB1C20BA57}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Code": (5, 2, (8, 0), (), "Code", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"CreditAccountCode": (7, 2, (8, 0), (), "CreditAccountCode", None),
		"CreditCardCode": (6, 2, (3, 0), (), "CreditCardCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CreditAccountCode": ((7, LCID, 4, 0),()),
		"CreditCardCode": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDefaultDocuments(DispatchBaseClass):
	'IDefaultDocuments Interface'
	CLSID = IID('{38EFFD46-32F0-4190-A769-E13A5CCC3F47}')
	coclass_clsid = IID('{84920F8B-AB22-4ECF-997E-DDEDEDA235B3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AddExport": (9, 2, (3, 0), (), "AddExport", None),
		"AddPrint": (8, 2, (3, 0), (), "AddPrint", None),
		"Code": (5, 2, (8, 0), (), "Code", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"EnglishKeyboardEnteringBPC": (17, 2, (3, 0), (), "EnglishKeyboardEnteringBPC", None),
		"EnglishKeyboardEnteringItem": (16, 2, (3, 0), (), "EnglishKeyboardEnteringItem", None),
		"NoofCopies": (7, 2, (3, 0), (), "NoofCopies", None),
		"NoofCopiesforManualDoc": (15, 2, (3, 0), (), "NoofCopiesforManualDoc", None),
		"ObjectType": (6, 2, (8, 0), (), "ObjectType", None),
		"PermanentRemark": (11, 2, (8, 0), (), "PermanentRemark", None),
		"PrintDiscountData": (14, 2, (3, 0), (), "PrintDiscountData", None),
		"PrintTotals": (12, 2, (3, 0), (), "PrintTotals", None),
		"PrintVendorCatalogNo": (13, 2, (3, 0), (), "PrintVendorCatalogNo", None),
		"TotalsRounding": (10, 2, (3, 0), (), "TotalsRounding", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AddExport": ((9, LCID, 4, 0),()),
		"AddPrint": ((8, LCID, 4, 0),()),
		"EnglishKeyboardEnteringBPC": ((17, LCID, 4, 0),()),
		"EnglishKeyboardEnteringItem": ((16, LCID, 4, 0),()),
		"NoofCopies": ((7, LCID, 4, 0),()),
		"NoofCopiesforManualDoc": ((15, LCID, 4, 0),()),
		"ObjectType": ((6, LCID, 4, 0),()),
		"PermanentRemark": ((11, LCID, 4, 0),()),
		"PrintDiscountData": ((14, LCID, 4, 0),()),
		"PrintTotals": ((12, LCID, 4, 0),()),
		"PrintVendorCatalogNo": ((13, LCID, 4, 0),()),
		"TotalsRounding": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDefaultElectronicSeriesParams(DispatchBaseClass):
	'IDefaultElectronicSeriesParams Interface'
	CLSID = IID('{C9379AB8-CDE2-4A35-99CE-DB1CE9D7950E}')
	coclass_clsid = IID('{D5F33B11-D467-4234-AE58-63E6D70E6E26}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ElectronicSeries": (11, 2, (3, 0), (), "ElectronicSeries", None),
		"Series": (10, 2, (3, 0), (), "Series", None),
	}
	_prop_map_put_ = {
		"ElectronicSeries": ((11, LCID, 4, 0),()),
		"Series": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDefaultReportParams(DispatchBaseClass):
	'IDefaultReportParams Interface'
	CLSID = IID('{90E9CFE3-0440-4E26-B8E7-975A9A4638B4}')
	coclass_clsid = IID('{A67C6121-4F92-41C5-9517-38E9D760A0C0}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CardCode": (13, 2, (8, 0), (), "CardCode", None),
		"LayoutCode": (11, 2, (8, 0), (), "LayoutCode", None),
		"ReportCode": (10, 2, (8, 0), (), "ReportCode", None),
		"UserID": (12, 2, (3, 0), (), "UserID", None),
	}
	_prop_map_put_ = {
		"CardCode": ((13, LCID, 4, 0),()),
		"LayoutCode": ((11, LCID, 4, 0),()),
		"ReportCode": ((10, LCID, 4, 0),()),
		"UserID": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDepartment(DispatchBaseClass):
	'IDepartment Interface'
	CLSID = IID('{B4CCEAAF-2511-4E3A-916F-8F0F7B6479C5}')
	coclass_clsid = IID('{2BFFCB89-7037-4E72-AA73-9E5667B51A78}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDepartmentParams(DispatchBaseClass):
	'IDepartmentParams Interface'
	CLSID = IID('{99E84704-3E04-40DD-BE1D-854068378E3A}')
	coclass_clsid = IID('{8C6FB6CA-693A-4647-9F88-B0427A245D60}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDepartmentsParams(DispatchBaseClass):
	'IDepartmentsParams Interface'
	CLSID = IID('{A7A2DCAC-BFE4-4CAA-B5D0-A337C4783C60}')
	coclass_clsid = IID('{D70469B5-F299-4F3E-9417-527D9BFEF649}')

	# Result is of type IDepartmentParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{99E84704-3E04-40DD-BE1D-854068378E3A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDepartmentParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{99E84704-3E04-40DD-BE1D-854068378E3A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{99E84704-3E04-40DD-BE1D-854068378E3A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{99E84704-3E04-40DD-BE1D-854068378E3A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDepartmentsService(DispatchBaseClass):
	'IDepartmentsService Interface'
	CLSID = IID('{C842A9F9-CB16-4E6A-A1DB-7D8964889C74}')
	coclass_clsid = IID('{C50A9BDA-E5A7-4458-A7CE-0029E035B1B7}')

	# Result is of type IDepartmentParams
	def AddDepartment(self, pIDepartment=defaultNamedNotOptArg):
		'AddDepartment'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIDepartment
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddDepartment', '{99E84704-3E04-40DD-BE1D-854068378E3A}')
		return ret

	def DeleteDepartment(self, pIDepartmentParams=defaultNamedNotOptArg):
		'DeleteDepartment'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIDepartmentParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IDepartment
	def GetDepartment(self, pIDepartmentParams=defaultNamedNotOptArg):
		'GetDepartment'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIDepartmentParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDepartment', '{B4CCEAAF-2511-4E3A-916F-8F0F7B6479C5}')
		return ret

	# Result is of type IDepartmentsParams
	def GetDepartmentList(self):
		'GetDepartmentList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetDepartmentList', '{A7A2DCAC-BFE4-4CAA-B5D0-A337C4783C60}')
		return ret

	def UpdateDepartment(self, pIDepartment=defaultNamedNotOptArg):
		'UpdateDepartment'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIDepartment
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDeposit(DispatchBaseClass):
	'IDeposit Interface'
	CLSID = IID('{29A116DF-AE12-4A45-A5F0-3436E170B26B}')
	coclass_clsid = IID('{77B8BCD1-46B3-41EF-92DD-F1F6680159DA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (38, 2, (3, 0), (), "AbsEntry", None),
		"AllocationAccount": (24, 2, (8, 0), (), "AllocationAccount", None),
		# Method 'BOEs' returns object of type 'IBOELines'
		"BOEs": (35, 2, (9, 0), (), "BOEs", '{87ED882F-80FA-487D-8DA1-058E42B6BFA8}'),
		"BPLID": (51, 2, (3, 0), (), "BPLID", None),
		"Bank": (16, 2, (8, 0), (), "Bank", None),
		"BankAccountNum": (17, 2, (8, 0), (), "BankAccountNum", None),
		"BankBranch": (18, 2, (8, 0), (), "BankBranch", None),
		"BankReference": (19, 2, (8, 0), (), "BankReference", None),
		# Method 'Checks' returns object of type 'ICheckLines'
		"Checks": (33, 2, (9, 0), (), "Checks", '{4DA92EEC-3781-4B5B-B466-4001E7B6F439}'),
		"Commission": (29, 2, (5, 0), (), "Commission", None),
		"CommissionAccount": (28, 2, (8, 0), (), "CommissionAccount", None),
		"CommissionCurrency": (46, 2, (8, 0), (), "CommissionCurrency", None),
		"CommissionDate": (30, 2, (7, 0), (), "CommissionDate", None),
		"CommissionFC": (48, 2, (5, 0), (), "CommissionFC", None),
		"CommissionSC": (47, 2, (5, 0), (), "CommissionSC", None),
		# Method 'Credits' returns object of type 'ICreditLines'
		"Credits": (34, 2, (9, 0), (), "Credits", '{0219BFB4-6A47-47F5-942F-8B05389A05FB}'),
		"DepositAccount": (14, 2, (8, 0), (), "DepositAccount", None),
		"DepositAccountType": (32, 2, (3, 0), (), "DepositAccountType", None),
		"DepositCurrency": (13, 2, (8, 0), (), "DepositCurrency", None),
		"DepositDate": (12, 2, (7, 0), (), "DepositDate", None),
		"DepositNumber": (10, 2, (3, 0), (), "DepositNumber", None),
		"DepositType": (11, 2, (3, 0), (), "DepositType", None),
		"DepositorName": (15, 2, (8, 0), (), "DepositorName", None),
		"DistributionRule": (41, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (42, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (43, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (44, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (45, 2, (8, 0), (), "DistributionRule5", None),
		"DocRate": (25, 2, (5, 0), (), "DocRate", None),
		"JournalRemarks": (20, 2, (8, 0), (), "JournalRemarks", None),
		"Project": (40, 2, (8, 0), (), "Project", None),
		"ReconcileAfterDeposit": (36, 2, (3, 0), (), "ReconcileAfterDeposit", None),
		"Series": (39, 2, (3, 0), (), "Series", None),
		"TaxAccount": (26, 2, (8, 0), (), "TaxAccount", None),
		"TaxAmount": (27, 2, (5, 0), (), "TaxAmount", None),
		"TaxAmountFC": (50, 2, (5, 0), (), "TaxAmountFC", None),
		"TaxAmountSC": (49, 2, (5, 0), (), "TaxAmountSC", None),
		"TaxCode": (31, 2, (8, 0), (), "TaxCode", None),
		"TotalFC": (22, 2, (5, 0), (), "TotalFC", None),
		"TotalLC": (21, 2, (5, 0), (), "TotalLC", None),
		"TotalSC": (23, 2, (5, 0), (), "TotalSC", None),
		"VoucherAccount": (37, 2, (8, 0), (), "VoucherAccount", None),
	}
	_prop_map_put_ = {
		"AllocationAccount": ((24, LCID, 4, 0),()),
		"BPLID": ((51, LCID, 4, 0),()),
		"Bank": ((16, LCID, 4, 0),()),
		"BankAccountNum": ((17, LCID, 4, 0),()),
		"BankBranch": ((18, LCID, 4, 0),()),
		"BankReference": ((19, LCID, 4, 0),()),
		"Commission": ((29, LCID, 4, 0),()),
		"CommissionAccount": ((28, LCID, 4, 0),()),
		"CommissionCurrency": ((46, LCID, 4, 0),()),
		"CommissionDate": ((30, LCID, 4, 0),()),
		"DepositAccount": ((14, LCID, 4, 0),()),
		"DepositAccountType": ((32, LCID, 4, 0),()),
		"DepositCurrency": ((13, LCID, 4, 0),()),
		"DepositDate": ((12, LCID, 4, 0),()),
		"DepositType": ((11, LCID, 4, 0),()),
		"DepositorName": ((15, LCID, 4, 0),()),
		"DistributionRule": ((41, LCID, 4, 0),()),
		"DistributionRule2": ((42, LCID, 4, 0),()),
		"DistributionRule3": ((43, LCID, 4, 0),()),
		"DistributionRule4": ((44, LCID, 4, 0),()),
		"DistributionRule5": ((45, LCID, 4, 0),()),
		"DocRate": ((25, LCID, 4, 0),()),
		"JournalRemarks": ((20, LCID, 4, 0),()),
		"Project": ((40, LCID, 4, 0),()),
		"ReconcileAfterDeposit": ((36, LCID, 4, 0),()),
		"Series": ((39, LCID, 4, 0),()),
		"TaxAccount": ((26, LCID, 4, 0),()),
		"TaxAmount": ((27, LCID, 4, 0),()),
		"TaxCode": ((31, LCID, 4, 0),()),
		"TotalLC": ((21, LCID, 4, 0),()),
		"VoucherAccount": ((37, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDepositParams(DispatchBaseClass):
	'IDepositParams Interface'
	CLSID = IID('{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')
	coclass_clsid = IID('{93BF348F-60F8-4803-8621-9E3DB48B1852}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (11, 2, (3, 0), (), "AbsEntry", None),
		"DepositNumber": (10, 2, (3, 0), (), "DepositNumber", None),
		"Series": (12, 2, (3, 0), (), "Series", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((11, LCID, 4, 0),()),
		"DepositNumber": ((10, LCID, 4, 0),()),
		"Series": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDepositsParams(DispatchBaseClass):
	'IDepositsParams Interface'
	CLSID = IID('{3FFD991B-9010-4832-89C6-903CBB33AD7D}')
	coclass_clsid = IID('{CD72781D-9EE9-4A21-8953-C5721F506955}')

	# Result is of type IDepositParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDepositParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDepositsService(DispatchBaseClass):
	'IDepositsService Interface'
	CLSID = IID('{8D14FB10-4616-4AF3-B477-0B87C797AEBC}')
	coclass_clsid = IID('{1A645E6A-B777-419D-84A6-6074EB069C86}')

	# Result is of type IDepositParams
	def AddDeposit(self, pIDeposit=defaultNamedNotOptArg):
		'AddDeposit'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIDeposit
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddDeposit', '{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')
		return ret

	def CancelDeposit(self, pIDepositParams=defaultNamedNotOptArg):
		'CancelDeposit'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pIDepositParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IDeposit
	def GetDeposit(self, pIDepositParams=defaultNamedNotOptArg):
		'GetDeposit'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIDepositParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDeposit', '{29A116DF-AE12-4A45-A5F0-3436E170B26B}')
		return ret

	# Result is of type IDepositsParams
	def GetDepositList(self):
		'GetDepositList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetDepositList', '{3FFD991B-9010-4832-89C6-903CBB33AD7D}')
		return ret

	def UpdateDeposit(self, pIDeposit=defaultNamedNotOptArg):
		'UpdateDeposit'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIDeposit
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDimension(DispatchBaseClass):
	'IDimension Interface'
	CLSID = IID('{0C349981-9E5F-4814-910B-8995D5E9D32E}')
	coclass_clsid = IID('{63E62D10-4344-4575-9C8C-FCEE9779316C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DimensionCode": (10, 2, (3, 0), (), "DimensionCode", None),
		"DimensionDescription": (13, 2, (8, 0), (), "DimensionDescription", None),
		"DimensionName": (11, 2, (8, 0), (), "DimensionName", None),
		"IsActive": (12, 2, (3, 0), (), "IsActive", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (14, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
	}
	_prop_map_put_ = {
		"DimensionDescription": ((13, LCID, 4, 0),()),
		"IsActive": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDimensionParams(DispatchBaseClass):
	'IDimensionParams Interface'
	CLSID = IID('{D50B349A-0226-4D72-9FEC-B38D21C65FE0}')
	coclass_clsid = IID('{F63FB1C7-CC5F-4FBD-AF7A-A1686D1BCD64}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DimensionCode": (10, 2, (3, 0), (), "DimensionCode", None),
		"DimensionName": (11, 2, (8, 0), (), "DimensionName", None),
	}
	_prop_map_put_ = {
		"DimensionCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDimensionsParams(DispatchBaseClass):
	'IDimensionsParams Interface'
	CLSID = IID('{7055A28F-3019-4826-A4CC-FC4E5D5E42C7}')
	coclass_clsid = IID('{8C66EF53-C778-466A-AC1C-6BEB8605425D}')

	# Result is of type IDimensionParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{D50B349A-0226-4D72-9FEC-B38D21C65FE0}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDimensionParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{D50B349A-0226-4D72-9FEC-B38D21C65FE0}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{D50B349A-0226-4D72-9FEC-B38D21C65FE0}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{D50B349A-0226-4D72-9FEC-B38D21C65FE0}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDimensionsService(DispatchBaseClass):
	'IDimensionsService Interface'
	CLSID = IID('{17854208-BA31-4EAB-9481-C0806F815FA0}')
	coclass_clsid = IID('{9E01385A-524C-4A76-87AD-9FF9058E0185}')

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IDimension
	def GetDimension(self, pIDimensionParams=defaultNamedNotOptArg):
		'GetDimension'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIDimensionParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDimension', '{0C349981-9E5F-4814-910B-8995D5E9D32E}')
		return ret

	# Result is of type IDimensionsParams
	def GetDimensionList(self):
		'GetDimensionList'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetDimensionList', '{7055A28F-3019-4826-A4CC-FC4E5D5E42C7}')
		return ret

	def UpdateDimension(self, pIDimension=defaultNamedNotOptArg):
		'UpdateDimension'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((9, 1),),pIDimension
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDiscountGroups(DispatchBaseClass):
	'IDiscountGroups Interface'
	CLSID = IID('{7B78B94A-9F54-4A05-9A64-0A1E89484ECB}')
	coclass_clsid = IID('{63F3E235-30B2-4C42-8A9A-5953779F0C4E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPCode": (7, 2, (8, 0), (), "BPCode", None),
		"BaseObjectType": (8, 2, (3, 0), (), "BaseObjectType", None),
		"Count": (4, 2, (3, 0), (), "Count", None),
		"DiscountPercentage": (6, 2, (5, 0), (), "DiscountPercentage", None),
		"ObjectEntry": (5, 2, (8, 0), (), "ObjectEntry", None),
	}
	_prop_map_put_ = {
		"DiscountPercentage": ((6, LCID, 4, 0),()),
		"ObjectEntry": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(4, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDiscountLine(DispatchBaseClass):
	'IDiscountLine Interface'
	CLSID = IID('{73042DE8-A510-4C53-B256-FD249BA13723}')
	coclass_clsid = IID('{4821A00E-CC17-4B2F-99A7-61D49901AC89}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Day": (14, 2, (3, 0), (), "Day", None),
		"Discount": (13, 2, (5, 0), (), "Discount", None),
		"DiscountCode": (10, 2, (8, 0), (), "DiscountCode", None),
		"LineId": (11, 2, (3, 0), (), "LineId", None),
		"Month": (15, 2, (3, 0), (), "Month", None),
		"NumOfDays": (12, 2, (3, 0), (), "NumOfDays", None),
	}
	_prop_map_put_ = {
		"Day": ((14, LCID, 4, 0),()),
		"Discount": ((13, LCID, 4, 0),()),
		"Month": ((15, LCID, 4, 0),()),
		"NumOfDays": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDiscountLines(DispatchBaseClass):
	'IDiscountLines Interface'
	CLSID = IID('{E14BAC45-1772-407F-B255-178FF23F91E3}')
	coclass_clsid = IID('{C15B6D2B-EA40-48FC-990E-6CE5EB32B7E4}')

	# Result is of type IDiscountLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{73042DE8-A510-4C53-B256-FD249BA13723}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDiscountLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{73042DE8-A510-4C53-B256-FD249BA13723}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{73042DE8-A510-4C53-B256-FD249BA13723}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{73042DE8-A510-4C53-B256-FD249BA13723}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDistributionRule(DispatchBaseClass):
	'IDistributionRule Interface'
	CLSID = IID('{FC2AB5F1-3242-42D2-985E-D23052C9834A}')
	coclass_clsid = IID('{07E15DBA-2CB3-40D0-BE23-686EBE7F192D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Active": (16, 2, (3, 0), (), "Active", None),
		"Direct": (13, 2, (8, 0), (), "Direct", None),
		# Method 'DistributionRuleLines' returns object of type 'IDistributionRuleLines'
		"DistributionRuleLines": (15, 2, (9, 0), (), "DistributionRuleLines", '{0B5DE094-FB49-4B4C-AA7C-F87F5E3A932F}'),
		"FactorCode": (10, 2, (8, 0), (), "FactorCode", None),
		"FactorDescription": (11, 2, (8, 0), (), "FactorDescription", None),
		"InWhichDimension": (14, 2, (3, 0), (), "InWhichDimension", None),
		"TotalFactor": (12, 2, (5, 0), (), "TotalFactor", None),
	}
	_prop_map_put_ = {
		"Active": ((16, LCID, 4, 0),()),
		"Direct": ((13, LCID, 4, 0),()),
		"FactorCode": ((10, LCID, 4, 0),()),
		"FactorDescription": ((11, LCID, 4, 0),()),
		"InWhichDimension": ((14, LCID, 4, 0),()),
		"TotalFactor": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDistributionRuleLine(DispatchBaseClass):
	'IDistributionRuleLine Interface'
	CLSID = IID('{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}')
	coclass_clsid = IID('{01EC1A1A-17D7-4A77-BCD5-2AE1B2FE4385}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CenterCode": (10, 2, (8, 0), (), "CenterCode", None),
		"EffectiveTo": (13, 2, (7, 0), (), "EffectiveTo", None),
		"Effectivefrom": (12, 2, (7, 0), (), "Effectivefrom", None),
		"TotalInCenter": (11, 2, (5, 0), (), "TotalInCenter", None),
	}
	_prop_map_put_ = {
		"CenterCode": ((10, LCID, 4, 0),()),
		"EffectiveTo": ((13, LCID, 4, 0),()),
		"Effectivefrom": ((12, LCID, 4, 0),()),
		"TotalInCenter": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDistributionRuleLines(DispatchBaseClass):
	'IDistributionRuleLines Interface'
	CLSID = IID('{0B5DE094-FB49-4B4C-AA7C-F87F5E3A932F}')
	coclass_clsid = IID('{635ED325-EEA5-4340-AA1A-5845D97CFCC1}')

	# Result is of type IDistributionRuleLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDistributionRuleLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDistributionRuleParams(DispatchBaseClass):
	'IDistributionRuleParams Interface'
	CLSID = IID('{A91769F5-16B5-49A6-8305-A2DC6054206F}')
	coclass_clsid = IID('{DB0B495A-9C94-4B49-8DB1-DEA4B58C73C2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"FactorCode": (10, 2, (8, 0), (), "FactorCode", None),
		"FactorDescription": (11, 2, (8, 0), (), "FactorDescription", None),
	}
	_prop_map_put_ = {
		"FactorCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDistributionRulesParams(DispatchBaseClass):
	'IDistributionRulesParams Interface'
	CLSID = IID('{E5EB0192-6BCF-43FF-94E7-8A17C7F6B566}')
	coclass_clsid = IID('{22F927F7-9B09-4F79-8D9E-564CB2047BCE}')

	# Result is of type IDistributionRuleParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A91769F5-16B5-49A6-8305-A2DC6054206F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDistributionRuleParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{A91769F5-16B5-49A6-8305-A2DC6054206F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{A91769F5-16B5-49A6-8305-A2DC6054206F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{A91769F5-16B5-49A6-8305-A2DC6054206F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDistributionRulesService(DispatchBaseClass):
	'IDistributionRulesService Interface'
	CLSID = IID('{061D26BF-D1D2-4A8C-A29E-9ECB34E36AC4}')
	coclass_clsid = IID('{D30C3CFB-358F-45C2-9F62-9CE26AF80E13}')

	# Result is of type IDistributionRuleParams
	def AddDistributionRule(self, pIDistributionRule=defaultNamedNotOptArg):
		'AddDistributionRule'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIDistributionRule
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddDistributionRule', '{A91769F5-16B5-49A6-8305-A2DC6054206F}')
		return ret

	def DeleteDistributionRule(self, pIDistributionRuleParams=defaultNamedNotOptArg):
		'DeleteDistributionRule'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIDistributionRuleParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IDistributionRule
	def GetDistributionRule(self, pIDistributionRuleParams=defaultNamedNotOptArg):
		'GetDistributionRule'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIDistributionRuleParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDistributionRule', '{FC2AB5F1-3242-42D2-985E-D23052C9834A}')
		return ret

	# Result is of type IDistributionRulesParams
	def GetDistributionRuleList(self):
		'GetDistributionRuleList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetDistributionRuleList', '{E5EB0192-6BCF-43FF-94E7-8A17C7F6B566}')
		return ret

	def UpdateDistributionRule(self, pIDistributionRule=defaultNamedNotOptArg):
		'UpdateDistributionRule'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIDistributionRule
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDocumentChangeMenuName(DispatchBaseClass):
	'IDocumentChangeMenuName Interface'
	CLSID = IID('{9A5FCF99-FC73-47E0-A68D-A8156EB864E5}')
	coclass_clsid = IID('{2E4A01AF-5881-4F33-8D91-A4EBBFADBADA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ChangedMenuName": (13, 2, (8, 0), (), "ChangedMenuName", None),
		"Document": (12, 2, (8, 0), (), "Document", None),
		"DocumentSubType": (11, 2, (8, 0), (), "DocumentSubType", None),
	}
	_prop_map_put_ = {
		"ChangedMenuName": ((13, LCID, 4, 0),()),
		"Document": ((12, LCID, 4, 0),()),
		"DocumentSubType": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDocumentPackageItems(DispatchBaseClass):
	'IDocumentPackageItems Interface'
	CLSID = IID('{8E861D67-6E55-4201-9AE5-F193127E6F67}')
	coclass_clsid = IID('{061EDFD2-1326-4FC7-B95A-CD30593B6448}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"ItemCode": (6, 2, (8, 0), (), "ItemCode", None),
		"Quantity": (7, 2, (5, 0), (), "Quantity", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ItemCode": ((6, LCID, 4, 0),()),
		"Quantity": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDocumentPackages(DispatchBaseClass):
	'IDocumentPackages Interface'
	CLSID = IID('{07F27714-4BA9-42E3-8E93-3418F73C55E4}')
	coclass_clsid = IID('{46BED4FA-A7F1-4067-8FC7-A6303F0F3A5C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		# Method 'Items' returns object of type 'IDocumentPackageItems'
		"Items": (6, 2, (9, 0), (), "Items", '{8E861D67-6E55-4201-9AE5-F193127E6F67}'),
		"Number": (7, 2, (3, 0), (), "Number", None),
		"TotalWeight": (9, 2, (5, 0), (), "TotalWeight", None),
		"Type": (8, 2, (8, 0), (), "Type", None),
		"Units": (10, 2, (3, 0), (), "Units", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Number": ((7, LCID, 4, 0),()),
		"Type": ((8, LCID, 4, 0),()),
		"Units": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDocumentSeriesParams(DispatchBaseClass):
	'IDocumentSeriesParams Interface'
	CLSID = IID('{E24C2504-36B4-4EE4-A990-0F487E774211}')
	coclass_clsid = IID('{284C40A5-FADD-4910-90EF-21825F75E6FD}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Document": (12, 2, (8, 0), (), "Document", None),
		"DocumentSubType": (11, 2, (8, 0), (), "DocumentSubType", None),
		"Series": (13, 2, (3, 0), (), "Series", None),
	}
	_prop_map_put_ = {
		"Document": ((12, LCID, 4, 0),()),
		"DocumentSubType": ((11, LCID, 4, 0),()),
		"Series": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDocumentSeriesUserParams(DispatchBaseClass):
	'IDocumentSeriesUserParams Interface'
	CLSID = IID('{AADAC0AA-6CBA-47EC-B923-05B029715123}')
	coclass_clsid = IID('{CA9C97EF-439D-4040-B1A1-39F83CBC2CD5}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Document": (13, 2, (8, 0), (), "Document", None),
		"DocumentSubType": (12, 2, (8, 0), (), "DocumentSubType", None),
		"Series": (14, 2, (3, 0), (), "Series", None),
		"User": (11, 2, (3, 0), (), "User", None),
	}
	_prop_map_put_ = {
		"Document": ((13, LCID, 4, 0),()),
		"DocumentSubType": ((12, LCID, 4, 0),()),
		"Series": ((14, LCID, 4, 0),()),
		"User": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDocumentTypeParams(DispatchBaseClass):
	'IDocumentTypeParams Interface'
	CLSID = IID('{B5196CD2-270C-42E8-81F5-735A99BECEA6}')
	coclass_clsid = IID('{A04457CF-8DB7-477B-9298-374E7CDAA9D8}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Document": (12, 2, (8, 0), (), "Document", None),
		"DocumentSubType": (11, 2, (8, 0), (), "DocumentSubType", None),
	}
	_prop_map_put_ = {
		"Document": ((12, LCID, 4, 0),()),
		"DocumentSubType": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDocument_ApprovalRequests(DispatchBaseClass):
	'IDocument_ApprovalRequests Interface'
	CLSID = IID('{CEDAC9E2-A77F-4518-A524-1403050FFD3D}')
	coclass_clsid = IID('{1BB46BE0-4ECB-44DB-B6ED-64356031568E}')

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ApprovalTemplatesID": (4, 2, (3, 0), (), "ApprovalTemplatesID", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"Remarks": (5, 2, (8, 0), (), "Remarks", None),
	}
	_prop_map_put_ = {
		"Remarks": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDocument_Installments(DispatchBaseClass):
	'IDocument_Installments Interface'
	CLSID = IID('{3E64E5EC-70CA-4129-BC06-0CE9B2058843}')
	coclass_clsid = IID('{1EFBEFDD-F21B-44B1-B275-3091E89031B7}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"DueDate": (6, 2, (7, 0), (), "DueDate", None),
		"DunningLevel": (10, 2, (3, 0), (), "DunningLevel", None),
		"InstallmentId": (12, 2, (3, 0), (), "InstallmentId", None),
		"LastDunningDate": (9, 2, (7, 0), (), "LastDunningDate", None),
		"PaymentOrdered": (13, 2, (3, 0), (), "PaymentOrdered", None),
		"Percentage": (7, 2, (5, 0), (), "Percentage", None),
		"Total": (8, 2, (5, 0), (), "Total", None),
		"TotalFC": (11, 2, (5, 0), (), "TotalFC", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"DueDate": ((6, LCID, 4, 0),()),
		"DunningLevel": ((10, LCID, 4, 0),()),
		"Percentage": ((7, LCID, 4, 0),()),
		"Total": ((8, LCID, 4, 0),()),
		"TotalFC": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDocument_Lines(DispatchBaseClass):
	'IDocument_Lines Interface'
	CLSID = IID('{248B28DD-1281-4C6C-9780-22D19BA13D1F}')
	coclass_clsid = IID('{E9B749CA-045B-4BDD-A5BD-143458EBA752}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(120, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(48, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (18, 2, (8, 0), (), "AccountCode", None),
		"ActualBaseEntry": (196, 2, (3, 0), (), "ActualBaseEntry", None),
		"ActualBaseLine": (197, 2, (3, 0), (), "ActualBaseLine", None),
		"ActualDeliveryDate": (132, 2, (7, 0), (), "ActualDeliveryDate", None),
		"Address": (54, 2, (8, 0), (), "Address", None),
		"AgreementNo": (193, 2, (3, 0), (), "AgreementNo", None),
		"AgreementRowNumber": (194, 2, (3, 0), (), "AgreementRowNumber", None),
		"AppliedTax": (74, 2, (5, 0), (), "AppliedTax", None),
		"AppliedTaxFC": (75, 2, (5, 0), (), "AppliedTaxFC", None),
		"AppliedTaxSC": (76, 2, (5, 0), (), "AppliedTaxSC", None),
		"BackOrder": (62, 2, (3, 0), (), "BackOrder", None),
		"BarCode": (23, 2, (8, 0), (), "BarCode", None),
		"BaseEntry": (42, 2, (3, 0), (), "BaseEntry", None),
		"BaseLine": (43, 2, (3, 0), (), "BaseLine", None),
		"BaseOpenQuantity": (122, 2, (5, 0), (), "BaseOpenQuantity", None),
		"BaseType": (41, 2, (3, 0), (), "BaseType", None),
		# Method 'BatchNumbers' returns object of type 'IBatchNumbers'
		"BatchNumbers": (69, 2, (9, 0), (), "BatchNumbers", '{1FEF5698-93E1-4167-AEA0-4BB151792623}'),
		"CFOPCode": (99, 2, (8, 0), (), "CFOPCode", None),
		"COGSAccountCode": (129, 2, (8, 0), (), "COGSAccountCode", None),
		"COGSCostingCode": (128, 2, (8, 0), (), "COGSCostingCode", None),
		"COGSCostingCode2": (184, 2, (8, 0), (), "COGSCostingCode2", None),
		"COGSCostingCode3": (185, 2, (8, 0), (), "COGSCostingCode3", None),
		"COGSCostingCode4": (186, 2, (8, 0), (), "COGSCostingCode4", None),
		"COGSCostingCode5": (187, 2, (8, 0), (), "COGSCostingCode5", None),
		"CSTCode": (100, 2, (8, 0), (), "CSTCode", None),
		"CSTforCOFINS": (190, 2, (8, 0), (), "CSTforCOFINS", None),
		"CSTforIPI": (188, 2, (8, 0), (), "CSTforIPI", None),
		"CSTforPIS": (189, 2, (8, 0), (), "CSTforPIS", None),
		"ChangeAssemlyBoMWarehouse": (130, 2, (8, 0), (), "ChangeAssemlyBoMWarehouse", None),
		"CommisionPercent": (16, 2, (5, 0), (), "CommisionPercent", None),
		"ConsumerSalesForecast": (97, 2, (3, 0), (), "ConsumerSalesForecast", None),
		"CorrInvAmountToDiffAcct": (73, 2, (5, 0), (), "CorrInvAmountToDiffAcct", None),
		"CorrInvAmountToStock": (72, 2, (5, 0), (), "CorrInvAmountToStock", None),
		"CorrectionInvoiceItem": (71, 2, (3, 0), (), "CorrectionInvoiceItem", None),
		"CostingCode": (21, 2, (8, 0), (), "CostingCode", None),
		"CostingCode2": (134, 2, (8, 0), (), "CostingCode2", None),
		"CostingCode3": (135, 2, (8, 0), (), "CostingCode3", None),
		"CostingCode4": (136, 2, (8, 0), (), "CostingCode4", None),
		"CostingCode5": (137, 2, (8, 0), (), "CostingCode5", None),
		"Count": (47, 2, (3, 0), (), "Count", None),
		"CountryOrg": (95, 2, (8, 0), (), "CountryOrg", None),
		"CreditOriginCode": (191, 2, (8, 0), (), "CreditOriginCode", None),
		"Currency": (9, 2, (8, 0), (), "Currency", None),
		"DefectAndBreakup": (202, 2, (5, 0), (), "DefectAndBreakup", None),
		"DeferredTax": (88, 2, (3, 0), (), "DeferredTax", None),
		"DiscountPercent": (11, 2, (5, 0), (), "DiscountPercent", None),
		"DistributeExpense": (107, 2, (3, 0), (), "DistributeExpense", None),
		"DocEntry": (198, 2, (3, 0), (), "DocEntry", None),
		"EqualizationTaxPercent": (78, 2, (5, 0), (), "EqualizationTaxPercent", None),
		"ExLineNo": (173, 2, (8, 0), (), "ExLineNo", None),
		"ExciseAmount": (92, 2, (5, 0), (), "ExciseAmount", None),
		# Method 'Expenses' returns object of type 'IDocument_LinesAdditionalExpenses'
		"Expenses": (70, 2, (9, 0), (), "Expenses", '{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}'),
		# Method 'ExportProcesses' returns object of type 'IExportProcesses'
		"ExportProcesses": (200, 2, (9, 0), (), "ExportProcesses", '{E3F9ACA7-17D5-4A5B-8AAF-91CB41E2896F}'),
		"Factor1": (37, 2, (5, 0), (), "Factor1", None),
		"Factor2": (38, 2, (5, 0), (), "Factor2", None),
		"Factor3": (39, 2, (5, 0), (), "Factor3", None),
		"Factor4": (40, 2, (5, 0), (), "Factor4", None),
		"FreeText": (63, 2, (8, 0), (), "FreeText", None),
		"GrossBase": (171, 2, (3, 0), (), "GrossBase", None),
		"GrossBuyPrice": (170, 2, (5, 0), (), "GrossBuyPrice", None),
		"GrossProfitTotalBasePrice": (172, 2, (5, 0), (), "GrossProfitTotalBasePrice", None),
		"Height1": (25, 2, (5, 0), (), "Height1", None),
		"Height2": (27, 2, (5, 0), (), "Height2", None),
		"Height2Unit": (28, 2, (3, 0), (), "Height2Unit", None),
		"Hight1Unit": (26, 2, (3, 0), (), "Hight1Unit", None),
		# Method 'ImportProcesses' returns object of type 'IImportProcesses'
		"ImportProcesses": (199, 2, (9, 0), (), "ImportProcesses", '{8A8F6C7B-BD55-45C5-A28C-C81A786B0EB8}'),
		"ItemCode": (3, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (4, 2, (8, 0), (), "ItemDescription", None),
		"ItemDetails": (131, 2, (8, 0), (), "ItemDetails", None),
		"LastBuyDistributeSum": (114, 2, (5, 0), (), "LastBuyDistributeSum", None),
		"LastBuyDistributeSumFc": (112, 2, (5, 0), (), "LastBuyDistributeSumFc", None),
		"LastBuyDistributeSumSc": (113, 2, (5, 0), (), "LastBuyDistributeSumSc", None),
		"LastBuyInmPrice": (111, 2, (5, 0), (), "LastBuyInmPrice", None),
		"Lengh1": (29, 2, (5, 0), (), "Lengh1", None),
		"Lengh1Unit": (30, 2, (3, 0), (), "Lengh1Unit", None),
		"Lengh2": (31, 2, (5, 0), (), "Lengh2", None),
		"Lengh2Unit": (32, 2, (3, 0), (), "Lengh2Unit", None),
		"LineNum": (2, 2, (3, 0), (), "LineNum", None),
		"LineStatus": (124, 2, (3, 0), (), "LineStatus", None),
		"LineTotal": (84, 2, (5, 0), (), "LineTotal", None),
		"LineType": (127, 2, (3, 0), (), "LineType", None),
		"LocationCode": (133, 2, (3, 0), (), "LocationCode", None),
		"MeasureUnit": (90, 2, (8, 0), (), "MeasureUnit", None),
		"NetTaxAmount": (81, 2, (5, 0), (), "NetTaxAmount", None),
		"NetTaxAmountFC": (82, 2, (5, 0), (), "NetTaxAmountFC", None),
		"NetTaxAmountSC": (83, 2, (5, 0), (), "NetTaxAmountSC", None),
		"OpenAmount": (139, 2, (5, 0), (), "OpenAmount", None),
		"OpenAmountFC": (140, 2, (5, 0), (), "OpenAmountFC", None),
		"OpenAmountSC": (141, 2, (5, 0), (), "OpenAmountSC", None),
		"OriginalItem": (61, 2, (8, 0), (), "OriginalItem", None),
		"POTargetEntry": (66, 2, (8, 0), (), "POTargetEntry", None),
		"POTargetNum": (65, 2, (3, 0), (), "POTargetNum", None),
		"POTargetRowNum": (67, 2, (8, 0), (), "POTargetRowNum", None),
		"PackageQuantity": (125, 2, (5, 0), (), "PackageQuantity", None),
		"PickListIdNumber": (60, 2, (3, 0), (), "PickListIdNumber", None),
		"PickQuantity": (59, 2, (5, 0), (), "PickQuantity", None),
		"PickStatus": (58, 2, (3, 0), (), "PickStatus", None),
		"PickStatusEx": (119, 2, (3, 0), (), "PickStatusEx", None),
		"Price": (7, 2, (5, 0), (), "Price", None),
		"PriceAfterVAT": (8, 2, (5, 0), (), "PriceAfterVAT", None),
		"ProjectCode": (22, 2, (8, 0), (), "ProjectCode", None),
		"Quantity": (5, 2, (5, 0), (), "Quantity", None),
		"Rate": (10, 2, (5, 0), (), "Rate", None),
		"RemainingOpenQuantity": (138, 2, (5, 0), (), "RemainingOpenQuantity", None),
		"RequiredDate": (182, 2, (7, 0), (), "RequiredDate", None),
		"RequiredQuantity": (183, 2, (5, 0), (), "RequiredQuantity", None),
		"RowTotalFC": (109, 2, (5, 0), (), "RowTotalFC", None),
		"RowTotalSC": (110, 2, (5, 0), (), "RowTotalSC", None),
		"SWW": (96, 2, (8, 0), (), "SWW", None),
		"SalesPersonCode": (15, 2, (3, 0), (), "SalesPersonCode", None),
		"SerialNum": (13, 2, (8, 0), (), "SerialNum", None),
		# Method 'SerialNumbers' returns object of type 'ISerialNumbers'
		"SerialNumbers": (68, 2, (9, 0), (), "SerialNumbers", '{93E5E52B-181E-46B8-96CB-1C066AC04DCA}'),
		"ShipDate": (6, 2, (7, 0), (), "ShipDate", None),
		"ShipToCode": (108, 2, (8, 0), (), "ShipToCode", None),
		"ShipToDescription": (195, 2, (8, 0), (), "ShipToDescription", None),
		"ShippingMethod": (64, 2, (3, 0), (), "ShippingMethod", None),
		"Shortages": (203, 2, (5, 0), (), "Shortages", None),
		"StockDistributesum": (117, 2, (5, 0), (), "StockDistributesum", None),
		"StockDistributesumForeign": (115, 2, (5, 0), (), "StockDistributesumForeign", None),
		"StockDistributesumSystem": (116, 2, (5, 0), (), "StockDistributesumSystem", None),
		"StockInmPrice": (118, 2, (5, 0), (), "StockInmPrice", None),
		"SupplierCatNum": (20, 2, (8, 0), (), "SupplierCatNum", None),
		"Surpluses": (201, 2, (5, 0), (), "Surpluses", None),
		"TaxBeforeDPM": (103, 2, (5, 0), (), "TaxBeforeDPM", None),
		"TaxBeforeDPMFC": (104, 2, (5, 0), (), "TaxBeforeDPMFC", None),
		"TaxBeforeDPMSC": (105, 2, (5, 0), (), "TaxBeforeDPMSC", None),
		"TaxCode": (55, 2, (8, 0), (), "TaxCode", None),
		# Method 'TaxJurisdictions' returns object of type 'ITaxJurisdictions'
		"TaxJurisdictions": (181, 2, (9, 0), (), "TaxJurisdictions", '{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}'),
		"TaxLiable": (57, 2, (3, 0), (), "TaxLiable", None),
		"TaxOnly": (102, 2, (3, 0), (), "TaxOnly", None),
		"TaxPerUnit": (93, 2, (5, 0), (), "TaxPerUnit", None),
		"TaxPercentagePerRow": (86, 2, (5, 0), (), "TaxPercentagePerRow", None),
		"TaxTotal": (87, 2, (5, 0), (), "TaxTotal", None),
		"TaxType": (56, 2, (3, 0), (), "TaxType", None),
		"Text": (126, 2, (8, 0), (), "Text", None),
		"TotalEqualizationTax": (89, 2, (5, 0), (), "TotalEqualizationTax", None),
		"TotalEqualizationTaxFC": (79, 2, (5, 0), (), "TotalEqualizationTaxFC", None),
		"TotalEqualizationTaxSC": (80, 2, (5, 0), (), "TotalEqualizationTaxSC", None),
		"TotalInclTax": (94, 2, (5, 0), (), "TotalInclTax", None),
		"TransactionType": (106, 2, (3, 0), (), "TransactionType", None),
		"TreeType": (17, 2, (3, 0), (), "TreeType", None),
		"UnitPrice": (123, 2, (5, 0), (), "UnitPrice", None),
		"UnitsOfMeasurment": (91, 2, (5, 0), (), "UnitsOfMeasurment", None),
		"Usage": (101, 2, (8, 0), (), "Usage", None),
		"UseBaseUnits": (19, 2, (3, 0), (), "UseBaseUnits", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (49, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatGroup": (24, 2, (8, 0), (), "VatGroup", None),
		"VendorNum": (12, 2, (8, 0), (), "VendorNum", None),
		"VisualOrder": (121, 2, (3, 0), (), "VisualOrder", None),
		"Volume": (45, 2, (5, 0), (), "Volume", None),
		"VolumeUnit": (46, 2, (3, 0), (), "VolumeUnit", None),
		"WTLiable": (77, 2, (3, 0), (), "WTLiable", None),
		"WarehouseCode": (14, 2, (8, 0), (), "WarehouseCode", None),
		"Weight1": (33, 2, (5, 0), (), "Weight1", None),
		"Weight1Unit": (34, 2, (3, 0), (), "Weight1Unit", None),
		"Weight2": (35, 2, (5, 0), (), "Weight2", None),
		"Weight2Unit": (36, 2, (3, 0), (), "Weight2Unit", None),
		"Width1": (50, 2, (5, 0), (), "Width1", None),
		"Width1Unit": (51, 2, (3, 0), (), "Width1Unit", None),
		"Width2": (52, 2, (5, 0), (), "Width2", None),
		"Width2Unit": (53, 2, (3, 0), (), "Width2Unit", None),
		# Method 'WithholdingTaxLines' returns object of type 'IWithholdingTaxLines'
		"WithholdingTaxLines": (98, 2, (9, 0), (), "WithholdingTaxLines", '{458A15A5-B980-4543-A289-F6477A36EB24}'),
		"WithoutInventoryMovement": (192, 2, (3, 0), (), "WithoutInventoryMovement", None),
	}
	_prop_map_put_ = {
		"AccountCode": ((18, LCID, 4, 0),()),
		"ActualBaseEntry": ((196, LCID, 4, 0),()),
		"ActualBaseLine": ((197, LCID, 4, 0),()),
		"ActualDeliveryDate": ((132, LCID, 4, 0),()),
		"Address": ((54, LCID, 4, 0),()),
		"AgreementNo": ((193, LCID, 4, 0),()),
		"AgreementRowNumber": ((194, LCID, 4, 0),()),
		"BackOrder": ((62, LCID, 4, 0),()),
		"BarCode": ((23, LCID, 4, 0),()),
		"BaseEntry": ((42, LCID, 4, 0),()),
		"BaseLine": ((43, LCID, 4, 0),()),
		"BaseType": ((41, LCID, 4, 0),()),
		"CFOPCode": ((99, LCID, 4, 0),()),
		"COGSAccountCode": ((129, LCID, 4, 0),()),
		"COGSCostingCode": ((128, LCID, 4, 0),()),
		"COGSCostingCode2": ((184, LCID, 4, 0),()),
		"COGSCostingCode3": ((185, LCID, 4, 0),()),
		"COGSCostingCode4": ((186, LCID, 4, 0),()),
		"COGSCostingCode5": ((187, LCID, 4, 0),()),
		"CSTCode": ((100, LCID, 4, 0),()),
		"CSTforCOFINS": ((190, LCID, 4, 0),()),
		"CSTforIPI": ((188, LCID, 4, 0),()),
		"CSTforPIS": ((189, LCID, 4, 0),()),
		"ChangeAssemlyBoMWarehouse": ((130, LCID, 4, 0),()),
		"CommisionPercent": ((16, LCID, 4, 0),()),
		"ConsumerSalesForecast": ((97, LCID, 4, 0),()),
		"CorrInvAmountToDiffAcct": ((73, LCID, 4, 0),()),
		"CorrInvAmountToStock": ((72, LCID, 4, 0),()),
		"CorrectionInvoiceItem": ((71, LCID, 4, 0),()),
		"CostingCode": ((21, LCID, 4, 0),()),
		"CostingCode2": ((134, LCID, 4, 0),()),
		"CostingCode3": ((135, LCID, 4, 0),()),
		"CostingCode4": ((136, LCID, 4, 0),()),
		"CostingCode5": ((137, LCID, 4, 0),()),
		"CountryOrg": ((95, LCID, 4, 0),()),
		"CreditOriginCode": ((191, LCID, 4, 0),()),
		"Currency": ((9, LCID, 4, 0),()),
		"DefectAndBreakup": ((202, LCID, 4, 0),()),
		"DeferredTax": ((88, LCID, 4, 0),()),
		"DiscountPercent": ((11, LCID, 4, 0),()),
		"DistributeExpense": ((107, LCID, 4, 0),()),
		"ExLineNo": ((173, LCID, 4, 0),()),
		"ExciseAmount": ((92, LCID, 4, 0),()),
		"Factor1": ((37, LCID, 4, 0),()),
		"Factor2": ((38, LCID, 4, 0),()),
		"Factor3": ((39, LCID, 4, 0),()),
		"Factor4": ((40, LCID, 4, 0),()),
		"FreeText": ((63, LCID, 4, 0),()),
		"GrossBase": ((171, LCID, 4, 0),()),
		"GrossBuyPrice": ((170, LCID, 4, 0),()),
		"GrossProfitTotalBasePrice": ((172, LCID, 4, 0),()),
		"Height1": ((25, LCID, 4, 0),()),
		"Height2": ((27, LCID, 4, 0),()),
		"Height2Unit": ((28, LCID, 4, 0),()),
		"Hight1Unit": ((26, LCID, 4, 0),()),
		"ItemCode": ((3, LCID, 4, 0),()),
		"ItemDescription": ((4, LCID, 4, 0),()),
		"ItemDetails": ((131, LCID, 4, 0),()),
		"Lengh1": ((29, LCID, 4, 0),()),
		"Lengh1Unit": ((30, LCID, 4, 0),()),
		"Lengh2": ((31, LCID, 4, 0),()),
		"Lengh2Unit": ((32, LCID, 4, 0),()),
		"LineStatus": ((124, LCID, 4, 0),()),
		"LineTotal": ((84, LCID, 4, 0),()),
		"LineType": ((127, LCID, 4, 0),()),
		"LocationCode": ((133, LCID, 4, 0),()),
		"MeasureUnit": ((90, LCID, 4, 0),()),
		"NetTaxAmount": ((81, LCID, 4, 0),()),
		"NetTaxAmountFC": ((82, LCID, 4, 0),()),
		"Price": ((7, LCID, 4, 0),()),
		"PriceAfterVAT": ((8, LCID, 4, 0),()),
		"ProjectCode": ((22, LCID, 4, 0),()),
		"Quantity": ((5, LCID, 4, 0),()),
		"Rate": ((10, LCID, 4, 0),()),
		"RequiredDate": ((182, LCID, 4, 0),()),
		"RequiredQuantity": ((183, LCID, 4, 0),()),
		"RowTotalFC": ((109, LCID, 4, 0),()),
		"SWW": ((96, LCID, 4, 0),()),
		"SalesPersonCode": ((15, LCID, 4, 0),()),
		"SerialNum": ((13, LCID, 4, 0),()),
		"ShipDate": ((6, LCID, 4, 0),()),
		"ShipToCode": ((108, LCID, 4, 0),()),
		"ShipToDescription": ((195, LCID, 4, 0),()),
		"ShippingMethod": ((64, LCID, 4, 0),()),
		"Shortages": ((203, LCID, 4, 0),()),
		"SupplierCatNum": ((20, LCID, 4, 0),()),
		"Surpluses": ((201, LCID, 4, 0),()),
		"TaxCode": ((55, LCID, 4, 0),()),
		"TaxLiable": ((57, LCID, 4, 0),()),
		"TaxOnly": ((102, LCID, 4, 0),()),
		"TaxPercentagePerRow": ((86, LCID, 4, 0),()),
		"TaxTotal": ((87, LCID, 4, 0),()),
		"TaxType": ((56, LCID, 4, 0),()),
		"TransactionType": ((106, LCID, 4, 0),()),
		"UnitPrice": ((123, LCID, 4, 0),()),
		"UnitsOfMeasurment": ((91, LCID, 4, 0),()),
		"Usage": ((101, LCID, 4, 0),()),
		"UseBaseUnits": ((19, LCID, 4, 0),()),
		"VatGroup": ((24, LCID, 4, 0),()),
		"VendorNum": ((12, LCID, 4, 0),()),
		"Volume": ((45, LCID, 4, 0),()),
		"VolumeUnit": ((46, LCID, 4, 0),()),
		"WTLiable": ((77, LCID, 4, 0),()),
		"WarehouseCode": ((14, LCID, 4, 0),()),
		"Weight1": ((33, LCID, 4, 0),()),
		"Weight1Unit": ((34, LCID, 4, 0),()),
		"Weight2": ((35, LCID, 4, 0),()),
		"Weight2Unit": ((36, LCID, 4, 0),()),
		"Width1": ((50, LCID, 4, 0),()),
		"Width1Unit": ((51, LCID, 4, 0),()),
		"Width2": ((52, LCID, 4, 0),()),
		"Width2Unit": ((53, LCID, 4, 0),()),
		"WithoutInventoryMovement": ((192, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(47, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDocument_LinesAdditionalExpenses(DispatchBaseClass):
	'IDocument_LinesAdditionalExpenses Interface'
	CLSID = IID('{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}')
	coclass_clsid = IID('{7F3611B7-822C-41C3-82DB-2D8909B59C7A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(102, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(101, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AquisitionTax": (19, 2, (3, 0), (), "AquisitionTax", None),
		"BaseGroup": (105, 2, (3, 0), (), "BaseGroup", None),
		"Count": (100, 2, (3, 0), (), "Count", None),
		"DeductibleTaxSum": (16, 2, (5, 0), (), "DeductibleTaxSum", None),
		"DeductibleTaxSumFC": (17, 2, (5, 0), (), "DeductibleTaxSumFC", None),
		"DeductibleTaxSumSys": (18, 2, (5, 0), (), "DeductibleTaxSumSys", None),
		"DistributionRule": (107, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (123, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (124, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (125, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (126, 2, (8, 0), (), "DistributionRule5", None),
		"EqualizationTaxFC": (27, 2, (5, 0), (), "EqualizationTaxFC", None),
		"EqualizationTaxPercent": (25, 2, (5, 0), (), "EqualizationTaxPercent", None),
		"EqualizationTaxSum": (26, 2, (5, 0), (), "EqualizationTaxSum", None),
		"EqualizationTaxSys": (28, 2, (5, 0), (), "EqualizationTaxSys", None),
		"ExpenseCode": (3, 2, (3, 0), (), "ExpenseCode", None),
		"GroupCode": (2, 2, (3, 0), (), "GroupCode", None),
		"LineNumber": (1, 2, (3, 0), (), "LineNumber", None),
		"LineTotal": (4, 2, (5, 0), (), "LineTotal", None),
		"LineTotalFC": (5, 2, (5, 0), (), "LineTotalFC", None),
		"LineTotalSys": (6, 2, (5, 0), (), "LineTotalSys", None),
		"PaidToDate": (7, 2, (5, 0), (), "PaidToDate", None),
		"PaidToDateFC": (8, 2, (5, 0), (), "PaidToDateFC", None),
		"PaidToDateSys": (9, 2, (5, 0), (), "PaidToDateSys", None),
		"Project": (122, 2, (8, 0), (), "Project", None),
		"TaxCode": (106, 2, (8, 0), (), "TaxCode", None),
		# Method 'TaxJurisdictions' returns object of type 'ITaxJurisdictions'
		"TaxJurisdictions": (121, 2, (9, 0), (), "TaxJurisdictions", '{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}'),
		"TaxLiable": (10, 2, (3, 0), (), "TaxLiable", None),
		"TaxPaid": (22, 2, (5, 0), (), "TaxPaid", None),
		"TaxPaidFC": (23, 2, (5, 0), (), "TaxPaidFC", None),
		"TaxPaidSys": (24, 2, (5, 0), (), "TaxPaidSys", None),
		"TaxPercent": (12, 2, (5, 0), (), "TaxPercent", None),
		"TaxSum": (13, 2, (5, 0), (), "TaxSum", None),
		"TaxSumFC": (14, 2, (5, 0), (), "TaxSumFC", None),
		"TaxSumSys": (15, 2, (5, 0), (), "TaxSumSys", None),
		"TaxTotalSum": (29, 2, (5, 0), (), "TaxTotalSum", None),
		"TaxTotalSumFC": (30, 2, (5, 0), (), "TaxTotalSumFC", None),
		"TaxTotalSumSys": (31, 2, (5, 0), (), "TaxTotalSumSys", None),
		"TaxType": (21, 2, (3, 0), (), "TaxType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (104, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatGroup": (11, 2, (8, 0), (), "VatGroup", None),
		"WTLiable": (103, 2, (3, 0), (), "WTLiable", None),
	}
	_prop_map_put_ = {
		"BaseGroup": ((105, LCID, 4, 0),()),
		"DistributionRule": ((107, LCID, 4, 0),()),
		"DistributionRule2": ((123, LCID, 4, 0),()),
		"DistributionRule3": ((124, LCID, 4, 0),()),
		"DistributionRule4": ((125, LCID, 4, 0),()),
		"DistributionRule5": ((126, LCID, 4, 0),()),
		"ExpenseCode": ((3, LCID, 4, 0),()),
		"GroupCode": ((2, LCID, 4, 0),()),
		"LineNumber": ((1, LCID, 4, 0),()),
		"LineTotal": ((4, LCID, 4, 0),()),
		"Project": ((122, LCID, 4, 0),()),
		"TaxCode": ((106, LCID, 4, 0),()),
		"TaxSum": ((13, LCID, 4, 0),()),
		"TaxType": ((21, LCID, 4, 0),()),
		"VatGroup": ((11, LCID, 4, 0),()),
		"WTLiable": ((103, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(100, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDocument_SpecialLines(DispatchBaseClass):
	'IDocument_SpecialLines Interface'
	CLSID = IID('{6ECD0990-1D31-4DDF-AF93-494A9DD7A104}')
	coclass_clsid = IID('{E0F9420B-02BE-490B-BE28-1216726EF3FD}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AfterLineNumber": (11, 2, (3, 0), (), "AfterLineNumber", None),
		"Count": (4, 2, (3, 0), (), "Count", None),
		"Freight1": (21, 2, (5, 0), (), "Freight1", None),
		"Freight1FC": (22, 2, (5, 0), (), "Freight1FC", None),
		"Freight1SC": (23, 2, (5, 0), (), "Freight1SC", None),
		"Freight2": (24, 2, (5, 0), (), "Freight2", None),
		"Freight2FC": (25, 2, (5, 0), (), "Freight2FC", None),
		"Freight2SC": (26, 2, (5, 0), (), "Freight2SC", None),
		"Freight3": (27, 2, (5, 0), (), "Freight3", None),
		"Freight3FC": (28, 2, (5, 0), (), "Freight3FC", None),
		"Freight3SC": (29, 2, (5, 0), (), "Freight3SC", None),
		"GrossTotal": (30, 2, (5, 0), (), "GrossTotal", None),
		"GrossTotalFC": (31, 2, (5, 0), (), "GrossTotalFC", None),
		"GrossTotalSC": (32, 2, (5, 0), (), "GrossTotalSC", None),
		"LineNum": (10, 2, (3, 0), (), "LineNum", None),
		"LineText": (15, 2, (8, 0), (), "LineText", None),
		"LineType": (13, 2, (3, 0), (), "LineType", None),
		"OrderNumber": (12, 2, (3, 0), (), "OrderNumber", None),
		"Subtotal": (14, 2, (5, 0), (), "Subtotal", None),
		"SubtotalFC": (16, 2, (5, 0), (), "SubtotalFC", None),
		"SubtotalSC": (17, 2, (5, 0), (), "SubtotalSC", None),
		"TaxAmount": (18, 2, (5, 0), (), "TaxAmount", None),
		"TaxAmountFC": (19, 2, (5, 0), (), "TaxAmountFC", None),
		"TaxAmountSC": (20, 2, (5, 0), (), "TaxAmountSC", None),
	}
	_prop_map_put_ = {
		"AfterLineNumber": ((11, LCID, 4, 0),()),
		"LineText": ((15, LCID, 4, 0),()),
		"LineType": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(4, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDocuments(DispatchBaseClass):
	'IDocuments Interface'
	CLSID = IID('{A6DA575B-E105-4585-9F4B-50CC4044EEDD}')
	coclass_clsid = IID('{4AFE074D-4F31-4E7B-87DF-64D55098DA5E}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(44, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(45, LCID, 1, (3, 0), (),)

	def GetApprovalTemplates(self):
		'method GetApprovalTemplates'
		return self._oleobj_.InvokeTypes(214, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(137, LCID, 1, (8, 0), (),)

	def GetByKey(self, AbsEntry=defaultNamedNotOptArg):
		'Get by key'
		return self._oleobj_.InvokeTypes(35, LCID, 1, (11, 0), ((3, 0),),AbsEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(46, LCID, 1, (3, 0), (),)

	def Reopen(self):
		'method Reopen'
		return self._oleobj_.InvokeTypes(171, LCID, 1, (3, 0), (),)

	def SaveDraftToDocument(self):
		'method SaveDraftToDocument'
		return self._oleobj_.InvokeTypes(213, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(138, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save object as XML document'
		return self._ApplyTypes_(38, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(39, LCID, 1, (3, 0), (),)

	def UpdateFromXML(self, FileName=defaultNamedNotOptArg):
		'method UpdateFromXML'
		return self._oleobj_.InvokeTypes(217, LCID, 1, (3, 0), ((8, 1),),FileName
			)

	_prop_map_get_ = {
		"Address": (11, 2, (8, 0), (), "Address", None),
		"Address2": (125, 2, (8, 0), (), "Address2", None),
		# Method 'AddressExtension' returns object of type 'IAddressExtension'
		"AddressExtension": (173, 2, (9, 0), (), "AddressExtension", '{7CBD5DDC-C99C-4D73-9ECC-C8B6CDF2FB92}'),
		"AgentCode": (97, 2, (8, 0), (), "AgentCode", None),
		"AnnualInvoiceDeclarationReference": (226, 2, (3, 0), (), "AnnualInvoiceDeclarationReference", None),
		"ApplyCurrentVATRatesForDownPaymentsToDraw": (204, 2, (3, 0), (), "ApplyCurrentVATRatesForDownPaymentsToDraw", None),
		"ApplyTaxOnFirstInstallment": (103, 2, (3, 0), (), "ApplyTaxOnFirstInstallment", None),
		"ArchiveNonremovableSalesQuotation": (175, 2, (3, 0), (), "ArchiveNonremovableSalesQuotation", None),
		"AuthorizationStatus": (216, 2, (3, 0), (), "AuthorizationStatus", None),
		"BPChannelCode": (121, 2, (8, 0), (), "BPChannelCode", None),
		"BPChannelContact": (122, 2, (3, 0), (), "BPChannelContact", None),
		"BPLName": (224, 2, (8, 0), (), "BPLName", None),
		"BPL_IDAssignedToInvoice": (139, 2, (3, 0), (), "BPL_IDAssignedToInvoice", None),
		"BaseAmount": (114, 2, (5, 0), (), "BaseAmount", None),
		"BaseAmountFC": (111, 2, (5, 0), (), "BaseAmountFC", None),
		"BaseAmountSC": (110, 2, (5, 0), (), "BaseAmountSC", None),
		"BillOfExchangeReserved": (96, 2, (3, 0), (), "BillOfExchangeReserved", None),
		"BlanketAgreementNumber": (230, 2, (3, 0), (), "BlanketAgreementNumber", None),
		"BlockDunning": (67, 2, (3, 0), (), "BlockDunning", None),
		"Box1099": (63, 2, (8, 0), (), "Box1099", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (48, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CancelDate": (66, 2, (7, 0), (), "CancelDate", None),
		"Cancelled": (169, 2, (3, 0), (), "Cancelled", None),
		"CardCode": (9, 2, (8, 0), (), "CardCode", None),
		"CardName": (10, 2, (8, 0), (), "CardName", None),
		"CashDiscountDateOffset": (180, 2, (3, 0), (), "CashDiscountDateOffset", None),
		"CentralBankIndicator": (75, 2, (8, 0), (), "CentralBankIndicator", None),
		"CertificationNumber": (188, 2, (8, 0), (), "CertificationNumber", None),
		"ClosingDate": (140, 2, (7, 0), (), "ClosingDate", None),
		"ClosingOption": (210, 2, (3, 0), (), "ClosingOption", None),
		"ClosingRemarks": (165, 2, (8, 0), (), "ClosingRemarks", None),
		"Comments": (18, 2, (8, 0), (), "Comments", None),
		"Confirmed": (25, 2, (3, 0), (), "Confirmed", None),
		"ContactPersonCode": (28, 2, (3, 0), (), "ContactPersonCode", None),
		"ControlAccount": (174, 2, (8, 0), (), "ControlAccount", None),
		"CreateOnlineQuotation": (200, 2, (3, 0), (), "CreateOnlineQuotation", None),
		"CreationDate": (52, 2, (7, 0), (), "CreationDate", None),
		"DeferredTax": (92, 2, (3, 0), (), "DeferredTax", None),
		"DiscountPercent": (49, 2, (5, 0), (), "DiscountPercent", None),
		"DocCurrency": (13, 2, (8, 0), (), "DocCurrency", None),
		"DocDate": (7, 2, (7, 0), (), "DocDate", None),
		"DocDueDate": (8, 2, (7, 0), (), "DocDueDate", None),
		"DocEntry": (51, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (3, 2, (3, 0), (), "DocNum", None),
		"DocObjectCode": (40, 2, (3, 0), (), "DocObjectCode", None),
		"DocObjectCodeEx": (124, 2, (8, 0), (), "DocObjectCodeEx", None),
		"DocRate": (14, 2, (5, 0), (), "DocRate", None),
		"DocTime": (21, 2, (7, 0), (), "DocTime", None),
		"DocTotal": (15, 2, (5, 0), (), "DocTotal", None),
		"DocTotalFc": (60, 2, (5, 0), (), "DocTotalFc", None),
		"DocTotalSys": (61, 2, (5, 0), (), "DocTotalSys", None),
		"DocType": (4, 2, (3, 0), (), "DocType", None),
		"DocumentStatus": (126, 2, (3, 0), (), "DocumentStatus", None),
		"DocumentSubType": (120, 2, (3, 0), (), "DocumentSubType", None),
		# Method 'Document_ApprovalRequests' returns object of type 'IDocument_ApprovalRequests'
		"Document_ApprovalRequests": (215, 2, (9, 0), (), "Document_ApprovalRequests", '{CEDAC9E2-A77F-4518-A524-1403050FFD3D}'),
		"DocumentsOwner": (130, 2, (3, 0), (), "DocumentsOwner", None),
		"DownPayment": (147, 2, (5, 0), (), "DownPayment", None),
		"DownPaymentAmount": (158, 2, (5, 0), (), "DownPaymentAmount", None),
		"DownPaymentAmountFC": (162, 2, (5, 0), (), "DownPaymentAmountFC", None),
		"DownPaymentAmountSC": (163, 2, (5, 0), (), "DownPaymentAmountSC", None),
		"DownPaymentPercentage": (159, 2, (5, 0), (), "DownPaymentPercentage", None),
		"DownPaymentStatus": (199, 2, (3, 0), (), "DownPaymentStatus", None),
		"DownPaymentType": (160, 2, (3, 0), (), "DownPaymentType", None),
		# Method 'DownPaymentsToDraw' returns object of type 'IDownPaymentsToDraw'
		"DownPaymentsToDraw": (161, 2, (9, 0), (), "DownPaymentsToDraw", '{DFF94208-9A06-4594-992D-8D758D296BD4}'),
		"EDocErrorCode": (222, 2, (8, 0), (), "EDocErrorCode", None),
		"EDocErrorMessage": (223, 2, (8, 0), (), "EDocErrorMessage", None),
		"EDocExportFormat": (198, 2, (3, 0), (), "EDocExportFormat", None),
		"EDocGenerationType": (195, 2, (3, 0), (), "EDocGenerationType", None),
		"EDocNum": (197, 2, (8, 0), (), "EDocNum", None),
		"EDocSeries": (196, 2, (3, 0), (), "EDocSeries", None),
		"EDocStatus": (221, 2, (3, 0), (), "EDocStatus", None),
		"ETaxNumber": (184, 2, (8, 0), (), "ETaxNumber", None),
		"ETaxWebSite": (183, 2, (3, 0), (), "ETaxWebSite", None),
		"ExemptionValidityDateFrom": (80, 2, (7, 0), (), "ExemptionValidityDateFrom", None),
		"ExemptionValidityDateTo": (81, 2, (7, 0), (), "ExemptionValidityDateTo", None),
		# Method 'Expenses' returns object of type 'IDocumentsAdditionalExpenses'
		"Expenses": (83, 2, (9, 0), (), "Expenses", '{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}'),
		"ExternalCorrectedDocNum": (89, 2, (8, 0), (), "ExternalCorrectedDocNum", None),
		"ExtraDays": (179, 2, (3, 0), (), "ExtraDays", None),
		"ExtraMonth": (178, 2, (3, 0), (), "ExtraMonth", None),
		"FederalTaxID": (43, 2, (8, 0), (), "FederalTaxID", None),
		"FinancialPeriod": (54, 2, (3, 0), (), "FinancialPeriod", None),
		"FolioNumber": (119, 2, (3, 0), (), "FolioNumber", None),
		"FolioPrefixString": (131, 2, (8, 0), (), "FolioPrefixString", None),
		"Form1099": (62, 2, (3, 0), (), "Form1099", None),
		"GTSChecker": (176, 2, (3, 0), (), "GTSChecker", None),
		"GTSPayee": (177, 2, (3, 0), (), "GTSPayee", None),
		"GroupHandWritten": (192, 2, (3, 0), (), "GroupHandWritten", None),
		"GroupNumber": (191, 2, (3, 0), (), "GroupNumber", None),
		"GroupSeries": (190, 2, (3, 0), (), "GroupSeries", None),
		"HandWritten": (5, 2, (3, 0), (), "HandWritten", None),
		"ImportFileNum": (26, 2, (3, 0), (), "ImportFileNum", None),
		"Indicator": (42, 2, (8, 0), (), "Indicator", None),
		# Method 'Installments' returns object of type 'IDocument_Installments'
		"Installments": (156, 2, (9, 0), (), "Installments", '{3E64E5EC-70CA-4129-BC06-0CE9B2058843}'),
		"InsuranceOperation347": (170, 2, (3, 0), (), "InsuranceOperation347", None),
		"InternalCorrectedDocNum": (90, 2, (3, 0), (), "InternalCorrectedDocNum", None),
		"IsAlteration": (231, 2, (3, 0), (), "IsAlteration", None),
		"IsPayToBank": (132, 2, (3, 0), (), "IsPayToBank", None),
		"JournalMemo": (19, 2, (8, 0), (), "JournalMemo", None),
		"LanguageCode": (149, 2, (3, 0), (), "LanguageCode", None),
		# Method 'Lines' returns object of type 'IDocument_Lines'
		"Lines": (2, 2, (9, 0), (), "Lines", '{248B28DD-1281-4C6C-9780-22D19BA13D1F}'),
		"ManualNumber": (117, 2, (8, 0), (), "ManualNumber", None),
		"MaximumCashDiscount": (76, 2, (3, 0), (), "MaximumCashDiscount", None),
		"NTSApproved": (182, 2, (3, 0), (), "NTSApproved", None),
		"NTSApprovedNumber": (185, 2, (8, 0), (), "NTSApprovedNumber", None),
		"NetProcedure": (59, 2, (3, 0), (), "NetProcedure", None),
		"NextCorrectingDocument": (91, 2, (3, 0), (), "NextCorrectingDocument", None),
		"NumAtCard": (12, 2, (8, 0), (), "NumAtCard", None),
		"NumberOfInstallments": (102, 2, (3, 0), (), "NumberOfInstallments", None),
		"OpenForLandedCosts": (212, 2, (3, 0), (), "OpenForLandedCosts", None),
		"OpeningRemarks": (164, 2, (8, 0), (), "OpeningRemarks", None),
		"POSCashierNumber": (203, 2, (3, 0), (), "POSCashierNumber", None),
		"POSEquipmentNumber": (201, 2, (8, 0), (), "POSEquipmentNumber", None),
		"POSManufacturerSerialNumber": (202, 2, (8, 0), (), "POSManufacturerSerialNumber", None),
		# Method 'Packages' returns object of type 'IDocumentPackages'
		"Packages": (155, 2, (9, 0), (), "Packages", '{07F27714-4BA9-42E3-8E93-3418F73C55E4}'),
		"PartialSupply": (32, 2, (3, 0), (), "PartialSupply", None),
		"PayToBankAccountNo": (135, 2, (8, 0), (), "PayToBankAccountNo", None),
		"PayToBankBranch": (136, 2, (8, 0), (), "PayToBankBranch", None),
		"PayToBankCode": (134, 2, (8, 0), (), "PayToBankCode", None),
		"PayToBankCountry": (133, 2, (8, 0), (), "PayToBankCountry", None),
		"PayToCode": (129, 2, (8, 0), (), "PayToCode", None),
		"PaymentBlock": (73, 2, (3, 0), (), "PaymentBlock", None),
		"PaymentBlockEntry": (74, 2, (3, 0), (), "PaymentBlockEntry", None),
		"PaymentGroupCode": (20, 2, (3, 0), (), "PaymentGroupCode", None),
		"PaymentMethod": (72, 2, (8, 0), (), "PaymentMethod", None),
		"PaymentReference": (50, 2, (8, 0), (), "PaymentReference", None),
		"PeriodIndicator": (127, 2, (8, 0), (), "PeriodIndicator", None),
		"Pick": (71, 2, (3, 0), (), "Pick", None),
		"PickRemark": (151, 2, (8, 0), (), "PickRemark", None),
		"PickStatus": (70, 2, (3, 0), (), "PickStatus", None),
		"Printed": (6, 2, (3, 0), (), "Printed", None),
		"PrivateKeyVersion": (189, 2, (3, 0), (), "PrivateKeyVersion", None),
		"Project": (78, 2, (8, 0), (), "Project", None),
		"Receiver": (229, 2, (3, 0), (), "Receiver", None),
		"Reference1": (16, 2, (8, 0), (), "Reference1", None),
		"Reference2": (17, 2, (8, 0), (), "Reference2", None),
		"Releaser": (228, 2, (3, 0), (), "Releaser", None),
		"RelevantToGTS": (220, 2, (3, 0), (), "RelevantToGTS", None),
		"ReopenManuallyClosedOrCanceledDocument": (194, 2, (3, 0), (), "ReopenManuallyClosedOrCanceledDocument", None),
		"ReopenOriginalDocument": (193, 2, (3, 0), (), "ReopenOriginalDocument", None),
		"RequriedDate": (65, 2, (7, 0), (), "RequriedDate", None),
		"Reserve": (77, 2, (3, 0), (), "Reserve", None),
		"ReserveInvoice": (148, 2, (3, 0), (), "ReserveInvoice", None),
		"RevisionPo": (64, 2, (3, 0), (), "RevisionPo", None),
		"Rounding": (84, 2, (3, 0), (), "Rounding", None),
		"RoundingDiffAmount": (166, 2, (5, 0), (), "RoundingDiffAmount", None),
		"RoundingDiffAmountFC": (167, 2, (5, 0), (), "RoundingDiffAmountFC", None),
		"RoundingDiffAmountSC": (168, 2, (5, 0), (), "RoundingDiffAmountSC", None),
		"SalesPersonCode": (22, 2, (3, 0), (), "SalesPersonCode", None),
		"Segment": (69, 2, (3, 0), (), "Segment", None),
		"SequenceCode": (142, 2, (3, 0), (), "SequenceCode", None),
		"SequenceModel": (145, 2, (8, 0), (), "SequenceModel", None),
		"SequenceSerial": (141, 2, (3, 0), (), "SequenceSerial", None),
		"Series": (30, 2, (3, 0), (), "Series", None),
		"SeriesString": (143, 2, (8, 0), (), "SeriesString", None),
		"ServiceGrossProfitPercent": (172, 2, (5, 0), (), "ServiceGrossProfitPercent", None),
		"ShipToCode": (41, 2, (8, 0), (), "ShipToCode", None),
		"ShowSCN": (29, 2, (3, 0), (), "ShowSCN", None),
		"SignatureDigest": (187, 2, (8, 0), (), "SignatureDigest", None),
		"SignatureInputMessage": (186, 2, (8, 0), (), "SignatureInputMessage", None),
		# Method 'SpecialLines' returns object of type 'IDocument_SpecialLines'
		"SpecialLines": (157, 2, (9, 0), (), "SpecialLines", '{6ECD0990-1D31-4DDF-AF93-494A9DD7A104}'),
		"SpecifiedClosingDate": (211, 2, (7, 0), (), "SpecifiedClosingDate", None),
		"StartFrom": (181, 2, (3, 0), (), "StartFrom", None),
		"SubSeriesString": (144, 2, (8, 0), (), "SubSeriesString", None),
		"Submitted": (68, 2, (3, 0), (), "Submitted", None),
		"SummeryType": (27, 2, (3, 0), (), "SummeryType", None),
		"Supplier": (227, 2, (8, 0), (), "Supplier", None),
		"TaxDate": (31, 2, (7, 0), (), "TaxDate", None),
		"TaxExemptionLetterNum": (93, 2, (8, 0), (), "TaxExemptionLetterNum", None),
		# Method 'TaxExtension' returns object of type 'ITaxExtension'
		"TaxExtension": (146, 2, (9, 0), (), "TaxExtension", '{8CC29ECE-02C3-4C7B-851B-5533D2C83627}'),
		"TotalDiscount": (153, 2, (5, 0), (), "TotalDiscount", None),
		"TotalDiscountFC": (218, 2, (5, 0), (), "TotalDiscountFC", None),
		"TotalDiscountSC": (219, 2, (5, 0), (), "TotalDiscountSC", None),
		"TotalEqualizationTax": (99, 2, (5, 0), (), "TotalEqualizationTax", None),
		"TotalEqualizationTaxFC": (100, 2, (5, 0), (), "TotalEqualizationTaxFC", None),
		"TotalEqualizationTaxSC": (101, 2, (5, 0), (), "TotalEqualizationTaxSC", None),
		"TrackingNumber": (150, 2, (8, 0), (), "TrackingNumber", None),
		"TransNum": (55, 2, (3, 0), (), "TransNum", None),
		"TransportationCode": (23, 2, (3, 0), (), "TransportationCode", None),
		"UpdateDate": (53, 2, (7, 0), (), "UpdateDate", None),
		"UseCorrectionVATGroup": (152, 2, (3, 0), (), "UseCorrectionVATGroup", None),
		"UseShpdGoodsAct": (118, 2, (3, 0), (), "UseShpdGoodsAct", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (37, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATRegNum": (225, 2, (8, 0), (), "VATRegNum", None),
		"VatDate": (116, 2, (7, 0), (), "VatDate", None),
		"VatPercent": (154, 2, (5, 0), (), "VatPercent", None),
		"VatSum": (56, 2, (5, 0), (), "VatSum", None),
		"VatSumFc": (58, 2, (5, 0), (), "VatSumFc", None),
		"VatSumSys": (57, 2, (5, 0), (), "VatSumSys", None),
		"WTAmount": (115, 2, (5, 0), (), "WTAmount", None),
		"WTAmountFC": (112, 2, (5, 0), (), "WTAmountFC", None),
		"WTAmountSC": (113, 2, (5, 0), (), "WTAmountSC", None),
		"WTApplied": (94, 2, (5, 0), (), "WTApplied", None),
		"WTAppliedFC": (95, 2, (5, 0), (), "WTAppliedFC", None),
		"WTAppliedSC": (98, 2, (5, 0), (), "WTAppliedSC", None),
		"WTExemptedAmount": (107, 2, (5, 0), (), "WTExemptedAmount", None),
		"WTExemptedAmountFC": (109, 2, (5, 0), (), "WTExemptedAmountFC", None),
		"WTExemptedAmountSC": (108, 2, (5, 0), (), "WTExemptedAmountSC", None),
		"WTNonSubjectAmount": (104, 2, (5, 0), (), "WTNonSubjectAmount", None),
		"WTNonSubjectAmountFC": (106, 2, (5, 0), (), "WTNonSubjectAmountFC", None),
		"WTNonSubjectAmountSC": (105, 2, (5, 0), (), "WTNonSubjectAmountSC", None),
		"WareHouseUpdateType": (82, 2, (3, 0), (), "WareHouseUpdateType", None),
		# Method 'WithholdingTaxData' returns object of type 'IWithholdingTaxData'
		"WithholdingTaxData": (123, 2, (9, 0), (), "WithholdingTaxData", '{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}'),
	}
	_prop_map_put_ = {
		"Address": ((11, LCID, 4, 0),()),
		"Address2": ((125, LCID, 4, 0),()),
		"AgentCode": ((97, LCID, 4, 0),()),
		"AnnualInvoiceDeclarationReference": ((226, LCID, 4, 0),()),
		"ApplyCurrentVATRatesForDownPaymentsToDraw": ((204, LCID, 4, 0),()),
		"ApplyTaxOnFirstInstallment": ((103, LCID, 4, 0),()),
		"ArchiveNonremovableSalesQuotation": ((175, LCID, 4, 0),()),
		"BPChannelCode": ((121, LCID, 4, 0),()),
		"BPChannelContact": ((122, LCID, 4, 0),()),
		"BPL_IDAssignedToInvoice": ((139, LCID, 4, 0),()),
		"BlanketAgreementNumber": ((230, LCID, 4, 0),()),
		"BlockDunning": ((67, LCID, 4, 0),()),
		"Box1099": ((63, LCID, 4, 0),()),
		"CancelDate": ((66, LCID, 4, 0),()),
		"CardCode": ((9, LCID, 4, 0),()),
		"CardName": ((10, LCID, 4, 0),()),
		"CashDiscountDateOffset": ((180, LCID, 4, 0),()),
		"CentralBankIndicator": ((75, LCID, 4, 0),()),
		"ClosingDate": ((140, LCID, 4, 0),()),
		"ClosingOption": ((210, LCID, 4, 0),()),
		"ClosingRemarks": ((165, LCID, 4, 0),()),
		"Comments": ((18, LCID, 4, 0),()),
		"Confirmed": ((25, LCID, 4, 0),()),
		"ContactPersonCode": ((28, LCID, 4, 0),()),
		"ControlAccount": ((174, LCID, 4, 0),()),
		"CreateOnlineQuotation": ((200, LCID, 4, 0),()),
		"DeferredTax": ((92, LCID, 4, 0),()),
		"DiscountPercent": ((49, LCID, 4, 0),()),
		"DocCurrency": ((13, LCID, 4, 0),()),
		"DocDate": ((7, LCID, 4, 0),()),
		"DocDueDate": ((8, LCID, 4, 0),()),
		"DocNum": ((3, LCID, 4, 0),()),
		"DocObjectCode": ((40, LCID, 4, 0),()),
		"DocObjectCodeEx": ((124, LCID, 4, 0),()),
		"DocRate": ((14, LCID, 4, 0),()),
		"DocTime": ((21, LCID, 4, 0),()),
		"DocTotal": ((15, LCID, 4, 0),()),
		"DocTotalFc": ((60, LCID, 4, 0),()),
		"DocType": ((4, LCID, 4, 0),()),
		"DocumentSubType": ((120, LCID, 4, 0),()),
		"DocumentsOwner": ((130, LCID, 4, 0),()),
		"DownPayment": ((147, LCID, 4, 0),()),
		"DownPaymentAmount": ((158, LCID, 4, 0),()),
		"DownPaymentAmountFC": ((162, LCID, 4, 0),()),
		"DownPaymentAmountSC": ((163, LCID, 4, 0),()),
		"DownPaymentPercentage": ((159, LCID, 4, 0),()),
		"DownPaymentStatus": ((199, LCID, 4, 0),()),
		"DownPaymentType": ((160, LCID, 4, 0),()),
		"EDocErrorCode": ((222, LCID, 4, 0),()),
		"EDocErrorMessage": ((223, LCID, 4, 0),()),
		"EDocExportFormat": ((198, LCID, 4, 0),()),
		"EDocGenerationType": ((195, LCID, 4, 0),()),
		"EDocSeries": ((196, LCID, 4, 0),()),
		"EDocStatus": ((221, LCID, 4, 0),()),
		"ETaxNumber": ((184, LCID, 4, 0),()),
		"ETaxWebSite": ((183, LCID, 4, 0),()),
		"ExemptionValidityDateFrom": ((80, LCID, 4, 0),()),
		"ExemptionValidityDateTo": ((81, LCID, 4, 0),()),
		"ExternalCorrectedDocNum": ((89, LCID, 4, 0),()),
		"ExtraDays": ((179, LCID, 4, 0),()),
		"ExtraMonth": ((178, LCID, 4, 0),()),
		"FederalTaxID": ((43, LCID, 4, 0),()),
		"FolioNumber": ((119, LCID, 4, 0),()),
		"FolioPrefixString": ((131, LCID, 4, 0),()),
		"Form1099": ((62, LCID, 4, 0),()),
		"GTSChecker": ((176, LCID, 4, 0),()),
		"GTSPayee": ((177, LCID, 4, 0),()),
		"GroupHandWritten": ((192, LCID, 4, 0),()),
		"GroupNumber": ((191, LCID, 4, 0),()),
		"GroupSeries": ((190, LCID, 4, 0),()),
		"HandWritten": ((5, LCID, 4, 0),()),
		"ImportFileNum": ((26, LCID, 4, 0),()),
		"Indicator": ((42, LCID, 4, 0),()),
		"InsuranceOperation347": ((170, LCID, 4, 0),()),
		"InternalCorrectedDocNum": ((90, LCID, 4, 0),()),
		"IsAlteration": ((231, LCID, 4, 0),()),
		"IsPayToBank": ((132, LCID, 4, 0),()),
		"JournalMemo": ((19, LCID, 4, 0),()),
		"LanguageCode": ((149, LCID, 4, 0),()),
		"ManualNumber": ((117, LCID, 4, 0),()),
		"MaximumCashDiscount": ((76, LCID, 4, 0),()),
		"NTSApproved": ((182, LCID, 4, 0),()),
		"NTSApprovedNumber": ((185, LCID, 4, 0),()),
		"NumAtCard": ((12, LCID, 4, 0),()),
		"NumberOfInstallments": ((102, LCID, 4, 0),()),
		"OpenForLandedCosts": ((212, LCID, 4, 0),()),
		"OpeningRemarks": ((164, LCID, 4, 0),()),
		"POSCashierNumber": ((203, LCID, 4, 0),()),
		"POSEquipmentNumber": ((201, LCID, 4, 0),()),
		"POSManufacturerSerialNumber": ((202, LCID, 4, 0),()),
		"PartialSupply": ((32, LCID, 4, 0),()),
		"PayToBankAccountNo": ((135, LCID, 4, 0),()),
		"PayToBankBranch": ((136, LCID, 4, 0),()),
		"PayToBankCode": ((134, LCID, 4, 0),()),
		"PayToBankCountry": ((133, LCID, 4, 0),()),
		"PayToCode": ((129, LCID, 4, 0),()),
		"PaymentBlock": ((73, LCID, 4, 0),()),
		"PaymentBlockEntry": ((74, LCID, 4, 0),()),
		"PaymentGroupCode": ((20, LCID, 4, 0),()),
		"PaymentMethod": ((72, LCID, 4, 0),()),
		"PaymentReference": ((50, LCID, 4, 0),()),
		"Pick": ((71, LCID, 4, 0),()),
		"PickRemark": ((151, LCID, 4, 0),()),
		"Printed": ((6, LCID, 4, 0),()),
		"Project": ((78, LCID, 4, 0),()),
		"Receiver": ((229, LCID, 4, 0),()),
		"Reference1": ((16, LCID, 4, 0),()),
		"Reference2": ((17, LCID, 4, 0),()),
		"Releaser": ((228, LCID, 4, 0),()),
		"RelevantToGTS": ((220, LCID, 4, 0),()),
		"ReopenManuallyClosedOrCanceledDocument": ((194, LCID, 4, 0),()),
		"ReopenOriginalDocument": ((193, LCID, 4, 0),()),
		"RequriedDate": ((65, LCID, 4, 0),()),
		"ReserveInvoice": ((148, LCID, 4, 0),()),
		"RevisionPo": ((64, LCID, 4, 0),()),
		"Rounding": ((84, LCID, 4, 0),()),
		"RoundingDiffAmount": ((166, LCID, 4, 0),()),
		"SalesPersonCode": ((22, LCID, 4, 0),()),
		"SequenceCode": ((142, LCID, 4, 0),()),
		"SequenceModel": ((145, LCID, 4, 0),()),
		"SequenceSerial": ((141, LCID, 4, 0),()),
		"Series": ((30, LCID, 4, 0),()),
		"SeriesString": ((143, LCID, 4, 0),()),
		"ServiceGrossProfitPercent": ((172, LCID, 4, 0),()),
		"ShipToCode": ((41, LCID, 4, 0),()),
		"ShowSCN": ((29, LCID, 4, 0),()),
		"SpecifiedClosingDate": ((211, LCID, 4, 0),()),
		"StartFrom": ((181, LCID, 4, 0),()),
		"SubSeriesString": ((144, LCID, 4, 0),()),
		"SummeryType": ((27, LCID, 4, 0),()),
		"Supplier": ((227, LCID, 4, 0),()),
		"TaxDate": ((31, LCID, 4, 0),()),
		"TaxExemptionLetterNum": ((93, LCID, 4, 0),()),
		"TrackingNumber": ((150, LCID, 4, 0),()),
		"TransportationCode": ((23, LCID, 4, 0),()),
		"UseCorrectionVATGroup": ((152, LCID, 4, 0),()),
		"UseShpdGoodsAct": ((118, LCID, 4, 0),()),
		"VatDate": ((116, LCID, 4, 0),()),
		"VatPercent": ((154, LCID, 4, 0),()),
		"WareHouseUpdateType": ((82, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDocumentsAdditionalExpenses(DispatchBaseClass):
	'IDocumentsAdditionalExpenses Interface'
	CLSID = IID('{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}')
	coclass_clsid = IID('{5E9FC07C-E9A5-465A-A532-F12DC65304D4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AquisitionTax": (22, 2, (3, 0), (), "AquisitionTax", None),
		"BaseDocEntry": (36, 2, (3, 0), (), "BaseDocEntry", None),
		"BaseDocLine": (37, 2, (3, 0), (), "BaseDocLine", None),
		"BaseDocType": (38, 2, (3, 0), (), "BaseDocType", None),
		"BaseDocumentReference": (41, 2, (3, 0), (), "BaseDocumentReference", None),
		"Count": (1, 2, (3, 0), (), "Count", None),
		"DeductibleTaxSum": (19, 2, (5, 0), (), "DeductibleTaxSum", None),
		"DeductibleTaxSumFC": (20, 2, (5, 0), (), "DeductibleTaxSumFC", None),
		"DeductibleTaxSumSys": (21, 2, (5, 0), (), "DeductibleTaxSumSys", None),
		"DistributionMethod": (12, 2, (3, 0), (), "DistributionMethod", None),
		"DistributionRule": (49, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (63, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (64, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (65, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (66, 2, (8, 0), (), "DistributionRule5", None),
		"EqualizationTaxFC": (30, 2, (5, 0), (), "EqualizationTaxFC", None),
		"EqualizationTaxPercent": (28, 2, (5, 0), (), "EqualizationTaxPercent", None),
		"EqualizationTaxSum": (29, 2, (5, 0), (), "EqualizationTaxSum", None),
		"EqualizationTaxSys": (31, 2, (5, 0), (), "EqualizationTaxSys", None),
		"ExpenseCode": (4, 2, (3, 0), (), "ExpenseCode", None),
		"LastPurchasePrice": (43, 2, (3, 0), (), "LastPurchasePrice", None),
		"LineNum": (42, 2, (3, 0), (), "LineNum", None),
		"LineTotal": (5, 2, (5, 0), (), "LineTotal", None),
		"LineTotalFC": (6, 2, (5, 0), (), "LineTotalFC", None),
		"LineTotalSys": (7, 2, (5, 0), (), "LineTotalSys", None),
		"PaidToDate": (8, 2, (5, 0), (), "PaidToDate", None),
		"PaidToDateFC": (9, 2, (5, 0), (), "PaidToDateFC", None),
		"PaidToDateSys": (10, 2, (5, 0), (), "PaidToDateSys", None),
		"Project": (62, 2, (8, 0), (), "Project", None),
		"Remarks": (11, 2, (8, 0), (), "Remarks", None),
		"Status": (44, 2, (3, 0), (), "Status", None),
		"Stock": (45, 2, (3, 0), (), "Stock", None),
		"TargetAbsEntry": (46, 2, (3, 0), (), "TargetAbsEntry", None),
		"TargetType": (47, 2, (3, 0), (), "TargetType", None),
		"TaxCode": (23, 2, (8, 0), (), "TaxCode", None),
		# Method 'TaxJurisdictions' returns object of type 'ITaxJurisdictions'
		"TaxJurisdictions": (61, 2, (9, 0), (), "TaxJurisdictions", '{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}'),
		"TaxLiable": (13, 2, (3, 0), (), "TaxLiable", None),
		"TaxPaid": (25, 2, (5, 0), (), "TaxPaid", None),
		"TaxPaidFC": (26, 2, (5, 0), (), "TaxPaidFC", None),
		"TaxPaidSys": (27, 2, (5, 0), (), "TaxPaidSys", None),
		"TaxPercent": (15, 2, (5, 0), (), "TaxPercent", None),
		"TaxSum": (16, 2, (5, 0), (), "TaxSum", None),
		"TaxSumFC": (17, 2, (5, 0), (), "TaxSumFC", None),
		"TaxSumSys": (18, 2, (5, 0), (), "TaxSumSys", None),
		"TaxTotalSum": (32, 2, (5, 0), (), "TaxTotalSum", None),
		"TaxTotalSumFC": (33, 2, (5, 0), (), "TaxTotalSumFC", None),
		"TaxTotalSumSys": (34, 2, (5, 0), (), "TaxTotalSumSys", None),
		"TaxType": (24, 2, (3, 0), (), "TaxType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (35, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatGroup": (14, 2, (8, 0), (), "VatGroup", None),
		"WTLiable": (48, 2, (3, 0), (), "WTLiable", None),
	}
	_prop_map_put_ = {
		"BaseDocEntry": ((36, LCID, 4, 0),()),
		"BaseDocLine": ((37, LCID, 4, 0),()),
		"BaseDocType": ((38, LCID, 4, 0),()),
		"DeductibleTaxSum": ((19, LCID, 4, 0),()),
		"DistributionMethod": ((12, LCID, 4, 0),()),
		"DistributionRule": ((49, LCID, 4, 0),()),
		"DistributionRule2": ((63, LCID, 4, 0),()),
		"DistributionRule3": ((64, LCID, 4, 0),()),
		"DistributionRule4": ((65, LCID, 4, 0),()),
		"DistributionRule5": ((66, LCID, 4, 0),()),
		"ExpenseCode": ((4, LCID, 4, 0),()),
		"LastPurchasePrice": ((43, LCID, 4, 0),()),
		"LineTotal": ((5, LCID, 4, 0),()),
		"Project": ((62, LCID, 4, 0),()),
		"Remarks": ((11, LCID, 4, 0),()),
		"Stock": ((45, LCID, 4, 0),()),
		"TaxCode": ((23, LCID, 4, 0),()),
		"TaxSum": ((16, LCID, 4, 0),()),
		"VatGroup": ((14, LCID, 4, 0),()),
		"WTLiable": ((48, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDownPaymentsToDraw(DispatchBaseClass):
	'IDownPaymentsToDraw Interface'
	CLSID = IID('{DFF94208-9A06-4594-992D-8D758D296BD4}')
	coclass_clsid = IID('{BD563FC1-66EC-4D79-AFF0-CB3057D01161}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AmountToDraw": (15, 2, (5, 0), (), "AmountToDraw", None),
		"AmountToDrawFC": (17, 2, (5, 0), (), "AmountToDrawFC", None),
		"AmountToDrawSC": (18, 2, (5, 0), (), "AmountToDrawSC", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Details": (14, 2, (8, 0), (), "Details", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"DocInternalID": (30, 2, (3, 0), (), "DocInternalID", None),
		"DocNumber": (21, 2, (3, 0), (), "DocNumber", None),
		"DownPaymentType": (16, 2, (3, 0), (), "DownPaymentType", None),
		# Method 'DownPaymentsToDrawDetails' returns object of type 'IDownPaymentsToDrawDetails'
		"DownPaymentsToDrawDetails": (29, 2, (9, 0), (), "DownPaymentsToDrawDetails", '{A177F24C-3E47-498B-9013-8CC3EEC13F78}'),
		"DueDate": (12, 2, (7, 0), (), "DueDate", None),
		"GrossAmountToDraw": (25, 2, (5, 0), (), "GrossAmountToDraw", None),
		"GrossAmountToDrawFC": (26, 2, (5, 0), (), "GrossAmountToDrawFC", None),
		"GrossAmountToDrawSC": (27, 2, (5, 0), (), "GrossAmountToDrawSC", None),
		"IsGrossLine": (28, 2, (3, 0), (), "IsGrossLine", None),
		"Name": (13, 2, (8, 0), (), "Name", None),
		"PostingDate": (11, 2, (7, 0), (), "PostingDate", None),
		"RowNum": (20, 2, (3, 0), (), "RowNum", None),
		"Tax": (22, 2, (5, 0), (), "Tax", None),
		"TaxFC": (23, 2, (5, 0), (), "TaxFC", None),
		"TaxSC": (24, 2, (5, 0), (), "TaxSC", None),
	}
	_prop_map_put_ = {
		"AmountToDraw": ((15, LCID, 4, 0),()),
		"AmountToDrawFC": ((17, LCID, 4, 0),()),
		"AmountToDrawSC": ((18, LCID, 4, 0),()),
		"DocEntry": ((10, LCID, 4, 0),()),
		"GrossAmountToDraw": ((25, LCID, 4, 0),()),
		"GrossAmountToDrawFC": ((26, LCID, 4, 0),()),
		"GrossAmountToDrawSC": ((27, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDownPaymentsToDrawDetails(DispatchBaseClass):
	'IDownPaymentsToDrawDetails Interface'
	CLSID = IID('{A177F24C-3E47-498B-9013-8CC3EEC13F78}')
	coclass_clsid = IID('{986A5D5D-8D68-40EF-B579-C5A4CBAC0CFE}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AmountToDraw": (8, 2, (5, 0), (), "AmountToDraw", None),
		"AmountToDrawFC": (9, 2, (5, 0), (), "AmountToDrawFC", None),
		"AmountToDrawSC": (10, 2, (5, 0), (), "AmountToDrawSC", None),
		"Count": (19, 2, (3, 0), (), "Count", None),
		"DocEntry": (5, 2, (3, 0), (), "DocEntry", None),
		"DocInternalID": (20, 2, (3, 0), (), "DocInternalID", None),
		"GrossAmountToDraw": (15, 2, (5, 0), (), "GrossAmountToDraw", None),
		"GrossAmountToDrawFC": (16, 2, (5, 0), (), "GrossAmountToDrawFC", None),
		"GrossAmountToDrawSC": (17, 2, (5, 0), (), "GrossAmountToDrawSC", None),
		"IsGrossLine": (14, 2, (3, 0), (), "IsGrossLine", None),
		"LineType": (18, 2, (3, 0), (), "LineType", None),
		"RowNum": (3, 2, (3, 0), (), "RowNum", None),
		"SeqNum": (4, 2, (3, 0), (), "SeqNum", None),
		"Tax": (11, 2, (5, 0), (), "Tax", None),
		"TaxAdjust": (21, 2, (3, 0), (), "TaxAdjust", None),
		"TaxFC": (12, 2, (5, 0), (), "TaxFC", None),
		"TaxSC": (13, 2, (5, 0), (), "TaxSC", None),
		"VatGroupCode": (6, 2, (8, 0), (), "VatGroupCode", None),
		"VatPercent": (7, 2, (5, 0), (), "VatPercent", None),
	}
	_prop_map_put_ = {
		"AmountToDraw": ((8, LCID, 4, 0),()),
		"AmountToDrawFC": ((9, LCID, 4, 0),()),
		"AmountToDrawSC": ((10, LCID, 4, 0),()),
		"GrossAmountToDraw": ((15, LCID, 4, 0),()),
		"GrossAmountToDrawFC": ((16, LCID, 4, 0),()),
		"GrossAmountToDrawSC": ((17, LCID, 4, 0),()),
		"RowNum": ((3, LCID, 4, 0),()),
		"Tax": ((11, LCID, 4, 0),()),
		"TaxFC": ((12, LCID, 4, 0),()),
		"TaxSC": ((13, LCID, 4, 0),()),
		"VatGroupCode": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(19, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDunningLetters(DispatchBaseClass):
	'IDunningLetters Interface'
	CLSID = IID('{F8DE7AAE-13BF-46BD-A4B0-CD9535AAED63}')
	coclass_clsid = IID('{8C9A31B4-0BEA-4A72-8D4E-F4C00F683E6B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(19, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(13, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (17, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CalcInterest": (7, 2, (3, 0), (), "CalcInterest", None),
		"Effectiveafter": (4, 2, (8, 0), (), "Effectiveafter", None),
		"FeeCurrency": (1, 2, (8, 0), (), "FeeCurrency", None),
		"Feeperletter": (6, 2, (5, 0), (), "Feeperletter", None),
		"LetterFormat": (3, 2, (8, 0), (), "LetterFormat", None),
		"MinimumBalance": (8, 2, (5, 0), (), "MinimumBalance", None),
		"MinimumBalanceCurrency": (5, 2, (8, 0), (), "MinimumBalanceCurrency", None),
		"RowNumber": (2, 2, (3, 0), (), "RowNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (16, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CalcInterest": ((7, LCID, 4, 0),()),
		"Effectiveafter": ((4, LCID, 4, 0),()),
		"FeeCurrency": ((1, LCID, 4, 0),()),
		"Feeperletter": ((6, LCID, 4, 0),()),
		"LetterFormat": ((3, LCID, 4, 0),()),
		"MinimumBalance": ((8, LCID, 4, 0),()),
		"MinimumBalanceCurrency": ((5, LCID, 4, 0),()),
		"RowNumber": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDunningTerm(DispatchBaseClass):
	'IDunningTerm Interface'
	CLSID = IID('{43A00E70-9D54-4A08-BE46-BD22286DF8EB}')
	coclass_clsid = IID('{C56982FE-CF84-47FD-9FE3-5E983ED0C419}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ApplyHighestLetterTemplate": (23, 2, (3, 0), (), "ApplyHighestLetterTemplate", None),
		"AutomaticPosting": (25, 2, (3, 0), (), "AutomaticPosting", None),
		"BaseDateSelect": (28, 2, (3, 0), (), "BaseDateSelect", None),
		"CalculateInterestMethod": (15, 2, (3, 0), (), "CalculateInterestMethod", None),
		"Code": (10, 2, (8, 0), (), "Code", None),
		"DaysInMonth": (14, 2, (3, 0), (), "DaysInMonth", None),
		"DaysInYear": (13, 2, (3, 0), (), "DaysInYear", None),
		# Method 'DunningTermLines' returns object of type 'IDunningTermLines'
		"DunningTermLines": (24, 2, (9, 0), (), "DunningTermLines", '{831AB766-3423-4E64-8EB1-42614102CDC7}'),
		"ExchangeRateSelect": (16, 2, (3, 0), (), "ExchangeRateSelect", None),
		"FeeAccount": (27, 2, (8, 0), (), "FeeAccount", None),
		"GroupingMethod": (12, 2, (3, 0), (), "GroupingMethod", None),
		"IncludeInterest": (22, 2, (3, 0), (), "IncludeInterest", None),
		"InterestAccount": (26, 2, (8, 0), (), "InterestAccount", None),
		"LetterFee": (18, 2, (5, 0), (), "LetterFee", None),
		"LetterFeeCurrency": (19, 2, (8, 0), (), "LetterFeeCurrency", None),
		"MinimumBalance": (20, 2, (5, 0), (), "MinimumBalance", None),
		"MinimumBalanceCurrency": (21, 2, (8, 0), (), "MinimumBalanceCurrency", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"YearlyInterestRate": (17, 2, (5, 0), (), "YearlyInterestRate", None),
	}
	_prop_map_put_ = {
		"ApplyHighestLetterTemplate": ((23, LCID, 4, 0),()),
		"AutomaticPosting": ((25, LCID, 4, 0),()),
		"BaseDateSelect": ((28, LCID, 4, 0),()),
		"CalculateInterestMethod": ((15, LCID, 4, 0),()),
		"Code": ((10, LCID, 4, 0),()),
		"DaysInMonth": ((14, LCID, 4, 0),()),
		"DaysInYear": ((13, LCID, 4, 0),()),
		"ExchangeRateSelect": ((16, LCID, 4, 0),()),
		"FeeAccount": ((27, LCID, 4, 0),()),
		"GroupingMethod": ((12, LCID, 4, 0),()),
		"IncludeInterest": ((22, LCID, 4, 0),()),
		"InterestAccount": ((26, LCID, 4, 0),()),
		"LetterFee": ((18, LCID, 4, 0),()),
		"LetterFeeCurrency": ((19, LCID, 4, 0),()),
		"MinimumBalance": ((20, LCID, 4, 0),()),
		"MinimumBalanceCurrency": ((21, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"YearlyInterestRate": ((17, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDunningTermLine(DispatchBaseClass):
	'IDunningTermLine Interface'
	CLSID = IID('{D7B39E88-0C6D-4B8A-A083-AEC336746884}')
	coclass_clsid = IID('{AEDDBC24-5587-4895-A37D-E41F54A42A44}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CalculateInterest": (17, 2, (3, 0), (), "CalculateInterest", None),
		"Effectiveafter": (12, 2, (8, 0), (), "Effectiveafter", None),
		"LetterFee": (13, 2, (5, 0), (), "LetterFee", None),
		"LetterFeeCurrency": (14, 2, (8, 0), (), "LetterFeeCurrency", None),
		"LetterFormat": (11, 2, (3, 0), (), "LetterFormat", None),
		"LevelNum": (10, 2, (3, 0), (), "LevelNum", None),
		"MininumBalance": (15, 2, (5, 0), (), "MininumBalance", None),
		"MininumBalanceCurrency": (16, 2, (8, 0), (), "MininumBalanceCurrency", None),
	}
	_prop_map_put_ = {
		"CalculateInterest": ((17, LCID, 4, 0),()),
		"Effectiveafter": ((12, LCID, 4, 0),()),
		"LetterFee": ((13, LCID, 4, 0),()),
		"LetterFeeCurrency": ((14, LCID, 4, 0),()),
		"LetterFormat": ((11, LCID, 4, 0),()),
		"MininumBalance": ((15, LCID, 4, 0),()),
		"MininumBalanceCurrency": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDunningTermLines(DispatchBaseClass):
	'IDunningTermLines Interface'
	CLSID = IID('{831AB766-3423-4E64-8EB1-42614102CDC7}')
	coclass_clsid = IID('{8529DA4C-CD2E-4D6B-95F9-E4BE53D72883}')

	# Result is of type IDunningTermLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{D7B39E88-0C6D-4B8A-A083-AEC336746884}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDunningTermLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{D7B39E88-0C6D-4B8A-A083-AEC336746884}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{D7B39E88-0C6D-4B8A-A083-AEC336746884}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{D7B39E88-0C6D-4B8A-A083-AEC336746884}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDunningTermParams(DispatchBaseClass):
	'IDunningTermParams Interface'
	CLSID = IID('{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')
	coclass_clsid = IID('{7BD692D0-D375-4754-AC78-310F1035CEF8}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDunningTermsParams(DispatchBaseClass):
	'IDunningTermsParams Interface'
	CLSID = IID('{E0E5F6AB-18E3-45F8-A9DA-D2AB88B08A54}')
	coclass_clsid = IID('{FB73DAFB-EA3A-4D1B-9EFC-57F68BF26A2E}')

	# Result is of type IDunningTermParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IDunningTermParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IDunningTermsService(DispatchBaseClass):
	'IDunningTermsService Interface'
	CLSID = IID('{788DDDE0-9FE1-4653-8F1A-DCBFF4DD0B49}')
	coclass_clsid = IID('{C18E808F-F2E2-4D1D-8F5F-5CCE8C2D274B}')

	# Result is of type IDunningTermParams
	def AddDunningTerm(self, pIDunningTerm=defaultNamedNotOptArg):
		'AddDunningTerm'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIDunningTerm
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddDunningTerm', '{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')
		return ret

	def DeleteDunningTerm(self, pIDunningTermParams=defaultNamedNotOptArg):
		'DeleteDunningTerm'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIDunningTermParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IDunningTerm
	def GetDunningTerm(self, pIDunningTermParams=defaultNamedNotOptArg):
		'GetDunningTerm'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIDunningTermParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDunningTerm', '{43A00E70-9D54-4A08-BE46-BD22286DF8EB}')
		return ret

	# Result is of type IDunningTermsParams
	def GetDunningTermList(self):
		'GetDunningTermList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetDunningTermList', '{E0E5F6AB-18E3-45F8-A9DA-D2AB88B08A54}')
		return ret

	def UpdateDunningTerm(self, pIDunningTerm=defaultNamedNotOptArg):
		'UpdateDunningTerm'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIDunningTerm
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IDynamicSystemStrings(DispatchBaseClass):
	'IDynamicSystemStrings Interface'
	CLSID = IID('{910C52B1-ABDC-409F-80EE-D6219E33497E}')
	coclass_clsid = IID('{EAA25EB5-36C7-4AC8-936E-6AA6CF421FDD}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrFormId=defaultNamedNotOptArg, bstrItemNum=defaultNamedNotOptArg, bstrColNum=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1), (8, 1), (8, 1)),bstrFormId
			, bstrItemNum, bstrColNum)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ColumnID": (11, 2, (8, 0), (), "ColumnID", None),
		"FormID": (9, 2, (8, 0), (), "FormID", None),
		"IsBold": (13, 2, (3, 0), (), "IsBold", None),
		"IsItalics": (14, 2, (3, 0), (), "IsItalics", None),
		"ItemID": (10, 2, (8, 0), (), "ItemID", None),
		"ItemString": (12, 2, (8, 0), (), "ItemString", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ColumnID": ((11, LCID, 4, 0),()),
		"FormID": ((9, LCID, 4, 0),()),
		"IsBold": ((13, LCID, 4, 0),()),
		"IsItalics": ((14, LCID, 4, 0),()),
		"ItemID": ((10, LCID, 4, 0),()),
		"ItemString": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IElectronicFileFormat(DispatchBaseClass):
	'IElectronicFileFormat Interface'
	CLSID = IID('{F788A8C7-F4E4-47BD-BBC8-79670F3EAE61}')
	coclass_clsid = IID('{D63B7918-80EA-4553-A01E-A574620DCEF6}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (12, 2, (8, 0), (), "Description", None),
		"FormatID": (10, 2, (3, 0), (), "FormatID", None),
		"MenuName": (16, 2, (8, 0), (), "MenuName", None),
		"MenuPath": (17, 2, (8, 0), (), "MenuPath", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"OutputFilePath": (15, 2, (8, 0), (), "OutputFilePath", None),
		"SchemaVersion": (14, 2, (8, 0), (), "SchemaVersion", None),
		"Version": (13, 2, (8, 0), (), "Version", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IElectronicFileFormatParams(DispatchBaseClass):
	'IElectronicFileFormatParams Interface'
	CLSID = IID('{B1D15948-E323-4C52-BA55-70E0678549CD}')
	coclass_clsid = IID('{417DC595-38A9-48E4-ABC1-AD08B2C0070B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"FormatID": (10, 2, (3, 0), (), "FormatID", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"FormatID": ((10, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IElectronicFileFormatsParams(DispatchBaseClass):
	'IElectronicFileFormatsParams Interface'
	CLSID = IID('{58E6063A-F616-4E44-AC69-8E40356F5830}')
	coclass_clsid = IID('{12E82740-BADE-4630-8BDB-2C3073D27F45}')

	# Result is of type IElectronicFileFormatParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{B1D15948-E323-4C52-BA55-70E0678549CD}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IElectronicFileFormatParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{B1D15948-E323-4C52-BA55-70E0678549CD}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{B1D15948-E323-4C52-BA55-70E0678549CD}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{B1D15948-E323-4C52-BA55-70E0678549CD}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IElectronicFileFormatsService(DispatchBaseClass):
	'IElectronicFileFormatsService Interface'
	CLSID = IID('{457DC126-2E63-4241-9497-1A104E8AB550}')
	coclass_clsid = IID('{ADFCD5D9-B501-4CB5-892C-61FE7FB225B3}')

	# Result is of type IElectronicFileFormatParams
	def AddElectronicFileFormat(self, pIImportFileParam=defaultNamedNotOptArg):
		'AddElectronicFileFormat'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIImportFileParam
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddElectronicFileFormat', '{B1D15948-E323-4C52-BA55-70E0678549CD}')
		return ret

	def DeleteElectronicFileFormat(self, pIElectronicFileFormatParams=defaultNamedNotOptArg):
		'DeleteElectronicFileFormat'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIElectronicFileFormatParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IElectronicFileFormat
	def GetElectronicFileFormat(self, pIElectronicFileFormatParams=defaultNamedNotOptArg):
		'GetElectronicFileFormat'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIElectronicFileFormatParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetElectronicFileFormat', '{F788A8C7-F4E4-47BD-BBC8-79670F3EAE61}')
		return ret

	# Result is of type IElectronicFileFormatsParams
	def GetElectronicFileFormatList(self):
		'GetElectronicFileFormatList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetElectronicFileFormatList', '{58E6063A-F616-4E44-AC69-8E40356F5830}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IElectronicSeries(DispatchBaseClass):
	'IElectronicSeries Interface'
	CLSID = IID('{2309689C-63EA-4D8E-B675-E6459533E27A}')
	coclass_clsid = IID('{96C491DF-52C0-42C6-802A-5890F273BE5A}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ApprovalNumber": (19, 2, (3, 0), (), "ApprovalNumber", None),
		"ApprovalYear": (18, 2, (3, 0), (), "ApprovalYear", None),
		"ElectronicSeries": (11, 2, (3, 0), (), "ElectronicSeries", None),
		"InitialNumber": (14, 2, (8, 0), (), "InitialNumber", None),
		"LastNumber": (16, 2, (8, 0), (), "LastNumber", None),
		"Name": (13, 2, (8, 0), (), "Name", None),
		"NextNumber": (15, 2, (8, 0), (), "NextNumber", None),
		"Prefix": (17, 2, (8, 0), (), "Prefix", None),
		"Remarks": (20, 2, (8, 0), (), "Remarks", None),
		"Series": (12, 2, (3, 0), (), "Series", None),
	}
	_prop_map_put_ = {
		"ApprovalNumber": ((19, LCID, 4, 0),()),
		"ApprovalYear": ((18, LCID, 4, 0),()),
		"InitialNumber": ((14, LCID, 4, 0),()),
		"LastNumber": ((16, LCID, 4, 0),()),
		"Name": ((13, LCID, 4, 0),()),
		"Prefix": ((17, LCID, 4, 0),()),
		"Remarks": ((20, LCID, 4, 0),()),
		"Series": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IElectronicSeriesCollection(DispatchBaseClass):
	'IElectronicSeriesCollection Interface'
	CLSID = IID('{B6F90D8C-7E5B-4EE0-8E60-D536FD4C3665}')
	coclass_clsid = IID('{0561126D-01CD-453B-A5FB-6AC3C11E05D5}')

	# Result is of type IElectronicSeries
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{2309689C-63EA-4D8E-B675-E6459533E27A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IElectronicSeries
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{2309689C-63EA-4D8E-B675-E6459533E27A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{2309689C-63EA-4D8E-B675-E6459533E27A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{2309689C-63EA-4D8E-B675-E6459533E27A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IElectronicSeriesParams(DispatchBaseClass):
	'IElectronicSeriesParams Interface'
	CLSID = IID('{135ACD20-6799-42E5-8ECC-4077CEF72812}')
	coclass_clsid = IID('{026951FA-5BBD-4559-BA2D-771C19E66BBD}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ElectronicSeries": (10, 2, (3, 0), (), "ElectronicSeries", None),
	}
	_prop_map_put_ = {
		"ElectronicSeries": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeAbsenceInfo(DispatchBaseClass):
	'IEmployeeAbsenceInfo Interface'
	CLSID = IID('{CD47A725-AEA8-4224-93D3-F31848990C42}')
	coclass_clsid = IID('{A574B4DA-F87A-414B-AC49-ED8C6BF84B2C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ApprovedBy": (9, 2, (8, 0), (), "ApprovedBy", None),
		"ConfirmerNumber": (13, 2, (3, 0), (), "ConfirmerNumber", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"EmployeeID": (10, 2, (3, 0), (), "EmployeeID", None),
		"FromDate": (6, 2, (7, 0), (), "FromDate", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"Reason": (8, 2, (8, 0), (), "Reason", None),
		"ToDate": (7, 2, (7, 0), (), "ToDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ApprovedBy": ((9, LCID, 4, 0),()),
		"ConfirmerNumber": ((13, LCID, 4, 0),()),
		"EmployeeID": ((10, LCID, 4, 0),()),
		"FromDate": ((6, LCID, 4, 0),()),
		"Reason": ((8, LCID, 4, 0),()),
		"ToDate": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeEducationInfo(DispatchBaseClass):
	'IEmployeeEducationInfo Interface'
	CLSID = IID('{A5EC07B2-5898-4104-8015-F876A386D231}')
	coclass_clsid = IID('{8D158412-BA39-4046-8326-2E22EE49F8C1}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Diploma": (11, 2, (8, 0), (), "Diploma", None),
		"EducationType": (8, 2, (3, 0), (), "EducationType", None),
		"EmployeeNo": (12, 2, (3, 0), (), "EmployeeNo", None),
		"FromDate": (6, 2, (7, 0), (), "FromDate", None),
		"Institute": (9, 2, (8, 0), (), "Institute", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"Major": (10, 2, (8, 0), (), "Major", None),
		"ToDate": (7, 2, (7, 0), (), "ToDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Diploma": ((11, LCID, 4, 0),()),
		"EducationType": ((8, LCID, 4, 0),()),
		"EmployeeNo": ((12, LCID, 4, 0),()),
		"FromDate": ((6, LCID, 4, 0),()),
		"Institute": ((9, LCID, 4, 0),()),
		"Major": ((10, LCID, 4, 0),()),
		"ToDate": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeIDType(DispatchBaseClass):
	'IEmployeeIDType Interface'
	CLSID = IID('{17F42A0A-DF72-432D-9953-1993A831A197}')
	coclass_clsid = IID('{5C3925BA-87A6-4C77-B1DE-ABB68B9814FA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"IDType": (10, 2, (8, 0), (), "IDType", None),
	}
	_prop_map_put_ = {
		"IDType": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeIDTypeParams(DispatchBaseClass):
	'IEmployeeIDTypeParams Interface'
	CLSID = IID('{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')
	coclass_clsid = IID('{2C6522F2-47AE-4707-B34C-A4973216808E}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"IDType": (10, 2, (8, 0), (), "IDType", None),
	}
	_prop_map_put_ = {
		"IDType": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeIDTypeParamsCollection(DispatchBaseClass):
	'IEmployeeIDTypeParamsCollection Interface'
	CLSID = IID('{BDD8F465-17AF-49ED-AA8D-50A52B849D4F}')
	coclass_clsid = IID('{E2AABE75-E867-4BE2-8E09-AD1EE61C62BC}')

	# Result is of type IEmployeeIDTypeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IEmployeeIDTypeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeIDTypeService(DispatchBaseClass):
	'IEmployeeIDTypeService Interface'
	CLSID = IID('{6B7F9C14-6E99-4405-8796-51F1EF735889}')
	coclass_clsid = IID('{F574C00A-3CAE-4269-84D7-E77A6237CAE0}')

	# Result is of type IEmployeeIDTypeParams
	def Add(self, pIEmployeeIDType=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIEmployeeIDType
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')
		return ret

	def Delete(self, pIEmployeeIDTypeParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIEmployeeIDTypeParams
			)

	# Result is of type IEmployeeIDType
	def Get(self, pIEmployeeIDTypeParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIEmployeeIDTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{17F42A0A-DF72-432D-9953-1993A831A197}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IEmployeeIDTypeParamsCollection
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{BDD8F465-17AF-49ED-AA8D-50A52B849D4F}')
		return ret

	def Update(self, pIEmployeeIDType=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIEmployeeIDType
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeePrevEmpoymentInfo(DispatchBaseClass):
	'IEmployeePrevEmpoymentInfo Interface'
	CLSID = IID('{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}')
	coclass_clsid = IID('{9E334DDA-DD14-48A7-8482-292392B27A13}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"EmployeeNo": (11, 2, (3, 0), (), "EmployeeNo", None),
		"Employer": (8, 2, (8, 0), (), "Employer", None),
		"FromDtae": (6, 2, (7, 0), (), "FromDtae", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"Position": (9, 2, (8, 0), (), "Position", None),
		"Remarks": (10, 2, (8, 0), (), "Remarks", None),
		"ToDate": (7, 2, (7, 0), (), "ToDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"EmployeeNo": ((11, LCID, 4, 0),()),
		"Employer": ((8, LCID, 4, 0),()),
		"FromDtae": ((6, LCID, 4, 0),()),
		"Position": ((9, LCID, 4, 0),()),
		"Remarks": ((10, LCID, 4, 0),()),
		"ToDate": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeReviewsInfo(DispatchBaseClass):
	'IEmployeeReviewsInfo Interface'
	CLSID = IID('{C4397D01-E44E-4B76-80AB-4B888EEA10DD}')
	coclass_clsid = IID('{3FF527E2-2FBB-4F74-BBF9-C0EDBF44E63C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Date": (6, 2, (7, 0), (), "Date", None),
		"EmployeeNo": (11, 2, (3, 0), (), "EmployeeNo", None),
		"Grade": (9, 2, (8, 0), (), "Grade", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"Manager": (8, 2, (3, 0), (), "Manager", None),
		"Remarks": (10, 2, (8, 0), (), "Remarks", None),
		"ReviewDescription": (7, 2, (8, 0), (), "ReviewDescription", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Date": ((6, LCID, 4, 0),()),
		"EmployeeNo": ((11, LCID, 4, 0),()),
		"Grade": ((9, LCID, 4, 0),()),
		"Manager": ((8, LCID, 4, 0),()),
		"Remarks": ((10, LCID, 4, 0),()),
		"ReviewDescription": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeRoleSetup(DispatchBaseClass):
	'IEmployeeRoleSetup Interface'
	CLSID = IID('{B9127E1F-9408-4957-B724-6A3A9AE42C74}')
	coclass_clsid = IID('{1D5336D5-065A-44D3-AFCC-D8BBEFB03234}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"TypeID": (10, 2, (3, 0), (), "TypeID", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeRoleSetupParams(DispatchBaseClass):
	'IEmployeeRoleSetupParams Interface'
	CLSID = IID('{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')
	coclass_clsid = IID('{C04822E7-C6E2-46D3-94FC-712AFB757912}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Name": (11, 2, (8, 0), (), "Name", None),
		"TypeID": (10, 2, (3, 0), (), "TypeID", None),
	}
	_prop_map_put_ = {
		"TypeID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeRoleSetupParamsCollection(DispatchBaseClass):
	'IEmployeeRoleSetupParamsCollection Interface'
	CLSID = IID('{9A49C2D7-CC5F-4CEE-95B9-6A8B16CA2031}')
	coclass_clsid = IID('{879F8B93-27BD-48D8-BFB9-34F47B572F48}')

	# Result is of type IEmployeeRoleSetupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IEmployeeRoleSetupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeRolesInfo(DispatchBaseClass):
	'IEmployeeRolesInfo Interface'
	CLSID = IID('{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}')
	coclass_clsid = IID('{E644A5ED-C97E-4EE8-8191-E20EBC9508AB}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"EmployeeID": (2, 2, (3, 0), (), "EmployeeID", None),
		"LineNum": (3, 2, (3, 0), (), "LineNum", None),
		"RoleID": (1, 2, (3, 0), (), "RoleID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"EmployeeID": ((2, LCID, 4, 0),()),
		"RoleID": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeRolesSetupService(DispatchBaseClass):
	'IEmployeeRolesSetupService Interface'
	CLSID = IID('{26767B5A-7011-4E58-A9FE-D6D1F8568B0F}')
	coclass_clsid = IID('{1E3842BA-EAE5-4CAC-A134-0328B7986BBC}')

	# Result is of type IEmployeeRoleSetupParams
	def AddEmployeeRoleSetup(self, pIEmployeeRoleSetup=defaultNamedNotOptArg):
		'AddEmployeeRoleSetup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIEmployeeRoleSetup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddEmployeeRoleSetup', '{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')
		return ret

	def DeleteEmployeeRoleSetup(self, pIEmployeeRoleSetupParams=defaultNamedNotOptArg):
		'DeleteEmployeeRoleSetup'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIEmployeeRoleSetupParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IEmployeeRoleSetup
	def GetEmployeeRoleSetup(self, pIEmployeeRoleSetupParams=defaultNamedNotOptArg):
		'GetEmployeeRoleSetup'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIEmployeeRoleSetupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetEmployeeRoleSetup', '{B9127E1F-9408-4957-B724-6A3A9AE42C74}')
		return ret

	# Result is of type IEmployeeRoleSetupParamsCollection
	def GetEmployeeRoleSetupList(self):
		'GetEmployeeRoleSetupList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetEmployeeRoleSetupList', '{9A49C2D7-CC5F-4CEE-95B9-6A8B16CA2031}')
		return ret

	def UpdateEmployeeRoleSetup(self, pIEmployeeRoleSetup=defaultNamedNotOptArg):
		'UpdateEmployeeRoleSetup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIEmployeeRoleSetup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeSavingsPaymentInfo(DispatchBaseClass):
	'IEmployeeSavingsPaymentInfo Interface'
	CLSID = IID('{669DAF62-7776-4DF5-AB51-B35DABFC4ACE}')
	coclass_clsid = IID('{9AF2EEA5-78E2-4CE5-A748-29C849AD9096}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AG": (11, 2, (8, 0), (), "AG", None),
		"AGcurrency": (12, 2, (8, 0), (), "AGcurrency", None),
		"AN": (9, 2, (8, 0), (), "AN", None),
		"ANcurrency": (10, 2, (8, 0), (), "ANcurrency", None),
		"BankAccount": (15, 2, (8, 0), (), "BankAccount", None),
		"BankCode": (14, 2, (8, 0), (), "BankCode", None),
		"BankName": (13, 2, (8, 0), (), "BankName", None),
		"ContractName": (7, 2, (8, 0), (), "ContractName", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"EmployeeID": (6, 2, (3, 0), (), "EmployeeID", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"PaymentNotes": (8, 2, (8, 0), (), "PaymentNotes", None),
		"Sequence": (16, 2, (3, 0), (), "Sequence", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AG": ((11, LCID, 4, 0),()),
		"AGcurrency": ((12, LCID, 4, 0),()),
		"AN": ((9, LCID, 4, 0),()),
		"ANcurrency": ((10, LCID, 4, 0),()),
		"BankAccount": ((15, LCID, 4, 0),()),
		"BankCode": ((14, LCID, 4, 0),()),
		"BankName": ((13, LCID, 4, 0),()),
		"ContractName": ((7, LCID, 4, 0),()),
		"EmployeeID": ((6, LCID, 4, 0),()),
		"PaymentNotes": ((8, LCID, 4, 0),()),
		"Sequence": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeTransfer(DispatchBaseClass):
	'IEmployeeTransfer Interface'
	CLSID = IID('{B63DD56F-5008-48E8-B7FF-DA56720F422D}')
	coclass_clsid = IID('{38DFDAC8-1F86-4E1D-9CDE-00425A5143BA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Comment": (16, 2, (8, 0), (), "Comment", None),
		# Method 'EmployeeTransferDetails' returns object of type 'IEmployeeTransferDetails'
		"EmployeeTransferDetails": (17, 2, (9, 0), (), "EmployeeTransferDetails", '{9324B0F9-58FC-404D-81BB-5591BE9E6A27}'),
		"Status": (15, 2, (3, 0), (), "Status", None),
		"TransEndDate": (13, 2, (7, 0), (), "TransEndDate", None),
		"TransEndTime": (14, 2, (7, 0), (), "TransEndTime", None),
		"TransStartDate": (11, 2, (7, 0), (), "TransStartDate", None),
		"TransStartTime": (12, 2, (7, 0), (), "TransStartTime", None),
		"TransferID": (10, 2, (3, 0), (), "TransferID", None),
	}
	_prop_map_put_ = {
		"Comment": ((16, LCID, 4, 0),()),
		"Status": ((15, LCID, 4, 0),()),
		"TransEndDate": ((13, LCID, 4, 0),()),
		"TransEndTime": ((14, LCID, 4, 0),()),
		"TransStartDate": ((11, LCID, 4, 0),()),
		"TransStartTime": ((12, LCID, 4, 0),()),
		"TransferID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeTransferDetail(DispatchBaseClass):
	'IEmployeeTransferDetail Interface'
	CLSID = IID('{0038F785-2853-4267-9629-3444A3CCC2AD}')
	coclass_clsid = IID('{05F0D981-435B-46CE-B13D-25D4A87B8088}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Comment": (15, 2, (8, 0), (), "Comment", None),
		"EmployeeID": (11, 2, (3, 0), (), "EmployeeID", None),
		"Status": (14, 2, (3, 0), (), "Status", None),
		"TransferID": (10, 2, (3, 0), (), "TransferID", None),
		"TransferedDate": (12, 2, (7, 0), (), "TransferedDate", None),
		"TransferedTime": (13, 2, (7, 0), (), "TransferedTime", None),
	}
	_prop_map_put_ = {
		"Comment": ((15, LCID, 4, 0),()),
		"EmployeeID": ((11, LCID, 4, 0),()),
		"Status": ((14, LCID, 4, 0),()),
		"TransferedDate": ((12, LCID, 4, 0),()),
		"TransferedTime": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeTransferDetails(DispatchBaseClass):
	'IEmployeeTransferDetails Interface'
	CLSID = IID('{9324B0F9-58FC-404D-81BB-5591BE9E6A27}')
	coclass_clsid = IID('{AAD58C85-8182-4A48-AC46-3D29F6E02F83}')

	# Result is of type IEmployeeTransferDetail
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{0038F785-2853-4267-9629-3444A3CCC2AD}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IEmployeeTransferDetail
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{0038F785-2853-4267-9629-3444A3CCC2AD}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{0038F785-2853-4267-9629-3444A3CCC2AD}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{0038F785-2853-4267-9629-3444A3CCC2AD}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeTransferParams(DispatchBaseClass):
	'IEmployeeTransferParams Interface'
	CLSID = IID('{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')
	coclass_clsid = IID('{BDDB80DE-CB4A-44DC-8BAC-1F1169E23805}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"TransferID": (10, 2, (3, 0), (), "TransferID", None),
	}
	_prop_map_put_ = {
		"TransferID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeeTransfersParams(DispatchBaseClass):
	'IEmployeeTransfersParams Interface'
	CLSID = IID('{DFBE6ED2-7510-49C9-8C39-35B939DB586D}')
	coclass_clsid = IID('{2FCB8823-03A3-47F9-BC0B-EEC815138967}')

	# Result is of type IEmployeeTransferParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IEmployeeTransferParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IEmployeeTransfersService(DispatchBaseClass):
	'IEmployeeTransfersService Interface'
	CLSID = IID('{1678F2A9-8FBA-47E8-A678-FE06A7D22007}')
	coclass_clsid = IID('{E8E96048-6DF2-4DE2-8311-72582D7F4512}')

	# Result is of type IEmployeeTransferParams
	def AddEmployeeTransfer(self, pIEmployeeTransfer=defaultNamedNotOptArg):
		'AddEmployeeTransfer'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIEmployeeTransfer
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddEmployeeTransfer', '{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')
		return ret

	def DeleteEmployeeTransfer(self, pIEmployeeTransferParams=defaultNamedNotOptArg):
		'DeleteEmployeeTransfer'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pIEmployeeTransferParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IEmployeeTransfer
	def GetEmployeeTransfer(self, pIEmployeeTransferParams=defaultNamedNotOptArg):
		'GetEmployeeTransfer'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIEmployeeTransferParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetEmployeeTransfer', '{B63DD56F-5008-48E8-B7FF-DA56720F422D}')
		return ret

	# Result is of type IEmployeeTransfersParams
	def GetEmployeeTransferList(self):
		'GetEmployeeTransferList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetEmployeeTransferList', '{DFBE6ED2-7510-49C9-8C39-35B939DB586D}')
		return ret

	def UpdateEmployeeTransfer(self, pIEmployeeTransfer=defaultNamedNotOptArg):
		'UpdateEmployeeTransfer'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIEmployeeTransfer
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IEmployeesInfo(DispatchBaseClass):
	'IEmployeesInfo Interface'
	CLSID = IID('{B2CFCDE5-3753-4A47-9199-38D08718B3AE}')
	coclass_clsid = IID('{EB49B71E-C20E-4D6D-8ECD-A641B0BAAA35}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(72, LCID, 1, (8, 0), (),)

	def GetByKey(self, EmployeeID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),EmployeeID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(73, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'AbsenceInfo' returns object of type 'IEmployeeAbsenceInfo'
		"AbsenceInfo": (68, 2, (9, 0), (), "AbsenceInfo", '{CD47A725-AEA8-4224-93D3-F31848990C42}'),
		"AccountantResponsible": (127, 2, (3, 0), (), "AccountantResponsible", None),
		"Active": (131, 2, (3, 0), (), "Active", None),
		"AdditionalAmount": (103, 2, (5, 0), (), "AdditionalAmount", None),
		"AdditionalCurrency": (105, 2, (8, 0), (), "AdditionalCurrency", None),
		"AdditionalUnit": (104, 2, (3, 0), (), "AdditionalUnit", None),
		"ApplicationUserID": (26, 2, (3, 0), (), "ApplicationUserID", None),
		"AttachmentEntry": (76, 2, (3, 0), (), "AttachmentEntry", None),
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (64, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		"BPLID": (133, 2, (3, 0), (), "BPLID", None),
		"BankAccount": (46, 2, (8, 0), (), "BankAccount", None),
		"BankBranch": (44, 2, (8, 0), (), "BankBranch", None),
		"BankBranchNum": (45, 2, (8, 0), (), "BankBranchNum", None),
		"BankCode": (43, 2, (8, 0), (), "BankCode", None),
		"BankCodeForDATEV": (116, 2, (8, 0), (), "BankCodeForDATEV", None),
		"BirthPlace": (121, 2, (8, 0), (), "BirthPlace", None),
		"Branch": (17, 2, (3, 0), (), "Branch", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CPF": (125, 2, (8, 0), (), "CPF", None),
		"CRCNumber": (126, 2, (8, 0), (), "CRCNumber", None),
		"CRCState": (130, 2, (8, 0), (), "CRCState", None),
		"CitizenshipCountryCode": (59, 2, (8, 0), (), "CitizenshipCountryCode", None),
		"CompanyNumber": (92, 2, (8, 0), (), "CompanyNumber", None),
		"CostCenterCode": (91, 2, (8, 0), (), "CostCenterCode", None),
		"CountryOfBirth": (55, 2, (8, 0), (), "CountryOfBirth", None),
		"DIRFResponsible": (129, 2, (3, 0), (), "DIRFResponsible", None),
		"DateOfBirth": (54, 2, (7, 0), (), "DateOfBirth", None),
		"Department": (16, 2, (3, 0), (), "Department", None),
		"DeviatingBankAccountOwner": (117, 2, (3, 0), (), "DeviatingBankAccountOwner", None),
		# Method 'EducationInfo' returns object of type 'IEmployeeEducationInfo'
		"EducationInfo": (70, 2, (9, 0), (), "EducationInfo", '{A5EC07B2-5898-4104-8015-F876A386D231}'),
		"EducationStatus": (113, 2, (8, 0), (), "EducationStatus", None),
		"EmployeeCostUnit": (40, 2, (3, 0), (), "EmployeeCostUnit", None),
		"EmployeeCosts": (39, 2, (5, 0), (), "EmployeeCosts", None),
		"EmployeeCostsCurrency": (66, 2, (8, 0), (), "EmployeeCostsCurrency", None),
		"EmployeeID": (9, 2, (3, 0), (), "EmployeeID", None),
		# Method 'EmployeeRolesInfo' returns object of type 'IEmployeeRolesInfo'
		"EmployeeRolesInfo": (71, 2, (9, 0), (), "EmployeeRolesInfo", '{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}'),
		"EmployeeType": (15, 2, (3, 0), (), "EmployeeType", None),
		"ExemptionAmount": (100, 2, (5, 0), (), "ExemptionAmount", None),
		"ExemptionCurrency": (102, 2, (8, 0), (), "ExemptionCurrency", None),
		"ExemptionUnit": (101, 2, (3, 0), (), "ExemptionUnit", None),
		"ExternalEmployeeNumber": (120, 2, (8, 0), (), "ExternalEmployeeNumber", None),
		"Fax": (33, 2, (8, 0), (), "Fax", None),
		"FirstName": (11, 2, (8, 0), (), "FirstName", None),
		"Gender": (13, 2, (3, 0), (), "Gender", None),
		"HealthInsuranceCode": (109, 2, (8, 0), (), "HealthInsuranceCode", None),
		"HealthInsuranceName": (108, 2, (8, 0), (), "HealthInsuranceName", None),
		"HealthInsuranceType": (110, 2, (8, 0), (), "HealthInsuranceType", None),
		"HomeBlock": (48, 2, (8, 0), (), "HomeBlock", None),
		"HomeBuildingFloorRoom": (75, 2, (8, 0), (), "HomeBuildingFloorRoom", None),
		"HomeCity": (50, 2, (8, 0), (), "HomeCity", None),
		"HomeCountry": (52, 2, (8, 0), (), "HomeCountry", None),
		"HomeCounty": (51, 2, (8, 0), (), "HomeCounty", None),
		"HomePhone": (32, 2, (8, 0), (), "HomePhone", None),
		"HomeState": (53, 2, (8, 0), (), "HomeState", None),
		"HomeStreet": (47, 2, (8, 0), (), "HomeStreet", None),
		"HomeZipCode": (49, 2, (8, 0), (), "HomeZipCode", None),
		"IDType": (132, 2, (8, 0), (), "IDType", None),
		"IdNumber": (58, 2, (8, 0), (), "IdNumber", None),
		"IncomeTaxLiability": (97, 2, (8, 0), (), "IncomeTaxLiability", None),
		"JobTitle": (14, 2, (8, 0), (), "JobTitle", None),
		"JobTitleCode": (115, 2, (8, 0), (), "JobTitleCode", None),
		"LastName": (10, 2, (8, 0), (), "LastName", None),
		"LegalRepresentative": (128, 2, (3, 0), (), "LegalRepresentative", None),
		"Manager": (25, 2, (3, 0), (), "Manager", None),
		"MartialStatus": (56, 2, (3, 0), (), "MartialStatus", None),
		"MiddleName": (12, 2, (8, 0), (), "MiddleName", None),
		"MobilePhone": (30, 2, (8, 0), (), "MobilePhone", None),
		"MunicipalityKey": (95, 2, (8, 0), (), "MunicipalityKey", None),
		"NumOfChildren": (57, 2, (3, 0), (), "NumOfChildren", None),
		"OfficeExtension": (29, 2, (8, 0), (), "OfficeExtension", None),
		"OfficePhone": (28, 2, (8, 0), (), "OfficePhone", None),
		"Pager": (31, 2, (8, 0), (), "Pager", None),
		"PartnerReligion": (99, 2, (8, 0), (), "PartnerReligion", None),
		"PassportExpirationDate": (61, 2, (7, 0), (), "PassportExpirationDate", None),
		"PassportNumber": (60, 2, (8, 0), (), "PassportNumber", None),
		"PaymentMethod": (122, 2, (3, 0), (), "PaymentMethod", None),
		"PersonGroup": (114, 2, (8, 0), (), "PersonGroup", None),
		"Picture": (62, 2, (8, 0), (), "Picture", None),
		"Position": (77, 2, (3, 0), (), "Position", None),
		# Method 'PreviousEmpoymentInfo' returns object of type 'IEmployeePrevEmpoymentInfo'
		"PreviousEmpoymentInfo": (69, 2, (9, 0), (), "PreviousEmpoymentInfo", '{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}'),
		"ProfessionStatus": (112, 2, (8, 0), (), "ProfessionStatus", None),
		"Religion": (98, 2, (8, 0), (), "Religion", None),
		"Remarks": (63, 2, (8, 0), (), "Remarks", None),
		# Method 'ReviewsInfo' returns object of type 'IEmployeeReviewsInfo'
		"ReviewsInfo": (67, 2, (9, 0), (), "ReviewsInfo", '{C4397D01-E44E-4B76-80AB-4B888EEA10DD}'),
		"STDCode": (124, 2, (3, 0), (), "STDCode", None),
		"Salary": (37, 2, (5, 0), (), "Salary", None),
		"SalaryCurrency": (65, 2, (8, 0), (), "SalaryCurrency", None),
		"SalaryUnit": (38, 2, (3, 0), (), "SalaryUnit", None),
		"SalesPersonCode": (27, 2, (3, 0), (), "SalesPersonCode", None),
		# Method 'SavingsPaymentInfo' returns object of type 'IEmployeeSavingsPaymentInfo'
		"SavingsPaymentInfo": (123, 2, (9, 0), (), "SavingsPaymentInfo", '{669DAF62-7776-4DF5-AB51-B35DABFC4ACE}'),
		"SocialInsuranceNumber": (111, 2, (8, 0), (), "SocialInsuranceNumber", None),
		"SpouseFirstName": (118, 2, (8, 0), (), "SpouseFirstName", None),
		"SpouseSurname": (119, 2, (8, 0), (), "SpouseSurname", None),
		"StartDate": (35, 2, (7, 0), (), "StartDate", None),
		"StatusCode": (36, 2, (3, 0), (), "StatusCode", None),
		"TaxClass": (96, 2, (8, 0), (), "TaxClass", None),
		"TaxOfficeName": (106, 2, (8, 0), (), "TaxOfficeName", None),
		"TaxOfficeNumber": (107, 2, (8, 0), (), "TaxOfficeNumber", None),
		"TerminationDate": (41, 2, (7, 0), (), "TerminationDate", None),
		"TreminationReason": (42, 2, (3, 0), (), "TreminationReason", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VacationCurrentYear": (94, 2, (3, 0), (), "VacationCurrentYear", None),
		"VacationPreviousYear": (93, 2, (3, 0), (), "VacationPreviousYear", None),
		"WorkBlock": (19, 2, (8, 0), (), "WorkBlock", None),
		"WorkBuildingFloorRoom": (74, 2, (8, 0), (), "WorkBuildingFloorRoom", None),
		"WorkCity": (21, 2, (8, 0), (), "WorkCity", None),
		"WorkCountryCode": (23, 2, (8, 0), (), "WorkCountryCode", None),
		"WorkCounty": (22, 2, (8, 0), (), "WorkCounty", None),
		"WorkStateCode": (24, 2, (8, 0), (), "WorkStateCode", None),
		"WorkStreet": (18, 2, (8, 0), (), "WorkStreet", None),
		"WorkZipCode": (20, 2, (8, 0), (), "WorkZipCode", None),
		"eMail": (34, 2, (8, 0), (), "eMail", None),
	}
	_prop_map_put_ = {
		"AccountantResponsible": ((127, LCID, 4, 0),()),
		"Active": ((131, LCID, 4, 0),()),
		"AdditionalAmount": ((103, LCID, 4, 0),()),
		"AdditionalCurrency": ((105, LCID, 4, 0),()),
		"AdditionalUnit": ((104, LCID, 4, 0),()),
		"ApplicationUserID": ((26, LCID, 4, 0),()),
		"AttachmentEntry": ((76, LCID, 4, 0),()),
		"BPLID": ((133, LCID, 4, 0),()),
		"BankAccount": ((46, LCID, 4, 0),()),
		"BankBranch": ((44, LCID, 4, 0),()),
		"BankBranchNum": ((45, LCID, 4, 0),()),
		"BankCode": ((43, LCID, 4, 0),()),
		"BankCodeForDATEV": ((116, LCID, 4, 0),()),
		"BirthPlace": ((121, LCID, 4, 0),()),
		"Branch": ((17, LCID, 4, 0),()),
		"CPF": ((125, LCID, 4, 0),()),
		"CRCNumber": ((126, LCID, 4, 0),()),
		"CRCState": ((130, LCID, 4, 0),()),
		"CitizenshipCountryCode": ((59, LCID, 4, 0),()),
		"CompanyNumber": ((92, LCID, 4, 0),()),
		"CostCenterCode": ((91, LCID, 4, 0),()),
		"CountryOfBirth": ((55, LCID, 4, 0),()),
		"DIRFResponsible": ((129, LCID, 4, 0),()),
		"DateOfBirth": ((54, LCID, 4, 0),()),
		"Department": ((16, LCID, 4, 0),()),
		"DeviatingBankAccountOwner": ((117, LCID, 4, 0),()),
		"EducationStatus": ((113, LCID, 4, 0),()),
		"EmployeeCostUnit": ((40, LCID, 4, 0),()),
		"EmployeeCosts": ((39, LCID, 4, 0),()),
		"EmployeeCostsCurrency": ((66, LCID, 4, 0),()),
		"EmployeeType": ((15, LCID, 4, 0),()),
		"ExemptionAmount": ((100, LCID, 4, 0),()),
		"ExemptionCurrency": ((102, LCID, 4, 0),()),
		"ExemptionUnit": ((101, LCID, 4, 0),()),
		"ExternalEmployeeNumber": ((120, LCID, 4, 0),()),
		"Fax": ((33, LCID, 4, 0),()),
		"FirstName": ((11, LCID, 4, 0),()),
		"Gender": ((13, LCID, 4, 0),()),
		"HealthInsuranceCode": ((109, LCID, 4, 0),()),
		"HealthInsuranceName": ((108, LCID, 4, 0),()),
		"HealthInsuranceType": ((110, LCID, 4, 0),()),
		"HomeBlock": ((48, LCID, 4, 0),()),
		"HomeBuildingFloorRoom": ((75, LCID, 4, 0),()),
		"HomeCity": ((50, LCID, 4, 0),()),
		"HomeCountry": ((52, LCID, 4, 0),()),
		"HomeCounty": ((51, LCID, 4, 0),()),
		"HomePhone": ((32, LCID, 4, 0),()),
		"HomeState": ((53, LCID, 4, 0),()),
		"HomeStreet": ((47, LCID, 4, 0),()),
		"HomeZipCode": ((49, LCID, 4, 0),()),
		"IDType": ((132, LCID, 4, 0),()),
		"IdNumber": ((58, LCID, 4, 0),()),
		"IncomeTaxLiability": ((97, LCID, 4, 0),()),
		"JobTitle": ((14, LCID, 4, 0),()),
		"JobTitleCode": ((115, LCID, 4, 0),()),
		"LastName": ((10, LCID, 4, 0),()),
		"LegalRepresentative": ((128, LCID, 4, 0),()),
		"Manager": ((25, LCID, 4, 0),()),
		"MartialStatus": ((56, LCID, 4, 0),()),
		"MiddleName": ((12, LCID, 4, 0),()),
		"MobilePhone": ((30, LCID, 4, 0),()),
		"MunicipalityKey": ((95, LCID, 4, 0),()),
		"NumOfChildren": ((57, LCID, 4, 0),()),
		"OfficeExtension": ((29, LCID, 4, 0),()),
		"OfficePhone": ((28, LCID, 4, 0),()),
		"Pager": ((31, LCID, 4, 0),()),
		"PartnerReligion": ((99, LCID, 4, 0),()),
		"PassportExpirationDate": ((61, LCID, 4, 0),()),
		"PassportNumber": ((60, LCID, 4, 0),()),
		"PaymentMethod": ((122, LCID, 4, 0),()),
		"PersonGroup": ((114, LCID, 4, 0),()),
		"Picture": ((62, LCID, 4, 0),()),
		"Position": ((77, LCID, 4, 0),()),
		"ProfessionStatus": ((112, LCID, 4, 0),()),
		"Religion": ((98, LCID, 4, 0),()),
		"Remarks": ((63, LCID, 4, 0),()),
		"STDCode": ((124, LCID, 4, 0),()),
		"Salary": ((37, LCID, 4, 0),()),
		"SalaryCurrency": ((65, LCID, 4, 0),()),
		"SalaryUnit": ((38, LCID, 4, 0),()),
		"SalesPersonCode": ((27, LCID, 4, 0),()),
		"SocialInsuranceNumber": ((111, LCID, 4, 0),()),
		"SpouseFirstName": ((118, LCID, 4, 0),()),
		"SpouseSurname": ((119, LCID, 4, 0),()),
		"StartDate": ((35, LCID, 4, 0),()),
		"StatusCode": ((36, LCID, 4, 0),()),
		"TaxClass": ((96, LCID, 4, 0),()),
		"TaxOfficeName": ((106, LCID, 4, 0),()),
		"TaxOfficeNumber": ((107, LCID, 4, 0),()),
		"TerminationDate": ((41, LCID, 4, 0),()),
		"TreminationReason": ((42, LCID, 4, 0),()),
		"VacationCurrentYear": ((94, LCID, 4, 0),()),
		"VacationPreviousYear": ((93, LCID, 4, 0),()),
		"WorkBlock": ((19, LCID, 4, 0),()),
		"WorkBuildingFloorRoom": ((74, LCID, 4, 0),()),
		"WorkCity": ((21, LCID, 4, 0),()),
		"WorkCountryCode": ((23, LCID, 4, 0),()),
		"WorkCounty": ((22, LCID, 4, 0),()),
		"WorkStateCode": ((24, LCID, 4, 0),()),
		"WorkStreet": ((18, LCID, 4, 0),()),
		"WorkZipCode": ((20, LCID, 4, 0),()),
		"eMail": ((34, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExportProcesses(DispatchBaseClass):
	'IExportProcesses Interface'
	CLSID = IID('{E3F9ACA7-17D5-4A5B-8AAF-91CB41E2896F}')
	coclass_clsid = IID('{DF1B1704-3860-4602-914C-71D3A9789748}')

	_prop_map_get_ = {
		"ExportationDeclarationDate": (12, 2, (7, 0), (), "ExportationDeclarationDate", None),
		"ExportationDeclarationNumber": (11, 2, (3, 0), (), "ExportationDeclarationNumber", None),
		"ExportationDocumentTypeCode": (10, 2, (3, 0), (), "ExportationDocumentTypeCode", None),
		"ExportationNatureCode": (13, 2, (3, 0), (), "ExportationNatureCode", None),
		"ExportationRegistryDate": (15, 2, (7, 0), (), "ExportationRegistryDate", None),
		"ExportationRegistryNumber": (14, 2, (3, 0), (), "ExportationRegistryNumber", None),
		"LadingBillDate": (17, 2, (7, 0), (), "LadingBillDate", None),
		"LadingBillNumber": (16, 2, (8, 0), (), "LadingBillNumber", None),
		"LadingBillTypeCode": (19, 2, (3, 0), (), "LadingBillTypeCode", None),
		"MerchandiseLeftCustomsDate": (18, 2, (7, 0), (), "MerchandiseLeftCustomsDate", None),
	}
	_prop_map_put_ = {
		"ExportationDeclarationDate": ((12, LCID, 4, 0),()),
		"ExportationDeclarationNumber": ((11, LCID, 4, 0),()),
		"ExportationDocumentTypeCode": ((10, LCID, 4, 0),()),
		"ExportationNatureCode": ((13, LCID, 4, 0),()),
		"ExportationRegistryDate": ((15, LCID, 4, 0),()),
		"ExportationRegistryNumber": ((14, LCID, 4, 0),()),
		"LadingBillDate": ((17, LCID, 4, 0),()),
		"LadingBillNumber": ((16, LCID, 4, 0),()),
		"LadingBillTypeCode": ((19, LCID, 4, 0),()),
		"MerchandiseLeftCustomsDate": ((18, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExtendedAdminInfo(DispatchBaseClass):
	'IExtendedAdminInfo Interface'
	CLSID = IID('{6AAAB602-C1E1-4988-BF5D-ECE369936FC0}')
	coclass_clsid = IID('{3E8F0EBB-ED4D-4C8D-B14C-5012989DC570}')

	_prop_map_get_ = {
		"AddressType": (5, 2, (8, 0), (), "AddressType", None),
		"CommercialRegister": (18, 2, (8, 0), (), "CommercialRegister", None),
		"CompanyQualificationCode": (15, 2, (3, 0), (), "CompanyQualificationCode", None),
		"CooperativeAssociationTypeCode": (13, 2, (3, 0), (), "CooperativeAssociationTypeCode", None),
		"CreditContributionOriginCode": (11, 2, (8, 0), (), "CreditContributionOriginCode", None),
		"DateOfIncorporation": (19, 2, (7, 0), (), "DateOfIncorporation", None),
		"DeclarerTypeCode": (16, 2, (3, 0), (), "DeclarerTypeCode", None),
		"EconomicActivityTypeCode": (10, 2, (3, 0), (), "EconomicActivityTypeCode", None),
		"EnvironmentType": (21, 2, (3, 0), (), "EnvironmentType", None),
		"IPIPeriodCode": (12, 2, (8, 0), (), "IPIPeriodCode", None),
		"IPITaxContributor": (17, 2, (3, 0), (), "IPITaxContributor", None),
		"NatureOfCompanyCode": (9, 2, (3, 0), (), "NatureOfCompanyCode", None),
		"OKDPNumber": (23, 2, (8, 0), (), "OKDPNumber", None),
		"Opting4ICMS": (22, 2, (3, 0), (), "Opting4ICMS", None),
		"ProfitTaxationCode": (14, 2, (3, 0), (), "ProfitTaxationCode", None),
		"SPEDProfile": (20, 2, (8, 0), (), "SPEDProfile", None),
		"STDCode": (7, 2, (3, 0), (), "STDCode", None),
		"STDCodeForeign": (8, 2, (3, 0), (), "STDCodeForeign", None),
		"StreetNo": (6, 2, (8, 0), (), "StreetNo", None),
	}
	_prop_map_put_ = {
		"AddressType": ((5, LCID, 4, 0),()),
		"CommercialRegister": ((18, LCID, 4, 0),()),
		"CompanyQualificationCode": ((15, LCID, 4, 0),()),
		"CooperativeAssociationTypeCode": ((13, LCID, 4, 0),()),
		"CreditContributionOriginCode": ((11, LCID, 4, 0),()),
		"DateOfIncorporation": ((19, LCID, 4, 0),()),
		"DeclarerTypeCode": ((16, LCID, 4, 0),()),
		"EconomicActivityTypeCode": ((10, LCID, 4, 0),()),
		"EnvironmentType": ((21, LCID, 4, 0),()),
		"IPIPeriodCode": ((12, LCID, 4, 0),()),
		"IPITaxContributor": ((17, LCID, 4, 0),()),
		"NatureOfCompanyCode": ((9, LCID, 4, 0),()),
		"OKDPNumber": ((23, LCID, 4, 0),()),
		"Opting4ICMS": ((22, LCID, 4, 0),()),
		"ProfitTaxationCode": ((14, LCID, 4, 0),()),
		"SPEDProfile": ((20, LCID, 4, 0),()),
		"STDCode": ((7, LCID, 4, 0),()),
		"STDCodeForeign": ((8, LCID, 4, 0),()),
		"StreetNo": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExtendedTranslation(DispatchBaseClass):
	'IExtendedTranslation Interface'
	CLSID = IID('{EB9E1080-A979-4BA0-895B-D424C68063BC}')
	coclass_clsid = IID('{F8306AD8-D5B1-4CBE-A36B-ECF55FF2D3FE}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Category": (11, 2, (3, 0), (), "Category", None),
		"CreateDate": (16, 2, (7, 0), (), "CreateDate", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		# Method 'ExtendedTranslation_ItemLines' returns object of type 'IExtendedTranslation_ItemLines'
		"ExtendedTranslation_ItemLines": (17, 2, (9, 0), (), "ExtendedTranslation_ItemLines", '{323B7F1F-31D3-45CE-A325-B81187DA9C0C}'),
		"ID": (12, 2, (8, 0), (), "ID", None),
		"SecondaryID": (13, 2, (8, 0), (), "SecondaryID", None),
		"SourceLanguage": (14, 2, (3, 0), (), "SourceLanguage", None),
		"UpdateDate": (15, 2, (7, 0), (), "UpdateDate", None),
	}
	_prop_map_put_ = {
		"Category": ((11, LCID, 4, 0),()),
		"ID": ((12, LCID, 4, 0),()),
		"SecondaryID": ((13, LCID, 4, 0),()),
		"SourceLanguage": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExtendedTranslationParams(DispatchBaseClass):
	'IExtendedTranslationParams Interface'
	CLSID = IID('{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')
	coclass_clsid = IID('{0CA3C6AF-091A-4C96-9F9D-F9B99F868AB7}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Category": (11, 2, (3, 0), (), "Category", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"ID": (12, 2, (8, 0), (), "ID", None),
		"SecondaryID": (13, 2, (8, 0), (), "SecondaryID", None),
	}
	_prop_map_put_ = {
		"Category": ((11, LCID, 4, 0),()),
		"DocEntry": ((10, LCID, 4, 0),()),
		"ID": ((12, LCID, 4, 0),()),
		"SecondaryID": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExtendedTranslation_ItemLine(DispatchBaseClass):
	'IExtendedTranslation_ItemLine Interface'
	CLSID = IID('{FFA101D6-62B7-4615-A050-5BEE79FBF640}')
	coclass_clsid = IID('{58CF80CD-7170-4036-93FC-C43C324FE006}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		# Method 'ExtendedTranslation_ResultLines' returns object of type 'IExtendedTranslation_ResultLines'
		"ExtendedTranslation_ResultLines": (18, 2, (9, 0), (), "ExtendedTranslation_ResultLines", '{49836643-1102-4273-B5DC-F4ADEC94D843}'),
		"ItemCode": (12, 2, (8, 0), (), "ItemCode", None),
		"ItemType": (13, 2, (8, 0), (), "ItemType", None),
		"LineNumber": (11, 2, (3, 0), (), "LineNumber", None),
		"MaxLength": (15, 2, (3, 0), (), "MaxLength", None),
		"Memo": (17, 2, (8, 0), (), "Memo", None),
		"SlimType": (14, 2, (8, 0), (), "SlimType", None),
		"SourceText": (16, 2, (8, 0), (), "SourceText", None),
	}
	_prop_map_put_ = {
		"ItemCode": ((12, LCID, 4, 0),()),
		"ItemType": ((13, LCID, 4, 0),()),
		"MaxLength": ((15, LCID, 4, 0),()),
		"Memo": ((17, LCID, 4, 0),()),
		"SlimType": ((14, LCID, 4, 0),()),
		"SourceText": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExtendedTranslation_ItemLines(DispatchBaseClass):
	'IExtendedTranslation_ItemLines Interface'
	CLSID = IID('{323B7F1F-31D3-45CE-A325-B81187DA9C0C}')
	coclass_clsid = IID('{E08287E7-64BE-4C4F-B25D-78EEEB40A94C}')

	# Result is of type IExtendedTranslation_ItemLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{FFA101D6-62B7-4615-A050-5BEE79FBF640}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IExtendedTranslation_ItemLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{FFA101D6-62B7-4615-A050-5BEE79FBF640}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{FFA101D6-62B7-4615-A050-5BEE79FBF640}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{FFA101D6-62B7-4615-A050-5BEE79FBF640}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IExtendedTranslation_ResultLine(DispatchBaseClass):
	'IExtendedTranslation_ResultLine Interface'
	CLSID = IID('{50ACD964-9DDC-46E4-9719-56DB0EED92AB}')
	coclass_clsid = IID('{4CD3DB89-C622-42EF-BEBD-7BB1CF9F5E54}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"LanguageCode": (13, 2, (3, 0), (), "LanguageCode", None),
		"LineNumber": (11, 2, (3, 0), (), "LineNumber", None),
		"SubLineNumber": (12, 2, (3, 0), (), "SubLineNumber", None),
		"TranslatedText": (14, 2, (8, 0), (), "TranslatedText", None),
	}
	_prop_map_put_ = {
		"LanguageCode": ((13, LCID, 4, 0),()),
		"TranslatedText": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExtendedTranslation_ResultLines(DispatchBaseClass):
	'IExtendedTranslation_ResultLines Interface'
	CLSID = IID('{49836643-1102-4273-B5DC-F4ADEC94D843}')
	coclass_clsid = IID('{23CD8BD9-08A1-469B-936F-6C468F37B31A}')

	# Result is of type IExtendedTranslation_ResultLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{50ACD964-9DDC-46E4-9719-56DB0EED92AB}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IExtendedTranslation_ResultLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{50ACD964-9DDC-46E4-9719-56DB0EED92AB}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{50ACD964-9DDC-46E4-9719-56DB0EED92AB}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{50ACD964-9DDC-46E4-9719-56DB0EED92AB}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IExtendedTranslationsParams(DispatchBaseClass):
	'IExtendedTranslationsParams Interface'
	CLSID = IID('{57FF304C-3414-48FA-8059-4F3B10FB37C9}')
	coclass_clsid = IID('{C24AF27A-8F41-42CD-8881-98F964EDF2C1}')

	# Result is of type IExtendedTranslationParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IExtendedTranslationParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IExtendedTranslationsService(DispatchBaseClass):
	'IExtendedTranslationsService Interface'
	CLSID = IID('{F41E89FB-D3D8-47BE-858C-332AC9DF8A86}')
	coclass_clsid = IID('{E7011745-D89C-48AA-AC84-93CFC315B5CC}')

	# Result is of type IExtendedTranslationParams
	def AddExtendedTranslation(self, pIExtendedTranslation=defaultNamedNotOptArg):
		'AddExtendedTranslation'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIExtendedTranslation
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddExtendedTranslation', '{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')
		return ret

	def DeleteExtendedTranslation(self, pIExtendedTranslationParams=defaultNamedNotOptArg):
		'DeleteExtendedTranslation'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIExtendedTranslationParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IExtendedTranslation
	def GetExtendedTranslation(self, pIExtendedTranslationParams=defaultNamedNotOptArg):
		'GetExtendedTranslation'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIExtendedTranslationParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetExtendedTranslation', '{EB9E1080-A979-4BA0-895B-D424C68063BC}')
		return ret

	# Result is of type IExtendedTranslationsParams
	def GetExtendedTranslationList(self):
		'GetExtendedTranslationList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetExtendedTranslationList', '{57FF304C-3414-48FA-8059-4F3B10FB37C9}')
		return ret

	def UpdateExtendedTranslation(self, pIExtendedTranslation=defaultNamedNotOptArg):
		'UpdateExtendedTranslation'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIExtendedTranslation
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExternalCall(DispatchBaseClass):
	'IExternalCall Interface'
	CLSID = IID('{B2BFF6DD-6309-40EB-BC59-75D1996BD77D}')
	coclass_clsid = IID('{0247151C-E23B-4C8A-B5BB-3BC1203A04EC}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		# Method 'CallArguments' returns object of type 'ICallArguments'
		"CallArguments": (18, 2, (9, 0), (), "CallArguments", '{EBBCE4C7-AE00-46A4-A0BA-851F42E7CADF}'),
		# Method 'CallMessages' returns object of type 'ICallMessages'
		"CallMessages": (19, 2, (9, 0), (), "CallMessages", '{1B562911-6C93-4858-B003-D2586E02BA48}'),
		"Category": (11, 2, (3, 0), (), "Category", None),
		"CreationDate": (13, 2, (7, 0), (), "CreationDate", None),
		"CreationTime": (14, 2, (3, 0), (), "CreationTime", None),
		"ID": (10, 2, (3, 0), (), "ID", None),
		"LastUpdateDate": (15, 2, (7, 0), (), "LastUpdateDate", None),
		"LastUpdateTime": (16, 2, (3, 0), (), "LastUpdateTime", None),
		"LastUpdateUserCode": (17, 2, (8, 0), (), "LastUpdateUserCode", None),
		"Status": (12, 2, (3, 0), (), "Status", None),
	}
	_prop_map_put_ = {
		"Category": ((11, LCID, 4, 0),()),
		"LastUpdateDate": ((15, LCID, 4, 0),()),
		"LastUpdateTime": ((16, LCID, 4, 0),()),
		"LastUpdateUserCode": ((17, LCID, 4, 0),()),
		"Status": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExternalCallParams(DispatchBaseClass):
	'IExternalCallParams Interface'
	CLSID = IID('{6AC1DA43-B01F-4E2E-8B5A-184BE9C05D80}')
	coclass_clsid = IID('{42D4F1DC-5789-4594-A1D7-601CAFBBA6C9}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ID": (10, 2, (3, 0), (), "ID", None),
	}
	_prop_map_put_ = {
		"ID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IExternalCallsService(DispatchBaseClass):
	'IExternalCallsService Interface'
	CLSID = IID('{1AD8B5F7-8076-488A-8493-1E430FF9EEAA}')
	coclass_clsid = IID('{215D7856-947B-49AC-BE80-CF521824D692}')

	# Result is of type IExternalCall
	def GetCall(self, pIExternalCallParams=defaultNamedNotOptArg):
		'GetCall'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIExternalCallParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetCall', '{B2BFF6DD-6309-40EB-BC59-75D1996BD77D}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IExternalCallParams
	def SendCall(self, pIExternalCall=defaultNamedNotOptArg):
		'SendCall'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIExternalCall
			)
		if ret is not None:
			ret = Dispatch(ret, u'SendCall', '{6AC1DA43-B01F-4E2E-8B5A-184BE9C05D80}')
		return ret

	def UpdateCall(self, pIExternalCall=defaultNamedNotOptArg):
		'UpdateCall'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIExternalCall
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFIFOLayers(DispatchBaseClass):
	'IFIFOLayers Interface'
	CLSID = IID('{2C4B93F4-860D-481D-85C5-020876095197}')
	coclass_clsid = IID('{4FE2A366-A423-4720-967D-4227EC04B8DE}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (7, 2, (3, 0), (), "Count", None),
		"LayerID": (2, 2, (3, 0), (), "LayerID", None),
		"LineTotal": (5, 2, (5, 0), (), "LineTotal", None),
		"Price": (4, 2, (5, 0), (), "Price", None),
		"Quantity": (3, 2, (5, 0), (), "Quantity", None),
		"TransactionSequenceNum": (1, 2, (3, 0), (), "TransactionSequenceNum", None),
	}
	_prop_map_put_ = {
		"LayerID": ((2, LCID, 4, 0),()),
		"LineTotal": ((5, LCID, 4, 0),()),
		"Price": ((4, LCID, 4, 0),()),
		"Quantity": ((3, LCID, 4, 0),()),
		"TransactionSequenceNum": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(7, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IFactoringIndicators(DispatchBaseClass):
	'IFactoringIndicators Interface'
	CLSID = IID('{DFE5A4A8-345B-43B3-A77F-906F10F142EE}')
	coclass_clsid = IID('{7178EF0A-1740-4B4C-89A2-779BB1E618D9}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),bstrCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"IndicatorCode": (9, 2, (8, 0), (), "IndicatorCode", None),
		"IndicatorName": (10, 2, (8, 0), (), "IndicatorName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"IndicatorCode": ((9, LCID, 4, 0),()),
		"IndicatorName": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFeatureStatus(DispatchBaseClass):
	'IFeatureStatus Interface'
	CLSID = IID('{B551C968-0DE9-48FA-B48D-385284294F16}')
	coclass_clsid = IID('{605E409B-D305-4DB4-8FC2-FFE8E3AD8EE9}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Blocked": (11, 2, (3, 0), (), "Blocked", None),
		"FeatureID": (10, 2, (8, 0), (), "FeatureID", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFeatureStatusCollection(DispatchBaseClass):
	'IFeatureStatusCollection Interface'
	CLSID = IID('{CB4596BC-49AF-40FF-AF45-DC92A9C75C97}')
	coclass_clsid = IID('{384B70CF-CF41-42B7-8599-B65597837C3F}')

	# Result is of type IFeatureStatus
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{B551C968-0DE9-48FA-B48D-385284294F16}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IFeatureStatus
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{B551C968-0DE9-48FA-B48D-385284294F16}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{B551C968-0DE9-48FA-B48D-385284294F16}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{B551C968-0DE9-48FA-B48D-385284294F16}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IField(DispatchBaseClass):
	'IField Interface'
	CLSID = IID('{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')
	coclass_clsid = IID('{0B6BCB38-6594-4EAB-88A8-5EEB856FF1EB}')

	def IsNull(self):
		'method IsNull'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	def SetNullValue(self):
		'method SetNullValue'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"DefaultValue": (13, 2, (8, 0), (), "DefaultValue", None),
		"Description": (5, 2, (8, 0), (), "Description", None),
		"FieldID": (17, 2, (3, 0), (), "FieldID", None),
		"LinkedTable": (12, 2, (8, 0), (), "LinkedTable", None),
		"Mandatory": (14, 2, (3, 0), (), "Mandatory", None),
		"Name": (1, 2, (8, 0), (), "Name", None),
		"Size": (3, 2, (3, 0), (), "Size", None),
		"SubType": (11, 2, (3, 0), (), "SubType", None),
		"Table": (18, 2, (8, 0), (), "Table", None),
		"Type": (2, 2, (3, 0), (), "Type", None),
		"ValidValue": (6, 2, (8, 0), (), "ValidValue", None),
		# Method 'ValidValues' returns object of type 'IValidValues'
		"ValidValues": (10, 2, (9, 0), (), "ValidValues", '{48B89C08-2AE9-435F-B7C4-D7219E938E46}'),
		"Value": (4, 2, (12, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"ValidValue": ((6, LCID, 4, 0),()),
		"Value": ((4, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(4, 2, (12, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFields(DispatchBaseClass):
	'IFields Interface'
	CLSID = IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')
	coclass_clsid = IID('{9D3B180E-A24C-48C9-A742-093663FF1878}')

	# Result is of type IField
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')
		return ret

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IFinancePeriod(DispatchBaseClass):
	'IFinancePeriod Interface'
	CLSID = IID('{39DAE3AB-708D-4123-BC50-CC57F05D734E}')
	coclass_clsid = IID('{F1CD6BFD-F77D-4059-A4E7-016D298C5C4D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsoluteEntry": (10, 2, (3, 0), (), "AbsoluteEntry", None),
		"ActiveforFeed": (19, 2, (3, 0), (), "ActiveforFeed", None),
		"AdditionalSubPeriods": (21, 2, (3, 0), (), "AdditionalSubPeriods", None),
		"Locked": (20, 2, (3, 0), (), "Locked", None),
		"PeriodCode": (11, 2, (8, 0), (), "PeriodCode", None),
		"PeriodIndicator": (23, 2, (8, 0), (), "PeriodIndicator", None),
		"PeriodName": (12, 2, (8, 0), (), "PeriodName", None),
		"PeriodStatus": (25, 2, (3, 0), (), "PeriodStatus", None),
		"PostingDateFrom": (13, 2, (7, 0), (), "PostingDateFrom", None),
		"PostingDateTo": (14, 2, (7, 0), (), "PostingDateTo", None),
		"SubNum": (24, 2, (3, 0), (), "SubNum", None),
		"TaxDateFrom": (17, 2, (7, 0), (), "TaxDateFrom", None),
		"TaxDateTo": (18, 2, (7, 0), (), "TaxDateTo", None),
		"ValueDateFrom": (15, 2, (7, 0), (), "ValueDateFrom", None),
		"ValueDateTo": (16, 2, (7, 0), (), "ValueDateTo", None),
	}
	_prop_map_put_ = {
		"ActiveforFeed": ((19, LCID, 4, 0),()),
		"Locked": ((20, LCID, 4, 0),()),
		"PeriodCode": ((11, LCID, 4, 0),()),
		"PeriodIndicator": ((23, LCID, 4, 0),()),
		"PeriodName": ((12, LCID, 4, 0),()),
		"PeriodStatus": ((25, LCID, 4, 0),()),
		"PostingDateFrom": ((13, LCID, 4, 0),()),
		"PostingDateTo": ((14, LCID, 4, 0),()),
		"TaxDateFrom": ((17, LCID, 4, 0),()),
		"TaxDateTo": ((18, LCID, 4, 0),()),
		"ValueDateFrom": ((15, LCID, 4, 0),()),
		"ValueDateTo": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFinancePeriodParams(DispatchBaseClass):
	'IFinancePeriodParams Interface'
	CLSID = IID('{DA6203BB-DE30-4AC7-9567-5822C3463335}')
	coclass_clsid = IID('{6CC3E1D1-D934-46CD-9DAD-33C30A06CA1C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsoluteEntry": (10, 2, (3, 0), (), "AbsoluteEntry", None),
		"PeriodIndicator": (11, 2, (8, 0), (), "PeriodIndicator", None),
	}
	_prop_map_put_ = {
		"AbsoluteEntry": ((10, LCID, 4, 0),()),
		"PeriodIndicator": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFinancePeriods(DispatchBaseClass):
	'IFinancePeriods Interface'
	CLSID = IID('{4CA3F302-7EC4-4514-9F07-CB688C56A2ED}')
	coclass_clsid = IID('{E4546110-84BF-46DE-9E5B-CB9CA610296E}')

	# Result is of type IFinancePeriod
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{39DAE3AB-708D-4123-BC50-CC57F05D734E}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IFinancePeriod
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{39DAE3AB-708D-4123-BC50-CC57F05D734E}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{39DAE3AB-708D-4123-BC50-CC57F05D734E}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{39DAE3AB-708D-4123-BC50-CC57F05D734E}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IFinancialYear(DispatchBaseClass):
	'IFinancialYear Interface'
	CLSID = IID('{C29BB9BD-1EC7-4427-A484-E79EC58F7224}')
	coclass_clsid = IID('{A44871DD-1C9F-4CCA-B9F9-CF688753D4B2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"AssessYear": (15, 2, (8, 0), (), "AssessYear", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"EndDate": (14, 2, (7, 0), (), "EndDate", None),
		"StartDate": (13, 2, (7, 0), (), "StartDate", None),
	}
	_prop_map_put_ = {
		"AssessYear": ((15, LCID, 4, 0),()),
		"Code": ((11, LCID, 4, 0),()),
		"Description": ((12, LCID, 4, 0),()),
		"StartDate": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFinancialYearParams(DispatchBaseClass):
	'IFinancialYearParams Interface'
	CLSID = IID('{83C6551A-5E1D-4651-8272-88BA8B56E728}')
	coclass_clsid = IID('{81305C7E-36A1-4336-A7D6-FEDB889A790B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFinancialYearsParams(DispatchBaseClass):
	'IFinancialYearsParams Interface'
	CLSID = IID('{9306DAC4-5FDE-4695-AF50-96349ABA5F74}')
	coclass_clsid = IID('{41CE0964-B3EC-45D0-AB38-D1D70788750E}')

	# Result is of type IFinancialYearParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{83C6551A-5E1D-4651-8272-88BA8B56E728}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IFinancialYearParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{83C6551A-5E1D-4651-8272-88BA8B56E728}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{83C6551A-5E1D-4651-8272-88BA8B56E728}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{83C6551A-5E1D-4651-8272-88BA8B56E728}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IFinancialYearsService(DispatchBaseClass):
	'IFinancialYearsService Interface'
	CLSID = IID('{58A42D29-DF69-4C14-9467-656666D09CD5}')
	coclass_clsid = IID('{1870838E-C4B4-4ACB-A0F8-FD98EE7673F6}')

	# Result is of type IFinancialYearParams
	def AddFinancialYear(self, pIFinancialYear=defaultNamedNotOptArg):
		'AddFinancialYear'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIFinancialYear
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddFinancialYear', '{83C6551A-5E1D-4651-8272-88BA8B56E728}')
		return ret

	def DeleteFinancialYear(self, pIFinancialYearParams=defaultNamedNotOptArg):
		'DeleteFinancialYear'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIFinancialYearParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IFinancialYear
	def GetFinancialYear(self, pIFinancialYearParams=defaultNamedNotOptArg):
		'GetFinancialYear'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIFinancialYearParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetFinancialYear', '{C29BB9BD-1EC7-4427-A484-E79EC58F7224}')
		return ret

	# Result is of type IFinancialYearsParams
	def GetFinancialYearList(self):
		'GetFinancialYearList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetFinancialYearList', '{9306DAC4-5FDE-4695-AF50-96349ABA5F74}')
		return ret

	def UpdateFinancialYear(self, pIFinancialYear=defaultNamedNotOptArg):
		'UpdateFinancialYear'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIFinancialYear
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFormPreferencesService(DispatchBaseClass):
	'IFormPreferencesService Interface'
	CLSID = IID('{177775C1-0633-42DE-8711-AF5D5DD650D8}')
	coclass_clsid = IID('{08F86A95-6E92-4287-AA3A-8B044183ED1F}')

	# Result is of type IColumnsPreferences
	def GetColumnsPreferences(self, pIColumnsPreferencesParams=defaultNamedNotOptArg):
		'GetColumnsPreferences'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIColumnsPreferencesParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetColumnsPreferences', '{5079035B-D0E5-4D0E-AFB1-6CB1FBAB11AE}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def UpdateColumnsPreferences(self, pIColumnsPreferencesParams=defaultNamedNotOptArg, pIColumnsPreferences=defaultNamedNotOptArg):
		'UpdateColumnsPreferences'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1), (9, 1)),pIColumnsPreferencesParams
			, pIColumnsPreferences)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IFormattedSearches(DispatchBaseClass):
	'IFormattedSearches Interface'
	CLSID = IID('{3CE45D97-D58D-4011-812D-32D867DDA8A7}')
	coclass_clsid = IID('{B4031DD0-97CA-4315-8ED6-211B8368E96F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lIndex=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lIndex
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Action": (13, 2, (3, 0), (), "Action", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ByField": (19, 2, (3, 0), (), "ByField", None),
		"ColumnID": (12, 2, (8, 0), (), "ColumnID", None),
		"FieldID": (17, 2, (8, 0), (), "FieldID", None),
		"ForceRefresh": (18, 2, (3, 0), (), "ForceRefresh", None),
		"FormID": (10, 2, (8, 0), (), "FormID", None),
		"Index": (15, 2, (3, 0), (), "Index", None),
		"ItemID": (11, 2, (8, 0), (), "ItemID", None),
		"QueryID": (14, 2, (3, 0), (), "QueryID", None),
		"Refresh": (16, 2, (3, 0), (), "Refresh", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		# Method 'UserValidValues' returns object of type 'IUserValidValues'
		"UserValidValues": (20, 2, (9, 0), (), "UserValidValues", '{280836CC-E077-4487-8759-D06DC3E31076}'),
	}
	_prop_map_put_ = {
		"Action": ((13, LCID, 4, 0),()),
		"ByField": ((19, LCID, 4, 0),()),
		"ColumnID": ((12, LCID, 4, 0),()),
		"FieldID": ((17, LCID, 4, 0),()),
		"ForceRefresh": ((18, LCID, 4, 0),()),
		"FormID": ((10, LCID, 4, 0),()),
		"ItemID": ((11, LCID, 4, 0),()),
		"QueryID": ((14, LCID, 4, 0),()),
		"Refresh": ((16, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IForms1099(DispatchBaseClass):
	'IForms1099 Interface'
	CLSID = IID('{5FE3FCA3-E93E-4106-8190-F62CB9FBF137}')
	coclass_clsid = IID('{97B3DA37-698B-4ED4-84E8-B8A110AEC25E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lFormCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lFormCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Boxes1099' returns object of type 'IBoxes1099'
		"Boxes1099": (16, 2, (9, 0), (), "Boxes1099", '{1C7661BB-2694-4ECF-94EF-588ECB0CB8AD}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Form1099": (13, 2, (8, 0), (), "Form1099", None),
		"FormCode": (12, 2, (3, 0), (), "FormCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Form1099": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IGLAccount(DispatchBaseClass):
	'IGLAccount Interface'
	CLSID = IID('{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}')
	coclass_clsid = IID('{9D04BDB8-F941-49C2-A9C1-E11A71681BAA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Credit": (13, 2, (5, 0), (), "Credit", None),
		"Debit": (12, 2, (5, 0), (), "Debit", None),
		"DueDate": (11, 2, (7, 0), (), "DueDate", None),
		"ForeignCredit": (17, 2, (5, 0), (), "ForeignCredit", None),
		"ForeignCurrency": (18, 2, (8, 0), (), "ForeignCurrency", None),
		"ForeignDebit": (16, 2, (5, 0), (), "ForeignDebit", None),
		"SystemCredit": (15, 2, (5, 0), (), "SystemCredit", None),
		"SystemDebit": (14, 2, (5, 0), (), "SystemDebit", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
		"Credit": ((13, LCID, 4, 0),()),
		"Debit": ((12, LCID, 4, 0),()),
		"DueDate": ((11, LCID, 4, 0),()),
		"ForeignCredit": ((17, LCID, 4, 0),()),
		"ForeignCurrency": ((18, LCID, 4, 0),()),
		"ForeignDebit": ((16, LCID, 4, 0),()),
		"SystemCredit": ((15, LCID, 4, 0),()),
		"SystemDebit": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IGLAccounts(DispatchBaseClass):
	'IGLAccounts Interface'
	CLSID = IID('{DFFEC465-C3AA-45DD-ABBC-9D025A328335}')
	coclass_clsid = IID('{F7DE78D1-5738-4D41-8002-396D495E6483}')

	# Result is of type IGLAccount
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IGLAccount
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IGTIParams(DispatchBaseClass):
	'IGTIParams Interface'
	CLSID = IID('{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}')
	coclass_clsid = IID('{9B1154A7-0B01-4FF6-89F3-9A601676D895}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (11, 2, (3, 0), (), "AbsEntry", None),
		"InboundFile": (10, 2, (8, 0), (), "InboundFile", None),
	}
	_prop_map_put_ = {
		"InboundFile": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IGTIParamsCollection(DispatchBaseClass):
	'IGTIParamsCollection Interface'
	CLSID = IID('{DF63C280-18C5-4444-BDAF-59318E9ED979}')
	coclass_clsid = IID('{47C12E2F-E1CA-41E8-A9FA-F8415E2B6125}')

	# Result is of type IGTIParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IGTIParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IGTIsService(DispatchBaseClass):
	'IGTIsService Interface'
	CLSID = IID('{D0A0837D-25C5-4511-9C31-B749CA452C8F}')
	coclass_clsid = IID('{E90FD334-9FC7-4E35-8E2D-43D338D63C1F}')

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IGTIParamsCollection
	def Import(self, pIGTIParams=defaultNamedNotOptArg):
		'Import'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIGTIParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Import', '{DF63C280-18C5-4444-BDAF-59318E9ED979}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IGeneralCollectionParams(DispatchBaseClass):
	'IGeneralCollectionParams Interface'
	CLSID = IID('{ACAC0540-ACCA-4278-8EB8-2300D893ADD1}')
	coclass_clsid = IID('{BA6EBBED-CE1B-4EB3-9B32-FE16126BFFC2}')

	# Result is of type IGeneralDataParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IGeneralDataParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IGeneralData(DispatchBaseClass):
	'IGeneralData Interface'
	CLSID = IID('{C131D463-24C3-424A-B734-589D0F452D2E}')
	coclass_clsid = IID('{2240A153-81F1-4335-8702-1EB085CB1056}')

	# Result is of type IGeneralDataCollection
	def Child(self, bstrDataName=defaultNamedNotOptArg):
		'Child'
		ret = self._oleobj_.InvokeTypes(8, LCID, 1, (9, 0), ((8, 1),),bstrDataName
			)
		if ret is not None:
			ret = Dispatch(ret, u'Child', '{646FEBEB-91D7-4517-8CB0-B550DCA64490}')
		return ret

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetProperty(self, bstrPropertyName=defaultNamedNotOptArg):
		'GetProperty'
		return self._ApplyTypes_(9, 1, (12, 0), ((8, 1),), u'GetProperty', None,bstrPropertyName
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def SetProperty(self, bstrPropertyName=defaultNamedNotOptArg, vtValue=defaultNamedNotOptArg):
		'SetProperty'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1), (12, 1)),bstrPropertyName
			, vtValue)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IGeneralDataCollection(DispatchBaseClass):
	'IGeneralDataCollection Interface'
	CLSID = IID('{646FEBEB-91D7-4517-8CB0-B550DCA64490}')
	coclass_clsid = IID('{16BDDE57-AD9D-48FE-9E33-964239B3F414}')

	# Result is of type IGeneralData
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{C131D463-24C3-424A-B734-589D0F452D2E}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IGeneralData
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{C131D463-24C3-424A-B734-589D0F452D2E}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{C131D463-24C3-424A-B734-589D0F452D2E}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{C131D463-24C3-424A-B734-589D0F452D2E}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IGeneralDataParams(DispatchBaseClass):
	'IGeneralDataParams Interface'
	CLSID = IID('{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')
	coclass_clsid = IID('{E56E576E-555C-4F31-8170-0EFA192411E2}')

	def GetProperty(self, bstrPropertyName=defaultNamedNotOptArg):
		'GetProperty'
		return self._ApplyTypes_(9, 1, (12, 0), ((8, 1),), u'GetProperty', None,bstrPropertyName
			)

	def SetProperty(self, bstrPropertyName=defaultNamedNotOptArg, vtValue=defaultNamedNotOptArg):
		'SetProperty'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1), (12, 1)),bstrPropertyName
			, vtValue)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IGeneralService(DispatchBaseClass):
	'IGeneralService Interface'
	CLSID = IID('{31DE5655-438F-420E-83D0-016C88203706}')
	coclass_clsid = IID('{5433B477-761B-47F3-8F1B-12694ED7AE47}')

	# Result is of type IGeneralDataParams
	def Add(self, pIGeneralData=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIGeneralData
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')
		return ret

	def Cancel(self, pIGeneralDataParams=defaultNamedNotOptArg):
		'Cancel'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((9, 1),),pIGeneralDataParams
			)

	def Close(self, pIGeneralDataParams=defaultNamedNotOptArg):
		'Close'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (24, 0), ((9, 1),),pIGeneralDataParams
			)

	def Delete(self, pIGeneralDataParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIGeneralDataParams
			)

	# Result is of type IGeneralData
	def DoCommand(self, pGeneralData=defaultNamedNotOptArg, Command_Name=defaultNamedNotOptArg):
		'DoCommand'
		ret = self._oleobj_.InvokeTypes(18, LCID, 1, (9, 0), ((9, 1), (8, 0)),pGeneralData
			, Command_Name)
		if ret is not None:
			ret = Dispatch(ret, u'DoCommand', '{C131D463-24C3-424A-B734-589D0F452D2E}')
		return ret

	# Result is of type IGeneralData
	def GetByParams(self, pIGeneralDataParams=defaultNamedNotOptArg):
		'GetByParams'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((9, 1),),pIGeneralDataParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetByParams', '{C131D463-24C3-424A-B734-589D0F452D2E}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IGeneralCollectionParams
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{ACAC0540-ACCA-4278-8EB8-2300D893ADD1}')
		return ret

	# Result is of type IInvokeParams
	def InvokeMethod(self, pIInvokeParams=defaultNamedNotOptArg, pIGeneralData=defaultNamedNotOptArg):
		'InvokeMethod'
		ret = self._oleobj_.InvokeTypes(17, LCID, 1, (9, 0), ((9, 1), (9, 1)),pIInvokeParams
			, pIGeneralData)
		if ret is not None:
			ret = Dispatch(ret, u'InvokeMethod', '{D6BF90B4-5DE1-4A71-8463-FEB7AB1A9AB4}')
		return ret

	def Update(self, pIGeneralData=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIGeneralData
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IGetChangeLogParams(DispatchBaseClass):
	'IGetChangeLogParams Interface'
	CLSID = IID('{E8632E10-873F-4EBF-8339-E57C985D4472}')
	coclass_clsid = IID('{BCB7B6F8-6750-499E-B446-BC080CAD82D1}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Object": (11, 2, (3, 0), (), "Object", None),
		"PrimaryKey": (10, 2, (8, 0), (), "PrimaryKey", None),
		"UDOObjectCode": (12, 2, (8, 0), (), "UDOObjectCode", None),
	}
	_prop_map_put_ = {
		"Object": ((11, LCID, 4, 0),()),
		"PrimaryKey": ((10, LCID, 4, 0),()),
		"UDOObjectCode": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IHouseBankAccounts(DispatchBaseClass):
	'IHouseBankAccounts Interface'
	CLSID = IID('{B83BBBFA-E5AF-48B4-B147-2DE092BF1E64}')
	coclass_clsid = IID('{65307EF1-BD5A-4297-B9F0-7F957D7CC0FC}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsEntry=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lAbsEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AbsoluteEntry": (41, 2, (3, 0), (), "AbsoluteEntry", None),
		"AccNo": (11, 2, (8, 0), (), "AccNo", None),
		"AccountCheckDigit": (51, 2, (8, 0), (), "AccountCheckDigit", None),
		"AccountName": (61, 2, (8, 0), (), "AccountName", None),
		"AddressType": (54, 2, (8, 0), (), "AddressType", None),
		"AgreementNumber": (53, 2, (8, 0), (), "AgreementNumber", None),
		"BICSwiftCode": (62, 2, (8, 0), (), "BICSwiftCode", None),
		"BISR": (22, 2, (3, 0), (), "BISR", None),
		"BankCode": (10, 2, (8, 0), (), "BankCode", None),
		"BankKey": (42, 2, (3, 0), (), "BankKey", None),
		"BankonCollection": (35, 2, (8, 0), (), "BankonCollection", None),
		"BankonDiscounted": (36, 2, (8, 0), (), "BankonDiscounted", None),
		"Block": (16, 2, (8, 0), (), "Block", None),
		"Branch": (12, 2, (8, 0), (), "Branch", None),
		"BranchCheckDigit": (71, 2, (8, 0), (), "BranchCheckDigit", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Building": (56, 2, (8, 0), (), "Building", None),
		"City": (18, 2, (8, 0), (), "City", None),
		"CollectionCode": (72, 2, (8, 0), (), "CollectionCode", None),
		"ControlKey": (23, 2, (8, 0), (), "ControlKey", None),
		"Country": (20, 2, (8, 0), (), "Country", None),
		"County": (19, 2, (8, 0), (), "County", None),
		"CustomerIdNumber": (48, 2, (8, 0), (), "CustomerIdNumber", None),
		"DaysInAdvance": (34, 2, (3, 0), (), "DaysInAdvance", None),
		"DebtofDiscountedBillofExc": (29, 2, (8, 0), (), "DebtofDiscountedBillofExc", None),
		"DiscountAccount": (65, 2, (8, 0), (), "DiscountAccount", None),
		"DiscountLimit": (33, 2, (5, 0), (), "DiscountLimit", None),
		"FileSeqNextNumber": (73, 2, (3, 0), (), "FileSeqNextNumber", None),
		"FineAccount": (63, 2, (8, 0), (), "FineAccount", None),
		"GLAccount": (14, 2, (8, 0), (), "GLAccount", None),
		"GLInterimAccount": (37, 2, (8, 0), (), "GLInterimAccount", None),
		"IBAN": (28, 2, (8, 0), (), "IBAN", None),
		"IOFTaxAccount": (67, 2, (8, 0), (), "IOFTaxAccount", None),
		"ISRBillerID": (49, 2, (8, 0), (), "ISRBillerID", None),
		"ISRType": (50, 2, (3, 0), (), "ISRType", None),
		"ImportFileName": (60, 2, (8, 0), (), "ImportFileName", None),
		"IncomingPaymentSeries": (57, 2, (3, 0), (), "IncomingPaymentSeries", None),
		"InterestAccount": (64, 2, (8, 0), (), "InterestAccount", None),
		"JournalEntrySeries": (59, 2, (3, 0), (), "JournalEntrySeries", None),
		"LockChecksPrinting": (43, 2, (3, 0), (), "LockChecksPrinting", None),
		"MaxAmountofBillofExchan": (32, 2, (5, 0), (), "MaxAmountofBillofExchan", None),
		"MaximumLines": (46, 2, (3, 0), (), "MaximumLines", None),
		"MinAmountofBillofExchang": (31, 2, (5, 0), (), "MinAmountofBillofExchang", None),
		"NextCheckNo": (13, 2, (3, 0), (), "NextCheckNo", None),
		"OtherExpensesAccount": (68, 2, (8, 0), (), "OtherExpensesAccount", None),
		"OtherIncomesAccount": (69, 2, (8, 0), (), "OtherIncomesAccount", None),
		"OurNumber": (52, 2, (3, 0), (), "OurNumber", None),
		"OutgoingPaymentSeries": (58, 2, (3, 0), (), "OutgoingPaymentSeries", None),
		"PrintOn": (47, 2, (3, 0), (), "PrintOn", None),
		"RetornoFileName": (70, 2, (8, 0), (), "RetornoFileName", None),
		"ServiceFeeAccount": (66, 2, (8, 0), (), "ServiceFeeAccount", None),
		"State": (21, 2, (8, 0), (), "State", None),
		"Street": (15, 2, (8, 0), (), "Street", None),
		"StreetNo": (55, 2, (8, 0), (), "StreetNo", None),
		"TemplateName": (44, 2, (8, 0), (), "TemplateName", None),
		"ToleranceDays": (30, 2, (3, 0), (), "ToleranceDays", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserNo1": (24, 2, (8, 0), (), "UserNo1", None),
		"UserNo2": (25, 2, (8, 0), (), "UserNo2", None),
		"UserNo3": (26, 2, (8, 0), (), "UserNo3", None),
		"UserNo4": (27, 2, (8, 0), (), "UserNo4", None),
		"ZipCode": (17, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AccNo": ((11, LCID, 4, 0),()),
		"AccountCheckDigit": ((51, LCID, 4, 0),()),
		"AccountName": ((61, LCID, 4, 0),()),
		"AddressType": ((54, LCID, 4, 0),()),
		"AgreementNumber": ((53, LCID, 4, 0),()),
		"BICSwiftCode": ((62, LCID, 4, 0),()),
		"BISR": ((22, LCID, 4, 0),()),
		"BankKey": ((42, LCID, 4, 0),()),
		"BankonCollection": ((35, LCID, 4, 0),()),
		"BankonDiscounted": ((36, LCID, 4, 0),()),
		"Block": ((16, LCID, 4, 0),()),
		"Branch": ((12, LCID, 4, 0),()),
		"BranchCheckDigit": ((71, LCID, 4, 0),()),
		"Building": ((56, LCID, 4, 0),()),
		"City": ((18, LCID, 4, 0),()),
		"CollectionCode": ((72, LCID, 4, 0),()),
		"ControlKey": ((23, LCID, 4, 0),()),
		"County": ((19, LCID, 4, 0),()),
		"CustomerIdNumber": ((48, LCID, 4, 0),()),
		"DaysInAdvance": ((34, LCID, 4, 0),()),
		"DebtofDiscountedBillofExc": ((29, LCID, 4, 0),()),
		"DiscountAccount": ((65, LCID, 4, 0),()),
		"DiscountLimit": ((33, LCID, 4, 0),()),
		"FileSeqNextNumber": ((73, LCID, 4, 0),()),
		"FineAccount": ((63, LCID, 4, 0),()),
		"GLAccount": ((14, LCID, 4, 0),()),
		"GLInterimAccount": ((37, LCID, 4, 0),()),
		"IBAN": ((28, LCID, 4, 0),()),
		"IOFTaxAccount": ((67, LCID, 4, 0),()),
		"ISRBillerID": ((49, LCID, 4, 0),()),
		"ISRType": ((50, LCID, 4, 0),()),
		"ImportFileName": ((60, LCID, 4, 0),()),
		"IncomingPaymentSeries": ((57, LCID, 4, 0),()),
		"InterestAccount": ((64, LCID, 4, 0),()),
		"JournalEntrySeries": ((59, LCID, 4, 0),()),
		"LockChecksPrinting": ((43, LCID, 4, 0),()),
		"MaxAmountofBillofExchan": ((32, LCID, 4, 0),()),
		"MaximumLines": ((46, LCID, 4, 0),()),
		"MinAmountofBillofExchang": ((31, LCID, 4, 0),()),
		"NextCheckNo": ((13, LCID, 4, 0),()),
		"OtherExpensesAccount": ((68, LCID, 4, 0),()),
		"OtherIncomesAccount": ((69, LCID, 4, 0),()),
		"OurNumber": ((52, LCID, 4, 0),()),
		"OutgoingPaymentSeries": ((58, LCID, 4, 0),()),
		"PrintOn": ((47, LCID, 4, 0),()),
		"RetornoFileName": ((70, LCID, 4, 0),()),
		"ServiceFeeAccount": ((66, LCID, 4, 0),()),
		"State": ((21, LCID, 4, 0),()),
		"Street": ((15, LCID, 4, 0),()),
		"StreetNo": ((55, LCID, 4, 0),()),
		"TemplateName": ((44, LCID, 4, 0),()),
		"ToleranceDays": ((30, LCID, 4, 0),()),
		"UserNo1": ((24, LCID, 4, 0),()),
		"UserNo2": ((25, LCID, 4, 0),()),
		"UserNo3": ((26, LCID, 4, 0),()),
		"UserNo4": ((27, LCID, 4, 0),()),
		"ZipCode": ((17, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IImportFileParam(DispatchBaseClass):
	'IImportFileParam Interface'
	CLSID = IID('{4AA87BC6-363C-4A35-9EB3-473BF6785478}')
	coclass_clsid = IID('{6A174FBA-0ED4-4619-BC5F-2DF68BB53C89}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"FilePath": (10, 2, (8, 0), (), "FilePath", None),
	}
	_prop_map_put_ = {
		"FilePath": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IImportProcesses(DispatchBaseClass):
	'IImportProcesses Interface'
	CLSID = IID('{8A8F6C7B-BD55-45C5-A28C-C81A786B0EB8}')
	coclass_clsid = IID('{0F2D8F44-9F7D-4290-8A2C-9B08EC782ECD}')

	_prop_map_get_ = {
		"AdditionalItemDiscountValue": (16, 2, (5, 0), (), "AdditionalItemDiscountValue", None),
		"AdditionalNumber": (15, 2, (8, 0), (), "AdditionalNumber", None),
		"CustomsClearanceDate": (13, 2, (7, 0), (), "CustomsClearanceDate", None),
		"DateOfRegistry_DI_DSI_DA": (12, 2, (7, 0), (), "DateOfRegistry_DI_DSI_DA", None),
		"DrawbackRegimeConcessionAccountNumber": (14, 2, (8, 0), (), "DrawbackRegimeConcessionAccountNumber", None),
		"ImportationDocumentNumber": (11, 2, (8, 0), (), "ImportationDocumentNumber", None),
		"ImportationDocumentTypeCode": (10, 2, (8, 0), (), "ImportationDocumentTypeCode", None),
	}
	_prop_map_put_ = {
		"AdditionalItemDiscountValue": ((16, LCID, 4, 0),()),
		"AdditionalNumber": ((15, LCID, 4, 0),()),
		"CustomsClearanceDate": ((13, LCID, 4, 0),()),
		"DateOfRegistry_DI_DSI_DA": ((12, LCID, 4, 0),()),
		"DrawbackRegimeConcessionAccountNumber": ((14, LCID, 4, 0),()),
		"ImportationDocumentNumber": ((11, LCID, 4, 0),()),
		"ImportationDocumentTypeCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IIndustries(DispatchBaseClass):
	'IIndustries Interface'
	CLSID = IID('{68C60132-0DD3-4AD2-B4FF-DB358A6184BC}')
	coclass_clsid = IID('{4E6D1836-16F8-4D8F-9BF8-0271F4856450}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(11, LCID, 1, (8, 0), (),)

	def GetByKey(self, Code=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (11, 0), ((3, 1),),Code
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(8, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (10, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"IndustryCode": (3, 2, (3, 0), (), "IndustryCode", None),
		"IndustryDescription": (1, 2, (8, 0), (), "IndustryDescription", None),
		"IndustryName": (2, 2, (8, 0), (), "IndustryName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (9, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"IndustryDescription": ((1, LCID, 4, 0),()),
		"IndustryName": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IInventoryCycles(DispatchBaseClass):
	'IInventoryCycles Interface'
	CLSID = IID('{C9C6EE8B-66E6-4C3E-91ED-49482CF4B903}')
	coclass_clsid = IID('{A9FD63E5-C131-4554-975C-7D8C5C0A2A0A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CycleCode": (10, 2, (3, 0), (), "CycleCode", None),
		"CycleName": (11, 2, (8, 0), (), "CycleName", None),
		"Day": (13, 2, (3, 0), (), "Day", None),
		"Frequency": (12, 2, (3, 0), (), "Frequency", None),
		"Hour": (14, 2, (7, 0), (), "Hour", None),
		"NextCountingDate": (15, 2, (7, 0), (), "NextCountingDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CycleName": ((11, LCID, 4, 0),()),
		"Day": ((13, LCID, 4, 0),()),
		"Frequency": ((12, LCID, 4, 0),()),
		"Hour": ((14, LCID, 4, 0),()),
		"NextCountingDate": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IInvokeParams(DispatchBaseClass):
	'IInvokeParams Interface'
	CLSID = IID('{D6BF90B4-5DE1-4A71-8463-FEB7AB1A9AB4}')
	coclass_clsid = IID('{49353779-B77E-4F0C-B8DE-499566F0A89A}')

	_prop_map_get_ = {
		"Value": (10, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Value": ((10, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(10, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IItemCycleCount(DispatchBaseClass):
	'IItemCycleCount Interface'
	CLSID = IID('{743A4F30-AC7F-4606-9AA3-5139F07E08A2}')
	coclass_clsid = IID('{17865049-85ED-47FE-8CCF-C481E3373439}')

	_prop_map_get_ = {
		"Alert": (5, 2, (3, 0), (), "Alert", None),
		"AlertTime": (7, 2, (7, 0), (), "AlertTime", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"CycleCode": (4, 2, (3, 0), (), "CycleCode", None),
		"DestinationUser": (8, 2, (3, 0), (), "DestinationUser", None),
		"NextCountingDate": (6, 2, (7, 0), (), "NextCountingDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (3, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WarehouseCode": (9, 2, (8, 0), (), "WarehouseCode", None),
	}
	_prop_map_put_ = {
		"Alert": ((5, LCID, 4, 0),()),
		"AlertTime": ((7, LCID, 4, 0),()),
		"CycleCode": ((4, LCID, 4, 0),()),
		"DestinationUser": ((8, LCID, 4, 0),()),
		"NextCountingDate": ((6, LCID, 4, 0),()),
		"WarehouseCode": ((9, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IItemGroups(DispatchBaseClass):
	'IItemGroups Interface'
	CLSID = IID('{216974E8-B66D-4022-9AB1-97BAA96084A3}')
	coclass_clsid = IID('{5F2AE736-E6D3-4D3A-BCB5-F9EE3A45872A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(42, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(49, LCID, 1, (8, 0), (),)

	def GetByKey(self, GroupCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(45, LCID, 1, (11, 0), ((3, 1),),GroupCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(44, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(50, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(46, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(43, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Alert": (28, 2, (3, 0), (), "Alert", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (48, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CostAccount": (38, 2, (8, 0), (), "CostAccount", None),
		"CostInflationAccount": (15, 2, (8, 0), (), "CostInflationAccount", None),
		"CostInflationOffsetAccount": (21, 2, (8, 0), (), "CostInflationOffsetAccount", None),
		"CycleCode": (37, 2, (3, 0), (), "CycleCode", None),
		"DecreaseGLAccount": (23, 2, (8, 0), (), "DecreaseGLAccount", None),
		"DecreasingAccount": (32, 2, (8, 0), (), "DecreasingAccount", None),
		"EUExpensesAccount": (35, 2, (8, 0), (), "EUExpensesAccount", None),
		"EUPurchaseCreditAcc": (56, 2, (8, 0), (), "EUPurchaseCreditAcc", None),
		"EURevenuesAccount": (39, 2, (8, 0), (), "EURevenuesAccount", None),
		"ExchangeRateDifferencesAccount": (5, 2, (8, 0), (), "ExchangeRateDifferencesAccount", None),
		"ExemptRevenuesAccount": (31, 2, (8, 0), (), "ExemptRevenuesAccount", None),
		"ExemptedCredits": (60, 2, (8, 0), (), "ExemptedCredits", None),
		"ExpenseClearingAct": (54, 2, (8, 0), (), "ExpenseClearingAct", None),
		"ExpenseOffsetAccount": (63, 2, (8, 0), (), "ExpenseOffsetAccount", None),
		"ExpensesAccount": (16, 2, (8, 0), (), "ExpensesAccount", None),
		"ForeignExpensesAccount": (36, 2, (8, 0), (), "ForeignExpensesAccount", None),
		"ForeignPurchaseCreditAcc": (57, 2, (8, 0), (), "ForeignPurchaseCreditAcc", None),
		"ForeignRevenuesAccount": (27, 2, (8, 0), (), "ForeignRevenuesAccount", None),
		"GoodsClearingAccount": (25, 2, (8, 0), (), "GoodsClearingAccount", None),
		"GroupName": (41, 2, (8, 0), (), "GroupName", None),
		"IncreaseGLAccount": (26, 2, (8, 0), (), "IncreaseGLAccount", None),
		"IncreasingAccount": (6, 2, (8, 0), (), "IncreasingAccount", None),
		"InventoryAccount": (22, 2, (8, 0), (), "InventoryAccount", None),
		"InventoryOffsetProfitAndLossAccount": (72, 2, (8, 0), (), "InventoryOffsetProfitAndLossAccount", None),
		"InventorySystem": (10, 2, (3, 0), (), "InventorySystem", None),
		"LeadTime": (19, 2, (3, 0), (), "LeadTime", None),
		"MinimumOrderQuantity": (3, 2, (5, 0), (), "MinimumOrderQuantity", None),
		"NegativeInventoryAdjustmentAccount": (64, 2, (8, 0), (), "NegativeInventoryAdjustmentAccount", None),
		"Number": (24, 2, (3, 0), (), "Number", None),
		"OrderInterval": (4, 2, (3, 0), (), "OrderInterval", None),
		"OrderMultiple": (20, 2, (5, 0), (), "OrderMultiple", None),
		"PAReturnAccount": (40, 2, (8, 0), (), "PAReturnAccount", None),
		"PlanningSystem": (12, 2, (3, 0), (), "PlanningSystem", None),
		"PriceDifferencesAccount": (1, 2, (8, 0), (), "PriceDifferencesAccount", None),
		"ProcurementMethod": (8, 2, (3, 0), (), "ProcurementMethod", None),
		"PurchaseAccount": (13, 2, (8, 0), (), "PurchaseAccount", None),
		"PurchaseCreditAcc": (55, 2, (8, 0), (), "PurchaseCreditAcc", None),
		"PurchaseOffsetAccount": (9, 2, (8, 0), (), "PurchaseOffsetAccount", None),
		"ReturningAccount": (14, 2, (8, 0), (), "ReturningAccount", None),
		"RevenuesAccount": (17, 2, (8, 0), (), "RevenuesAccount", None),
		"SalesCreditAcc": (58, 2, (8, 0), (), "SalesCreditAcc", None),
		"SalesCreditEUAcc": (59, 2, (8, 0), (), "SalesCreditEUAcc", None),
		"SalesCreditForeignAcc": (61, 2, (8, 0), (), "SalesCreditForeignAcc", None),
		"ShippedGoodsAccount": (30, 2, (8, 0), (), "ShippedGoodsAccount", None),
		"StockInTransitAccount": (67, 2, (8, 0), (), "StockInTransitAccount", None),
		"StockInflationAdjustAccount": (2, 2, (8, 0), (), "StockInflationAdjustAccount", None),
		"StockInflationOffsetAccount": (7, 2, (8, 0), (), "StockInflationOffsetAccount", None),
		"ToleranceDays": (73, 2, (3, 0), (), "ToleranceDays", None),
		"TransfersAccount": (18, 2, (8, 0), (), "TransfersAccount", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (47, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATInRevenueAccount": (33, 2, (8, 0), (), "VATInRevenueAccount", None),
		"VarianceAccount": (34, 2, (8, 0), (), "VarianceAccount", None),
		"WHIncomingCenvatAccount": (65, 2, (8, 0), (), "WHIncomingCenvatAccount", None),
		"WHOutgoingCenvatAccount": (66, 2, (8, 0), (), "WHOutgoingCenvatAccount", None),
		"WIPMaterialAccount": (29, 2, (8, 0), (), "WIPMaterialAccount", None),
		"WIPMaterialVarianceAccount": (11, 2, (8, 0), (), "WIPMaterialVarianceAccount", None),
		"WipOffsetProfitAndLossAccount": (71, 2, (8, 0), (), "WipOffsetProfitAndLossAccount", None),
	}
	_prop_map_put_ = {
		"Alert": ((28, LCID, 4, 0),()),
		"CostAccount": ((38, LCID, 4, 0),()),
		"CostInflationAccount": ((15, LCID, 4, 0),()),
		"CostInflationOffsetAccount": ((21, LCID, 4, 0),()),
		"CycleCode": ((37, LCID, 4, 0),()),
		"DecreaseGLAccount": ((23, LCID, 4, 0),()),
		"DecreasingAccount": ((32, LCID, 4, 0),()),
		"EUExpensesAccount": ((35, LCID, 4, 0),()),
		"EUPurchaseCreditAcc": ((56, LCID, 4, 0),()),
		"EURevenuesAccount": ((39, LCID, 4, 0),()),
		"ExchangeRateDifferencesAccount": ((5, LCID, 4, 0),()),
		"ExemptRevenuesAccount": ((31, LCID, 4, 0),()),
		"ExemptedCredits": ((60, LCID, 4, 0),()),
		"ExpenseClearingAct": ((54, LCID, 4, 0),()),
		"ExpenseOffsetAccount": ((63, LCID, 4, 0),()),
		"ExpensesAccount": ((16, LCID, 4, 0),()),
		"ForeignExpensesAccount": ((36, LCID, 4, 0),()),
		"ForeignPurchaseCreditAcc": ((57, LCID, 4, 0),()),
		"ForeignRevenuesAccount": ((27, LCID, 4, 0),()),
		"GoodsClearingAccount": ((25, LCID, 4, 0),()),
		"GroupName": ((41, LCID, 4, 0),()),
		"IncreaseGLAccount": ((26, LCID, 4, 0),()),
		"IncreasingAccount": ((6, LCID, 4, 0),()),
		"InventoryAccount": ((22, LCID, 4, 0),()),
		"InventoryOffsetProfitAndLossAccount": ((72, LCID, 4, 0),()),
		"InventorySystem": ((10, LCID, 4, 0),()),
		"LeadTime": ((19, LCID, 4, 0),()),
		"MinimumOrderQuantity": ((3, LCID, 4, 0),()),
		"NegativeInventoryAdjustmentAccount": ((64, LCID, 4, 0),()),
		"OrderInterval": ((4, LCID, 4, 0),()),
		"OrderMultiple": ((20, LCID, 4, 0),()),
		"PAReturnAccount": ((40, LCID, 4, 0),()),
		"PlanningSystem": ((12, LCID, 4, 0),()),
		"PriceDifferencesAccount": ((1, LCID, 4, 0),()),
		"ProcurementMethod": ((8, LCID, 4, 0),()),
		"PurchaseAccount": ((13, LCID, 4, 0),()),
		"PurchaseCreditAcc": ((55, LCID, 4, 0),()),
		"PurchaseOffsetAccount": ((9, LCID, 4, 0),()),
		"ReturningAccount": ((14, LCID, 4, 0),()),
		"RevenuesAccount": ((17, LCID, 4, 0),()),
		"SalesCreditAcc": ((58, LCID, 4, 0),()),
		"SalesCreditEUAcc": ((59, LCID, 4, 0),()),
		"SalesCreditForeignAcc": ((61, LCID, 4, 0),()),
		"ShippedGoodsAccount": ((30, LCID, 4, 0),()),
		"StockInTransitAccount": ((67, LCID, 4, 0),()),
		"StockInflationAdjustAccount": ((2, LCID, 4, 0),()),
		"StockInflationOffsetAccount": ((7, LCID, 4, 0),()),
		"ToleranceDays": ((73, LCID, 4, 0),()),
		"TransfersAccount": ((18, LCID, 4, 0),()),
		"VATInRevenueAccount": ((33, LCID, 4, 0),()),
		"VarianceAccount": ((34, LCID, 4, 0),()),
		"WHIncomingCenvatAccount": ((65, LCID, 4, 0),()),
		"WHOutgoingCenvatAccount": ((66, LCID, 4, 0),()),
		"WIPMaterialAccount": ((29, LCID, 4, 0),()),
		"WIPMaterialVarianceAccount": ((11, LCID, 4, 0),()),
		"WipOffsetProfitAndLossAccount": ((71, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IItemLocalizationInfos(DispatchBaseClass):
	'IItemLocalizationInfos Interface'
	CLSID = IID('{04B4DCB9-A2CD-4C53-BD52-FA43B7754803}')
	coclass_clsid = IID('{2254824E-D59D-4A5D-8817-2F49B620154E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNumber=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNumber
			)

	_prop_map_get_ = {
		"Count": (7, 2, (3, 0), (), "Count", None),
		"IncomeNature": (10, 2, (8, 0), (), "IncomeNature", None),
		"ItemCode": (9, 2, (8, 0), (), "ItemCode", None),
	}
	_prop_map_put_ = {
		"IncomeNature": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(7, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IItemProperties(DispatchBaseClass):
	'IItemProperties Interface'
	CLSID = IID('{BD54054F-D434-4DC7-8D84-8020C653432C}')
	coclass_clsid = IID('{91CC17DA-3F2C-464A-8060-8338ADD207DA}')

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lGroupCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lGroupCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Number": (11, 2, (3, 0), (), "Number", None),
		"PropertyName": (12, 2, (8, 0), (), "PropertyName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"PropertyName": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IItemWarehouseInfo(DispatchBaseClass):
	'IItemWarehouseInfo Interface'
	CLSID = IID('{CDB52791-B0FC-4BE1-A712-06941AF91D52}')
	coclass_clsid = IID('{494EAB50-0ED0-4773-8BCF-9F769A80B6BC}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'Delete current line'
		return self._oleobj_.InvokeTypes(61, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Committed": (26, 2, (5, 0), (), "Committed", None),
		"CostAccount": (9, 2, (8, 0), (), "CostAccount", None),
		"CostInflationAccount": (48, 2, (8, 0), (), "CostInflationAccount", None),
		"CostInflationOffsetAccount": (49, 2, (8, 0), (), "CostInflationOffsetAccount", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Counted": (30, 2, (5, 0), (), "Counted", None),
		"CountedQuantity": (28, 2, (5, 0), (), "CountedQuantity", None),
		"DecreasingAccount": (13, 2, (8, 0), (), "DecreasingAccount", None),
		"EUExpensesAccount": (18, 2, (8, 0), (), "EUExpensesAccount", None),
		"EUPurchaseCreditAcc": (36, 2, (8, 0), (), "EUPurchaseCreditAcc", None),
		"EURevenuesAccount": (17, 2, (8, 0), (), "EURevenuesAccount", None),
		"ExchangeRateDifferencesAcct": (45, 2, (8, 0), (), "ExchangeRateDifferencesAcct", None),
		"ExemptIncomeAcc": (21, 2, (8, 0), (), "ExemptIncomeAcc", None),
		"ExemptedCredits": (40, 2, (8, 0), (), "ExemptedCredits", None),
		"ExpenseClearingAct": (33, 2, (8, 0), (), "ExpenseClearingAct", None),
		"ExpenseOffsettingAccount": (42, 2, (8, 0), (), "ExpenseOffsettingAccount", None),
		"ExpensesAccount": (16, 2, (8, 0), (), "ExpensesAccount", None),
		"ForeignExpensAcc": (20, 2, (8, 0), (), "ForeignExpensAcc", None),
		"ForeignPurchaseCreditAcc": (37, 2, (8, 0), (), "ForeignPurchaseCreditAcc", None),
		"ForeignRevenueAcc": (19, 2, (8, 0), (), "ForeignRevenueAcc", None),
		"GLDecreaseAcct": (50, 2, (8, 0), (), "GLDecreaseAcct", None),
		"GLIncreaseAcct": (51, 2, (8, 0), (), "GLIncreaseAcct", None),
		"GoodsClearingAcct": (44, 2, (8, 0), (), "GoodsClearingAcct", None),
		"InStock": (25, 2, (5, 0), (), "InStock", None),
		"IncreasingAccount": (14, 2, (8, 0), (), "IncreasingAccount", None),
		"InventoryAccount": (8, 2, (8, 0), (), "InventoryAccount", None),
		"InventoryOffsetProfitAndLossAccount": (72, 2, (8, 0), (), "InventoryOffsetProfitAndLossAccount", None),
		# Method 'ItemCycleCount' returns object of type 'IItemCycleCount'
		"ItemCycleCount": (46, 2, (9, 0), (), "ItemCycleCount", '{743A4F30-AC7F-4606-9AA3-5139F07E08A2}'),
		"Locked": (7, 2, (3, 0), (), "Locked", None),
		"MaximalStock": (4, 2, (5, 0), (), "MaximalStock", None),
		"MinimalOrder": (5, 2, (5, 0), (), "MinimalOrder", None),
		"MinimalStock": (23, 2, (5, 0), (), "MinimalStock", None),
		"NegativeInventoryAdjustmentAccount": (47, 2, (8, 0), (), "NegativeInventoryAdjustmentAccount", None),
		"Ordered": (27, 2, (5, 0), (), "Ordered", None),
		"PAReturnAcct": (52, 2, (8, 0), (), "PAReturnAcct", None),
		"PriceDifferenceAcc": (22, 2, (8, 0), (), "PriceDifferenceAcc", None),
		"PurchaseAcct": (53, 2, (8, 0), (), "PurchaseAcct", None),
		"PurchaseCreditAcc": (34, 2, (8, 0), (), "PurchaseCreditAcc", None),
		"PurchaseOffsetAcct": (54, 2, (8, 0), (), "PurchaseOffsetAcct", None),
		"ReturningAccount": (15, 2, (8, 0), (), "ReturningAccount", None),
		"RevenuesAccount": (11, 2, (8, 0), (), "RevenuesAccount", None),
		"SalesCreditAcc": (38, 2, (8, 0), (), "SalesCreditAcc", None),
		"SalesCreditEUAcc": (39, 2, (8, 0), (), "SalesCreditEUAcc", None),
		"SalesCreditForeignAcc": (41, 2, (8, 0), (), "SalesCreditForeignAcc", None),
		"ShippedGoodsAccount": (55, 2, (8, 0), (), "ShippedGoodsAccount", None),
		"StandardAveragePrice": (6, 2, (5, 0), (), "StandardAveragePrice", None),
		"StockInTransitAccount": (62, 2, (8, 0), (), "StockInTransitAccount", None),
		"StockInflationAdjustAccount": (57, 2, (8, 0), (), "StockInflationAdjustAccount", None),
		"StockInflationOffsetAccount": (56, 2, (8, 0), (), "StockInflationOffsetAccount", None),
		"TransferAccount": (10, 2, (8, 0), (), "TransferAccount", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (31, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATInRevenueAccount": (58, 2, (8, 0), (), "VATInRevenueAccount", None),
		"VarienceAccount": (12, 2, (8, 0), (), "VarienceAccount", None),
		"WHIncomingCenvatAccount": (59, 2, (8, 0), (), "WHIncomingCenvatAccount", None),
		"WHOutgoingCenvatAccount": (60, 2, (8, 0), (), "WHOutgoingCenvatAccount", None),
		"WarehouseCode": (24, 2, (8, 0), (), "WarehouseCode", None),
		"WasCounted": (29, 2, (3, 0), (), "WasCounted", None),
		"WipAccount": (43, 2, (8, 0), (), "WipAccount", None),
		"WipOffsetProfitAndLossAccount": (71, 2, (8, 0), (), "WipOffsetProfitAndLossAccount", None),
		"WipVarianceAccount": (32, 2, (8, 0), (), "WipVarianceAccount", None),
	}
	_prop_map_put_ = {
		"CostAccount": ((9, LCID, 4, 0),()),
		"CostInflationAccount": ((48, LCID, 4, 0),()),
		"CostInflationOffsetAccount": ((49, LCID, 4, 0),()),
		"DecreasingAccount": ((13, LCID, 4, 0),()),
		"EUExpensesAccount": ((18, LCID, 4, 0),()),
		"EUPurchaseCreditAcc": ((36, LCID, 4, 0),()),
		"EURevenuesAccount": ((17, LCID, 4, 0),()),
		"ExchangeRateDifferencesAcct": ((45, LCID, 4, 0),()),
		"ExemptIncomeAcc": ((21, LCID, 4, 0),()),
		"ExemptedCredits": ((40, LCID, 4, 0),()),
		"ExpenseClearingAct": ((33, LCID, 4, 0),()),
		"ExpenseOffsettingAccount": ((42, LCID, 4, 0),()),
		"ExpensesAccount": ((16, LCID, 4, 0),()),
		"ForeignExpensAcc": ((20, LCID, 4, 0),()),
		"ForeignPurchaseCreditAcc": ((37, LCID, 4, 0),()),
		"ForeignRevenueAcc": ((19, LCID, 4, 0),()),
		"GLDecreaseAcct": ((50, LCID, 4, 0),()),
		"GLIncreaseAcct": ((51, LCID, 4, 0),()),
		"GoodsClearingAcct": ((44, LCID, 4, 0),()),
		"IncreasingAccount": ((14, LCID, 4, 0),()),
		"InventoryAccount": ((8, LCID, 4, 0),()),
		"InventoryOffsetProfitAndLossAccount": ((72, LCID, 4, 0),()),
		"Locked": ((7, LCID, 4, 0),()),
		"MaximalStock": ((4, LCID, 4, 0),()),
		"MinimalOrder": ((5, LCID, 4, 0),()),
		"MinimalStock": ((23, LCID, 4, 0),()),
		"NegativeInventoryAdjustmentAccount": ((47, LCID, 4, 0),()),
		"PAReturnAcct": ((52, LCID, 4, 0),()),
		"PriceDifferenceAcc": ((22, LCID, 4, 0),()),
		"PurchaseAcct": ((53, LCID, 4, 0),()),
		"PurchaseCreditAcc": ((34, LCID, 4, 0),()),
		"PurchaseOffsetAcct": ((54, LCID, 4, 0),()),
		"ReturningAccount": ((15, LCID, 4, 0),()),
		"RevenuesAccount": ((11, LCID, 4, 0),()),
		"SalesCreditAcc": ((38, LCID, 4, 0),()),
		"SalesCreditEUAcc": ((39, LCID, 4, 0),()),
		"SalesCreditForeignAcc": ((41, LCID, 4, 0),()),
		"ShippedGoodsAccount": ((55, LCID, 4, 0),()),
		"StandardAveragePrice": ((6, LCID, 4, 0),()),
		"StockInTransitAccount": ((62, LCID, 4, 0),()),
		"StockInflationAdjustAccount": ((57, LCID, 4, 0),()),
		"StockInflationOffsetAccount": ((56, LCID, 4, 0),()),
		"TransferAccount": ((10, LCID, 4, 0),()),
		"VATInRevenueAccount": ((58, LCID, 4, 0),()),
		"VarienceAccount": ((12, LCID, 4, 0),()),
		"WHIncomingCenvatAccount": ((59, LCID, 4, 0),()),
		"WHOutgoingCenvatAccount": ((60, LCID, 4, 0),()),
		"WarehouseCode": ((24, LCID, 4, 0),()),
		"WipAccount": ((43, LCID, 4, 0),()),
		"WipOffsetProfitAndLossAccount": ((71, LCID, 4, 0),()),
		"WipVarianceAccount": ((32, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IItems(DispatchBaseClass):
	'IItems Interface'
	CLSID = IID('{1EFF6EB3-9368-4A68-B619-0B57A134F0CE}')
	coclass_clsid = IID('{210393EC-DEF3-4E55-965C-C2891393A73C}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(47, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(48, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(133, LCID, 1, (8, 0), (),)

	def GetByKey(self, ItemCode=defaultNamedNotOptArg):
		'Get by key'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((8, 0),),ItemCode
			)

	# The method Properties is actually a property, but must be used as a method to correctly pass the arguments
	def Properties(self, GroupNum=defaultNamedNotOptArg):
		'Query group'
		return self._oleobj_.InvokeTypes(38, LCID, 2, (3, 0), ((3, 0),),GroupNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(46, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(134, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save object as XML document'
		return self._ApplyTypes_(39, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	# The method SetProperties is actually a property, but must be used as a method to correctly pass the arguments
	def SetProperties(self, GroupNum=defaultNamedNotOptArg, arg1=defaultUnnamedArg):
		'Query group'
		return self._oleobj_.InvokeTypes(38, LCID, 4, (24, 0), ((3, 0), (3, 1)),GroupNum
			, arg1)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(40, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"ApTaxCode": (126, 2, (8, 0), (), "ApTaxCode", None),
		"ArTaxCode": (127, 2, (8, 0), (), "ArTaxCode", None),
		"AssetItem": (33, 2, (3, 0), (), "AssetItem", None),
		"AutoCreateSerialNumbersOnRelease": (152, 2, (3, 0), (), "AutoCreateSerialNumbersOnRelease", None),
		"AvgStdPrice": (96, 2, (5, 0), (), "AvgStdPrice", None),
		"BarCode": (10, 2, (8, 0), (), "BarCode", None),
		"BaseUnitName": (123, 2, (8, 0), (), "BaseUnitName", None),
		"BeverageCommercialBrandCode": (160, 2, (3, 0), (), "BeverageCommercialBrandCode", None),
		"BeverageGroupCode": (159, 2, (8, 0), (), "BeverageGroupCode", None),
		"BeverageTableCode": (158, 2, (8, 0), (), "BeverageTableCode", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (59, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CommissionGroup": (31, 2, (3, 0), (), "CommissionGroup", None),
		"CommissionPercent": (29, 2, (5, 0), (), "CommissionPercent", None),
		"CommissionSum": (30, 2, (5, 0), (), "CommissionSum", None),
		"CostAccountingMethod": (128, 2, (3, 0), (), "CostAccountingMethod", None),
		"CustomsGroupCode": (8, 2, (3, 0), (), "CustomsGroupCode", None),
		"DNFEntry": (153, 2, (3, 0), (), "DNFEntry", None),
		"DataExportCode": (37, 2, (8, 0), (), "DataExportCode", None),
		"DefaultWarehouse": (97, 2, (8, 0), (), "DefaultWarehouse", None),
		"DesiredInventory": (22, 2, (5, 0), (), "DesiredInventory", None),
		"ECExpensesAccount": (95, 2, (8, 0), (), "ECExpensesAccount", None),
		"ECRevenuesAccount": (93, 2, (8, 0), (), "ECRevenuesAccount", None),
		"ExemptIncomeAccount": (16, 2, (8, 0), (), "ExemptIncomeAccount", None),
		"ExpanseAccount": (17, 2, (8, 0), (), "ExpanseAccount", None),
		"ForceSelectionOfSerialNumber": (120, 2, (3, 0), (), "ForceSelectionOfSerialNumber", None),
		"ForeignExpensesAccount": (94, 2, (8, 0), (), "ForeignExpensesAccount", None),
		"ForeignName": (6, 2, (8, 0), (), "ForeignName", None),
		"ForeignRevenuesAccount": (92, 2, (8, 0), (), "ForeignRevenuesAccount", None),
		"Frozen": (55, 2, (3, 0), (), "Frozen", None),
		"FrozenFrom": (56, 2, (7, 0), (), "FrozenFrom", None),
		"FrozenRemarks": (58, 2, (8, 0), (), "FrozenRemarks", None),
		"FrozenTo": (57, 2, (7, 0), (), "FrozenTo", None),
		"FuelID": (157, 2, (3, 0), (), "FuelID", None),
		"GLMethod": (99, 2, (3, 0), (), "GLMethod", None),
		"GTSItemSpec": (154, 2, (8, 0), (), "GTSItemSpec", None),
		"GTSItemTaxCategory": (155, 2, (8, 0), (), "GTSItemTaxCategory", None),
		"IncomeAccount": (15, 2, (8, 0), (), "IncomeAccount", None),
		"IncomingServiceCode": (146, 2, (3, 0), (), "IncomingServiceCode", None),
		"IndirectTax": (130, 2, (3, 0), (), "IndirectTax", None),
		"InventoryItem": (14, 2, (3, 0), (), "InventoryItem", None),
		"InventoryUOM": (136, 2, (8, 0), (), "InventoryUOM", None),
		"IsPhantom": (135, 2, (3, 0), (), "IsPhantom", None),
		"IssueMethod": (131, 2, (3, 0), (), "IssueMethod", None),
		"ItemClass": (144, 2, (3, 0), (), "ItemClass", None),
		"ItemCode": (4, 2, (8, 0), (), "ItemCode", None),
		"ItemCountryOrg": (124, 2, (8, 0), (), "ItemCountryOrg", None),
		"ItemName": (5, 2, (8, 0), (), "ItemName", None),
		"ItemType": (143, 2, (3, 0), (), "ItemType", None),
		"ItemsGroupCode": (7, 2, (3, 0), (), "ItemsGroupCode", None),
		"LeadTime": (141, 2, (3, 0), (), "LeadTime", None),
		# Method 'LocalizationInfos' returns object of type 'IItemLocalizationInfos'
		"LocalizationInfos": (163, 2, (9, 0), (), "LocalizationInfos", '{04B4DCB9-A2CD-4C53-BD52-FA43B7754803}'),
		"Mainsupplier": (18, 2, (8, 0), (), "Mainsupplier", None),
		"ManageBatchNumbers": (50, 2, (3, 0), (), "ManageBatchNumbers", None),
		"ManageSerialNumbers": (49, 2, (3, 0), (), "ManageSerialNumbers", None),
		"ManageSerialNumbersOnReleaseOnly": (121, 2, (3, 0), (), "ManageSerialNumbersOnReleaseOnly", None),
		"ManageStockByWarehouse": (103, 2, (3, 0), (), "ManageStockByWarehouse", None),
		"Manufacturer": (42, 2, (3, 0), (), "Manufacturer", None),
		"MaterialGroup": (150, 2, (3, 0), (), "MaterialGroup", None),
		"MaterialType": (149, 2, (3, 0), (), "MaterialType", None),
		"MaxInventory": (102, 2, (5, 0), (), "MaxInventory", None),
		"MinInventory": (23, 2, (5, 0), (), "MinInventory", None),
		"MinOrderQuantity": (142, 2, (5, 0), (), "MinOrderQuantity", None),
		"MovingAveragePrice": (83, 2, (5, 0), (), "MovingAveragePrice", None),
		"NCMCode": (148, 2, (3, 0), (), "NCMCode", None),
		"OrderIntervals": (139, 2, (8, 0), (), "OrderIntervals", None),
		"OrderMultiple": (140, 2, (5, 0), (), "OrderMultiple", None),
		"OutgoingServiceCode": (145, 2, (3, 0), (), "OutgoingServiceCode", None),
		"Picture": (26, 2, (8, 0), (), "Picture", None),
		"PlanningSystem": (137, 2, (3, 0), (), "PlanningSystem", None),
		# Method 'PreferredVendors' returns object of type 'IItems_PreferredVendors'
		"PreferredVendors": (156, 2, (9, 0), (), "PreferredVendors", '{9048203E-CE84-4B53-B4C7-61632BD2DEAC}'),
		# Method 'PriceList' returns object of type 'IItems_Prices'
		"PriceList": (41, 2, (9, 0), (), "PriceList", '{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}'),
		"ProcurementMethod": (138, 2, (3, 0), (), "ProcurementMethod", None),
		"ProductSource": (151, 2, (3, 0), (), "ProductSource", None),
		"PurchaseFactor1": (79, 2, (5, 0), (), "PurchaseFactor1", None),
		"PurchaseFactor2": (80, 2, (5, 0), (), "PurchaseFactor2", None),
		"PurchaseFactor3": (81, 2, (5, 0), (), "PurchaseFactor3", None),
		"PurchaseFactor4": (82, 2, (5, 0), (), "PurchaseFactor4", None),
		"PurchaseHeightUnit": (90, 2, (3, 0), (), "PurchaseHeightUnit", None),
		"PurchaseHeightUnit1": (104, 2, (3, 0), (), "PurchaseHeightUnit1", None),
		"PurchaseItem": (12, 2, (3, 0), (), "PurchaseItem", None),
		"PurchaseItemsPerUnit": (21, 2, (5, 0), (), "PurchaseItemsPerUnit", None),
		"PurchaseLengthUnit": (89, 2, (3, 0), (), "PurchaseLengthUnit", None),
		"PurchaseLengthUnit1": (106, 2, (3, 0), (), "PurchaseLengthUnit1", None),
		"PurchasePackagingUnit": (66, 2, (8, 0), (), "PurchasePackagingUnit", None),
		"PurchaseQtyPerPackUnit": (67, 2, (5, 0), (), "PurchaseQtyPerPackUnit", None),
		"PurchaseUnit": (20, 2, (8, 0), (), "PurchaseUnit", None),
		"PurchaseUnitHeight": (70, 2, (5, 0), (), "PurchaseUnitHeight", None),
		"PurchaseUnitHeight1": (105, 2, (5, 0), (), "PurchaseUnitHeight1", None),
		"PurchaseUnitLength": (68, 2, (5, 0), (), "PurchaseUnitLength", None),
		"PurchaseUnitLength1": (107, 2, (5, 0), (), "PurchaseUnitLength1", None),
		"PurchaseUnitVolume": (71, 2, (5, 0), (), "PurchaseUnitVolume", None),
		"PurchaseUnitWeight": (73, 2, (5, 0), (), "PurchaseUnitWeight", None),
		"PurchaseUnitWeight1": (109, 2, (5, 0), (), "PurchaseUnitWeight1", None),
		"PurchaseUnitWidth": (69, 2, (5, 0), (), "PurchaseUnitWidth", None),
		"PurchaseUnitWidth1": (111, 2, (5, 0), (), "PurchaseUnitWidth1", None),
		"PurchaseVATGroup": (74, 2, (8, 0), (), "PurchaseVATGroup", None),
		"PurchaseVolumeUnit": (72, 2, (3, 0), (), "PurchaseVolumeUnit", None),
		"PurchaseWeightUnit": (91, 2, (3, 0), (), "PurchaseWeightUnit", None),
		"PurchaseWeightUnit1": (108, 2, (3, 0), (), "PurchaseWeightUnit1", None),
		"PurchaseWidthUnit": (88, 2, (3, 0), (), "PurchaseWidthUnit", None),
		"PurchaseWidthUnit1": (110, 2, (3, 0), (), "PurchaseWidthUnit1", None),
		"QuantityOnStock": (43, 2, (5, 0), (), "QuantityOnStock", None),
		"QuantityOrderedByCustomers": (45, 2, (5, 0), (), "QuantityOrderedByCustomers", None),
		"QuantityOrderedFromVendors": (44, 2, (5, 0), (), "QuantityOrderedFromVendors", None),
		"SRIAndBatchManageMethod": (132, 2, (3, 0), (), "SRIAndBatchManageMethod", None),
		"SWW": (125, 2, (8, 0), (), "SWW", None),
		"SalesFactor1": (75, 2, (5, 0), (), "SalesFactor1", None),
		"SalesFactor2": (76, 2, (5, 0), (), "SalesFactor2", None),
		"SalesFactor3": (77, 2, (5, 0), (), "SalesFactor3", None),
		"SalesFactor4": (78, 2, (5, 0), (), "SalesFactor4", None),
		"SalesHeightUnit": (86, 2, (3, 0), (), "SalesHeightUnit", None),
		"SalesHeightUnit1": (112, 2, (3, 0), (), "SalesHeightUnit1", None),
		"SalesItem": (13, 2, (3, 0), (), "SalesItem", None),
		"SalesItemsPerUnit": (25, 2, (5, 0), (), "SalesItemsPerUnit", None),
		"SalesLengthUnit": (84, 2, (3, 0), (), "SalesLengthUnit", None),
		"SalesLengthUnit1": (114, 2, (3, 0), (), "SalesLengthUnit1", None),
		"SalesPackagingUnit": (60, 2, (8, 0), (), "SalesPackagingUnit", None),
		"SalesQtyPerPackUnit": (61, 2, (5, 0), (), "SalesQtyPerPackUnit", None),
		"SalesUnit": (24, 2, (8, 0), (), "SalesUnit", None),
		"SalesUnitHeight": (34, 2, (5, 0), (), "SalesUnitHeight", None),
		"SalesUnitHeight1": (113, 2, (5, 0), (), "SalesUnitHeight1", None),
		"SalesUnitLength": (62, 2, (5, 0), (), "SalesUnitLength", None),
		"SalesUnitLength1": (115, 2, (5, 0), (), "SalesUnitLength1", None),
		"SalesUnitVolume": (36, 2, (5, 0), (), "SalesUnitVolume", None),
		"SalesUnitWeight": (65, 2, (5, 0), (), "SalesUnitWeight", None),
		"SalesUnitWeight1": (117, 2, (5, 0), (), "SalesUnitWeight1", None),
		"SalesUnitWidth": (63, 2, (5, 0), (), "SalesUnitWidth", None),
		"SalesUnitWidth1": (119, 2, (5, 0), (), "SalesUnitWidth1", None),
		"SalesVATGroup": (9, 2, (8, 0), (), "SalesVATGroup", None),
		"SalesVolumeUnit": (64, 2, (3, 0), (), "SalesVolumeUnit", None),
		"SalesWeightUnit": (87, 2, (3, 0), (), "SalesWeightUnit", None),
		"SalesWeightUnit1": (116, 2, (3, 0), (), "SalesWeightUnit1", None),
		"SalesWidthUnit": (85, 2, (3, 0), (), "SalesWidthUnit", None),
		"SalesWidthUnit1": (118, 2, (3, 0), (), "SalesWidthUnit1", None),
		"SerialNum": (28, 2, (8, 0), (), "SerialNum", None),
		"Series": (161, 2, (3, 0), (), "Series", None),
		"ServiceGroup": (147, 2, (3, 0), (), "ServiceGroup", None),
		"ShipType": (98, 2, (3, 0), (), "ShipType", None),
		"SupplierCatalogNo": (19, 2, (8, 0), (), "SupplierCatalogNo", None),
		"TaxType": (100, 2, (3, 0), (), "TaxType", None),
		"ToleranceDays": (162, 2, (3, 0), (), "ToleranceDays", None),
		"TreeType": (32, 2, (3, 0), (), "TreeType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"User_Text": (27, 2, (8, 0), (), "User_Text", None),
		"Valid": (51, 2, (3, 0), (), "Valid", None),
		"ValidFrom": (52, 2, (7, 0), (), "ValidFrom", None),
		"ValidRemarks": (54, 2, (8, 0), (), "ValidRemarks", None),
		"ValidTo": (53, 2, (7, 0), (), "ValidTo", None),
		"VatLiable": (11, 2, (3, 0), (), "VatLiable", None),
		"WTLiable": (122, 2, (3, 0), (), "WTLiable", None),
		"WarrantyTemplate": (129, 2, (8, 0), (), "WarrantyTemplate", None),
		# Method 'WhsInfo' returns object of type 'IItemWarehouseInfo'
		"WhsInfo": (101, 2, (9, 0), (), "WhsInfo", '{CDB52791-B0FC-4BE1-A712-06941AF91D52}'),
	}
	_prop_map_put_ = {
		"ApTaxCode": ((126, LCID, 4, 0),()),
		"ArTaxCode": ((127, LCID, 4, 0),()),
		"AssetItem": ((33, LCID, 4, 0),()),
		"AutoCreateSerialNumbersOnRelease": ((152, LCID, 4, 0),()),
		"AvgStdPrice": ((96, LCID, 4, 0),()),
		"BarCode": ((10, LCID, 4, 0),()),
		"BaseUnitName": ((123, LCID, 4, 0),()),
		"BeverageCommercialBrandCode": ((160, LCID, 4, 0),()),
		"BeverageGroupCode": ((159, LCID, 4, 0),()),
		"BeverageTableCode": ((158, LCID, 4, 0),()),
		"CommissionGroup": ((31, LCID, 4, 0),()),
		"CommissionPercent": ((29, LCID, 4, 0),()),
		"CommissionSum": ((30, LCID, 4, 0),()),
		"CostAccountingMethod": ((128, LCID, 4, 0),()),
		"CustomsGroupCode": ((8, LCID, 4, 0),()),
		"DNFEntry": ((153, LCID, 4, 0),()),
		"DataExportCode": ((37, LCID, 4, 0),()),
		"DefaultWarehouse": ((97, LCID, 4, 0),()),
		"DesiredInventory": ((22, LCID, 4, 0),()),
		"ECExpensesAccount": ((95, LCID, 4, 0),()),
		"ECRevenuesAccount": ((93, LCID, 4, 0),()),
		"ExemptIncomeAccount": ((16, LCID, 4, 0),()),
		"ExpanseAccount": ((17, LCID, 4, 0),()),
		"ForceSelectionOfSerialNumber": ((120, LCID, 4, 0),()),
		"ForeignExpensesAccount": ((94, LCID, 4, 0),()),
		"ForeignName": ((6, LCID, 4, 0),()),
		"ForeignRevenuesAccount": ((92, LCID, 4, 0),()),
		"Frozen": ((55, LCID, 4, 0),()),
		"FrozenFrom": ((56, LCID, 4, 0),()),
		"FrozenRemarks": ((58, LCID, 4, 0),()),
		"FrozenTo": ((57, LCID, 4, 0),()),
		"FuelID": ((157, LCID, 4, 0),()),
		"GLMethod": ((99, LCID, 4, 0),()),
		"GTSItemSpec": ((154, LCID, 4, 0),()),
		"GTSItemTaxCategory": ((155, LCID, 4, 0),()),
		"IncomeAccount": ((15, LCID, 4, 0),()),
		"IncomingServiceCode": ((146, LCID, 4, 0),()),
		"IndirectTax": ((130, LCID, 4, 0),()),
		"InventoryItem": ((14, LCID, 4, 0),()),
		"InventoryUOM": ((136, LCID, 4, 0),()),
		"IsPhantom": ((135, LCID, 4, 0),()),
		"IssueMethod": ((131, LCID, 4, 0),()),
		"ItemClass": ((144, LCID, 4, 0),()),
		"ItemCode": ((4, LCID, 4, 0),()),
		"ItemCountryOrg": ((124, LCID, 4, 0),()),
		"ItemName": ((5, LCID, 4, 0),()),
		"ItemType": ((143, LCID, 4, 0),()),
		"ItemsGroupCode": ((7, LCID, 4, 0),()),
		"LeadTime": ((141, LCID, 4, 0),()),
		"Mainsupplier": ((18, LCID, 4, 0),()),
		"ManageBatchNumbers": ((50, LCID, 4, 0),()),
		"ManageSerialNumbers": ((49, LCID, 4, 0),()),
		"ManageSerialNumbersOnReleaseOnly": ((121, LCID, 4, 0),()),
		"ManageStockByWarehouse": ((103, LCID, 4, 0),()),
		"Manufacturer": ((42, LCID, 4, 0),()),
		"MaterialGroup": ((150, LCID, 4, 0),()),
		"MaterialType": ((149, LCID, 4, 0),()),
		"MaxInventory": ((102, LCID, 4, 0),()),
		"MinInventory": ((23, LCID, 4, 0),()),
		"MinOrderQuantity": ((142, LCID, 4, 0),()),
		"NCMCode": ((148, LCID, 4, 0),()),
		"OrderIntervals": ((139, LCID, 4, 0),()),
		"OrderMultiple": ((140, LCID, 4, 0),()),
		"OutgoingServiceCode": ((145, LCID, 4, 0),()),
		"Picture": ((26, LCID, 4, 0),()),
		"PlanningSystem": ((137, LCID, 4, 0),()),
		"ProcurementMethod": ((138, LCID, 4, 0),()),
		"ProductSource": ((151, LCID, 4, 0),()),
		"PurchaseFactor1": ((79, LCID, 4, 0),()),
		"PurchaseFactor2": ((80, LCID, 4, 0),()),
		"PurchaseFactor3": ((81, LCID, 4, 0),()),
		"PurchaseFactor4": ((82, LCID, 4, 0),()),
		"PurchaseHeightUnit": ((90, LCID, 4, 0),()),
		"PurchaseHeightUnit1": ((104, LCID, 4, 0),()),
		"PurchaseItem": ((12, LCID, 4, 0),()),
		"PurchaseItemsPerUnit": ((21, LCID, 4, 0),()),
		"PurchaseLengthUnit": ((89, LCID, 4, 0),()),
		"PurchaseLengthUnit1": ((106, LCID, 4, 0),()),
		"PurchasePackagingUnit": ((66, LCID, 4, 0),()),
		"PurchaseQtyPerPackUnit": ((67, LCID, 4, 0),()),
		"PurchaseUnit": ((20, LCID, 4, 0),()),
		"PurchaseUnitHeight": ((70, LCID, 4, 0),()),
		"PurchaseUnitHeight1": ((105, LCID, 4, 0),()),
		"PurchaseUnitLength": ((68, LCID, 4, 0),()),
		"PurchaseUnitLength1": ((107, LCID, 4, 0),()),
		"PurchaseUnitVolume": ((71, LCID, 4, 0),()),
		"PurchaseUnitWeight": ((73, LCID, 4, 0),()),
		"PurchaseUnitWeight1": ((109, LCID, 4, 0),()),
		"PurchaseUnitWidth": ((69, LCID, 4, 0),()),
		"PurchaseUnitWidth1": ((111, LCID, 4, 0),()),
		"PurchaseVATGroup": ((74, LCID, 4, 0),()),
		"PurchaseVolumeUnit": ((72, LCID, 4, 0),()),
		"PurchaseWeightUnit": ((91, LCID, 4, 0),()),
		"PurchaseWeightUnit1": ((108, LCID, 4, 0),()),
		"PurchaseWidthUnit": ((88, LCID, 4, 0),()),
		"PurchaseWidthUnit1": ((110, LCID, 4, 0),()),
		"SRIAndBatchManageMethod": ((132, LCID, 4, 0),()),
		"SWW": ((125, LCID, 4, 0),()),
		"SalesFactor1": ((75, LCID, 4, 0),()),
		"SalesFactor2": ((76, LCID, 4, 0),()),
		"SalesFactor3": ((77, LCID, 4, 0),()),
		"SalesFactor4": ((78, LCID, 4, 0),()),
		"SalesHeightUnit": ((86, LCID, 4, 0),()),
		"SalesHeightUnit1": ((112, LCID, 4, 0),()),
		"SalesItem": ((13, LCID, 4, 0),()),
		"SalesItemsPerUnit": ((25, LCID, 4, 0),()),
		"SalesLengthUnit": ((84, LCID, 4, 0),()),
		"SalesLengthUnit1": ((114, LCID, 4, 0),()),
		"SalesPackagingUnit": ((60, LCID, 4, 0),()),
		"SalesQtyPerPackUnit": ((61, LCID, 4, 0),()),
		"SalesUnit": ((24, LCID, 4, 0),()),
		"SalesUnitHeight": ((34, LCID, 4, 0),()),
		"SalesUnitHeight1": ((113, LCID, 4, 0),()),
		"SalesUnitLength": ((62, LCID, 4, 0),()),
		"SalesUnitLength1": ((115, LCID, 4, 0),()),
		"SalesUnitVolume": ((36, LCID, 4, 0),()),
		"SalesUnitWeight": ((65, LCID, 4, 0),()),
		"SalesUnitWeight1": ((117, LCID, 4, 0),()),
		"SalesUnitWidth": ((63, LCID, 4, 0),()),
		"SalesUnitWidth1": ((119, LCID, 4, 0),()),
		"SalesVATGroup": ((9, LCID, 4, 0),()),
		"SalesVolumeUnit": ((64, LCID, 4, 0),()),
		"SalesWeightUnit": ((87, LCID, 4, 0),()),
		"SalesWeightUnit1": ((116, LCID, 4, 0),()),
		"SalesWidthUnit": ((85, LCID, 4, 0),()),
		"SalesWidthUnit1": ((118, LCID, 4, 0),()),
		"SerialNum": ((28, LCID, 4, 0),()),
		"Series": ((161, LCID, 4, 0),()),
		"ServiceGroup": ((147, LCID, 4, 0),()),
		"ShipType": ((98, LCID, 4, 0),()),
		"SupplierCatalogNo": ((19, LCID, 4, 0),()),
		"TaxType": ((100, LCID, 4, 0),()),
		"ToleranceDays": ((162, LCID, 4, 0),()),
		"User_Text": ((27, LCID, 4, 0),()),
		"Valid": ((51, LCID, 4, 0),()),
		"ValidFrom": ((52, LCID, 4, 0),()),
		"ValidRemarks": ((54, LCID, 4, 0),()),
		"ValidTo": ((53, LCID, 4, 0),()),
		"VatLiable": ((11, LCID, 4, 0),()),
		"WTLiable": ((122, LCID, 4, 0),()),
		"WarrantyTemplate": ((129, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IItems_PreferredVendors(DispatchBaseClass):
	'IItems_PreferredVendors Interface'
	CLSID = IID('{9048203E-CE84-4B53-B4C7-61632BD2DEAC}')
	coclass_clsid = IID('{03826AF0-3BF7-4C97-B1F1-D5B2CCE19621}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPCode": (2, 2, (8, 0), (), "BPCode", None),
		"Count": (6, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
		"BPCode": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(6, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IItems_Prices(DispatchBaseClass):
	'IItems_Prices Interface'
	CLSID = IID('{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}')
	coclass_clsid = IID('{5C63DF2C-6C18-4447-A9BB-B6277EF0DAF2}')

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Currency": (7, 2, (8, 0), (), "Currency", None),
		"Price": (6, 2, (5, 0), (), "Price", None),
		"PriceList": (4, 2, (3, 0), (), "PriceList", None),
		"PriceListName": (5, 2, (8, 0), (), "PriceListName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Currency": ((7, LCID, 4, 0),()),
		"Price": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IJournalEntries(DispatchBaseClass):
	'IJournalEntries Interface'
	CLSID = IID('{060F033E-2FC9-4266-90AE-3271AC203A59}')
	coclass_clsid = IID('{6E3987D0-11D5-4A95-B5B7-E5BCFE88E060}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(30, LCID, 1, (8, 0), (),)

	def GetByKey(self, JdtNum=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((3, 0),),JdtNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(31, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(16, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(26, LCID, 1, (24, 0), ((3, 1),),LineNum
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AutoVAT": (35, 2, (3, 0), (), "AutoVAT", None),
		"AutomaticWT": (47, 2, (3, 0), (), "AutomaticWT", None),
		"BaseReference": (44, 2, (8, 0), (), "BaseReference", None),
		"BlanketAgreementNumber": (68, 2, (3, 0), (), "BlanketAgreementNumber", None),
		"BlockDunningLetter": (45, 2, (3, 0), (), "BlockDunningLetter", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (21, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CertificationNumber": (64, 2, (8, 0), (), "CertificationNumber", None),
		"Corisptivi": (52, 2, (3, 0), (), "Corisptivi", None),
		"Count": (25, 2, (3, 0), (), "Count", None),
		"DocumentType": (67, 2, (8, 0), (), "DocumentType", None),
		"DueDate": (32, 2, (7, 0), (), "DueDate", None),
		"FolioNumber": (37, 2, (3, 0), (), "FolioNumber", None),
		"FolioPrefixString": (38, 2, (8, 0), (), "FolioPrefixString", None),
		"Indicator": (22, 2, (8, 0), (), "Indicator", None),
		"JdtNum": (15, 2, (3, 0), (), "JdtNum", None),
		# Method 'Lines' returns object of type 'IJournalEntries_Lines'
		"Lines": (2, 2, (9, 0), (), "Lines", '{55053980-777B-44CF-8D76-84DD975171AA}'),
		"LocationCode": (42, 2, (3, 0), (), "LocationCode", None),
		"Memo": (6, 2, (8, 0), (), "Memo", None),
		"Number": (36, 2, (3, 0), (), "Number", None),
		"Original": (43, 2, (3, 0), (), "Original", None),
		"OriginalJournal": (46, 2, (3, 0), (), "OriginalJournal", None),
		"Printed": (41, 2, (3, 0), (), "Printed", None),
		"PrivateKeyVersion": (65, 2, (3, 0), (), "PrivateKeyVersion", None),
		"ProjectCode": (12, 2, (8, 0), (), "ProjectCode", None),
		"Reference": (7, 2, (8, 0), (), "Reference", None),
		"Reference2": (8, 2, (8, 0), (), "Reference2", None),
		"Reference3": (66, 2, (8, 0), (), "Reference3", None),
		"ReferenceDate": (5, 2, (7, 0), (), "ReferenceDate", None),
		"Report347": (40, 2, (3, 0), (), "Report347", None),
		"ReportEU": (39, 2, (3, 0), (), "ReportEU", None),
		"Series": (28, 2, (3, 0), (), "Series", None),
		"SignatureDigest": (63, 2, (8, 0), (), "SignatureDigest", None),
		"SignatureInputMessage": (62, 2, (8, 0), (), "SignatureInputMessage", None),
		"StampTax": (29, 2, (3, 0), (), "StampTax", None),
		"StornoDate": (24, 2, (7, 0), (), "StornoDate", None),
		"TaxDate": (14, 2, (7, 0), (), "TaxDate", None),
		"TransactionCode": (9, 2, (8, 0), (), "TransactionCode", None),
		"UseAutoStorno": (23, 2, (3, 0), (), "UseAutoStorno", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatDate": (27, 2, (7, 0), (), "VatDate", None),
		"WTSum": (48, 2, (5, 0), (), "WTSum", None),
		"WTSumFC": (50, 2, (5, 0), (), "WTSumFC", None),
		"WTSumSC": (49, 2, (5, 0), (), "WTSumSC", None),
		# Method 'WithholdingTaxData' returns object of type 'IWithholdingTaxData'
		"WithholdingTaxData": (51, 2, (9, 0), (), "WithholdingTaxData", '{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}'),
	}
	_prop_map_put_ = {
		"AutoVAT": ((35, LCID, 4, 0),()),
		"AutomaticWT": ((47, LCID, 4, 0),()),
		"BlockDunningLetter": ((45, LCID, 4, 0),()),
		"Corisptivi": ((52, LCID, 4, 0),()),
		"DocumentType": ((67, LCID, 4, 0),()),
		"DueDate": ((32, LCID, 4, 0),()),
		"Indicator": ((22, LCID, 4, 0),()),
		"LocationCode": ((42, LCID, 4, 0),()),
		"Memo": ((6, LCID, 4, 0),()),
		"ProjectCode": ((12, LCID, 4, 0),()),
		"Reference": ((7, LCID, 4, 0),()),
		"Reference2": ((8, LCID, 4, 0),()),
		"Reference3": ((66, LCID, 4, 0),()),
		"ReferenceDate": ((5, LCID, 4, 0),()),
		"Report347": ((40, LCID, 4, 0),()),
		"ReportEU": ((39, LCID, 4, 0),()),
		"Series": ((28, LCID, 4, 0),()),
		"StampTax": ((29, LCID, 4, 0),()),
		"StornoDate": ((24, LCID, 4, 0),()),
		"TaxDate": ((14, LCID, 4, 0),()),
		"TransactionCode": ((9, LCID, 4, 0),()),
		"UseAutoStorno": ((23, LCID, 4, 0),()),
		"VatDate": ((27, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(25, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IJournalEntries_Lines(DispatchBaseClass):
	'IJournalEntries_Lines Interface'
	CLSID = IID('{55053980-777B-44CF-8D76-84DD975171AA}')
	coclass_clsid = IID('{70BFE200-77E9-4D02-B0E6-49800F3E9AD2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (6, 2, (8, 0), (), "AccountCode", None),
		"AdditionalReference": (34, 2, (8, 0), (), "AdditionalReference", None),
		"BPLID": (61, 2, (3, 0), (), "BPLID", None),
		"BPLName": (62, 2, (8, 0), (), "BPLName", None),
		"BaseSum": (24, 2, (5, 0), (), "BaseSum", None),
		"BlockReason": (51, 2, (3, 0), (), "BlockReason", None),
		"CheckAbs": (35, 2, (3, 0), (), "CheckAbs", None),
		"ContraAccount": (14, 2, (8, 0), (), "ContraAccount", None),
		"ControlAccount": (49, 2, (8, 0), (), "ControlAccount", None),
		"CostingCode": (22, 2, (8, 0), (), "CostingCode", None),
		"CostingCode2": (36, 2, (8, 0), (), "CostingCode2", None),
		"CostingCode3": (37, 2, (8, 0), (), "CostingCode3", None),
		"CostingCode4": (38, 2, (8, 0), (), "CostingCode4", None),
		"CostingCode5": (42, 2, (8, 0), (), "CostingCode5", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Credit": (8, 2, (5, 0), (), "Credit", None),
		"CreditSys": (27, 2, (5, 0), (), "CreditSys", None),
		"Debit": (7, 2, (5, 0), (), "Debit", None),
		"DebitSys": (26, 2, (5, 0), (), "DebitSys", None),
		"DueDate": (12, 2, (7, 0), (), "DueDate", None),
		"EqualizationTaxAmount": (43, 2, (5, 0), (), "EqualizationTaxAmount", None),
		"FCCredit": (10, 2, (5, 0), (), "FCCredit", None),
		"FCCurrency": (11, 2, (8, 0), (), "FCCurrency", None),
		"FCDebit": (9, 2, (5, 0), (), "FCDebit", None),
		"FederalTaxID": (52, 2, (8, 0), (), "FederalTaxID", None),
		"GrossValue": (33, 2, (5, 0), (), "GrossValue", None),
		"LineMemo": (15, 2, (8, 0), (), "LineMemo", None),
		"Line_ID": (5, 2, (3, 0), (), "Line_ID", None),
		"LocationCode": (41, 2, (3, 0), (), "LocationCode", None),
		"PaymentBlock": (50, 2, (3, 0), (), "PaymentBlock", None),
		"PaymentOrdered": (54, 2, (3, 0), (), "PaymentOrdered", None),
		# Method 'PrimaryFormItems' returns object of type 'ICashFlowAssignments'
		"PrimaryFormItems": (53, 2, (9, 0), (), "PrimaryFormItems", '{A0307CBF-64B1-49E8-B60D-38803E20D107}'),
		"ProjectCode": (20, 2, (8, 0), (), "ProjectCode", None),
		"Reference1": (18, 2, (8, 0), (), "Reference1", None),
		"Reference2": (19, 2, (8, 0), (), "Reference2", None),
		"ReferenceDate1": (16, 2, (7, 0), (), "ReferenceDate1", None),
		"ReferenceDate2": (17, 2, (7, 0), (), "ReferenceDate2", None),
		"ShortName": (13, 2, (8, 0), (), "ShortName", None),
		"SystemBaseAmount": (30, 2, (5, 0), (), "SystemBaseAmount", None),
		"SystemEqualizationTaxAmount": (44, 2, (5, 0), (), "SystemEqualizationTaxAmount", None),
		"SystemTotalTax": (46, 2, (5, 0), (), "SystemTotalTax", None),
		"SystemVatAmount": (32, 2, (5, 0), (), "SystemVatAmount", None),
		"TaxCode": (39, 2, (8, 0), (), "TaxCode", None),
		"TaxDate": (23, 2, (7, 0), (), "TaxDate", None),
		"TaxGroup": (25, 2, (8, 0), (), "TaxGroup", None),
		"TaxPostAccount": (40, 2, (3, 0), (), "TaxPostAccount", None),
		"TotalTax": (45, 2, (5, 0), (), "TotalTax", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATRegNum": (63, 2, (8, 0), (), "VATRegNum", None),
		"VatAmount": (31, 2, (5, 0), (), "VatAmount", None),
		"VatDate": (28, 2, (7, 0), (), "VatDate", None),
		"VatLine": (29, 2, (3, 0), (), "VatLine", None),
		"WTLiable": (47, 2, (3, 0), (), "WTLiable", None),
		"WTRow": (48, 2, (3, 0), (), "WTRow", None),
	}
	_prop_map_put_ = {
		"AccountCode": ((6, LCID, 4, 0),()),
		"AdditionalReference": ((34, LCID, 4, 0),()),
		"BPLID": ((61, LCID, 4, 0),()),
		"BaseSum": ((24, LCID, 4, 0),()),
		"BlockReason": ((51, LCID, 4, 0),()),
		"ContraAccount": ((14, LCID, 4, 0),()),
		"ControlAccount": ((49, LCID, 4, 0),()),
		"CostingCode": ((22, LCID, 4, 0),()),
		"CostingCode2": ((36, LCID, 4, 0),()),
		"CostingCode3": ((37, LCID, 4, 0),()),
		"CostingCode4": ((38, LCID, 4, 0),()),
		"CostingCode5": ((42, LCID, 4, 0),()),
		"Credit": ((8, LCID, 4, 0),()),
		"CreditSys": ((27, LCID, 4, 0),()),
		"Debit": ((7, LCID, 4, 0),()),
		"DebitSys": ((26, LCID, 4, 0),()),
		"DueDate": ((12, LCID, 4, 0),()),
		"FCCredit": ((10, LCID, 4, 0),()),
		"FCCurrency": ((11, LCID, 4, 0),()),
		"FCDebit": ((9, LCID, 4, 0),()),
		"FederalTaxID": ((52, LCID, 4, 0),()),
		"GrossValue": ((33, LCID, 4, 0),()),
		"LineMemo": ((15, LCID, 4, 0),()),
		"LocationCode": ((41, LCID, 4, 0),()),
		"PaymentBlock": ((50, LCID, 4, 0),()),
		"ProjectCode": ((20, LCID, 4, 0),()),
		"Reference1": ((18, LCID, 4, 0),()),
		"Reference2": ((19, LCID, 4, 0),()),
		"ReferenceDate1": ((16, LCID, 4, 0),()),
		"ReferenceDate2": ((17, LCID, 4, 0),()),
		"ShortName": ((13, LCID, 4, 0),()),
		"SystemBaseAmount": ((30, LCID, 4, 0),()),
		"SystemVatAmount": ((32, LCID, 4, 0),()),
		"TaxCode": ((39, LCID, 4, 0),()),
		"TaxDate": ((23, LCID, 4, 0),()),
		"TaxGroup": ((25, LCID, 4, 0),()),
		"TaxPostAccount": ((40, LCID, 4, 0),()),
		"VatAmount": ((31, LCID, 4, 0),()),
		"VatDate": ((28, LCID, 4, 0),()),
		"VatLine": ((29, LCID, 4, 0),()),
		"WTLiable": ((47, LCID, 4, 0),()),
		"WTRow": ((48, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IJournalEntryDocumentType(DispatchBaseClass):
	'IJournalEntryDocumentType Interface'
	CLSID = IID('{56B7FEB9-ECC9-4A64-BDDF-0AB70C3746D0}')
	coclass_clsid = IID('{431269A1-6E83-4195-A446-19D355C7E6A0}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocTypeDescription": (11, 2, (8, 0), (), "DocTypeDescription", None),
		"JournalEntryType": (10, 2, (8, 0), (), "JournalEntryType", None),
		"ShortName": (12, 2, (8, 0), (), "ShortName", None),
	}
	_prop_map_put_ = {
		"DocTypeDescription": ((11, LCID, 4, 0),()),
		"JournalEntryType": ((10, LCID, 4, 0),()),
		"ShortName": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IJournalEntryDocumentTypeParams(DispatchBaseClass):
	'IJournalEntryDocumentTypeParams Interface'
	CLSID = IID('{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')
	coclass_clsid = IID('{8490CA7E-FCC5-422B-8359-BC2B74FDCD44}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocTypeDescription": (11, 2, (8, 0), (), "DocTypeDescription", None),
		"JournalEntryType": (10, 2, (8, 0), (), "JournalEntryType", None),
		"ShortName": (12, 2, (8, 0), (), "ShortName", None),
	}
	_prop_map_put_ = {
		"JournalEntryType": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IJournalEntryDocumentTypeParamsCollection(DispatchBaseClass):
	'IJournalEntryDocumentTypeParamsCollection Interface'
	CLSID = IID('{A0F06FB9-C420-4CA6-B1A5-D688A5322E8D}')
	coclass_clsid = IID('{84119864-5879-482E-ADE4-D1C839F40BCE}')

	# Result is of type IJournalEntryDocumentTypeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IJournalEntryDocumentTypeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IJournalEntryDocumentTypeService(DispatchBaseClass):
	'IJournalEntryDocumentTypeService Interface'
	CLSID = IID('{7E723574-58DD-46D4-9856-44426EE523AE}')
	coclass_clsid = IID('{12BC616F-58C9-4281-8EF8-633FD300E827}')

	# Result is of type IJournalEntryDocumentTypeParams
	def Add(self, pIJournalEntryDocumentType=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIJournalEntryDocumentType
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')
		return ret

	def Delete(self, pIJournalEntryDocumentTypeParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIJournalEntryDocumentTypeParams
			)

	# Result is of type IJournalEntryDocumentType
	def Get(self, pIJournalEntryDocumentTypeParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIJournalEntryDocumentTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{56B7FEB9-ECC9-4A64-BDDF-0AB70C3746D0}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IJournalEntryDocumentTypeParamsCollection
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{A0F06FB9-C420-4CA6-B1A5-D688A5322E8D}')
		return ret

	def Update(self, pIJournalEntryDocumentType=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIJournalEntryDocumentType
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IJournalVouchers(DispatchBaseClass):
	'IJournalVouchers Interface'
	CLSID = IID('{B9A56422-93A0-4480-BAF3-48907F403CB8}')
	coclass_clsid = IID('{FC75103E-6EAA-4246-A097-B6F81E9DD4A3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def LoadFromXML(self, FileName=defaultNamedNotOptArg):
		'method LoadFromXML'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveToXMLHierarchy(self, FileName=defaultNamedNotOptArg):
		'method SaveToXMLHierarchy'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	_prop_map_get_ = {
		# Method 'JournalEntries' returns object of type 'IJournalEntries'
		"JournalEntries": (2, 2, (9, 0), (), "JournalEntries", '{060F033E-2FC9-4266-90AE-3271AC203A59}'),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IKPI(DispatchBaseClass):
	'IKPI Interface'
	CLSID = IID('{087B9C04-C8CF-4606-A7B4-8FEC6CB8AE1D}')
	coclass_clsid = IID('{60A224F4-B8DA-4288-B9DC-1380D60DFD4C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"KPICode": (10, 2, (8, 0), (), "KPICode", None),
		"KPIName": (11, 2, (8, 0), (), "KPIName", None),
		"KPIType": (12, 2, (3, 0), (), "KPIType", None),
		# Method 'KPI_ItemLines' returns object of type 'IKPI_ItemLines'
		"KPI_ItemLines": (14, 2, (9, 0), (), "KPI_ItemLines", '{9D5AE661-24A0-4F2A-AE75-714F3FF59B91}'),
		"NumberOfColumns": (13, 2, (3, 0), (), "NumberOfColumns", None),
	}
	_prop_map_put_ = {
		"KPICode": ((10, LCID, 4, 0),()),
		"KPIName": ((11, LCID, 4, 0),()),
		"KPIType": ((12, LCID, 4, 0),()),
		"NumberOfColumns": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IKPIParams(DispatchBaseClass):
	'IKPIParams Interface'
	CLSID = IID('{41A28682-1C73-4C77-ADC8-5F805700B244}')
	coclass_clsid = IID('{828E364E-A21E-452E-9733-C49A96051736}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"KPICode": (10, 2, (8, 0), (), "KPICode", None),
		"KPIName": (11, 2, (8, 0), (), "KPIName", None),
	}
	_prop_map_put_ = {
		"KPICode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IKPI_ItemLine(DispatchBaseClass):
	'IKPI_ItemLine Interface'
	CLSID = IID('{48D8151E-BF85-4760-B7F8-B5E7E1B47937}')
	coclass_clsid = IID('{F56E791B-BAEE-49D5-9981-DB03FBFDFD47}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"KPICode": (10, 2, (8, 0), (), "KPICode", None),
		"KPILineNumber": (11, 2, (3, 0), (), "KPILineNumber", None),
		"KPIName": (12, 2, (8, 0), (), "KPIName", None),
		"KPIValue1": (13, 2, (5, 0), (), "KPIValue1", None),
		"KPIValue10": (22, 2, (5, 0), (), "KPIValue10", None),
		"KPIValue11": (23, 2, (5, 0), (), "KPIValue11", None),
		"KPIValue12": (24, 2, (5, 0), (), "KPIValue12", None),
		"KPIValue13": (25, 2, (5, 0), (), "KPIValue13", None),
		"KPIValue14": (26, 2, (5, 0), (), "KPIValue14", None),
		"KPIValue15": (27, 2, (5, 0), (), "KPIValue15", None),
		"KPIValue16": (28, 2, (5, 0), (), "KPIValue16", None),
		"KPIValue17": (29, 2, (5, 0), (), "KPIValue17", None),
		"KPIValue18": (30, 2, (5, 0), (), "KPIValue18", None),
		"KPIValue19": (31, 2, (5, 0), (), "KPIValue19", None),
		"KPIValue2": (14, 2, (5, 0), (), "KPIValue2", None),
		"KPIValue20": (32, 2, (5, 0), (), "KPIValue20", None),
		"KPIValue21": (33, 2, (5, 0), (), "KPIValue21", None),
		"KPIValue22": (34, 2, (5, 0), (), "KPIValue22", None),
		"KPIValue23": (35, 2, (5, 0), (), "KPIValue23", None),
		"KPIValue24": (36, 2, (5, 0), (), "KPIValue24", None),
		"KPIValue25": (37, 2, (5, 0), (), "KPIValue25", None),
		"KPIValue26": (38, 2, (5, 0), (), "KPIValue26", None),
		"KPIValue27": (39, 2, (5, 0), (), "KPIValue27", None),
		"KPIValue28": (40, 2, (5, 0), (), "KPIValue28", None),
		"KPIValue29": (41, 2, (5, 0), (), "KPIValue29", None),
		"KPIValue3": (15, 2, (5, 0), (), "KPIValue3", None),
		"KPIValue30": (42, 2, (5, 0), (), "KPIValue30", None),
		"KPIValue4": (16, 2, (5, 0), (), "KPIValue4", None),
		"KPIValue5": (17, 2, (5, 0), (), "KPIValue5", None),
		"KPIValue6": (18, 2, (5, 0), (), "KPIValue6", None),
		"KPIValue7": (19, 2, (5, 0), (), "KPIValue7", None),
		"KPIValue8": (20, 2, (5, 0), (), "KPIValue8", None),
		"KPIValue9": (21, 2, (5, 0), (), "KPIValue9", None),
	}
	_prop_map_put_ = {
		"KPIName": ((12, LCID, 4, 0),()),
		"KPIValue1": ((13, LCID, 4, 0),()),
		"KPIValue10": ((22, LCID, 4, 0),()),
		"KPIValue11": ((23, LCID, 4, 0),()),
		"KPIValue12": ((24, LCID, 4, 0),()),
		"KPIValue13": ((25, LCID, 4, 0),()),
		"KPIValue14": ((26, LCID, 4, 0),()),
		"KPIValue15": ((27, LCID, 4, 0),()),
		"KPIValue16": ((28, LCID, 4, 0),()),
		"KPIValue17": ((29, LCID, 4, 0),()),
		"KPIValue18": ((30, LCID, 4, 0),()),
		"KPIValue19": ((31, LCID, 4, 0),()),
		"KPIValue2": ((14, LCID, 4, 0),()),
		"KPIValue20": ((32, LCID, 4, 0),()),
		"KPIValue21": ((33, LCID, 4, 0),()),
		"KPIValue22": ((34, LCID, 4, 0),()),
		"KPIValue23": ((35, LCID, 4, 0),()),
		"KPIValue24": ((36, LCID, 4, 0),()),
		"KPIValue25": ((37, LCID, 4, 0),()),
		"KPIValue26": ((38, LCID, 4, 0),()),
		"KPIValue27": ((39, LCID, 4, 0),()),
		"KPIValue28": ((40, LCID, 4, 0),()),
		"KPIValue29": ((41, LCID, 4, 0),()),
		"KPIValue3": ((15, LCID, 4, 0),()),
		"KPIValue30": ((42, LCID, 4, 0),()),
		"KPIValue4": ((16, LCID, 4, 0),()),
		"KPIValue5": ((17, LCID, 4, 0),()),
		"KPIValue6": ((18, LCID, 4, 0),()),
		"KPIValue7": ((19, LCID, 4, 0),()),
		"KPIValue8": ((20, LCID, 4, 0),()),
		"KPIValue9": ((21, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IKPI_ItemLines(DispatchBaseClass):
	'IKPI_ItemLines Interface'
	CLSID = IID('{9D5AE661-24A0-4F2A-AE75-714F3FF59B91}')
	coclass_clsid = IID('{9A19D585-D582-4079-BDDB-CA9F28F76603}')

	# Result is of type IKPI_ItemLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{48D8151E-BF85-4760-B7F8-B5E7E1B47937}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IKPI_ItemLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{48D8151E-BF85-4760-B7F8-B5E7E1B47937}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{48D8151E-BF85-4760-B7F8-B5E7E1B47937}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{48D8151E-BF85-4760-B7F8-B5E7E1B47937}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IKPIsParams(DispatchBaseClass):
	'IKPIsParams Interface'
	CLSID = IID('{44F97BA6-22A5-4687-BFBF-863A346A414C}')
	coclass_clsid = IID('{6F959012-2D32-4854-814C-4B0B89621EE0}')

	# Result is of type IKPIParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{41A28682-1C73-4C77-ADC8-5F805700B244}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IKPIParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{41A28682-1C73-4C77-ADC8-5F805700B244}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{41A28682-1C73-4C77-ADC8-5F805700B244}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{41A28682-1C73-4C77-ADC8-5F805700B244}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IKPIsService(DispatchBaseClass):
	'IKPIsService Interface'
	CLSID = IID('{EA80E8EC-0D43-4C8B-9F8C-BA5D71F12578}')
	coclass_clsid = IID('{871E4EA1-65DD-402C-AD85-7739F14D13F1}')

	# Result is of type IKPIParams
	def Add(self, pIKPI=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIKPI
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{41A28682-1C73-4C77-ADC8-5F805700B244}')
		return ret

	def Delete(self, pIKPIParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIKPIParams
			)

	# Result is of type IKPI
	def Get(self, pIKPIParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIKPIParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{087B9C04-C8CF-4606-A7B4-8FEC6CB8AE1D}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IKPIsParams
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{44F97BA6-22A5-4687-BFBF-863A346A414C}')
		return ret

	def Update(self, pIKPI=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIKPI
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IKnowledgeBaseSolutions(DispatchBaseClass):
	'IKnowledgeBaseSolutions Interface'
	CLSID = IID('{1E293D13-1EC1-4DF2-A5CC-7FE45030EEE5}')
	coclass_clsid = IID('{7A042067-2E94-48B5-A7CB-3534F6223B35}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(62, LCID, 1, (8, 0), (),)

	def GetByKey(self, SolutionCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),SolutionCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(63, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AttachmentEntry": (64, 2, (3, 0), (), "AttachmentEntry", None),
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (18, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (19, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Cause": (16, 2, (8, 0), (), "Cause", None),
		"CreatedBy": (10, 2, (3, 0), (), "CreatedBy", None),
		"CreationDate": (11, 2, (7, 0), (), "CreationDate", None),
		"Description": (17, 2, (8, 0), (), "Description", None),
		"ItemCode": (7, 2, (8, 0), (), "ItemCode", None),
		"LastUpdateDate": (13, 2, (7, 0), (), "LastUpdateDate", None),
		"LastUpdatedBy": (12, 2, (3, 0), (), "LastUpdatedBy", None),
		"Owner": (9, 2, (3, 0), (), "Owner", None),
		"Solution": (14, 2, (8, 0), (), "Solution", None),
		"SolutionCode": (20, 2, (3, 0), (), "SolutionCode", None),
		"Status": (8, 2, (3, 0), (), "Status", None),
		"Symptom": (15, 2, (8, 0), (), "Symptom", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AttachmentEntry": ((64, LCID, 4, 0),()),
		"Cause": ((16, LCID, 4, 0),()),
		"Description": ((17, LCID, 4, 0),()),
		"ItemCode": ((7, LCID, 4, 0),()),
		"Solution": ((14, LCID, 4, 0),()),
		"Status": ((8, LCID, 4, 0),()),
		"Symptom": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILandedCost(DispatchBaseClass):
	'ILandedCost Interface'
	CLSID = IID('{069837FF-A1F4-4442-92EF-DFEA56C23992}')
	coclass_clsid = IID('{00AC5F7B-92BD-4EB4-AF80-0673AB0B0B7D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ActualCustoms": (25, 2, (5, 0), (), "ActualCustoms", None),
		"ActualCustomsFC": (47, 2, (5, 0), (), "ActualCustomsFC", None),
		"AmountToBalance": (39, 2, (5, 0), (), "AmountToBalance", None),
		"AmountToBalanceFC": (40, 2, (5, 0), (), "AmountToBalanceFC", None),
		"BeforeTax": (28, 2, (5, 0), (), "BeforeTax", None),
		"BeforeTaxFC": (34, 2, (5, 0), (), "BeforeTaxFC", None),
		"BillofLadingNumber": (41, 2, (8, 0), (), "BillofLadingNumber", None),
		"Broker": (16, 2, (8, 0), (), "Broker", None),
		"BrokerName": (17, 2, (8, 0), (), "BrokerName", None),
		"ClosedDocument": (18, 2, (3, 0), (), "ClosedDocument", None),
		"CustomsAffectsInventory": (38, 2, (3, 0), (), "CustomsAffectsInventory", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"DocumentCurrency": (22, 2, (8, 0), (), "DocumentCurrency", None),
		"DocumentRate": (23, 2, (5, 0), (), "DocumentRate", None),
		"DueDate": (13, 2, (7, 0), (), "DueDate", None),
		"FileNumber": (19, 2, (8, 0), (), "FileNumber", None),
		"JournalRemarks": (44, 2, (8, 0), (), "JournalRemarks", None),
		"LandedCostNumber": (11, 2, (3, 0), (), "LandedCostNumber", None),
		# Method 'LandedCost_CostLines' returns object of type 'ILandedCost_CostLines'
		"LandedCost_CostLines": (46, 2, (9, 0), (), "LandedCost_CostLines", '{83CB8BC4-7FE1-4C02-81B4-35EE3C252DC8}'),
		# Method 'LandedCost_ItemLines' returns object of type 'ILandedCost_ItemLines'
		"LandedCost_ItemLines": (45, 2, (9, 0), (), "LandedCost_ItemLines", '{36143269-AD6C-4AD9-9A2E-AE3273141D8C}'),
		"PostingDate": (12, 2, (7, 0), (), "PostingDate", None),
		"ProjectedCustoms": (24, 2, (5, 0), (), "ProjectedCustoms", None),
		"ProjectedCustomsFC": (31, 2, (5, 0), (), "ProjectedCustomsFC", None),
		"Reference": (21, 2, (8, 0), (), "Reference", None),
		"Remarks": (20, 2, (8, 0), (), "Remarks", None),
		"Series": (37, 2, (3, 0), (), "Series", None),
		"Tax1": (26, 2, (5, 0), (), "Tax1", None),
		"Tax1FC": (32, 2, (5, 0), (), "Tax1FC", None),
		"Tax2": (27, 2, (5, 0), (), "Tax2", None),
		"Tax2FC": (33, 2, (5, 0), (), "Tax2FC", None),
		"Total": (29, 2, (5, 0), (), "Total", None),
		"TotalFC": (35, 2, (5, 0), (), "TotalFC", None),
		"TotalFreightCharges": (30, 2, (5, 0), (), "TotalFreightCharges", None),
		"TotalFreightChargesFC": (36, 2, (5, 0), (), "TotalFreightChargesFC", None),
		"TransactionNumber": (43, 2, (3, 0), (), "TransactionNumber", None),
		"TransportType": (42, 2, (3, 0), (), "TransportType", None),
		"VendorCode": (14, 2, (8, 0), (), "VendorCode", None),
		"VendorName": (15, 2, (8, 0), (), "VendorName", None),
	}
	_prop_map_put_ = {
		"ActualCustoms": ((25, LCID, 4, 0),()),
		"ActualCustomsFC": ((47, LCID, 4, 0),()),
		"BillofLadingNumber": ((41, LCID, 4, 0),()),
		"Broker": ((16, LCID, 4, 0),()),
		"BrokerName": ((17, LCID, 4, 0),()),
		"ClosedDocument": ((18, LCID, 4, 0),()),
		"CustomsAffectsInventory": ((38, LCID, 4, 0),()),
		"DocumentCurrency": ((22, LCID, 4, 0),()),
		"DocumentRate": ((23, LCID, 4, 0),()),
		"DueDate": ((13, LCID, 4, 0),()),
		"FileNumber": ((19, LCID, 4, 0),()),
		"JournalRemarks": ((44, LCID, 4, 0),()),
		"PostingDate": ((12, LCID, 4, 0),()),
		"Reference": ((21, LCID, 4, 0),()),
		"Remarks": ((20, LCID, 4, 0),()),
		"Series": ((37, LCID, 4, 0),()),
		"Tax1": ((26, LCID, 4, 0),()),
		"Tax1FC": ((32, LCID, 4, 0),()),
		"Tax2": ((27, LCID, 4, 0),()),
		"Tax2FC": ((33, LCID, 4, 0),()),
		"TransportType": ((42, LCID, 4, 0),()),
		"VendorCode": ((14, LCID, 4, 0),()),
		"VendorName": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILandedCostParams(DispatchBaseClass):
	'ILandedCostParams Interface'
	CLSID = IID('{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')
	coclass_clsid = IID('{251C6447-671B-4ACB-9CB3-C8E072B5E60D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"LandedCostNumber": (10, 2, (3, 0), (), "LandedCostNumber", None),
	}
	_prop_map_put_ = {
		"LandedCostNumber": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILandedCost_CostLine(DispatchBaseClass):
	'ILandedCost_CostLine Interface'
	CLSID = IID('{7AF930C1-1211-4953-BD69-5F64B3743316}')
	coclass_clsid = IID('{8EDBEEE5-B0AB-4400-889A-851F0F74FFEF}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AllocationBy": (12, 2, (3, 0), (), "AllocationBy", None),
		"AmountFC": (14, 2, (5, 0), (), "AmountFC", None),
		"CostType": (16, 2, (3, 0), (), "CostType", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"Factor": (15, 2, (5, 0), (), "Factor", None),
		"IncludeForCustoms": (17, 2, (3, 0), (), "IncludeForCustoms", None),
		"LandedCostCode": (11, 2, (8, 0), (), "LandedCostCode", None),
		"amount": (13, 2, (5, 0), (), "amount", None),
	}
	_prop_map_put_ = {
		"AllocationBy": ((12, LCID, 4, 0),()),
		"AmountFC": ((14, LCID, 4, 0),()),
		"CostType": ((16, LCID, 4, 0),()),
		"IncludeForCustoms": ((17, LCID, 4, 0),()),
		"LandedCostCode": ((11, LCID, 4, 0),()),
		"amount": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILandedCost_CostLines(DispatchBaseClass):
	'ILandedCost_CostLines Interface'
	CLSID = IID('{83CB8BC4-7FE1-4C02-81B4-35EE3C252DC8}')
	coclass_clsid = IID('{A2EC2F58-8237-41EC-94A1-89BA109C8EB9}')

	# Result is of type ILandedCost_CostLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7AF930C1-1211-4953-BD69-5F64B3743316}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ILandedCost_CostLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{7AF930C1-1211-4953-BD69-5F64B3743316}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{7AF930C1-1211-4953-BD69-5F64B3743316}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{7AF930C1-1211-4953-BD69-5F64B3743316}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ILandedCost_ItemLine(DispatchBaseClass):
	'ILandedCost_ItemLine Interface'
	CLSID = IID('{052A6BA1-A1AA-4A04-ABDE-23FE11833711}')
	coclass_clsid = IID('{438F04FE-3A92-426F-BD6C-29807B132A19}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AllocatedCostsLineTotal": (60, 2, (5, 0), (), "AllocatedCostsLineTotal", None),
		"AllocatedUnitCostsLineTotal": (51, 2, (5, 0), (), "AllocatedUnitCostsLineTotal", None),
		"AllocatedUnitCostsLineTotalFC": (52, 2, (5, 0), (), "AllocatedUnitCostsLineTotalFC", None),
		"AutomaticExpenditure": (70, 2, (3, 0), (), "AutomaticExpenditure", None),
		"BaseDocumentPrice": (17, 2, (5, 0), (), "BaseDocumentPrice", None),
		"BaseDocumentType": (12, 2, (3, 0), (), "BaseDocumentType", None),
		"BaseDocumentValueLineTotal": (49, 2, (5, 0), (), "BaseDocumentValueLineTotal", None),
		"BaseDocumentValueLineTotalFC": (50, 2, (5, 0), (), "BaseDocumentValueLineTotalFC", None),
		"BaseEntry": (13, 2, (3, 0), (), "BaseEntry", None),
		"BaseLine": (58, 2, (3, 0), (), "BaseLine", None),
		"BlockNumber": (38, 2, (8, 0), (), "BlockNumber", None),
		"Currency": (73, 2, (8, 0), (), "Currency", None),
		"Customs": (47, 2, (5, 0), (), "Customs", None),
		"CustomsFC": (48, 2, (5, 0), (), "CustomsFC", None),
		"CustomsGroupRate": (74, 2, (5, 0), (), "CustomsGroupRate", None),
		"CustomsValue": (53, 2, (5, 0), (), "CustomsValue", None),
		"CustomsValueFC": (54, 2, (5, 0), (), "CustomsValueFC", None),
		"DistributionRule": (64, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (65, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (66, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (67, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (68, 2, (8, 0), (), "DistributionRule5", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"Expenditure": (21, 2, (5, 0), (), "Expenditure", None),
		"ExpenditureFC": (22, 2, (5, 0), (), "ExpenditureFC", None),
		"FOBandIncludedCosts": (61, 2, (5, 0), (), "FOBandIncludedCosts", None),
		"FOBandIncludedCostsFC": (62, 2, (5, 0), (), "FOBandIncludedCostsFC", None),
		"FactorWithCustoms": (36, 2, (5, 0), (), "FactorWithCustoms", None),
		"FactorWithoutCustoms": (35, 2, (5, 0), (), "FactorWithoutCustoms", None),
		"FixCosts": (44, 2, (5, 0), (), "FixCosts", None),
		"FixCostsFC": (46, 2, (5, 0), (), "FixCostsFC", None),
		"ImportLog": (39, 2, (8, 0), (), "ImportLog", None),
		"InventoryUOM": (37, 2, (8, 0), (), "InventoryUOM", None),
		"InventoryValuation": (71, 2, (3, 0), (), "InventoryValuation", None),
		"ItemDescription": (15, 2, (8, 0), (), "ItemDescription", None),
		"LineNumber": (11, 2, (3, 0), (), "LineNumber", None),
		"LineTotal": (25, 2, (5, 0), (), "LineTotal", None),
		"LineTotalFC": (26, 2, (5, 0), (), "LineTotalFC", None),
		"Number": (14, 2, (8, 0), (), "Number", None),
		"OriginLine": (72, 2, (3, 0), (), "OriginLine", None),
		"OriginalWarehouse": (40, 2, (8, 0), (), "OriginalWarehouse", None),
		"PriceList": (69, 2, (3, 0), (), "PriceList", None),
		"Project": (63, 2, (8, 0), (), "Project", None),
		"ProjectedCustoms": (19, 2, (5, 0), (), "ProjectedCustoms", None),
		"ProjectedCustomsFC": (20, 2, (5, 0), (), "ProjectedCustomsFC", None),
		"Quantity": (16, 2, (5, 0), (), "Quantity", None),
		"Rate": (18, 2, (5, 0), (), "Rate", None),
		"Reference": (34, 2, (8, 0), (), "Reference", None),
		"ReleaseNumber": (42, 2, (3, 0), (), "ReleaseNumber", None),
		"TotalCosts": (55, 2, (5, 0), (), "TotalCosts", None),
		"TotalCostsFC": (56, 2, (5, 0), (), "TotalCostsFC", None),
		"TotalLineProjectedCustoms": (59, 2, (5, 0), (), "TotalLineProjectedCustoms", None),
		"TotalVolume": (57, 2, (5, 0), (), "TotalVolume", None),
		"VariantCosts": (43, 2, (5, 0), (), "VariantCosts", None),
		"VariantCostsFC": (45, 2, (5, 0), (), "VariantCostsFC", None),
		"VendorCode": (33, 2, (8, 0), (), "VendorCode", None),
		"Volume": (27, 2, (5, 0), (), "Volume", None),
		"VolumeUoM": (28, 2, (3, 0), (), "VolumeUoM", None),
		"Warehouse": (41, 2, (8, 0), (), "Warehouse", None),
		"WarehousePrice": (23, 2, (5, 0), (), "WarehousePrice", None),
		"WarehousePriceFC": (24, 2, (5, 0), (), "WarehousePriceFC", None),
		"Weight1": (29, 2, (5, 0), (), "Weight1", None),
		"Weight1UnitCode": (30, 2, (3, 0), (), "Weight1UnitCode", None),
		"Weight2": (31, 2, (5, 0), (), "Weight2", None),
		"Weight2UnitCode": (32, 2, (3, 0), (), "Weight2UnitCode", None),
	}
	_prop_map_put_ = {
		"AllocatedUnitCostsLineTotal": ((51, LCID, 4, 0),()),
		"AllocatedUnitCostsLineTotalFC": ((52, LCID, 4, 0),()),
		"AutomaticExpenditure": ((70, LCID, 4, 0),()),
		"BaseDocumentPrice": ((17, LCID, 4, 0),()),
		"BaseDocumentType": ((12, LCID, 4, 0),()),
		"BaseEntry": ((13, LCID, 4, 0),()),
		"BaseLine": ((58, LCID, 4, 0),()),
		"BlockNumber": ((38, LCID, 4, 0),()),
		"Currency": ((73, LCID, 4, 0),()),
		"CustomsValue": ((53, LCID, 4, 0),()),
		"CustomsValueFC": ((54, LCID, 4, 0),()),
		"DistributionRule": ((64, LCID, 4, 0),()),
		"DistributionRule2": ((65, LCID, 4, 0),()),
		"DistributionRule3": ((66, LCID, 4, 0),()),
		"DistributionRule4": ((67, LCID, 4, 0),()),
		"DistributionRule5": ((68, LCID, 4, 0),()),
		"Expenditure": ((21, LCID, 4, 0),()),
		"ExpenditureFC": ((22, LCID, 4, 0),()),
		"ImportLog": ((39, LCID, 4, 0),()),
		"InventoryValuation": ((71, LCID, 4, 0),()),
		"OriginLine": ((72, LCID, 4, 0),()),
		"PriceList": ((69, LCID, 4, 0),()),
		"Project": ((63, LCID, 4, 0),()),
		"ProjectedCustoms": ((19, LCID, 4, 0),()),
		"ProjectedCustomsFC": ((20, LCID, 4, 0),()),
		"Quantity": ((16, LCID, 4, 0),()),
		"TotalVolume": ((57, LCID, 4, 0),()),
		"Volume": ((27, LCID, 4, 0),()),
		"VolumeUoM": ((28, LCID, 4, 0),()),
		"Warehouse": ((41, LCID, 4, 0),()),
		"Weight1": ((29, LCID, 4, 0),()),
		"Weight1UnitCode": ((30, LCID, 4, 0),()),
		"Weight2": ((31, LCID, 4, 0),()),
		"Weight2UnitCode": ((32, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILandedCost_ItemLines(DispatchBaseClass):
	'ILandedCost_ItemLines Interface'
	CLSID = IID('{36143269-AD6C-4AD9-9A2E-AE3273141D8C}')
	coclass_clsid = IID('{0F314F27-D439-454B-9722-A1C1AE6A11A5}')

	# Result is of type ILandedCost_ItemLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{052A6BA1-A1AA-4A04-ABDE-23FE11833711}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ILandedCost_ItemLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{052A6BA1-A1AA-4A04-ABDE-23FE11833711}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{052A6BA1-A1AA-4A04-ABDE-23FE11833711}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{052A6BA1-A1AA-4A04-ABDE-23FE11833711}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ILandedCostsCodes(DispatchBaseClass):
	'ILandedCostsCodes Interface'
	CLSID = IID('{1E6899F1-7A1B-460A-B134-3A82F9083C77}')
	coclass_clsid = IID('{52E836D1-B708-41C5-850C-624B33BB2BE3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),bstrCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AllocationBy": (13, 2, (3, 0), (), "AllocationBy", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"LandedCostsAllocationAccount": (14, 2, (8, 0), (), "LandedCostsAllocationAccount", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AllocationBy": ((13, LCID, 4, 0),()),
		"Code": ((11, LCID, 4, 0),()),
		"LandedCostsAllocationAccount": ((14, LCID, 4, 0),()),
		"Name": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILandedCostsParams(DispatchBaseClass):
	'ILandedCostsParams Interface'
	CLSID = IID('{F5221870-4600-47CC-AFA3-779B11403820}')
	coclass_clsid = IID('{1569ABCE-0AFF-4A64-9558-9B23DE1B0512}')

	# Result is of type ILandedCostParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ILandedCostParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ILandedCostsService(DispatchBaseClass):
	'ILandedCostsService Interface'
	CLSID = IID('{EF61561B-2AB6-42DB-82EF-C440E4A4A71C}')
	coclass_clsid = IID('{1DC7EF54-44B5-4B53-90E9-EA337660D8F2}')

	# Result is of type ILandedCostParams
	def AddLandedCost(self, pILandedCost=defaultNamedNotOptArg):
		'AddLandedCost'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pILandedCost
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddLandedCost', '{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')
		return ret

	def CancelLandedCost(self, pILandedCostParams=defaultNamedNotOptArg):
		'CancelLandedCost'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((9, 1),),pILandedCostParams
			)

	def CloseLandedCost(self, pILandedCostParams=defaultNamedNotOptArg):
		'CloseLandedCost'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((9, 1),),pILandedCostParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ILandedCost
	def GetLandedCost(self, pILandedCostParams=defaultNamedNotOptArg):
		'GetLandedCost'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pILandedCostParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetLandedCost', '{069837FF-A1F4-4442-92EF-DFEA56C23992}')
		return ret

	# Result is of type ILandedCostsParams
	def GetLandedCostList(self):
		'GetLandedCostList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetLandedCostList', '{F5221870-4600-47CC-AFA3-779B11403820}')
		return ret

	def UpdateLandedCost(self, pILandedCost=defaultNamedNotOptArg):
		'UpdateLandedCost'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pILandedCost
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILayer(DispatchBaseClass):
	'ILayer Interface'
	CLSID = IID('{9739A029-5EB0-499A-9E72-967B98D55ECF}')
	coclass_clsid = IID('{ABCF9B92-C676-4369-A84F-1A7B29838E4E}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CurrentCost": (15, 2, (5, 0), (), "CurrentCost", None),
		"DocNumber": (12, 2, (8, 0), (), "DocNumber", None),
		"DocType": (13, 2, (3, 0), (), "DocType", None),
		"EntryDate": (14, 2, (7, 0), (), "EntryDate", None),
		"LayerID": (11, 2, (3, 0), (), "LayerID", None),
		"OpenQty": (16, 2, (5, 0), (), "OpenQty", None),
		"TransactionSequenceNum": (10, 2, (3, 0), (), "TransactionSequenceNum", None),
	}
	_prop_map_put_ = {
		"LayerID": ((11, LCID, 4, 0),()),
		"TransactionSequenceNum": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILayers(DispatchBaseClass):
	'ILayers Interface'
	CLSID = IID('{6C589BC6-9ACE-4A99-8097-038E9AC52155}')
	coclass_clsid = IID('{43885104-EC53-4FF2-965B-BA783636A33E}')

	# Result is of type ILayer
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{9739A029-5EB0-499A-9E72-967B98D55ECF}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ILayer
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{9739A029-5EB0-499A-9E72-967B98D55ECF}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{9739A029-5EB0-499A-9E72-967B98D55ECF}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{9739A029-5EB0-499A-9E72-967B98D55ECF}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ILegalData(DispatchBaseClass):
	'ILegalData Interface'
	CLSID = IID('{59837FCB-2720-45D3-85BF-9F075D5D6560}')
	coclass_clsid = IID('{65BDBFCE-903B-43E2-98FD-8B46471141BD}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DateOfPrinting": (13, 2, (7, 0), (), "DateOfPrinting", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"DocumentNumber": (22, 2, (8, 0), (), "DocumentNumber", None),
		"FiscalNumber": (21, 2, (8, 0), (), "FiscalNumber", None),
		"FiscalSeries": (20, 2, (8, 0), (), "FiscalSeries", None),
		"FiscalUserID": (23, 2, (3, 0), (), "FiscalUserID", None),
		# Method 'LegalDataDetailCollection' returns object of type 'ILegalDataDetailCollection'
		"LegalDataDetailCollection": (24, 2, (9, 0), (), "LegalDataDetailCollection", '{70CF9E47-2388-4A02-BC90-6F7CA6220DCB}'),
		"PrinterBrand": (15, 2, (8, 0), (), "PrinterBrand", None),
		"PrinterDllVersion": (19, 2, (8, 0), (), "PrinterDllVersion", None),
		"PrinterFirmwareVersion": (18, 2, (8, 0), (), "PrinterFirmwareVersion", None),
		"PrinterModel": (17, 2, (8, 0), (), "PrinterModel", None),
		"PrinterType": (16, 2, (8, 0), (), "PrinterType", None),
		"SourceObjectEntry": (12, 2, (3, 0), (), "SourceObjectEntry", None),
		"SourceObjectType": (11, 2, (3, 0), (), "SourceObjectType", None),
		"TimeOfPrinting": (14, 2, (7, 0), (), "TimeOfPrinting", None),
	}
	_prop_map_put_ = {
		"DateOfPrinting": ((13, LCID, 4, 0),()),
		"DocumentNumber": ((22, LCID, 4, 0),()),
		"FiscalNumber": ((21, LCID, 4, 0),()),
		"FiscalSeries": ((20, LCID, 4, 0),()),
		"FiscalUserID": ((23, LCID, 4, 0),()),
		"PrinterBrand": ((15, LCID, 4, 0),()),
		"PrinterDllVersion": ((19, LCID, 4, 0),()),
		"PrinterFirmwareVersion": ((18, LCID, 4, 0),()),
		"PrinterModel": ((17, LCID, 4, 0),()),
		"PrinterType": ((16, LCID, 4, 0),()),
		"SourceObjectEntry": ((12, LCID, 4, 0),()),
		"SourceObjectType": ((11, LCID, 4, 0),()),
		"TimeOfPrinting": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILegalDataDetail(DispatchBaseClass):
	'ILegalDataDetail Interface'
	CLSID = IID('{86767BCE-5E50-43DB-98D1-AB217A925BF9}')
	coclass_clsid = IID('{B3DEEBBD-3798-43CD-9A29-1432782507D3}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"LineSequence": (11, 2, (3, 0), (), "LineSequence", None),
		"LineType": (12, 2, (3, 0), (), "LineType", None),
		"TaxCode": (13, 2, (8, 0), (), "TaxCode", None),
		"TaxRate": (14, 2, (5, 0), (), "TaxRate", None),
		"amount": (15, 2, (5, 0), (), "amount", None),
	}
	_prop_map_put_ = {
		"LineType": ((12, LCID, 4, 0),()),
		"TaxCode": ((13, LCID, 4, 0),()),
		"TaxRate": ((14, LCID, 4, 0),()),
		"amount": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILegalDataDetailCollection(DispatchBaseClass):
	'ILegalDataDetailCollection Interface'
	CLSID = IID('{70CF9E47-2388-4A02-BC90-6F7CA6220DCB}')
	coclass_clsid = IID('{486F8D7E-FB6A-49BA-9333-ED25151631D8}')

	# Result is of type ILegalDataDetail
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{86767BCE-5E50-43DB-98D1-AB217A925BF9}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ILegalDataDetail
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{86767BCE-5E50-43DB-98D1-AB217A925BF9}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{86767BCE-5E50-43DB-98D1-AB217A925BF9}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{86767BCE-5E50-43DB-98D1-AB217A925BF9}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ILegalDataParams(DispatchBaseClass):
	'ILegalDataParams Interface'
	CLSID = IID('{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')
	coclass_clsid = IID('{9A0BF629-D6FA-4CD8-A7E7-2C57E0677593}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"SourceObjectEntry": (12, 2, (3, 0), (), "SourceObjectEntry", None),
		"SourceObjectType": (11, 2, (8, 0), (), "SourceObjectType", None),
	}
	_prop_map_put_ = {
		"DocEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILegalDataParamsCollection(DispatchBaseClass):
	'ILegalDataParamsCollection Interface'
	CLSID = IID('{9C192F0B-809E-4115-B560-3D683C99D48E}')
	coclass_clsid = IID('{2B7E88E6-AA4B-48A5-A462-AD771C618A44}')

	# Result is of type ILegalDataParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ILegalDataParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ILegalDataService(DispatchBaseClass):
	'ILegalDataService Interface'
	CLSID = IID('{598819B6-D5B0-4CF1-A533-D966C1D9267A}')
	coclass_clsid = IID('{E8289C17-9062-4232-A0B9-F82C67364B57}')

	# Result is of type ILegalDataParams
	def Add(self, pILegalData=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pILegalData
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')
		return ret

	# Result is of type ILegalData
	def Get(self, pILegalDataParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pILegalDataParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{59837FCB-2720-45D3-85BF-9F075D5D6560}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def Update(self, pILegalData=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pILegalData
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILengthMeasures(DispatchBaseClass):
	'ILengthMeasures Interface'
	CLSID = IID('{2FE8BD34-3F78-4FE0-A577-EE9496E8F294}')
	coclass_clsid = IID('{F1778F57-69E0-4FED-8EA1-D4921A239055}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lUnitCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lUnitCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"UnitCode": (10, 2, (3, 0), (), "UnitCode", None),
		"UnitCodeforQuantityDisplay": (13, 2, (8, 0), (), "UnitCodeforQuantityDisplay", None),
		"UnitDisplay": (11, 2, (8, 0), (), "UnitDisplay", None),
		"UnitLengthinmm": (14, 2, (5, 0), (), "UnitLengthinmm", None),
		"UnitName": (12, 2, (8, 0), (), "UnitName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"UnitCodeforQuantityDisplay": ((13, LCID, 4, 0),()),
		"UnitDisplay": ((11, LCID, 4, 0),()),
		"UnitLengthinmm": ((14, LCID, 4, 0),()),
		"UnitName": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ILocalEra(DispatchBaseClass):
	'ILocalEra Interface'
	CLSID = IID('{B7A80F7E-77C0-404E-A8B3-01D0F9136DCF}')
	coclass_clsid = IID('{F0D891FD-5D68-466B-90C3-0EDE46E01241}')

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),bstrCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (9, 2, (8, 0), (), "Code", None),
		"EraName": (7, 2, (8, 0), (), "EraName", None),
		"StartDate": (8, 2, (7, 0), (), "StartDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IManufacturers(DispatchBaseClass):
	'IManufacturers Interface'
	CLSID = IID('{DBB3E886-60E7-4058-930A-1C7C07CADB2C}')
	coclass_clsid = IID('{04C582B6-340A-4E71-B18B-460A37A04A62}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (12, 2, (3, 0), (), "Code", None),
		"ManufacturerName": (13, 2, (8, 0), (), "ManufacturerName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ManufacturerName": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialGroup(DispatchBaseClass):
	'IMaterialGroup Interface'
	CLSID = IID('{CF683F67-7A73-4D71-9C10-821A1E7715DC}')
	coclass_clsid = IID('{BF695196-36EF-4BEE-AEA9-AB35D9B40D22}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"MaterialGroupCode": (11, 2, (8, 0), (), "MaterialGroupCode", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"MaterialGroupCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialGroupParams(DispatchBaseClass):
	'IMaterialGroupParams Interface'
	CLSID = IID('{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')
	coclass_clsid = IID('{E432B857-5835-4E67-A3E1-BF6ED7AED2D2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"MaterialGroupCode": (11, 2, (8, 0), (), "MaterialGroupCode", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialGroupsParams(DispatchBaseClass):
	'IMaterialGroupsParams Interface'
	CLSID = IID('{9AA94F66-6356-43C6-A77E-C638B796511B}')
	coclass_clsid = IID('{3E16229E-BFD2-42F0-9044-85D8EB97865F}')

	# Result is of type IMaterialGroupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IMaterialGroupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IMaterialGroupsService(DispatchBaseClass):
	'IMaterialGroupsService Interface'
	CLSID = IID('{843B58CC-38C1-4C93-B5F6-533BFB3006BD}')
	coclass_clsid = IID('{224BFAE2-6275-450B-B64A-D6D8521EE697}')

	# Result is of type IMaterialGroupParams
	def AddMaterialGroup(self, pIMaterialGroup=defaultNamedNotOptArg):
		'AddMaterialGroup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIMaterialGroup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddMaterialGroup', '{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')
		return ret

	def DeleteMaterialGroup(self, pIMaterialGroupParams=defaultNamedNotOptArg):
		'DeleteMaterialGroup'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIMaterialGroupParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IMaterialGroup
	def GetMaterialGroup(self, pIMaterialGroupParams=defaultNamedNotOptArg):
		'GetMaterialGroup'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIMaterialGroupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetMaterialGroup', '{CF683F67-7A73-4D71-9C10-821A1E7715DC}')
		return ret

	# Result is of type IMaterialGroupsParams
	def GetMaterialGroupList(self):
		'GetMaterialGroupList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetMaterialGroupList', '{9AA94F66-6356-43C6-A77E-C638B796511B}')
		return ret

	def UpdateMaterialGroup(self, pIMaterialGroup=defaultNamedNotOptArg):
		'UpdateMaterialGroup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIMaterialGroup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialRevaluation(DispatchBaseClass):
	'IMaterialRevaluation Interface'
	CLSID = IID('{461F000F-9DB2-45D0-808D-FA552126FF16}')
	coclass_clsid = IID('{B133843B-6DB2-4920-976F-1C7EB0AD60A2}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(29, LCID, 1, (8, 0), (),)

	def GetByKey(self, AbsEntry=defaultNamedNotOptArg):
		'Get by key'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (11, 0), ((3, 0),),AbsEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(30, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save object as XML document'
		return self._ApplyTypes_(14, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (19, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Comments": (7, 2, (8, 0), (), "Comments", None),
		"CreationDate": (21, 2, (7, 0), (), "CreationDate", None),
		"DataSource": (27, 2, (8, 0), (), "DataSource", None),
		"DocDate": (4, 2, (7, 0), (), "DocDate", None),
		"DocEntry": (20, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (3, 2, (3, 0), (), "DocNum", None),
		"DocTime": (9, 2, (7, 0), (), "DocTime", None),
		"InflationRevaluation": (51, 2, (3, 0), (), "InflationRevaluation", None),
		"JournalMemo": (8, 2, (8, 0), (), "JournalMemo", None),
		# Method 'Lines' returns object of type 'IMaterialRevaluation_lines'
		"Lines": (2, 2, (9, 0), (), "Lines", '{038A3F8E-2465-435E-8D05-F510620533C3}'),
		"Reference1": (5, 2, (8, 0), (), "Reference1", None),
		"Reference2": (6, 2, (8, 0), (), "Reference2", None),
		"RevalType": (24, 2, (8, 0), (), "RevalType", None),
		"RevaluationExpenseAccount": (26, 2, (8, 0), (), "RevaluationExpenseAccount", None),
		"RevaluationIncomeAccount": (25, 2, (8, 0), (), "RevaluationIncomeAccount", None),
		"Series": (10, 2, (3, 0), (), "Series", None),
		"TaxDate": (11, 2, (7, 0), (), "TaxDate", None),
		"TransNum": (23, 2, (3, 0), (), "TransNum", None),
		"UpdateDate": (22, 2, (7, 0), (), "UpdateDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (13, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (28, 2, (3, 0), (), "UserSignature", None),
	}
	_prop_map_put_ = {
		"Comments": ((7, LCID, 4, 0),()),
		"DocDate": ((4, LCID, 4, 0),()),
		"InflationRevaluation": ((51, LCID, 4, 0),()),
		"JournalMemo": ((8, LCID, 4, 0),()),
		"Reference2": ((6, LCID, 4, 0),()),
		"RevalType": ((24, LCID, 4, 0),()),
		"RevaluationExpenseAccount": ((26, LCID, 4, 0),()),
		"RevaluationIncomeAccount": ((25, LCID, 4, 0),()),
		"Series": ((10, LCID, 4, 0),()),
		"TaxDate": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialRevaluationFIFO(DispatchBaseClass):
	'IMaterialRevaluationFIFO Interface'
	CLSID = IID('{F5C29BC7-F643-4A93-9026-C045A11D564A}')
	coclass_clsid = IID('{53845C38-AC44-41AE-B21A-9A9EE1018A4D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		# Method 'Layers' returns object of type 'ILayers'
		"Layers": (10, 2, (9, 0), (), "Layers", '{6C589BC6-9ACE-4A99-8097-038E9AC52155}'),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialRevaluationFIFOParams(DispatchBaseClass):
	'IMaterialRevaluationFIFOParams Interface'
	CLSID = IID('{C1DD2F9D-7198-47C3-936D-46E421503333}')
	coclass_clsid = IID('{6DE9F2ED-C121-43F2-B922-CE373DC2EC17}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ItemCode": (10, 2, (8, 0), (), "ItemCode", None),
		"LocationCode": (12, 2, (8, 0), (), "LocationCode", None),
		"LocationType": (11, 2, (8, 0), (), "LocationType", None),
		"ShowIssuedLayers": (13, 2, (3, 0), (), "ShowIssuedLayers", None),
	}
	_prop_map_put_ = {
		"ItemCode": ((10, LCID, 4, 0),()),
		"LocationCode": ((12, LCID, 4, 0),()),
		"LocationType": ((11, LCID, 4, 0),()),
		"ShowIssuedLayers": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialRevaluationFIFOService(DispatchBaseClass):
	'IMaterialRevaluationFIFOService Interface'
	CLSID = IID('{B743C51D-0E51-400E-8245-91331C0A6762}')
	coclass_clsid = IID('{6AEEDCED-BA23-49D4-9853-D371A33AA311}')

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IMaterialRevaluationFIFO
	def GetMaterialRevaluationFIFO(self, pIMaterialRevaluationFIFOParams=defaultNamedNotOptArg):
		'GetMaterialRevaluationFIFO'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIMaterialRevaluationFIFOParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetMaterialRevaluationFIFO', '{F5C29BC7-F643-4A93-9026-C045A11D564A}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMaterialRevaluation_lines(DispatchBaseClass):
	'IMaterialRevaluation_lines Interface'
	CLSID = IID('{038A3F8E-2465-435E-8D05-F510620533C3}')
	coclass_clsid = IID('{64572B16-A58D-40D4-B869-10787D0A8EE2}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ActualPrice": (11, 2, (5, 0), (), "ActualPrice", None),
		"Count": (8, 2, (3, 0), (), "Count", None),
		"DebitCredit": (13, 2, (5, 0), (), "DebitCredit", None),
		"DistributionRule": (20, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (21, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (22, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (23, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (24, 2, (8, 0), (), "DistributionRule5", None),
		"DocEntry": (14, 2, (3, 0), (), "DocEntry", None),
		# Method 'FIFOLayers' returns object of type 'IFIFOLayers'
		"FIFOLayers": (18, 2, (9, 0), (), "FIFOLayers", '{2C4B93F4-860D-481D-85C5-020876095197}'),
		"ItemCode": (3, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (4, 2, (8, 0), (), "ItemDescription", None),
		"LineNum": (2, 2, (3, 0), (), "LineNum", None),
		"OnHand": (12, 2, (5, 0), (), "OnHand", None),
		"Price": (6, 2, (5, 0), (), "Price", None),
		"Project": (19, 2, (8, 0), (), "Project", None),
		"Quantity": (5, 2, (5, 0), (), "Quantity", None),
		"RevalAmountToStock": (17, 2, (5, 0), (), "RevalAmountToStock", None),
		"RevaluationDecrementAccount": (15, 2, (8, 0), (), "RevaluationDecrementAccount", None),
		"RevaluationIncrementAccount": (16, 2, (8, 0), (), "RevaluationIncrementAccount", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (10, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WarehouseCode": (7, 2, (8, 0), (), "WarehouseCode", None),
	}
	_prop_map_put_ = {
		"DebitCredit": ((13, LCID, 4, 0),()),
		"DistributionRule": ((20, LCID, 4, 0),()),
		"DistributionRule2": ((21, LCID, 4, 0),()),
		"DistributionRule3": ((22, LCID, 4, 0),()),
		"DistributionRule4": ((23, LCID, 4, 0),()),
		"DistributionRule5": ((24, LCID, 4, 0),()),
		"ItemCode": ((3, LCID, 4, 0),()),
		"Price": ((6, LCID, 4, 0),()),
		"Project": ((19, LCID, 4, 0),()),
		"Quantity": ((5, LCID, 4, 0),()),
		"RevaluationDecrementAccount": ((15, LCID, 4, 0),()),
		"RevaluationIncrementAccount": ((16, LCID, 4, 0),()),
		"WarehouseCode": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(8, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IMessage(DispatchBaseClass):
	'IMessage Interface'
	CLSID = IID('{32E2CAC3-EEFA-4C2B-B916-C43A8A39BEAE}')
	coclass_clsid = IID('{5F05E0D7-EA2B-4FA6-B7DB-D436CB1AAD63}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Attachment": (18, 2, (3, 0), (), "Attachment", None),
		# Method 'MessageDataColumns' returns object of type 'IMessageDataColumns'
		"MessageDataColumns": (19, 2, (9, 0), (), "MessageDataColumns", '{002ACD1C-A740-40C7-9927-33E4CB58536F}'),
		"Priority": (14, 2, (3, 0), (), "Priority", None),
		# Method 'RecipientCollection' returns object of type 'IRecipientCollection'
		"RecipientCollection": (21, 2, (9, 0), (), "RecipientCollection", '{2C728EFB-8BF9-4D0A-8135-E53AD4CDC064}'),
		"Subject": (15, 2, (8, 0), (), "Subject", None),
		"Text": (17, 2, (8, 0), (), "Text", None),
		"User": (12, 2, (3, 0), (), "User", None),
	}
	_prop_map_put_ = {
		"Attachment": ((18, LCID, 4, 0),()),
		"MessageDataColumns": ((19, LCID, 4, 0),()),
		"Priority": ((14, LCID, 4, 0),()),
		"RecipientCollection": ((21, LCID, 4, 0),()),
		"Subject": ((15, LCID, 4, 0),()),
		"Text": ((17, LCID, 4, 0),()),
		"User": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMessageDataColumn(DispatchBaseClass):
	'IMessageDataColumn Interface'
	CLSID = IID('{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}')
	coclass_clsid = IID('{6D9B2EFB-F9A8-4AE9-9C92-6C0DDF80EA56}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ColumnName": (11, 2, (8, 0), (), "ColumnName", None),
		"Link": (12, 2, (3, 0), (), "Link", None),
		# Method 'MessageDataLines' returns object of type 'IMessageDataLines'
		"MessageDataLines": (13, 2, (9, 0), (), "MessageDataLines", '{38FD1577-2135-4D5F-A037-E5388B413F83}'),
	}
	_prop_map_put_ = {
		"ColumnName": ((11, LCID, 4, 0),()),
		"Link": ((12, LCID, 4, 0),()),
		"MessageDataLines": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMessageDataColumns(DispatchBaseClass):
	'IMessageDataColumns Interface'
	CLSID = IID('{002ACD1C-A740-40C7-9927-33E4CB58536F}')
	coclass_clsid = IID('{36FA3872-B465-409C-8F70-24AC72D4D5CE}')

	# Result is of type IMessageDataColumn
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IMessageDataColumn
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IMessageDataLine(DispatchBaseClass):
	'IMessageDataLine Interface'
	CLSID = IID('{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}')
	coclass_clsid = IID('{DEA042B3-1E27-4546-9F43-D78BD356E060}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Object": (12, 2, (8, 0), (), "Object", None),
		"ObjectKey": (13, 2, (8, 0), (), "ObjectKey", None),
		"Value": (10, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Object": ((12, LCID, 4, 0),()),
		"ObjectKey": ((13, LCID, 4, 0),()),
		"Value": ((10, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(10, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMessageDataLines(DispatchBaseClass):
	'IMessageDataLines Interface'
	CLSID = IID('{38FD1577-2135-4D5F-A037-E5388B413F83}')
	coclass_clsid = IID('{6956AD8B-4137-40EE-8614-DBC251938619}')

	# Result is of type IMessageDataLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IMessageDataLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IMessageHeader(DispatchBaseClass):
	'IMessageHeader Interface'
	CLSID = IID('{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')
	coclass_clsid = IID('{FF4507B4-AF5E-4599-89D6-B24974CE248E}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (3, 0), (), "Code", None),
		"Read": (12, 2, (3, 0), (), "Read", None),
		"Received": (11, 2, (3, 0), (), "Received", None),
		"ReceivedDate": (13, 2, (7, 0), (), "ReceivedDate", None),
		"ReceivedTime": (14, 2, (7, 0), (), "ReceivedTime", None),
		"SentDate": (15, 2, (7, 0), (), "SentDate", None),
		"SentTime": (16, 2, (7, 0), (), "SentTime", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMessageHeaders(DispatchBaseClass):
	'IMessageHeaders Interface'
	CLSID = IID('{CBAB706D-E5DE-4D36-BB28-C6705D247335}')
	coclass_clsid = IID('{D03750AE-84B3-4539-A931-36AAA98C4EBB}')

	# Result is of type IMessageHeader
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IMessageHeader
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IMessages(DispatchBaseClass):
	'IMessages Interface'
	CLSID = IID('{C4DCA924-9189-4969-8609-8564D6E5AFAA}')
	coclass_clsid = IID('{C397C564-B506-4649-9C12-E4B63BBD7711}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def AddDataColumn(self, Title=defaultNamedNotOptArg, Text=defaultNamedNotOptArg, Object=defaultNamedNotOptArg, ObjectKey=defaultNamedNotOptArg):
		'method AddDataColumn'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((8, 0), (8, 0), (3, 0), (8, 0)),Title
			, Text, Object, ObjectKey)

	_prop_map_get_ = {
		"AttachmentEntry": (10, 2, (3, 0), (), "AttachmentEntry", None),
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (8, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		"MessageText": (4, 2, (8, 0), (), "MessageText", None),
		"Priority": (2, 2, (3, 0), (), "Priority", None),
		# Method 'Recipients' returns object of type 'IRecipients'
		"Recipients": (9, 2, (9, 0), (), "Recipients", '{F408B086-B6E4-4EE0-9B95-710C117E56F0}'),
		"Subject": (3, 2, (8, 0), (), "Subject", None),
	}
	_prop_map_put_ = {
		"AttachmentEntry": ((10, LCID, 4, 0),()),
		"MessageText": ((4, LCID, 4, 0),()),
		"Priority": ((2, LCID, 4, 0),()),
		"Subject": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMessagesService(DispatchBaseClass):
	'IMessagesService Interface'
	CLSID = IID('{A24C6BD6-06BA-47B3-8B67-D628AEFAD721}')
	coclass_clsid = IID('{4D2FFFD1-12AF-439B-9E32-049F24A661D8}')

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IMessageHeaders
	def GetInbox(self):
		'GetInbox'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetInbox', '{CBAB706D-E5DE-4D36-BB28-C6705D247335}')
		return ret

	# Result is of type IMessage
	def GetMessage(self, pMessageHeader=defaultNamedNotOptArg):
		'GetMessage'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pMessageHeader
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetMessage', '{32E2CAC3-EEFA-4C2B-B916-C43A8A39BEAE}')
		return ret

	# Result is of type IMessageHeaders
	def GetOutbox(self):
		'GetOutbox'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetOutbox', '{CBAB706D-E5DE-4D36-BB28-C6705D247335}')
		return ret

	# Result is of type IMessageHeaders
	def GetSentMessages(self):
		'GetSentMessages'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetSentMessages', '{CBAB706D-E5DE-4D36-BB28-C6705D247335}')
		return ret

	# Result is of type IMessageHeader
	def SendMessage(self, pMessage=defaultNamedNotOptArg):
		'SendMessage'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((9, 1),),pMessage
			)
		if ret is not None:
			ret = Dispatch(ret, u'SendMessage', '{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')
		return ret

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMultiLanguageTranslations(DispatchBaseClass):
	'IMultiLanguageTranslations Interface'
	CLSID = IID('{2CE582CB-83A3-49C0-AF0B-5C7F6EA88B0B}')
	coclass_clsid = IID('{F041210F-6968-47CD-B441-40A059D76A1A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsEntry=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lAbsEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"FieldAlias": (14, 2, (8, 0), (), "FieldAlias", None),
		"Numerator": (12, 2, (3, 0), (), "Numerator", None),
		"PrimaryKeyofobject": (15, 2, (8, 0), (), "PrimaryKeyofobject", None),
		"TableName": (13, 2, (8, 0), (), "TableName", None),
		# Method 'TranslationsInUserLanguages' returns object of type 'ITranslationsInUserLanguages'
		"TranslationsInUserLanguages": (17, 2, (9, 0), (), "TranslationsInUserLanguages", '{2AC79865-8E0D-42CD-8A97-AA4ADF24B4EE}'),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"FieldAlias": ((14, LCID, 4, 0),()),
		"PrimaryKeyofobject": ((15, LCID, 4, 0),()),
		"TableName": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMultiplePayment(DispatchBaseClass):
	'IMultiplePayment Interface'
	CLSID = IID('{738D011A-EA2A-4205-B009-53C7C64D73DD}')
	coclass_clsid = IID('{FDC4607A-1635-40A8-8519-A756C180FCFB}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AmountFC": (14, 2, (5, 0), (), "AmountFC", None),
		"AmountLC": (13, 2, (5, 0), (), "AmountLC", None),
		"BankStatmentLineID": (10, 2, (3, 0), (), "BankStatmentLineID", None),
		"DocumentIdentifier": (12, 2, (8, 0), (), "DocumentIdentifier", None),
		"IsDebit": (15, 2, (3, 0), (), "IsDebit", None),
		"ListLineID": (11, 2, (3, 0), (), "ListLineID", None),
	}
	_prop_map_put_ = {
		"AmountFC": ((14, LCID, 4, 0),()),
		"AmountLC": ((13, LCID, 4, 0),()),
		"DocumentIdentifier": ((12, LCID, 4, 0),()),
		"IsDebit": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IMultiplePayments(DispatchBaseClass):
	'IMultiplePayments Interface'
	CLSID = IID('{4207538F-AAC0-4EDD-9002-6F710410D5C6}')
	coclass_clsid = IID('{BF84F083-2917-4B14-80E4-3333A08C7073}')

	# Result is of type IMultiplePayment
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{738D011A-EA2A-4205-B009-53C7C64D73DD}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IMultiplePayment
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{738D011A-EA2A-4205-B009-53C7C64D73DD}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{738D011A-EA2A-4205-B009-53C7C64D73DD}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{738D011A-EA2A-4205-B009-53C7C64D73DD}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class INCMCodeSetup(DispatchBaseClass):
	'INCMCodeSetup Interface'
	CLSID = IID('{8ED60CF1-3116-4C89-A77D-B67ED48F2F22}')
	coclass_clsid = IID('{EAD60362-CE52-4064-BA2B-E76EA5297CB3}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"NCMCode": (11, 2, (8, 0), (), "NCMCode", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"NCMCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INCMCodeSetupParams(DispatchBaseClass):
	'INCMCodeSetupParams Interface'
	CLSID = IID('{C48ABD4C-43C8-4776-87E7-337D661050C2}')
	coclass_clsid = IID('{1B73D91C-F2B5-4BF3-A772-0A95FBBA1128}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"NCMCode": (11, 2, (8, 0), (), "NCMCode", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INCMCodeSetupParamsCollection(DispatchBaseClass):
	'INCMCodeSetupParamsCollection Interface'
	CLSID = IID('{B14AF4AA-36E3-4C09-9BEF-6DCED4B5EBFB}')
	coclass_clsid = IID('{F3C8C06A-7D48-4B85-9BD6-12344F1CC72E}')

	# Result is of type INCMCodeSetupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{C48ABD4C-43C8-4776-87E7-337D661050C2}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type INCMCodeSetupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{C48ABD4C-43C8-4776-87E7-337D661050C2}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{C48ABD4C-43C8-4776-87E7-337D661050C2}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{C48ABD4C-43C8-4776-87E7-337D661050C2}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class INCMCodesSetupService(DispatchBaseClass):
	'INCMCodesSetupService Interface'
	CLSID = IID('{1470A4FE-6338-4FC7-AD95-D6E2CB4DBB20}')
	coclass_clsid = IID('{F25B1134-169D-4C7C-B46A-B90707621373}')

	# Result is of type INCMCodeSetupParams
	def AddNCMCodeSetup(self, pINCMCodeSetup=defaultNamedNotOptArg):
		'AddNCMCodeSetup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pINCMCodeSetup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddNCMCodeSetup', '{C48ABD4C-43C8-4776-87E7-337D661050C2}')
		return ret

	def DeleteNCMCodeSetup(self, pINCMCodeSetupParams=defaultNamedNotOptArg):
		'DeleteNCMCodeSetup'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pINCMCodeSetupParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type INCMCodeSetup
	def GetNCMCodeSetup(self, pINCMCodeSetupParams=defaultNamedNotOptArg):
		'GetNCMCodeSetup'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pINCMCodeSetupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetNCMCodeSetup', '{8ED60CF1-3116-4C89-A77D-B67ED48F2F22}')
		return ret

	# Result is of type INCMCodeSetupParamsCollection
	def GetNCMCodeSetupList(self):
		'GetNCMCodeSetupList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetNCMCodeSetupList', '{B14AF4AA-36E3-4C09-9BEF-6DCED4B5EBFB}')
		return ret

	def UpdateNCMCodeSetup(self, pINCMCodeSetup=defaultNamedNotOptArg):
		'UpdateNCMCodeSetup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pINCMCodeSetup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INFModel(DispatchBaseClass):
	'INFModel Interface'
	CLSID = IID('{35E59851-3F5C-40B3-9613-BCC32E3B97B8}')
	coclass_clsid = IID('{F0C0A764-0170-479E-BEA9-152989FB0E55}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (8, 0), (), "AbsEntry", None),
		"NFMCode": (13, 2, (8, 0), (), "NFMCode", None),
		"NFMDescription": (12, 2, (8, 0), (), "NFMDescription", None),
		"NFMName": (11, 2, (8, 0), (), "NFMName", None),
	}
	_prop_map_put_ = {
		"NFMCode": ((13, LCID, 4, 0),()),
		"NFMDescription": ((12, LCID, 4, 0),()),
		"NFMName": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INFModelParams(DispatchBaseClass):
	'INFModelParams Interface'
	CLSID = IID('{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')
	coclass_clsid = IID('{4211C5EE-D841-47F4-85CE-752D2DB519C2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (8, 0), (), "AbsEntry", None),
		"NFMCode": (13, 2, (8, 0), (), "NFMCode", None),
		"NFMDescription": (12, 2, (8, 0), (), "NFMDescription", None),
		"NFMName": (11, 2, (8, 0), (), "NFMName", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INFModelsParams(DispatchBaseClass):
	'INFModelsParams Interface'
	CLSID = IID('{85830213-6564-4BBA-95DD-246624D1A4D2}')
	coclass_clsid = IID('{989D909A-FA21-488B-B144-A7AA6B920308}')

	# Result is of type INFModelParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type INFModelParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class INFModelsService(DispatchBaseClass):
	'INFModelsService Interface'
	CLSID = IID('{BC55E0FC-ADC0-4DF6-9F2A-5CD35E4F5A75}')
	coclass_clsid = IID('{6DFC79D0-66CD-483F-AF0E-DBEA40C86AAC}')

	# Result is of type INFModelParams
	def Add(self, pINFModel=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pINFModel
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')
		return ret

	def Delete(self, pINFModelParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pINFModelParams
			)

	# Result is of type INFModel
	def Get(self, pINFModelParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pINFModelParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{35E59851-3F5C-40B3-9613-BCC32E3B97B8}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type INFModelsParams
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{85830213-6564-4BBA-95DD-246624D1A4D2}')
		return ret

	def Update(self, pINFModel=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pINFModel
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INatureOfAssessee(DispatchBaseClass):
	'INatureOfAssessee Interface'
	CLSID = IID('{69A099F3-3B67-46A2-A4EB-6DC399C64078}')
	coclass_clsid = IID('{2E43D661-7B70-4889-95E8-63B49DF0CDFE}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"AssesseeType": (13, 2, (3, 0), (), "AssesseeType", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
	}
	_prop_map_put_ = {
		"AssesseeType": ((13, LCID, 4, 0),()),
		"Code": ((11, LCID, 4, 0),()),
		"Description": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INatureOfAssesseeParams(DispatchBaseClass):
	'INatureOfAssesseeParams Interface'
	CLSID = IID('{27D88079-2713-4D2E-94D4-3C6F14D18140}')
	coclass_clsid = IID('{31A74034-7CDC-4A30-AE5A-2F237201F390}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INatureOfAssesseesParams(DispatchBaseClass):
	'INatureOfAssesseesParams Interface'
	CLSID = IID('{CD0EAC7A-0E3F-4ED3-A9BF-42D4100A3FBB}')
	coclass_clsid = IID('{1CDABF4D-2512-4C50-8387-3D5661526475}')

	# Result is of type INatureOfAssesseeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{27D88079-2713-4D2E-94D4-3C6F14D18140}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type INatureOfAssesseeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{27D88079-2713-4D2E-94D4-3C6F14D18140}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{27D88079-2713-4D2E-94D4-3C6F14D18140}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{27D88079-2713-4D2E-94D4-3C6F14D18140}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class INatureOfAssesseesService(DispatchBaseClass):
	'INatureOfAssesseesService Interface'
	CLSID = IID('{A60820F4-BCF8-4153-8E22-34DDF1E4F1E9}')
	coclass_clsid = IID('{F3801C93-51D8-48E9-9018-0CAB9A4FCBC2}')

	# Result is of type INatureOfAssesseeParams
	def AddNatureOfAssessee(self, pINatureOfAssessee=defaultNamedNotOptArg):
		'AddNatureOfAssessee'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pINatureOfAssessee
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddNatureOfAssessee', '{27D88079-2713-4D2E-94D4-3C6F14D18140}')
		return ret

	def DeleteNatureOfAssessee(self, pINatureOfAssesseeParams=defaultNamedNotOptArg):
		'DeleteNatureOfAssessee'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pINatureOfAssesseeParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type INatureOfAssessee
	def GetNatureOfAssessee(self, pINatureOfAssesseeParams=defaultNamedNotOptArg):
		'GetNatureOfAssessee'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pINatureOfAssesseeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetNatureOfAssessee', '{69A099F3-3B67-46A2-A4EB-6DC399C64078}')
		return ret

	# Result is of type INatureOfAssesseesParams
	def GetNatureOfAssesseeList(self):
		'GetNatureOfAssesseeList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetNatureOfAssesseeList', '{CD0EAC7A-0E3F-4ED3-A9BF-42D4100A3FBB}')
		return ret

	def UpdateNatureOfAssessee(self, pINatureOfAssessee=defaultNamedNotOptArg):
		'UpdateNatureOfAssessee'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pINatureOfAssessee
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INotaFiscalCFOP(DispatchBaseClass):
	'INotaFiscalCFOP Interface'
	CLSID = IID('{AFFB904C-0D52-4359-B44B-FB594DC5618A}')
	coclass_clsid = IID('{9A38EECB-D61C-469C-9425-C66BAAA0623E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, ID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (11, 0), ((3, 0),),ID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(11, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Application": (4, 2, (8, 0), (), "Application", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (3, 2, (8, 0), (), "Code", None),
		"Description": (2, 2, (8, 0), (), "Description", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Application": ((4, LCID, 4, 0),()),
		"Code": ((3, LCID, 4, 0),()),
		"Description": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INotaFiscalCST(DispatchBaseClass):
	'INotaFiscalCST Interface'
	CLSID = IID('{54E2DDD8-87FE-415D-AA8E-2AC62C936C7A}')
	coclass_clsid = IID('{7CD6F364-32D1-4862-8470-E27D69A03F08}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(9, LCID, 1, (8, 0), (),)

	def GetByKey(self, ID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (11, 0), ((3, 0),),ID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(10, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CSTCodeOutgoing": (13, 2, (8, 0), (), "CSTCodeOutgoing", None),
		"Code": (2, 2, (8, 0), (), "Code", None),
		"DescriptionOutgoing": (14, 2, (8, 0), (), "DescriptionOutgoing", None),
		"Situation": (3, 2, (8, 0), (), "Situation", None),
		"TaxCategory": (12, 2, (3, 0), (), "TaxCategory", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CSTCodeOutgoing": ((13, LCID, 4, 0),()),
		"Code": ((2, LCID, 4, 0),()),
		"DescriptionOutgoing": ((14, LCID, 4, 0),()),
		"Situation": ((3, LCID, 4, 0),()),
		"TaxCategory": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class INotaFiscalUsage(DispatchBaseClass):
	'INotaFiscalUsage Interface'
	CLSID = IID('{E2C5A384-883B-4963-A4A4-30C6F553818F}')
	coclass_clsid = IID('{2C3D3B79-8BCD-4CF4-981D-1033A54CBF17}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(9, LCID, 1, (8, 0), (),)

	def GetByKey(self, ID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (11, 0), ((3, 0),),ID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(10, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (8, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Description": (18, 2, (8, 0), (), "Description", None),
		"ID": (2, 2, (3, 0), (), "ID", None),
		"IncomingImportCFOPCode": (14, 2, (8, 0), (), "IncomingImportCFOPCode", None),
		"IncomingInStateCFOPCode": (12, 2, (8, 0), (), "IncomingInStateCFOPCode", None),
		"IncomingOutStateCFOPCode": (13, 2, (8, 0), (), "IncomingOutStateCFOPCode", None),
		"OutgoingExportCFOPCode": (17, 2, (8, 0), (), "OutgoingExportCFOPCode", None),
		"OutgoingInStateCFOPCode": (15, 2, (8, 0), (), "OutgoingInStateCFOPCode", None),
		"OutgoingOutStateCFOPCode": (16, 2, (8, 0), (), "OutgoingOutStateCFOPCode", None),
		"Usage": (3, 2, (8, 0), (), "Usage", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Description": ((18, LCID, 4, 0),()),
		"IncomingImportCFOPCode": ((14, LCID, 4, 0),()),
		"IncomingInStateCFOPCode": ((12, LCID, 4, 0),()),
		"IncomingOutStateCFOPCode": ((13, LCID, 4, 0),()),
		"OutgoingExportCFOPCode": ((17, LCID, 4, 0),()),
		"OutgoingInStateCFOPCode": ((15, LCID, 4, 0),()),
		"OutgoingOutStateCFOPCode": ((16, LCID, 4, 0),()),
		"Usage": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IOccurenceCode(DispatchBaseClass):
	'IOccurenceCode Interface'
	CLSID = IID('{04305B71-95D2-4327-B7A5-ED12DFB5FB1B}')
	coclass_clsid = IID('{2A2351A9-3BB7-4FD0-807C-2D1FEAB7477D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"IsMovement": (15, 2, (3, 0), (), "IsMovement", None),
		"Note": (13, 2, (8, 0), (), "Note", None),
		"RequestedBoeStatus": (14, 2, (3, 0), (), "RequestedBoeStatus", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"Description": ((12, LCID, 4, 0),()),
		"IsMovement": ((15, LCID, 4, 0),()),
		"Note": ((13, LCID, 4, 0),()),
		"RequestedBoeStatus": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IOccurenceCodeParams(DispatchBaseClass):
	'IOccurenceCodeParams Interface'
	CLSID = IID('{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')
	coclass_clsid = IID('{62CDCF16-DA97-4440-AED9-3C1FB8C60D4B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"IsMovement": (15, 2, (3, 0), (), "IsMovement", None),
		"Note": (13, 2, (8, 0), (), "Note", None),
		"RequestedBoeStatus": (14, 2, (3, 0), (), "RequestedBoeStatus", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
		"Code": ((11, LCID, 4, 0),()),
		"IsMovement": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IOccurenceCodeParamsCollection(DispatchBaseClass):
	'IOccurenceCodeParamsCollection Interface'
	CLSID = IID('{116B0B02-4096-48F9-A00C-E99E6EE7ADA1}')
	coclass_clsid = IID('{D178B341-234B-4CEC-AB38-5D2227C64DF3}')

	# Result is of type IOccurenceCodeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IOccurenceCodeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IOccurrenceCodesService(DispatchBaseClass):
	'IOccurrenceCodesService Interface'
	CLSID = IID('{BB817262-453B-4151-9F56-BFD987164133}')
	coclass_clsid = IID('{9A0F5F4B-EE27-4C5D-8BC0-09F916CF962C}')

	# Result is of type IOccurenceCodeParams
	def Add(self, pIOccurenceCode=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIOccurenceCode
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')
		return ret

	def Delete(self, pIOccurenceCodeParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIOccurenceCodeParams
			)

	# Result is of type IOccurenceCode
	def Get(self, pIOccurenceCodeParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIOccurenceCodeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{04305B71-95D2-4327-B7A5-ED12DFB5FB1B}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IOccurenceCodeParamsCollection
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{116B0B02-4096-48F9-A00C-E99E6EE7ADA1}')
		return ret

	def Update(self, pIOccurenceCode=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIOccurenceCode
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IOpenningBalanceAccount(DispatchBaseClass):
	'IOpenningBalanceAccount Interface'
	CLSID = IID('{31BF39D4-A4A4-4FF6-A946-D7DFB4B37D5D}')
	coclass_clsid = IID('{6749C3DD-5643-464C-82AB-CEE67CC78C9C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Date": (11, 2, (7, 0), (), "Date", None),
		"Details": (14, 2, (8, 0), (), "Details", None),
		"OpenBalanceAccount": (10, 2, (8, 0), (), "OpenBalanceAccount", None),
		"Ref1": (12, 2, (8, 0), (), "Ref1", None),
		"Ref2": (13, 2, (8, 0), (), "Ref2", None),
	}
	_prop_map_put_ = {
		"Date": ((11, LCID, 4, 0),()),
		"Details": ((14, LCID, 4, 0),()),
		"OpenBalanceAccount": ((10, LCID, 4, 0),()),
		"Ref1": ((12, LCID, 4, 0),()),
		"Ref2": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IOriginalItem(DispatchBaseClass):
	'IOriginalItem Interface'
	CLSID = IID('{4631570A-DAE1-43BB-9E4A-BA9957E593E1}')
	coclass_clsid = IID('{3DAD979D-9F98-4BBA-8566-7789FD6C8615}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		# Method 'AlternativeItems' returns object of type 'IAlternativeItems'
		"AlternativeItems": (12, 2, (9, 0), (), "AlternativeItems", '{416CFADF-9DA6-47BD-A490-09AC890FC530}'),
		"ItemCode": (10, 2, (8, 0), (), "ItemCode", None),
		"ItemName": (11, 2, (8, 0), (), "ItemName", None),
	}
	_prop_map_put_ = {
		"ItemCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IOriginalItemParams(DispatchBaseClass):
	'IOriginalItemParams Interface'
	CLSID = IID('{BC7EF5B4-EEA5-4C83-8478-FBC484133A79}')
	coclass_clsid = IID('{5421B2C4-A3D9-4965-9ED8-1A0BEEECCD5C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ItemCode": (10, 2, (8, 0), (), "ItemCode", None),
		"ItemName": (11, 2, (8, 0), (), "ItemName", None),
	}
	_prop_map_put_ = {
		"ItemCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPackagesTypes(DispatchBaseClass):
	'IPackagesTypes Interface'
	CLSID = IID('{CE69987E-8F99-4FC1-8C86-837E5246AFA2}')
	coclass_clsid = IID('{84FAFD4C-5213-4CB8-9F2F-7FECB428F0ED}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (2, 2, (3, 0), (), "Code", None),
		"Type": (1, 2, (8, 0), (), "Type", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Type": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPartnersSetup(DispatchBaseClass):
	'IPartnersSetup Interface'
	CLSID = IID('{4DB4395A-231C-4BE3-B582-F6C7C70D109E}')
	coclass_clsid = IID('{28C5094B-E595-4D16-BB84-07C23357EDA0}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DefaultRelationship": (11, 2, (3, 0), (), "DefaultRelationship", None),
		"Details": (13, 2, (8, 0), (), "Details", None),
		"Name": (10, 2, (8, 0), (), "Name", None),
		"RelatedBP": (12, 2, (8, 0), (), "RelatedBP", None),
	}
	_prop_map_put_ = {
		"DefaultRelationship": ((11, LCID, 4, 0),()),
		"Details": ((13, LCID, 4, 0),()),
		"Name": ((10, LCID, 4, 0),()),
		"RelatedBP": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPartnersSetupParams(DispatchBaseClass):
	'IPartnersSetupParams Interface'
	CLSID = IID('{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')
	coclass_clsid = IID('{00F3FE74-2DDE-4095-888D-A0E7D4BA83AC}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DefaultRelationship": (12, 2, (3, 0), (), "DefaultRelationship", None),
		"Details": (14, 2, (8, 0), (), "Details", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"PartnerID": (10, 2, (3, 0), (), "PartnerID", None),
		"RelatedBP": (13, 2, (8, 0), (), "RelatedBP", None),
	}
	_prop_map_put_ = {
		"PartnerID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPartnersSetupsParams(DispatchBaseClass):
	'IPartnersSetupsParams Interface'
	CLSID = IID('{65C62A16-791E-4D58-A0F9-1ED312BE7ACB}')
	coclass_clsid = IID('{A64105B1-0FB5-47EA-852E-A9975E5A5722}')

	# Result is of type IPartnersSetupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IPartnersSetupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPartnersSetupsService(DispatchBaseClass):
	'IPartnersSetupsService Interface'
	CLSID = IID('{FCB4B06C-8747-4678-85EB-4F28B51A88C8}')
	coclass_clsid = IID('{15DB95C7-BC17-4B52-94E3-E8D252DB6F03}')

	# Result is of type IPartnersSetupParams
	def Add(self, pIPartnersSetup=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIPartnersSetup
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')
		return ret

	def Delete(self, pIPartnersSetupParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIPartnersSetupParams
			)

	# Result is of type IPartnersSetup
	def Get(self, pIPartnersSetupParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIPartnersSetupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{4DB4395A-231C-4BE3-B582-F6C7C70D109E}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IPartnersSetupsParams
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{65C62A16-791E-4D58-A0F9-1ED312BE7ACB}')
		return ret

	def Update(self, pIPartnersSetup=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIPartnersSetup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPathAdmin(DispatchBaseClass):
	'IPathAdmin Interface'
	CLSID = IID('{029D7691-D339-4790-9D8A-652C86A30458}')
	coclass_clsid = IID('{3FE3132C-CA33-4338-A4C7-140952E59D31}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AttachmentsFolderPath": (8, 2, (8, 0), (), "AttachmentsFolderPath", None),
		"ExtensionsFolderPath": (9, 2, (8, 0), (), "ExtensionsFolderPath", None),
		"PicturesFolderPath": (7, 2, (8, 0), (), "PicturesFolderPath", None),
		"PrintId": (10, 2, (8, 0), (), "PrintId", None),
		"WordTemplateFolderPath": (6, 2, (8, 0), (), "WordTemplateFolderPath", None),
	}
	_prop_map_put_ = {
		"AttachmentsFolderPath": ((8, LCID, 4, 0),()),
		"ExtensionsFolderPath": ((9, LCID, 4, 0),()),
		"PicturesFolderPath": ((7, LCID, 4, 0),()),
		"WordTemplateFolderPath": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPaymentBlock(DispatchBaseClass):
	'IPaymentBlock Interface'
	CLSID = IID('{F6964AD5-EB4F-4E38-824E-60026EA9F159}')
	coclass_clsid = IID('{3D580E7A-74D7-48C1-854B-269EFC3B7F59}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"PaymentBlockCode": (11, 2, (8, 0), (), "PaymentBlockCode", None),
	}
	_prop_map_put_ = {
		"PaymentBlockCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPaymentBlockParams(DispatchBaseClass):
	'IPaymentBlockParams Interface'
	CLSID = IID('{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')
	coclass_clsid = IID('{07C983CC-2615-4105-A114-AB0094DBD192}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"PaymentBlockCode": (11, 2, (8, 0), (), "PaymentBlockCode", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPaymentBlocksParams(DispatchBaseClass):
	'IPaymentBlocksParams Interface'
	CLSID = IID('{954AC9A0-5402-436F-A20B-38E093F0A636}')
	coclass_clsid = IID('{9CE26B68-F839-4799-A385-D31DDAB92BEB}')

	# Result is of type IPaymentBlockParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IPaymentBlockParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPaymentBlocksService(DispatchBaseClass):
	'IPaymentBlocksService Interface'
	CLSID = IID('{F72D84B1-6F70-44CD-8B91-2FC481ADFE2E}')
	coclass_clsid = IID('{4DBA16CD-1221-4A1F-90C3-E2472532E820}')

	# Result is of type IPaymentBlockParams
	def AddPaymentBlock(self, pIPaymentBlock=defaultNamedNotOptArg):
		'AddPaymentBlock'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIPaymentBlock
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddPaymentBlock', '{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')
		return ret

	def DeletePaymentBlock(self, pIPaymentBlockParams=defaultNamedNotOptArg):
		'DeletePaymentBlock'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIPaymentBlockParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IPaymentBlock
	def GetPaymentBlock(self, pIPaymentBlockParams=defaultNamedNotOptArg):
		'GetPaymentBlock'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIPaymentBlockParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetPaymentBlock', '{F6964AD5-EB4F-4E38-824E-60026EA9F159}')
		return ret

	# Result is of type IPaymentBlocksParams
	def GetPaymentBlockList(self):
		'GetPaymentBlockList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetPaymentBlockList', '{954AC9A0-5402-436F-A20B-38E093F0A636}')
		return ret

	def UpdatePaymentBlock(self, pIPaymentBlock=defaultNamedNotOptArg):
		'UpdatePaymentBlock'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIPaymentBlock
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPaymentRunExport(DispatchBaseClass):
	'IPaymentRunExport Interface'
	CLSID = IID('{9020ED56-6B7D-4FAC-8D93-B185D1E65A59}')
	coclass_clsid = IID('{856AB71E-0D54-4BA5-95CA-7135D77040EC}')

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(82, LCID, 1, (8, 0), (),)

	def GetByKey(self, PaymentRunExportCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (11, 0), ((3, 0),),PaymentRunExportCode
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(83, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save the object into xml file'
		return self._ApplyTypes_(4, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		"AdditionalIdNumber": (64, 2, (8, 0), (), "AdditionalIdNumber", None),
		"BankAccount": (30, 2, (8, 0), (), "BankAccount", None),
		"BankCode": (32, 2, (8, 0), (), "BankCode", None),
		"BankCountry": (31, 2, (8, 0), (), "BankCountry", None),
		"BankIBAN": (33, 2, (8, 0), (), "BankIBAN", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (3, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CollectionAuthorization": (45, 2, (3, 0), (), "CollectionAuthorization", None),
		"CompIsrBillerID": (62, 2, (8, 0), (), "CompIsrBillerID", None),
		"CompanyAddress": (60, 2, (8, 0), (), "CompanyAddress", None),
		"CompanyBlock": (86, 2, (8, 0), (), "CompanyBlock", None),
		"CompanyCity": (87, 2, (8, 0), (), "CompanyCity", None),
		"CompanyCounty": (88, 2, (8, 0), (), "CompanyCounty", None),
		"CompanyName": (59, 2, (8, 0), (), "CompanyName", None),
		"CompanyState": (89, 2, (8, 0), (), "CompanyState", None),
		"CompanyStreet": (90, 2, (8, 0), (), "CompanyStreet", None),
		"CompanyTaxNum": (12, 2, (8, 0), (), "CompanyTaxNum", None),
		"CompanyZipCode": (91, 2, (8, 0), (), "CompanyZipCode", None),
		"Countery": (11, 2, (8, 0), (), "Countery", None),
		"Currency": (35, 2, (8, 0), (), "Currency", None),
		"CustomerNum": (7, 2, (8, 0), (), "CustomerNum", None),
		"DebitMemo": (73, 2, (3, 0), (), "DebitMemo", None),
		"DocAmountForign": (38, 2, (5, 0), (), "DocAmountForign", None),
		"DocAmountLocal": (36, 2, (5, 0), (), "DocAmountLocal", None),
		"DocCashDiscount": (39, 2, (5, 0), (), "DocCashDiscount", None),
		"DocCashDiscountForign": (40, 2, (5, 0), (), "DocCashDiscountForign", None),
		"DocCurrnecy": (37, 2, (8, 0), (), "DocCurrnecy", None),
		"DocNum": (9, 2, (3, 0), (), "DocNum", None),
		"DocNumOffieldPaid": (41, 2, (3, 0), (), "DocNumOffieldPaid", None),
		"DocRate": (42, 2, (5, 0), (), "DocRate", None),
		"EUInternalTransfer": (74, 2, (3, 0), (), "EUInternalTransfer", None),
		"FilePath": (75, 2, (8, 0), (), "FilePath", None),
		"FiscalYear": (10, 2, (7, 0), (), "FiscalYear", None),
		"FormatName": (81, 2, (8, 0), (), "FormatName", None),
		"FreeText1": (99, 2, (8, 0), (), "FreeText1", None),
		"FreeText2": (100, 2, (8, 0), (), "FreeText2", None),
		"FreeText3": (101, 2, (8, 0), (), "FreeText3", None),
		"GLAccount": (34, 2, (8, 0), (), "GLAccount", None),
		"InstructionKey": (57, 2, (8, 0), (), "InstructionKey", None),
		# Method 'Lines' returns object of type 'IPaymentRunExport_Lines'
		"Lines": (2, 2, (9, 0), (), "Lines", '{917BA077-4D88-46A8-B78A-E396315D7E59}'),
		"OrderingParty": (76, 2, (8, 0), (), "OrderingParty", None),
		"OrganizationNumber": (65, 2, (8, 0), (), "OrganizationNumber", None),
		"PayeeBankAccount": (24, 2, (8, 0), (), "PayeeBankAccount", None),
		"PayeeBankBISR": (52, 2, (3, 0), (), "PayeeBankBISR", None),
		"PayeeBankBlock": (49, 2, (8, 0), (), "PayeeBankBlock", None),
		"PayeeBankBranch": (66, 2, (8, 0), (), "PayeeBankBranch", None),
		"PayeeBankCity": (21, 2, (8, 0), (), "PayeeBankCity", None),
		"PayeeBankCode": (25, 2, (8, 0), (), "PayeeBankCode", None),
		"PayeeBankCountry": (23, 2, (8, 0), (), "PayeeBankCountry", None),
		"PayeeBankCounty": (50, 2, (8, 0), (), "PayeeBankCounty", None),
		"PayeeBankCtrlKey": (26, 2, (8, 0), (), "PayeeBankCtrlKey", None),
		"PayeeBankHouseBank": (48, 2, (3, 0), (), "PayeeBankHouseBank", None),
		"PayeeBankIBAN": (28, 2, (8, 0), (), "PayeeBankIBAN", None),
		"PayeeBankName": (19, 2, (8, 0), (), "PayeeBankName", None),
		"PayeeBankNextCheckNumber": (47, 2, (3, 0), (), "PayeeBankNextCheckNumber", None),
		"PayeeBankPostOffice": (46, 2, (3, 0), (), "PayeeBankPostOffice", None),
		"PayeeBankState": (51, 2, (8, 0), (), "PayeeBankState", None),
		"PayeeBankStreet": (22, 2, (8, 0), (), "PayeeBankStreet", None),
		"PayeeBankSwiftNum": (27, 2, (8, 0), (), "PayeeBankSwiftNum", None),
		"PayeeBankUserNum1": (53, 2, (8, 0), (), "PayeeBankUserNum1", None),
		"PayeeBankUserNum2": (54, 2, (8, 0), (), "PayeeBankUserNum2", None),
		"PayeeBankUserNum3": (55, 2, (8, 0), (), "PayeeBankUserNum3", None),
		"PayeeBankUserNum4": (56, 2, (8, 0), (), "PayeeBankUserNum4", None),
		"PayeeBankZip": (20, 2, (8, 0), (), "PayeeBankZip", None),
		"PayeeCity": (15, 2, (8, 0), (), "PayeeCity", None),
		"PayeeCountry": (17, 2, (8, 0), (), "PayeeCountry", None),
		"PayeeName": (13, 2, (8, 0), (), "PayeeName", None),
		"PayeePostalCode": (14, 2, (8, 0), (), "PayeePostalCode", None),
		"PayeeReferenceDetails": (80, 2, (8, 0), (), "PayeeReferenceDetails", None),
		"PayeeState": (18, 2, (8, 0), (), "PayeeState", None),
		"PayeeStreet": (16, 2, (8, 0), (), "PayeeStreet", None),
		"PayeeTaxNumber": (78, 2, (8, 0), (), "PayeeTaxNumber", None),
		"PaymentBankBranch": (67, 2, (8, 0), (), "PaymentBankBranch", None),
		"PaymentBankCharges": (92, 2, (8, 0), (), "PaymentBankCharges", None),
		"PaymentBankChargesAllocationCode": (97, 2, (8, 0), (), "PaymentBankChargesAllocationCode", None),
		"PaymentBankControlKey": (77, 2, (8, 0), (), "PaymentBankControlKey", None),
		"PaymentBankUserNo1": (93, 2, (8, 0), (), "PaymentBankUserNo1", None),
		"PaymentBankUserNo2": (94, 2, (8, 0), (), "PaymentBankUserNo2", None),
		"PaymentBankUserNo3": (95, 2, (8, 0), (), "PaymentBankUserNo3", None),
		"PaymentBankUserNo4": (96, 2, (8, 0), (), "PaymentBankUserNo4", None),
		"PaymentDonewithCheck": (85, 2, (3, 0), (), "PaymentDonewithCheck", None),
		"PaymentFormat": (58, 2, (8, 0), (), "PaymentFormat", None),
		"PaymentKeyCode": (79, 2, (8, 0), (), "PaymentKeyCode", None),
		"PaymentMethod": (8, 2, (8, 0), (), "PaymentMethod", None),
		"PaymentOrderNum": (98, 2, (3, 0), (), "PaymentOrderNum", None),
		"PostingDate": (29, 2, (7, 0), (), "PostingDate", None),
		"RowType": (102, 2, (3, 0), (), "RowType", None),
		"RunDate": (5, 2, (7, 0), (), "RunDate", None),
		"Status": (61, 2, (3, 0), (), "Status", None),
		"UserDepartment": (72, 2, (3, 0), (), "UserDepartment", None),
		"UserEMail": (69, 2, (8, 0), (), "UserEMail", None),
		"UserFaxNumber": (71, 2, (8, 0), (), "UserFaxNumber", None),
		"UserMobilePhoneNumber": (70, 2, (8, 0), (), "UserMobilePhoneNumber", None),
		"UserName": (68, 2, (8, 0), (), "UserName", None),
		"VendorIsrBillerID": (63, 2, (8, 0), (), "VendorIsrBillerID", None),
		"VendorNum": (6, 2, (8, 0), (), "VendorNum", None),
		"WizCode": (44, 2, (3, 0), (), "WizCode", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPaymentRunExport_Lines(DispatchBaseClass):
	'IPaymentRunExport_Lines Interface'
	CLSID = IID('{917BA077-4D88-46A8-B78A-E396315D7E59}')
	coclass_clsid = IID('{A2A9F005-92C0-4949-B2D7-92B7D8AAA784}')

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPDebitPayableAccount": (16, 2, (8, 0), (), "BPDebitPayableAccount", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"CustomerNumber": (8, 2, (8, 0), (), "CustomerNumber", None),
		"DateOfPaymentRun": (5, 2, (7, 0), (), "DateOfPaymentRun", None),
		"DocumentCurrency": (17, 2, (8, 0), (), "DocumentCurrency", None),
		"DocumentLocalCurrency": (26, 2, (8, 0), (), "DocumentLocalCurrency", None),
		"DocumentNumber": (29, 2, (3, 0), (), "DocumentNumber", None),
		"DocumentObjectType": (13, 2, (3, 0), (), "DocumentObjectType", None),
		"DocumentObjectTypeEx": (28, 2, (8, 0), (), "DocumentObjectTypeEx", None),
		"DocumentPaymentTerms": (24, 2, (3, 0), (), "DocumentPaymentTerms", None),
		"DocumentPostingDate": (14, 2, (7, 0), (), "DocumentPostingDate", None),
		"DocumentRate": (18, 2, (5, 0), (), "DocumentRate", None),
		"DocumentRemarks": (23, 2, (8, 0), (), "DocumentRemarks", None),
		"DocumentTaxAmount": (21, 2, (5, 0), (), "DocumentTaxAmount", None),
		"DocumentTaxAmountFC": (22, 2, (5, 0), (), "DocumentTaxAmountFC", None),
		"DocumentTaxDate": (15, 2, (7, 0), (), "DocumentTaxDate", None),
		"DocumentTotal": (19, 2, (5, 0), (), "DocumentTotal", None),
		"DocumentTotalFC": (20, 2, (5, 0), (), "DocumentTotalFC", None),
		"FiscalYear": (11, 2, (7, 0), (), "FiscalYear", None),
		"FreeText1": (32, 2, (8, 0), (), "FreeText1", None),
		"FreeText2": (33, 2, (8, 0), (), "FreeText2", None),
		"FreeText3": (34, 2, (8, 0), (), "FreeText3", None),
		"PaymentDocNum": (10, 2, (3, 0), (), "PaymentDocNum", None),
		"PaymentDocReference": (25, 2, (8, 0), (), "PaymentDocReference", None),
		"PaymentMeans": (9, 2, (8, 0), (), "PaymentMeans", None),
		"PaymentNumber": (30, 2, (3, 0), (), "PaymentNumber", None),
		"PaymentOrderNum": (31, 2, (3, 0), (), "PaymentOrderNum", None),
		"PaymentTermsPeriod": (27, 2, (3, 0), (), "PaymentTermsPeriod", None),
		"PaymentWizardCode": (6, 2, (8, 0), (), "PaymentWizardCode", None),
		"RowNumber": (4, 2, (3, 0), (), "RowNumber", None),
		"VendorNumber": (7, 2, (8, 0), (), "VendorNumber", None),
		"VendorRefNum": (12, 2, (8, 0), (), "VendorRefNum", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPaymentTermsTypes(DispatchBaseClass):
	'IPaymentTermsTypes Interface'
	CLSID = IID('{F09A4CB0-F8CA-4342-A44D-82DE3395B011}')
	coclass_clsid = IID('{403E32F9-EBDD-4528-89C2-FE8BE8F7F0A6}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(26, LCID, 1, (8, 0), (),)

	def GetByKey(self, GroupNum=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),GroupNum
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(27, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"BaselineDate": (22, 2, (3, 0), (), "BaselineDate", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CreditLimit": (14, 2, (5, 0), (), "CreditLimit", None),
		"DiscountCode": (20, 2, (8, 0), (), "DiscountCode", None),
		"DunningCode": (21, 2, (8, 0), (), "DunningCode", None),
		"GeneralDiscount": (15, 2, (5, 0), (), "GeneralDiscount", None),
		"GroupNumber": (9, 2, (3, 0), (), "GroupNumber", None),
		"InterestOnArrears": (16, 2, (5, 0), (), "InterestOnArrears", None),
		"LoadLimit": (18, 2, (5, 0), (), "LoadLimit", None),
		"NumberOfAdditionalDays": (13, 2, (3, 0), (), "NumberOfAdditionalDays", None),
		"NumberOfAdditionalMonths": (12, 2, (3, 0), (), "NumberOfAdditionalMonths", None),
		"NumberOfInstallments": (23, 2, (3, 0), (), "NumberOfInstallments", None),
		"NumberOfToleranceDays": (24, 2, (3, 0), (), "NumberOfToleranceDays", None),
		"OpenReceipt": (19, 2, (3, 0), (), "OpenReceipt", None),
		"PaymentTermsGroupName": (10, 2, (8, 0), (), "PaymentTermsGroupName", None),
		"PriceListNo": (17, 2, (3, 0), (), "PriceListNo", None),
		"StartFrom": (11, 2, (3, 0), (), "StartFrom", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (25, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BaselineDate": ((22, LCID, 4, 0),()),
		"CreditLimit": ((14, LCID, 4, 0),()),
		"DiscountCode": ((20, LCID, 4, 0),()),
		"DunningCode": ((21, LCID, 4, 0),()),
		"GeneralDiscount": ((15, LCID, 4, 0),()),
		"InterestOnArrears": ((16, LCID, 4, 0),()),
		"LoadLimit": ((18, LCID, 4, 0),()),
		"NumberOfAdditionalDays": ((13, LCID, 4, 0),()),
		"NumberOfAdditionalMonths": ((12, LCID, 4, 0),()),
		"NumberOfToleranceDays": ((24, LCID, 4, 0),()),
		"OpenReceipt": ((19, LCID, 4, 0),()),
		"PaymentTermsGroupName": ((10, LCID, 4, 0),()),
		"PriceListNo": ((17, LCID, 4, 0),()),
		"StartFrom": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPayments(DispatchBaseClass):
	'IPayments Interface'
	CLSID = IID('{E79D3C41-BFE7-4C5A-B586-4F627E021A1C}')
	coclass_clsid = IID('{A52ED4BA-1C19-4553-9A60-D69B653E8CB5}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(43, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(44, LCID, 1, (3, 0), (),)

	def GetApprovalTemplates(self):
		'method GetApprovalTemplates'
		return self._oleobj_.InvokeTypes(104, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(76, LCID, 1, (8, 0), (),)

	def GetByKey(self, RctEntry=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((3, 0),),RctEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(42, LCID, 1, (3, 0), (),)

	def SaveDraftToDocument(self):
		'method SaveDraftToDocument'
		return self._oleobj_.InvokeTypes(103, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(77, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'AccountPayments' returns object of type 'IPayments_Accounts'
		"AccountPayments": (39, 2, (9, 0), (), "AccountPayments", '{231A13D7-5DA8-4467-A263-FDE84A268AC9}'),
		"Address": (13, 2, (8, 0), (), "Address", None),
		"ApplyVAT": (31, 2, (3, 0), (), "ApplyVAT", None),
		"AuthorizationStatus": (106, 2, (3, 0), (), "AuthorizationStatus", None),
		"BPLID": (111, 2, (3, 0), (), "BPLID", None),
		"BPLName": (112, 2, (8, 0), (), "BPLName", None),
		"BankAccount": (35, 2, (8, 0), (), "BankAccount", None),
		"BankChargeAmount": (78, 2, (5, 0), (), "BankChargeAmount", None),
		"BankChargeAmountInFC": (79, 2, (5, 0), (), "BankChargeAmountInFC", None),
		"BankChargeAmountInSC": (80, 2, (5, 0), (), "BankChargeAmountInSC", None),
		"BankCode": (34, 2, (8, 0), (), "BankCode", None),
		# Method 'BillOfExchange' returns object of type 'IBillOfExchange'
		"BillOfExchange": (54, 2, (9, 0), (), "BillOfExchange", '{741AA803-AB33-4FD7-B664-63116291D6CE}'),
		"BillOfExchangeAgent": (57, 2, (8, 0), (), "BillOfExchangeAgent", None),
		"BillOfExchangeAmount": (52, 2, (5, 0), (), "BillOfExchangeAmount", None),
		"BillOfExchangeAmountFC": (55, 2, (5, 0), (), "BillOfExchangeAmountFC", None),
		"BillOfExchangeAmountSC": (56, 2, (5, 0), (), "BillOfExchangeAmountSC", None),
		"BillofExchangeStatus": (53, 2, (3, 0), (), "BillofExchangeStatus", None),
		"BoeAccount": (51, 2, (8, 0), (), "BoeAccount", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (45, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Cancelled": (92, 2, (3, 0), (), "Cancelled", None),
		"CardCode": (11, 2, (8, 0), (), "CardCode", None),
		"CardName": (12, 2, (8, 0), (), "CardName", None),
		"CashAccount": (14, 2, (8, 0), (), "CashAccount", None),
		"CashSum": (16, 2, (5, 0), (), "CashSum", None),
		"CashSumFC": (49, 2, (5, 0), (), "CashSumFC", None),
		"CashSumSys": (50, 2, (5, 0), (), "CashSumSys", None),
		"CheckAccount": (17, 2, (8, 0), (), "CheckAccount", None),
		# Method 'Checks' returns object of type 'IPayments_Checks'
		"Checks": (36, 2, (9, 0), (), "Checks", '{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}'),
		"ContactPersonCode": (30, 2, (3, 0), (), "ContactPersonCode", None),
		"ControlAccount": (100, 2, (8, 0), (), "ControlAccount", None),
		"CounterReference": (26, 2, (8, 0), (), "CounterReference", None),
		# Method 'CreditCards' returns object of type 'IPayments_CreditCards'
		"CreditCards": (38, 2, (9, 0), (), "CreditCards", '{CC3579ED-1C61-4864-8E51-208A3DCDFC93}'),
		"DeductionPercent": (47, 2, (5, 0), (), "DeductionPercent", None),
		"DeductionSum": (48, 2, (5, 0), (), "DeductionSum", None),
		"DocCurrency": (15, 2, (8, 0), (), "DocCurrency", None),
		"DocDate": (10, 2, (7, 0), (), "DocDate", None),
		"DocEntry": (73, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (6, 2, (3, 0), (), "DocNum", None),
		"DocObjectCode": (72, 2, (3, 0), (), "DocObjectCode", None),
		"DocRate": (23, 2, (5, 0), (), "DocRate", None),
		"DocType": (71, 2, (3, 0), (), "DocType", None),
		"DocTypte": (7, 2, (3, 0), (), "DocTypte", None),
		"DueDate": (90, 2, (7, 0), (), "DueDate", None),
		"HandWritten": (8, 2, (3, 0), (), "HandWritten", None),
		# Method 'Invoices' returns object of type 'IPayments_Invoices'
		"Invoices": (37, 2, (9, 0), (), "Invoices", '{AB7947CF-8191-498D-8B3C-8E04A00957E7}'),
		"IsPayToBank": (70, 2, (3, 0), (), "IsPayToBank", None),
		"JournalRemarks": (28, 2, (8, 0), (), "JournalRemarks", None),
		"LocalCurrency": (22, 2, (3, 0), (), "LocalCurrency", None),
		"LocationCode": (91, 2, (3, 0), (), "LocationCode", None),
		"PayToBankAccountNo": (67, 2, (8, 0), (), "PayToBankAccountNo", None),
		"PayToBankBranch": (75, 2, (8, 0), (), "PayToBankBranch", None),
		"PayToBankCode": (74, 2, (8, 0), (), "PayToBankCode", None),
		"PayToBankCountry": (69, 2, (8, 0), (), "PayToBankCountry", None),
		"PayToCode": (68, 2, (8, 0), (), "PayToCode", None),
		"PaymentPriority": (65, 2, (3, 0), (), "PaymentPriority", None),
		"PaymentType": (83, 2, (3, 0), (), "PaymentType", None),
		# Method 'Payments_ApprovalRequests' returns object of type 'IPayments_ApprovalRequests'
		"Payments_ApprovalRequests": (105, 2, (9, 0), (), "Payments_ApprovalRequests", '{8276E7F7-9178-409D-88DB-5A8D41DED6E5}'),
		# Method 'PrimaryFormItems' returns object of type 'ICashFlowAssignments'
		"PrimaryFormItems": (102, 2, (9, 0), (), "PrimaryFormItems", '{A0307CBF-64B1-49E8-B60D-38803E20D107}'),
		"Printed": (9, 2, (3, 0), (), "Printed", None),
		"Proforma": (64, 2, (3, 0), (), "Proforma", None),
		"ProjectCode": (41, 2, (8, 0), (), "ProjectCode", None),
		"Reference1": (24, 2, (8, 0), (), "Reference1", None),
		"Reference2": (25, 2, (8, 0), (), "Reference2", None),
		"Remarks": (27, 2, (8, 0), (), "Remarks", None),
		"Series": (33, 2, (3, 0), (), "Series", None),
		"TaxDate": (32, 2, (7, 0), (), "TaxDate", None),
		"TaxGroup": (66, 2, (8, 0), (), "TaxGroup", None),
		"TransactionCode": (82, 2, (8, 0), (), "TransactionCode", None),
		"TransferAccount": (18, 2, (8, 0), (), "TransferAccount", None),
		"TransferDate": (20, 2, (7, 0), (), "TransferDate", None),
		"TransferRealAmount": (84, 2, (5, 0), (), "TransferRealAmount", None),
		"TransferReference": (21, 2, (8, 0), (), "TransferReference", None),
		"TransferSum": (19, 2, (5, 0), (), "TransferSum", None),
		"UnderOverpaymentdiffFC": (101, 2, (5, 0), (), "UnderOverpaymentdiffFC", None),
		"UnderOverpaymentdiffSC": (86, 2, (5, 0), (), "UnderOverpaymentdiffSC", None),
		"UnderOverpaymentdifference": (85, 2, (5, 0), (), "UnderOverpaymentdifference", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATRegNum": (113, 2, (8, 0), (), "VATRegNum", None),
		"VatDate": (81, 2, (7, 0), (), "VatDate", None),
		"WTAccount": (62, 2, (8, 0), (), "WTAccount", None),
		"WTAmount": (59, 2, (5, 0), (), "WTAmount", None),
		"WTAmountFC": (60, 2, (5, 0), (), "WTAmountFC", None),
		"WTAmountSC": (61, 2, (5, 0), (), "WTAmountSC", None),
		"WTCode": (58, 2, (8, 0), (), "WTCode", None),
		"WTTaxableAmount": (63, 2, (5, 0), (), "WTTaxableAmount", None),
		"WtBaseSum": (87, 2, (5, 0), (), "WtBaseSum", None),
		"WtBaseSumFC": (88, 2, (5, 0), (), "WtBaseSumFC", None),
		"WtBaseSumSC": (89, 2, (5, 0), (), "WtBaseSumSC", None),
	}
	_prop_map_put_ = {
		"Address": ((13, LCID, 4, 0),()),
		"ApplyVAT": ((31, LCID, 4, 0),()),
		"BPLID": ((111, LCID, 4, 0),()),
		"BankAccount": ((35, LCID, 4, 0),()),
		"BankChargeAmount": ((78, LCID, 4, 0),()),
		"BankCode": ((34, LCID, 4, 0),()),
		"BillOfExchangeAgent": ((57, LCID, 4, 0),()),
		"BillOfExchangeAmount": ((52, LCID, 4, 0),()),
		"BillofExchangeStatus": ((53, LCID, 4, 0),()),
		"BoeAccount": ((51, LCID, 4, 0),()),
		"CardCode": ((11, LCID, 4, 0),()),
		"CardName": ((12, LCID, 4, 0),()),
		"CashAccount": ((14, LCID, 4, 0),()),
		"CashSum": ((16, LCID, 4, 0),()),
		"CheckAccount": ((17, LCID, 4, 0),()),
		"ContactPersonCode": ((30, LCID, 4, 0),()),
		"ControlAccount": ((100, LCID, 4, 0),()),
		"CounterReference": ((26, LCID, 4, 0),()),
		"DeductionPercent": ((47, LCID, 4, 0),()),
		"DeductionSum": ((48, LCID, 4, 0),()),
		"DocCurrency": ((15, LCID, 4, 0),()),
		"DocDate": ((10, LCID, 4, 0),()),
		"DocNum": ((6, LCID, 4, 0),()),
		"DocObjectCode": ((72, LCID, 4, 0),()),
		"DocRate": ((23, LCID, 4, 0),()),
		"DocType": ((71, LCID, 4, 0),()),
		"DocTypte": ((7, LCID, 4, 0),()),
		"DueDate": ((90, LCID, 4, 0),()),
		"HandWritten": ((8, LCID, 4, 0),()),
		"IsPayToBank": ((70, LCID, 4, 0),()),
		"JournalRemarks": ((28, LCID, 4, 0),()),
		"LocalCurrency": ((22, LCID, 4, 0),()),
		"LocationCode": ((91, LCID, 4, 0),()),
		"PayToBankAccountNo": ((67, LCID, 4, 0),()),
		"PayToBankBranch": ((75, LCID, 4, 0),()),
		"PayToBankCode": ((74, LCID, 4, 0),()),
		"PayToBankCountry": ((69, LCID, 4, 0),()),
		"PayToCode": ((68, LCID, 4, 0),()),
		"PaymentPriority": ((65, LCID, 4, 0),()),
		"PaymentType": ((83, LCID, 4, 0),()),
		"Proforma": ((64, LCID, 4, 0),()),
		"ProjectCode": ((41, LCID, 4, 0),()),
		"Reference1": ((24, LCID, 4, 0),()),
		"Reference2": ((25, LCID, 4, 0),()),
		"Remarks": ((27, LCID, 4, 0),()),
		"Series": ((33, LCID, 4, 0),()),
		"TaxDate": ((32, LCID, 4, 0),()),
		"TaxGroup": ((66, LCID, 4, 0),()),
		"TransactionCode": ((82, LCID, 4, 0),()),
		"TransferAccount": ((18, LCID, 4, 0),()),
		"TransferDate": ((20, LCID, 4, 0),()),
		"TransferRealAmount": ((84, LCID, 4, 0),()),
		"TransferReference": ((21, LCID, 4, 0),()),
		"TransferSum": ((19, LCID, 4, 0),()),
		"VatDate": ((81, LCID, 4, 0),()),
		"WTAmount": ((59, LCID, 4, 0),()),
		"WTCode": ((58, LCID, 4, 0),()),
		"WtBaseSum": ((87, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPayments_Accounts(DispatchBaseClass):
	'IPayments_Accounts Interface'
	CLSID = IID('{231A13D7-5DA8-4467-A263-FDE84A268AC9}')
	coclass_clsid = IID('{0E77E5DB-93A3-4FCF-BB4B-BE8323F27387}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccountCode": (6, 2, (8, 0), (), "AccountCode", None),
		"AccountName": (11, 2, (8, 0), (), "AccountName", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"Decription": (9, 2, (8, 0), (), "Decription", None),
		"EqualizationVatAmount": (21, 2, (5, 0), (), "EqualizationVatAmount", None),
		"GrossAmount": (12, 2, (5, 0), (), "GrossAmount", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"LocationCode": (16, 2, (3, 0), (), "LocationCode", None),
		"ProfitCenter": (13, 2, (8, 0), (), "ProfitCenter", None),
		"ProfitCenter2": (17, 2, (8, 0), (), "ProfitCenter2", None),
		"ProfitCenter3": (18, 2, (8, 0), (), "ProfitCenter3", None),
		"ProfitCenter4": (19, 2, (8, 0), (), "ProfitCenter4", None),
		"ProfitCenter5": (20, 2, (8, 0), (), "ProfitCenter5", None),
		"ProjectCode": (14, 2, (8, 0), (), "ProjectCode", None),
		"SumPaid": (7, 2, (5, 0), (), "SumPaid", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VatAmount": (15, 2, (5, 0), (), "VatAmount", None),
		"VatGroup": (10, 2, (8, 0), (), "VatGroup", None),
	}
	_prop_map_put_ = {
		"AccountCode": ((6, LCID, 4, 0),()),
		"AccountName": ((11, LCID, 4, 0),()),
		"Decription": ((9, LCID, 4, 0),()),
		"GrossAmount": ((12, LCID, 4, 0),()),
		"ProfitCenter": ((13, LCID, 4, 0),()),
		"ProfitCenter2": ((17, LCID, 4, 0),()),
		"ProfitCenter3": ((18, LCID, 4, 0),()),
		"ProfitCenter4": ((19, LCID, 4, 0),()),
		"ProfitCenter5": ((20, LCID, 4, 0),()),
		"ProjectCode": ((14, LCID, 4, 0),()),
		"SumPaid": ((7, LCID, 4, 0),()),
		"VatAmount": ((15, LCID, 4, 0),()),
		"VatGroup": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPayments_ApprovalRequests(DispatchBaseClass):
	'IPayments_ApprovalRequests Interface'
	CLSID = IID('{8276E7F7-9178-409D-88DB-5A8D41DED6E5}')
	coclass_clsid = IID('{9BD8670D-B894-43A6-9CF7-F3C07E7DDCB6}')

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ApprovalTemplatesID": (4, 2, (3, 0), (), "ApprovalTemplatesID", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"Remarks": (5, 2, (8, 0), (), "Remarks", None),
	}
	_prop_map_put_ = {
		"Remarks": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPayments_Checks(DispatchBaseClass):
	'IPayments_Checks Interface'
	CLSID = IID('{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}')
	coclass_clsid = IID('{6155B8DA-5812-48F9-8955-67CE75857600}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AccounttNum": (10, 2, (8, 0), (), "AccounttNum", None),
		"BankCode": (8, 2, (8, 0), (), "BankCode", None),
		"Branch": (9, 2, (8, 0), (), "Branch", None),
		"CheckAbsEntry": (15, 2, (3, 0), (), "CheckAbsEntry", None),
		"CheckAccount": (16, 2, (8, 0), (), "CheckAccount", None),
		"CheckNumber": (7, 2, (3, 0), (), "CheckNumber", None),
		"CheckSum": (13, 2, (5, 0), (), "CheckSum", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"CountryCode": (14, 2, (8, 0), (), "CountryCode", None),
		"Details": (11, 2, (8, 0), (), "Details", None),
		"DueDate": (6, 2, (7, 0), (), "DueDate", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"ManualCheck": (17, 2, (3, 0), (), "ManualCheck", None),
		"Trnsfrable": (12, 2, (3, 0), (), "Trnsfrable", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AccounttNum": ((10, LCID, 4, 0),()),
		"BankCode": ((8, LCID, 4, 0),()),
		"Branch": ((9, LCID, 4, 0),()),
		"CheckAccount": ((16, LCID, 4, 0),()),
		"CheckNumber": ((7, LCID, 4, 0),()),
		"CheckSum": ((13, LCID, 4, 0),()),
		"CountryCode": ((14, LCID, 4, 0),()),
		"Details": ((11, LCID, 4, 0),()),
		"DueDate": ((6, LCID, 4, 0),()),
		"ManualCheck": ((17, LCID, 4, 0),()),
		"Trnsfrable": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPayments_CreditCards(DispatchBaseClass):
	'IPayments_CreditCards Interface'
	CLSID = IID('{CC3579ED-1C61-4864-8E51-208A3DCDFC93}')
	coclass_clsid = IID('{1C972937-3B53-45EE-9728-516996023C1A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AdditionalPaymentSum": (17, 2, (5, 0), (), "AdditionalPaymentSum", None),
		"CardValidUntil": (9, 2, (7, 0), (), "CardValidUntil", None),
		"ConfirmationNum": (21, 2, (8, 0), (), "ConfirmationNum", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"CreditAcct": (7, 2, (8, 0), (), "CreditAcct", None),
		"CreditCard": (6, 2, (3, 0), (), "CreditCard", None),
		"CreditCardNumber": (8, 2, (8, 0), (), "CreditCardNumber", None),
		"CreditSum": (18, 2, (5, 0), (), "CreditSum", None),
		"CreditType": (23, 2, (3, 0), (), "CreditType", None),
		"FirstPaymentDue": (15, 2, (7, 0), (), "FirstPaymentDue", None),
		"FirstPaymentSum": (16, 2, (5, 0), (), "FirstPaymentSum", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"NumOfCreditPayments": (22, 2, (3, 0), (), "NumOfCreditPayments", None),
		"NumOfPayments": (14, 2, (3, 0), (), "NumOfPayments", None),
		"OwnerIdNum": (11, 2, (8, 0), (), "OwnerIdNum", None),
		"OwnerPhone": (12, 2, (8, 0), (), "OwnerPhone", None),
		"PaymentMethodCode": (13, 2, (3, 0), (), "PaymentMethodCode", None),
		"SplitPayments": (24, 2, (3, 0), (), "SplitPayments", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VoucherNum": (10, 2, (8, 0), (), "VoucherNum", None),
	}
	_prop_map_put_ = {
		"AdditionalPaymentSum": ((17, LCID, 4, 0),()),
		"CardValidUntil": ((9, LCID, 4, 0),()),
		"ConfirmationNum": ((21, LCID, 4, 0),()),
		"CreditAcct": ((7, LCID, 4, 0),()),
		"CreditCard": ((6, LCID, 4, 0),()),
		"CreditCardNumber": ((8, LCID, 4, 0),()),
		"CreditSum": ((18, LCID, 4, 0),()),
		"CreditType": ((23, LCID, 4, 0),()),
		"FirstPaymentDue": ((15, LCID, 4, 0),()),
		"FirstPaymentSum": ((16, LCID, 4, 0),()),
		"NumOfCreditPayments": ((22, LCID, 4, 0),()),
		"NumOfPayments": ((14, LCID, 4, 0),()),
		"OwnerIdNum": ((11, LCID, 4, 0),()),
		"OwnerPhone": ((12, LCID, 4, 0),()),
		"PaymentMethodCode": ((13, LCID, 4, 0),()),
		"SplitPayments": ((24, LCID, 4, 0),()),
		"VoucherNum": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPayments_Invoices(DispatchBaseClass):
	'IPayments_Invoices Interface'
	CLSID = IID('{AB7947CF-8191-498D-8B3C-8E04A00957E7}')
	coclass_clsid = IID('{ADCC23F1-37CE-4327-BE13-88D1E14F8877}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AppliedFC": (8, 2, (5, 0), (), "AppliedFC", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"DiscountPercent": (13, 2, (5, 0), (), "DiscountPercent", None),
		"DistributionRule": (20, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (21, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (22, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (23, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (24, 2, (8, 0), (), "DistributionRule5", None),
		"DocEntry": (6, 2, (3, 0), (), "DocEntry", None),
		"DocLine": (11, 2, (3, 0), (), "DocLine", None),
		"InstallmentId": (15, 2, (3, 0), (), "InstallmentId", None),
		"InvoiceType": (12, 2, (3, 0), (), "InvoiceType", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"LinkDate": (19, 2, (7, 0), (), "LinkDate", None),
		"PaidSum": (14, 2, (5, 0), (), "PaidSum", None),
		"SumApplied": (7, 2, (5, 0), (), "SumApplied", None),
		"TotalDiscount": (25, 2, (5, 0), (), "TotalDiscount", None),
		"TotalDiscountFC": (26, 2, (5, 0), (), "TotalDiscountFC", None),
		"TotalDiscountSC": (27, 2, (5, 0), (), "TotalDiscountSC", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WitholdingTaxApplied": (16, 2, (5, 0), (), "WitholdingTaxApplied", None),
		"WitholdingTaxAppliedFC": (17, 2, (5, 0), (), "WitholdingTaxAppliedFC", None),
		"WitholdingTaxAppliedSC": (18, 2, (5, 0), (), "WitholdingTaxAppliedSC", None),
	}
	_prop_map_put_ = {
		"AppliedFC": ((8, LCID, 4, 0),()),
		"DiscountPercent": ((13, LCID, 4, 0),()),
		"DistributionRule": ((20, LCID, 4, 0),()),
		"DistributionRule2": ((21, LCID, 4, 0),()),
		"DistributionRule3": ((22, LCID, 4, 0),()),
		"DistributionRule4": ((23, LCID, 4, 0),()),
		"DistributionRule5": ((24, LCID, 4, 0),()),
		"DocEntry": ((6, LCID, 4, 0),()),
		"DocLine": ((11, LCID, 4, 0),()),
		"InstallmentId": ((15, LCID, 4, 0),()),
		"InvoiceType": ((12, LCID, 4, 0),()),
		"SumApplied": ((7, LCID, 4, 0),()),
		"TotalDiscount": ((25, LCID, 4, 0),()),
		"TotalDiscountFC": ((26, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPeriodCategory(DispatchBaseClass):
	'IPeriodCategory Interface'
	CLSID = IID('{1C764D4F-63DA-46FE-BD81-56548EEDB2F6}')
	coclass_clsid = IID('{6499CEB7-4CF2-48F6-93B7-93C949DBA246}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"APCashDiscountAccount": (35, 2, (8, 0), (), "APCashDiscountAccount", None),
		"APGainRealizedExchngeDif": (41, 2, (8, 0), (), "APGainRealizedExchngeDif", None),
		"APLossCashDiscountAccount": (36, 2, (8, 0), (), "APLossCashDiscountAccount", None),
		"APLossRealizedExchangeDif": (37, 2, (8, 0), (), "APLossRealizedExchangeDif", None),
		"ARCashDiscountAccount": (38, 2, (8, 0), (), "ARCashDiscountAccount", None),
		"ARGainRealizedExchngeDif": (42, 2, (8, 0), (), "ARGainRealizedExchngeDif", None),
		"ARLossRealizedExchangeDi": (39, 2, (8, 0), (), "ARLossRealizedExchangeDi", None),
		"AccountforCashReceipt": (11, 2, (8, 0), (), "AccountforCashReceipt", None),
		"AccountforCreditMemoPayme": (20, 2, (8, 0), (), "AccountforCreditMemoPayme", None),
		"AccountforOutgoingChecks": (10, 2, (8, 0), (), "AccountforOutgoingChecks", None),
		"AcountforOpeningWHBalance": (34, 2, (8, 0), (), "AcountforOpeningWHBalance", None),
		"AllocationAcc": (46, 2, (8, 0), (), "AllocationAcc", None),
		"BeginningofFinancialYear": (7, 2, (7, 0), (), "BeginningofFinancialYear", None),
		"BillofExchangeAccountsRece": (51, 2, (8, 0), (), "BillofExchangeAccountsRece", None),
		"BoEAccountsPayable": (56, 2, (8, 0), (), "BoEAccountsPayable", None),
		"BoEAccountsPayable2": (57, 2, (8, 0), (), "BoEAccountsPayable2", None),
		"CommissionAccountDefault": (14, 2, (8, 0), (), "CommissionAccountDefault", None),
		"CostOfGoodsSold": (45, 2, (8, 0), (), "CostOfGoodsSold", None),
		"CostofSaleRevOffsetAcct": (76, 2, (8, 0), (), "CostofSaleRevOffsetAcct", None),
		"CostofSaleRevaluationAcct": (68, 2, (8, 0), (), "CostofSaleRevaluationAcct", None),
		"CreditorsFollowUpAccount": (17, 2, (8, 0), (), "CreditorsFollowUpAccount", None),
		"CustBillofExchangeonC": (52, 2, (8, 0), (), "CustBillofExchangeonC", None),
		"CustomerBillofExchangePres": (53, 2, (8, 0), (), "CustomerBillofExchangePres", None),
		"CustomerBillofExchngeDisc": (54, 2, (8, 0), (), "CustomerBillofExchngeDisc", None),
		"CustomerDoubtfulDebtsAcct": (58, 2, (8, 0), (), "CustomerDoubtfulDebtsAcct", None),
		"CustomerDownPaymentsAccount": (49, 2, (8, 0), (), "CustomerDownPaymentsAccount", None),
		"CustomerUnpaidBoE": (55, 2, (8, 0), (), "CustomerUnpaidBoE", None),
		"CustomersDeductionatSource": (13, 2, (8, 0), (), "CustomersDeductionatSource", None),
		"DebitorsFollowUpAccount": (8, 2, (8, 0), (), "DebitorsFollowUpAccount", None),
		"DecreaseGLAcc": (32, 2, (8, 0), (), "DecreaseGLAcc", None),
		"DefaultSaleAccount": (25, 2, (8, 0), (), "DefaultSaleAccount", None),
		"DownPaymentPClearingAcct": (74, 2, (8, 0), (), "DownPaymentPClearingAcct", None),
		"DownPaymentSClearingAcct": (73, 2, (8, 0), (), "DownPaymentSClearingAcct", None),
		"DownPaymentVATAcctPurch": (72, 2, (8, 0), (), "DownPaymentVATAcctPurch", None),
		"DownPaymentVATAcctSale": (71, 2, (8, 0), (), "DownPaymentVATAcctSale", None),
		"DunningFeeAccount": (134, 2, (8, 0), (), "DunningFeeAccount", None),
		"DunningInterestAccount": (133, 2, (8, 0), (), "DunningInterestAccount", None),
		"EOYControlAccount": (63, 2, (8, 0), (), "EOYControlAccount", None),
		"EUAccountsPayable": (123, 2, (8, 0), (), "EUAccountsPayable", None),
		"EUAccountsReceivable": (122, 2, (8, 0), (), "EUAccountsReceivable", None),
		"EUExpenseAccount": (77, 2, (8, 0), (), "EUExpenseAccount", None),
		"EUPurchaseCreditAcc": (99, 2, (8, 0), (), "EUPurchaseCreditAcc", None),
		"ExchangeRateDifferencesAcct": (64, 2, (8, 0), (), "ExchangeRateDifferencesAcct", None),
		"ExemptedCredits": (103, 2, (8, 0), (), "ExemptedCredits", None),
		"ExpenseAccountDefault": (27, 2, (8, 0), (), "ExpenseAccountDefault", None),
		"ExpenseClearingAccount": (66, 2, (8, 0), (), "ExpenseClearingAccount", None),
		"ExpenseOffsetAccount": (67, 2, (8, 0), (), "ExpenseOffsetAccount", None),
		"ExpenseVarianceAccount": (75, 2, (8, 0), (), "ExpenseVarianceAccount", None),
		"ExpensesAccountForeign": (30, 2, (8, 0), (), "ExpensesAccountForeign", None),
		"FinancialYear": (118, 2, (3, 0), (), "FinancialYear", None),
		"ForeignAccountsReceivables": (16, 2, (8, 0), (), "ForeignAccountsReceivables", None),
		"ForeignPurchaseCreditAcc": (100, 2, (8, 0), (), "ForeignPurchaseCreditAcc", None),
		"FromDocumentDate": (114, 2, (7, 0), (), "FromDocumentDate", None),
		"FromDueDate": (112, 2, (7, 0), (), "FromDueDate", None),
		"FromPostingDate": (110, 2, (7, 0), (), "FromPostingDate", None),
		"GLRevaluationOffsetAccount": (86, 2, (8, 0), (), "GLRevaluationOffsetAccount", None),
		"GoodsClearingAcc": (65, 2, (8, 0), (), "GoodsClearingAcc", None),
		"IncreaseGLAccount": (43, 2, (8, 0), (), "IncreaseGLAccount", None),
		"InputTaxAccount": (21, 2, (8, 0), (), "InputTaxAccount", None),
		"InventoryOffsetDecrease": (80, 2, (8, 0), (), "InventoryOffsetDecrease", None),
		"InventoryOffsetIncrease": (79, 2, (8, 0), (), "InventoryOffsetIncrease", None),
		"InventoryOffsetProfitAndLossAccount": (132, 2, (8, 0), (), "InventoryOffsetProfitAndLossAccount", None),
		"InvoicePaymentBP": (85, 2, (8, 0), (), "InvoicePaymentBP", None),
		"NegativeInventoryAdjustmentAccount": (117, 2, (8, 0), (), "NegativeInventoryAdjustmentAccount", None),
		"NumberOfPeriods": (95, 2, (3, 0), (), "NumberOfPeriods", None),
		"OpeningBalancesAccount": (24, 2, (8, 0), (), "OpeningBalancesAccount", None),
		"OutgoingCashAccount": (19, 2, (8, 0), (), "OutgoingCashAccount", None),
		"OutgoingChecksAccount": (18, 2, (8, 0), (), "OutgoingChecksAccount", None),
		"OutgoingTaxAccount": (116, 2, (8, 0), (), "OutgoingTaxAccount", None),
		"OverpaymentsAPAccount": (87, 2, (8, 0), (), "OverpaymentsAPAccount", None),
		"OverpaymentsARAccount": (89, 2, (8, 0), (), "OverpaymentsARAccount", None),
		"PeriodCategory": (96, 2, (8, 0), (), "PeriodCategory", None),
		"PeriodName": (9, 2, (8, 0), (), "PeriodName", None),
		"PriceDifferenceAccount": (48, 2, (8, 0), (), "PriceDifferenceAccount", None),
		"PurchaseAccount": (60, 2, (8, 0), (), "PurchaseAccount", None),
		"PurchaseCreditAcc": (98, 2, (8, 0), (), "PurchaseCreditAcc", None),
		"PurchaseDownPaymentInterimAccount": (125, 2, (8, 0), (), "PurchaseDownPaymentInterimAccount", None),
		"PurchaseOffsetAccount": (62, 2, (8, 0), (), "PurchaseOffsetAccount", None),
		"PurchaseReturnAccount": (61, 2, (8, 0), (), "PurchaseReturnAccount", None),
		"PurchaseTax": (15, 2, (8, 0), (), "PurchaseTax", None),
		"RateDifferencesDefaultAcc": (31, 2, (8, 0), (), "RateDifferencesDefaultAcc", None),
		"ReconciliationDifference": (33, 2, (8, 0), (), "ReconciliationDifference", None),
		"RepomoAccount": (69, 2, (8, 0), (), "RepomoAccount", None),
		"RevenuesAccountForeign": (28, 2, (8, 0), (), "RevenuesAccountForeign", None),
		"RoundingAccount": (40, 2, (8, 0), (), "RoundingAccount", None),
		"SalesCreditAcc": (101, 2, (8, 0), (), "SalesCreditAcc", None),
		"SalesCreditEUAcc": (102, 2, (8, 0), (), "SalesCreditEUAcc", None),
		"SalesCreditForeignAcc": (104, 2, (8, 0), (), "SalesCreditForeignAcc", None),
		"SalesDownPaymentInterimAccount": (124, 2, (8, 0), (), "SalesDownPaymentInterimAccount", None),
		"SalesReturns": (44, 2, (8, 0), (), "SalesReturns", None),
		"SalesRevenueEU": (29, 2, (8, 0), (), "SalesRevenueEU", None),
		"SelfInvoiceExpenseAccount": (120, 2, (8, 0), (), "SelfInvoiceExpenseAccount", None),
		"SelfInvoiceRevenueAccount": (119, 2, (8, 0), (), "SelfInvoiceRevenueAccount", None),
		"StockAccount": (78, 2, (8, 0), (), "StockAccount", None),
		"StockInTransitAccount": (121, 2, (8, 0), (), "StockInTransitAccount", None),
		"StockRevaluationAccount": (82, 2, (8, 0), (), "StockRevaluationAccount", None),
		"StockRevaluationOffsetAcct": (83, 2, (8, 0), (), "StockRevaluationOffsetAcct", None),
		"SubPeriodType": (94, 2, (3, 0), (), "SubPeriodType", None),
		"TaxDefinition": (22, 2, (8, 0), (), "TaxDefinition", None),
		"TaxExemptRevenuesDefault": (26, 2, (8, 0), (), "TaxExemptRevenuesDefault", None),
		"ToDocumentDate": (115, 2, (7, 0), (), "ToDocumentDate", None),
		"ToDueDate": (113, 2, (7, 0), (), "ToDueDate", None),
		"ToPostingDate": (111, 2, (7, 0), (), "ToPostingDate", None),
		"UnderpaymentsAPAccount": (88, 2, (8, 0), (), "UnderpaymentsAPAccount", None),
		"UnderpaymentsARAccount": (90, 2, (8, 0), (), "UnderpaymentsARAccount", None),
		"VarianceAcc": (47, 2, (8, 0), (), "VarianceAcc", None),
		"VendorAssetsAccount": (81, 2, (8, 0), (), "VendorAssetsAccount", None),
		"VendorDoubtfulDebtsAcct": (59, 2, (8, 0), (), "VendorDoubtfulDebtsAcct", None),
		"VendorDownPaymentsAccount": (50, 2, (8, 0), (), "VendorDownPaymentsAccount", None),
		"WIPMaterialAccount": (84, 2, (8, 0), (), "WIPMaterialAccount", None),
		"WIPMaterialVarianceAccount": (70, 2, (8, 0), (), "WIPMaterialVarianceAccount", None),
		"WipOffsetProfitAndLossAccount": (131, 2, (8, 0), (), "WipOffsetProfitAndLossAccount", None),
		"WithholodingTax": (23, 2, (8, 0), (), "WithholodingTax", None),
	}
	_prop_map_put_ = {
		"APCashDiscountAccount": ((35, LCID, 4, 0),()),
		"APGainRealizedExchngeDif": ((41, LCID, 4, 0),()),
		"APLossCashDiscountAccount": ((36, LCID, 4, 0),()),
		"APLossRealizedExchangeDif": ((37, LCID, 4, 0),()),
		"ARCashDiscountAccount": ((38, LCID, 4, 0),()),
		"ARGainRealizedExchngeDif": ((42, LCID, 4, 0),()),
		"ARLossRealizedExchangeDi": ((39, LCID, 4, 0),()),
		"AccountforCashReceipt": ((11, LCID, 4, 0),()),
		"AccountforCreditMemoPayme": ((20, LCID, 4, 0),()),
		"AccountforOutgoingChecks": ((10, LCID, 4, 0),()),
		"AcountforOpeningWHBalance": ((34, LCID, 4, 0),()),
		"AllocationAcc": ((46, LCID, 4, 0),()),
		"BeginningofFinancialYear": ((7, LCID, 4, 0),()),
		"BillofExchangeAccountsRece": ((51, LCID, 4, 0),()),
		"BoEAccountsPayable": ((56, LCID, 4, 0),()),
		"BoEAccountsPayable2": ((57, LCID, 4, 0),()),
		"CommissionAccountDefault": ((14, LCID, 4, 0),()),
		"CostOfGoodsSold": ((45, LCID, 4, 0),()),
		"CostofSaleRevOffsetAcct": ((76, LCID, 4, 0),()),
		"CostofSaleRevaluationAcct": ((68, LCID, 4, 0),()),
		"CreditorsFollowUpAccount": ((17, LCID, 4, 0),()),
		"CustBillofExchangeonC": ((52, LCID, 4, 0),()),
		"CustomerBillofExchangePres": ((53, LCID, 4, 0),()),
		"CustomerBillofExchngeDisc": ((54, LCID, 4, 0),()),
		"CustomerDoubtfulDebtsAcct": ((58, LCID, 4, 0),()),
		"CustomerDownPaymentsAccount": ((49, LCID, 4, 0),()),
		"CustomerUnpaidBoE": ((55, LCID, 4, 0),()),
		"CustomersDeductionatSource": ((13, LCID, 4, 0),()),
		"DebitorsFollowUpAccount": ((8, LCID, 4, 0),()),
		"DecreaseGLAcc": ((32, LCID, 4, 0),()),
		"DefaultSaleAccount": ((25, LCID, 4, 0),()),
		"DownPaymentPClearingAcct": ((74, LCID, 4, 0),()),
		"DownPaymentSClearingAcct": ((73, LCID, 4, 0),()),
		"DownPaymentVATAcctPurch": ((72, LCID, 4, 0),()),
		"DownPaymentVATAcctSale": ((71, LCID, 4, 0),()),
		"DunningFeeAccount": ((134, LCID, 4, 0),()),
		"DunningInterestAccount": ((133, LCID, 4, 0),()),
		"EOYControlAccount": ((63, LCID, 4, 0),()),
		"EUAccountsPayable": ((123, LCID, 4, 0),()),
		"EUAccountsReceivable": ((122, LCID, 4, 0),()),
		"EUExpenseAccount": ((77, LCID, 4, 0),()),
		"EUPurchaseCreditAcc": ((99, LCID, 4, 0),()),
		"ExchangeRateDifferencesAcct": ((64, LCID, 4, 0),()),
		"ExemptedCredits": ((103, LCID, 4, 0),()),
		"ExpenseAccountDefault": ((27, LCID, 4, 0),()),
		"ExpenseClearingAccount": ((66, LCID, 4, 0),()),
		"ExpenseOffsetAccount": ((67, LCID, 4, 0),()),
		"ExpenseVarianceAccount": ((75, LCID, 4, 0),()),
		"ExpensesAccountForeign": ((30, LCID, 4, 0),()),
		"FinancialYear": ((118, LCID, 4, 0),()),
		"ForeignAccountsReceivables": ((16, LCID, 4, 0),()),
		"ForeignPurchaseCreditAcc": ((100, LCID, 4, 0),()),
		"FromDocumentDate": ((114, LCID, 4, 0),()),
		"FromDueDate": ((112, LCID, 4, 0),()),
		"FromPostingDate": ((110, LCID, 4, 0),()),
		"GLRevaluationOffsetAccount": ((86, LCID, 4, 0),()),
		"GoodsClearingAcc": ((65, LCID, 4, 0),()),
		"IncreaseGLAccount": ((43, LCID, 4, 0),()),
		"InputTaxAccount": ((21, LCID, 4, 0),()),
		"InventoryOffsetDecrease": ((80, LCID, 4, 0),()),
		"InventoryOffsetIncrease": ((79, LCID, 4, 0),()),
		"InventoryOffsetProfitAndLossAccount": ((132, LCID, 4, 0),()),
		"InvoicePaymentBP": ((85, LCID, 4, 0),()),
		"NegativeInventoryAdjustmentAccount": ((117, LCID, 4, 0),()),
		"NumberOfPeriods": ((95, LCID, 4, 0),()),
		"OpeningBalancesAccount": ((24, LCID, 4, 0),()),
		"OutgoingCashAccount": ((19, LCID, 4, 0),()),
		"OutgoingChecksAccount": ((18, LCID, 4, 0),()),
		"OutgoingTaxAccount": ((116, LCID, 4, 0),()),
		"OverpaymentsAPAccount": ((87, LCID, 4, 0),()),
		"OverpaymentsARAccount": ((89, LCID, 4, 0),()),
		"PeriodCategory": ((96, LCID, 4, 0),()),
		"PeriodName": ((9, LCID, 4, 0),()),
		"PriceDifferenceAccount": ((48, LCID, 4, 0),()),
		"PurchaseAccount": ((60, LCID, 4, 0),()),
		"PurchaseCreditAcc": ((98, LCID, 4, 0),()),
		"PurchaseDownPaymentInterimAccount": ((125, LCID, 4, 0),()),
		"PurchaseOffsetAccount": ((62, LCID, 4, 0),()),
		"PurchaseReturnAccount": ((61, LCID, 4, 0),()),
		"PurchaseTax": ((15, LCID, 4, 0),()),
		"RateDifferencesDefaultAcc": ((31, LCID, 4, 0),()),
		"ReconciliationDifference": ((33, LCID, 4, 0),()),
		"RepomoAccount": ((69, LCID, 4, 0),()),
		"RevenuesAccountForeign": ((28, LCID, 4, 0),()),
		"RoundingAccount": ((40, LCID, 4, 0),()),
		"SalesCreditAcc": ((101, LCID, 4, 0),()),
		"SalesCreditEUAcc": ((102, LCID, 4, 0),()),
		"SalesCreditForeignAcc": ((104, LCID, 4, 0),()),
		"SalesDownPaymentInterimAccount": ((124, LCID, 4, 0),()),
		"SalesReturns": ((44, LCID, 4, 0),()),
		"SalesRevenueEU": ((29, LCID, 4, 0),()),
		"SelfInvoiceExpenseAccount": ((120, LCID, 4, 0),()),
		"SelfInvoiceRevenueAccount": ((119, LCID, 4, 0),()),
		"StockAccount": ((78, LCID, 4, 0),()),
		"StockInTransitAccount": ((121, LCID, 4, 0),()),
		"StockRevaluationAccount": ((82, LCID, 4, 0),()),
		"StockRevaluationOffsetAcct": ((83, LCID, 4, 0),()),
		"SubPeriodType": ((94, LCID, 4, 0),()),
		"TaxDefinition": ((22, LCID, 4, 0),()),
		"TaxExemptRevenuesDefault": ((26, LCID, 4, 0),()),
		"ToDocumentDate": ((115, LCID, 4, 0),()),
		"ToDueDate": ((113, LCID, 4, 0),()),
		"ToPostingDate": ((111, LCID, 4, 0),()),
		"UnderpaymentsAPAccount": ((88, LCID, 4, 0),()),
		"UnderpaymentsARAccount": ((90, LCID, 4, 0),()),
		"VarianceAcc": ((47, LCID, 4, 0),()),
		"VendorAssetsAccount": ((81, LCID, 4, 0),()),
		"VendorDoubtfulDebtsAcct": ((59, LCID, 4, 0),()),
		"VendorDownPaymentsAccount": ((50, LCID, 4, 0),()),
		"WIPMaterialAccount": ((84, LCID, 4, 0),()),
		"WIPMaterialVarianceAccount": ((70, LCID, 4, 0),()),
		"WipOffsetProfitAndLossAccount": ((131, LCID, 4, 0),()),
		"WithholodingTax": ((23, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPeriodCategoryParams(DispatchBaseClass):
	'IPeriodCategoryParams Interface'
	CLSID = IID('{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')
	coclass_clsid = IID('{C473B788-84C8-4B04-B63F-AB4F7348BF1F}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsoluteEntry": (10, 2, (3, 0), (), "AbsoluteEntry", None),
	}
	_prop_map_put_ = {
		"AbsoluteEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPeriodCategoryParamsCollection(DispatchBaseClass):
	'IPeriodCategoryParamsCollection Interface'
	CLSID = IID('{A31EC6FB-9B3A-439E-828D-C95CB0646555}')
	coclass_clsid = IID('{BBC9323D-F9D4-4087-A7E0-1768D5F64538}')

	# Result is of type IPeriodCategoryParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IPeriodCategoryParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPickLists(DispatchBaseClass):
	'IPickLists Interface'
	CLSID = IID('{A1CC204F-6BD1-417A-A6F8-9A3E7C96D28B}')
	coclass_clsid = IID('{23BACDC0-773E-4283-BE9C-BB2D0A216961}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsEntry=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lAbsEntry
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AbsoluteEntry": (10, 2, (3, 0), (), "AbsoluteEntry", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		# Method 'Lines' returns object of type 'IPickLists_Lines'
		"Lines": (18, 2, (9, 0), (), "Lines", '{8C5A86ED-4B60-46EB-A0D5-9F529DDF069E}'),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"ObjectType": (17, 2, (8, 0), (), "ObjectType", None),
		"OwnerCode": (12, 2, (3, 0), (), "OwnerCode", None),
		"OwnerName": (13, 2, (8, 0), (), "OwnerName", None),
		"PickDate": (14, 2, (7, 0), (), "PickDate", None),
		"Remarks": (15, 2, (8, 0), (), "Remarks", None),
		"Status": (16, 2, (3, 0), (), "Status", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((11, LCID, 4, 0),()),
		"OwnerCode": ((12, LCID, 4, 0),()),
		"PickDate": ((14, LCID, 4, 0),()),
		"Remarks": ((15, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPickLists_Lines(DispatchBaseClass):
	'IPickLists_Lines Interface'
	CLSID = IID('{8C5A86ED-4B60-46EB-A0D5-9F529DDF069E}')
	coclass_clsid = IID('{9E2A9072-D759-4FEB-AD91-90CCC8BC7D64}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AbsoluteEntry": (5, 2, (3, 0), (), "AbsoluteEntry", None),
		"BaseObjectType": (13, 2, (8, 0), (), "BaseObjectType", None),
		# Method 'BatchNumbers' returns object of type 'IBatchNumbers'
		"BatchNumbers": (15, 2, (9, 0), (), "BatchNumbers", '{1FEF5698-93E1-4167-AEA0-4BB151792623}'),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"LineNumber": (6, 2, (3, 0), (), "LineNumber", None),
		"OrderEntry": (7, 2, (3, 0), (), "OrderEntry", None),
		"OrderRowID": (8, 2, (3, 0), (), "OrderRowID", None),
		"PickStatus": (10, 2, (3, 0), (), "PickStatus", None),
		"PickedQuantity": (9, 2, (5, 0), (), "PickedQuantity", None),
		"PreviouslyReleasedQuantity": (12, 2, (5, 0), (), "PreviouslyReleasedQuantity", None),
		"ReleasedQuantity": (11, 2, (5, 0), (), "ReleasedQuantity", None),
		# Method 'SerialNumbers' returns object of type 'ISerialNumbers'
		"SerialNumbers": (14, 2, (9, 0), (), "SerialNumbers", '{93E5E52B-181E-46B8-96CB-1C066AC04DCA}'),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BaseObjectType": ((13, LCID, 4, 0),()),
		"OrderEntry": ((7, LCID, 4, 0),()),
		"OrderRowID": ((8, LCID, 4, 0),()),
		"PickedQuantity": ((9, LCID, 4, 0),()),
		"ReleasedQuantity": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPredefinedText(DispatchBaseClass):
	'IPredefinedText Interface'
	CLSID = IID('{BFFF366B-1B1C-4EF6-8546-27C9BFF735CE}')
	coclass_clsid = IID('{1B107C12-CCB2-4F12-A67B-E1700F36570B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Numerator": (10, 2, (3, 0), (), "Numerator", None),
		"Text": (12, 2, (8, 0), (), "Text", None),
		"TextCode": (11, 2, (8, 0), (), "TextCode", None),
	}
	_prop_map_put_ = {
		"Text": ((12, LCID, 4, 0),()),
		"TextCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPredefinedTextParams(DispatchBaseClass):
	'IPredefinedTextParams Interface'
	CLSID = IID('{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')
	coclass_clsid = IID('{FEC77FB3-300B-4F11-9931-7BAA71C9EB9A}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Numerator": (10, 2, (3, 0), (), "Numerator", None),
		"TextCode": (11, 2, (8, 0), (), "TextCode", None),
	}
	_prop_map_put_ = {
		"Numerator": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPredefinedTextsParams(DispatchBaseClass):
	'IPredefinedTextsParams Interface'
	CLSID = IID('{A22E33CF-C423-4581-8C7C-382E5D59B301}')
	coclass_clsid = IID('{686C8BDD-2405-4A47-AE0B-4E2E0C7C27FF}')

	# Result is of type IPredefinedTextParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IPredefinedTextParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IPredefinedTextsService(DispatchBaseClass):
	'IPredefinedTextsService Interface'
	CLSID = IID('{17785C88-48FC-4D21-A790-81AC72C1D4CC}')
	coclass_clsid = IID('{C5006530-1F40-4FD6-A525-6BCBF66DE58B}')

	# Result is of type IPredefinedTextParams
	def AddPredefinedText(self, pIPredefinedText=defaultNamedNotOptArg):
		'AddPredefinedText'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIPredefinedText
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddPredefinedText', '{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')
		return ret

	def DeletePredefinedText(self, pIPredefinedTextParams=defaultNamedNotOptArg):
		'DeletePredefinedText'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIPredefinedTextParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IPredefinedText
	def GetPredefinedText(self, pIPredefinedTextParams=defaultNamedNotOptArg):
		'GetPredefinedText'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIPredefinedTextParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetPredefinedText', '{BFFF366B-1B1C-4EF6-8546-27C9BFF735CE}')
		return ret

	# Result is of type IPredefinedTextsParams
	def GetPredefinedTextList(self):
		'GetPredefinedTextList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetPredefinedTextList', '{A22E33CF-C423-4581-8C7C-382E5D59B301}')
		return ret

	def UpdatePredefinedText(self, pIPredefinedText=defaultNamedNotOptArg):
		'UpdatePredefinedText'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIPredefinedText
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IPriceLists(DispatchBaseClass):
	'IPriceLists Interface'
	CLSID = IID('{99FB9754-BDAE-4C8D-BA96-4F2263A73A6A}')
	coclass_clsid = IID('{C7E88977-022A-494D-BC9D-09FA85E7AC15}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(13, LCID, 1, (8, 0), (),)

	def GetByKey(self, QueueID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (11, 0), ((8, 1),),QueueID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(3, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"BasePriceList": (9, 2, (3, 0), (), "BasePriceList", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (5, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Factor": (10, 2, (5, 0), (), "Factor", None),
		"GroupNum": (8, 2, (3, 0), (), "GroupNum", None),
		"PriceListName": (12, 2, (8, 0), (), "PriceListName", None),
		"PriceListNo": (11, 2, (3, 0), (), "PriceListNo", None),
		"RoundingMethod": (7, 2, (3, 0), (), "RoundingMethod", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (2, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"BasePriceList": ((9, LCID, 4, 0),()),
		"Factor": ((10, LCID, 4, 0),()),
		"GroupNum": ((8, LCID, 4, 0),()),
		"PriceListName": ((12, LCID, 4, 0),()),
		"RoundingMethod": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProductTrees(DispatchBaseClass):
	'IProductTrees Interface'
	CLSID = IID('{9BCDAE48-582B-4E76-BD8F-E8A77BC6CF6E}')
	coclass_clsid = IID('{B2CC6793-FFCF-4389-980D-B5FF458B2EC8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(15, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((8, 0),),Key
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(16, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (13, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"DistributionRule": (17, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (19, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (20, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (21, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (22, 2, (8, 0), (), "DistributionRule5", None),
		# Method 'Items' returns object of type 'IProductTrees_Lines'
		"Items": (4, 2, (9, 0), (), "Items", '{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}'),
		"PriceList": (23, 2, (3, 0), (), "PriceList", None),
		"Project": (18, 2, (8, 0), (), "Project", None),
		"Quantity": (8, 2, (5, 0), (), "Quantity", None),
		"TreeCode": (6, 2, (8, 0), (), "TreeCode", None),
		"TreeType": (7, 2, (3, 0), (), "TreeType", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (14, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"Warehouse": (24, 2, (8, 0), (), "Warehouse", None),
	}
	_prop_map_put_ = {
		"DistributionRule": ((17, LCID, 4, 0),()),
		"DistributionRule2": ((19, LCID, 4, 0),()),
		"DistributionRule3": ((20, LCID, 4, 0),()),
		"DistributionRule4": ((21, LCID, 4, 0),()),
		"DistributionRule5": ((22, LCID, 4, 0),()),
		"PriceList": ((23, LCID, 4, 0),()),
		"Project": ((18, LCID, 4, 0),()),
		"Quantity": ((8, LCID, 4, 0),()),
		"TreeCode": ((6, LCID, 4, 0),()),
		"TreeType": ((7, LCID, 4, 0),()),
		"Warehouse": ((24, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProductTrees_Lines(DispatchBaseClass):
	'IProductTrees_Lines Interface'
	CLSID = IID('{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}')
	coclass_clsid = IID('{D9F478E8-7891-4C69-A96D-39D5881CFE39}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Comment": (13, 2, (8, 0), (), "Comment", None),
		"Count": (8, 2, (3, 0), (), "Count", None),
		"Currency": (6, 2, (8, 0), (), "Currency", None),
		"DistributionRule": (17, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (20, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (21, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (22, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (23, 2, (8, 0), (), "DistributionRule5", None),
		"InventoryUOM": (12, 2, (8, 0), (), "InventoryUOM", None),
		"IssueMethod": (11, 2, (3, 0), (), "IssueMethod", None),
		"ItemCode": (2, 2, (8, 0), (), "ItemCode", None),
		"ParentItem": (15, 2, (8, 0), (), "ParentItem", None),
		"Price": (5, 2, (5, 0), (), "Price", None),
		"PriceList": (16, 2, (3, 0), (), "PriceList", None),
		"Project": (19, 2, (8, 0), (), "Project", None),
		"Quantity": (3, 2, (5, 0), (), "Quantity", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (10, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"Warehouse": (4, 2, (8, 0), (), "Warehouse", None),
	}
	_prop_map_put_ = {
		"Comment": ((13, LCID, 4, 0),()),
		"Currency": ((6, LCID, 4, 0),()),
		"DistributionRule": ((17, LCID, 4, 0),()),
		"DistributionRule2": ((20, LCID, 4, 0),()),
		"DistributionRule3": ((21, LCID, 4, 0),()),
		"DistributionRule4": ((22, LCID, 4, 0),()),
		"DistributionRule5": ((23, LCID, 4, 0),()),
		"IssueMethod": ((11, LCID, 4, 0),()),
		"ItemCode": ((2, LCID, 4, 0),()),
		"ParentItem": ((15, LCID, 4, 0),()),
		"Price": ((5, LCID, 4, 0),()),
		"PriceList": ((16, LCID, 4, 0),()),
		"Project": ((19, LCID, 4, 0),()),
		"Quantity": ((3, LCID, 4, 0),()),
		"Warehouse": ((4, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(8, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IProductionOrders(DispatchBaseClass):
	'IProductionOrders Interface'
	CLSID = IID('{1C7C966F-B713-42BF-9A74-0B15A649E63D}')
	coclass_clsid = IID('{37C235F6-0465-4E85-80A0-776D4602B09B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lAbsEntry=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lAbsEntry
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AbsoluteEntry": (12, 2, (3, 0), (), "AbsoluteEntry", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ClosingDate": (28, 2, (7, 0), (), "ClosingDate", None),
		"CompletedQuantity": (19, 2, (5, 0), (), "CompletedQuantity", None),
		"CreationDate": (35, 2, (7, 0), (), "CreationDate", None),
		"CustomerCode": (30, 2, (8, 0), (), "CustomerCode", None),
		"DistributionRule": (38, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (40, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (41, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (42, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (43, 2, (8, 0), (), "DistributionRule5", None),
		"DocumentNumber": (13, 2, (3, 0), (), "DocumentNumber", None),
		"DueDate": (22, 2, (7, 0), (), "DueDate", None),
		"InventoryUOM": (32, 2, (8, 0), (), "InventoryUOM", None),
		"ItemNo": (15, 2, (8, 0), (), "ItemNo", None),
		"JournalRemarks": (33, 2, (8, 0), (), "JournalRemarks", None),
		# Method 'Lines' returns object of type 'IProductionOrders_Lines'
		"Lines": (36, 2, (9, 0), (), "Lines", '{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}'),
		"PlannedQuantity": (18, 2, (5, 0), (), "PlannedQuantity", None),
		"PostingDate": (21, 2, (7, 0), (), "PostingDate", None),
		"Printed": (37, 2, (3, 0), (), "Printed", None),
		"ProductionOrderOrigin": (25, 2, (3, 0), (), "ProductionOrderOrigin", None),
		"ProductionOrderOriginEntry": (23, 2, (3, 0), (), "ProductionOrderOriginEntry", None),
		"ProductionOrderOriginNumber": (24, 2, (3, 0), (), "ProductionOrderOriginNumber", None),
		"ProductionOrderStatus": (16, 2, (3, 0), (), "ProductionOrderStatus", None),
		"ProductionOrderType": (17, 2, (3, 0), (), "ProductionOrderType", None),
		"Project": (39, 2, (8, 0), (), "Project", None),
		"RejectedQuantity": (20, 2, (5, 0), (), "RejectedQuantity", None),
		"ReleaseDate": (29, 2, (7, 0), (), "ReleaseDate", None),
		"Remarks": (27, 2, (8, 0), (), "Remarks", None),
		# Method 'SalesOrderLines' returns object of type 'IProductionOrders_SalesOrderLines'
		"SalesOrderLines": (44, 2, (9, 0), (), "SalesOrderLines", '{DF6C475B-AD8D-4E52-A412-9500E69DB54B}'),
		"Series": (14, 2, (3, 0), (), "Series", None),
		"TransactionNumber": (34, 2, (3, 0), (), "TransactionNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (26, 2, (3, 0), (), "UserSignature", None),
		"Warehouse": (31, 2, (8, 0), (), "Warehouse", None),
	}
	_prop_map_put_ = {
		"ClosingDate": ((28, LCID, 4, 0),()),
		"CustomerCode": ((30, LCID, 4, 0),()),
		"DistributionRule": ((38, LCID, 4, 0),()),
		"DistributionRule2": ((40, LCID, 4, 0),()),
		"DistributionRule3": ((41, LCID, 4, 0),()),
		"DistributionRule4": ((42, LCID, 4, 0),()),
		"DistributionRule5": ((43, LCID, 4, 0),()),
		"DueDate": ((22, LCID, 4, 0),()),
		"ItemNo": ((15, LCID, 4, 0),()),
		"JournalRemarks": ((33, LCID, 4, 0),()),
		"PlannedQuantity": ((18, LCID, 4, 0),()),
		"PostingDate": ((21, LCID, 4, 0),()),
		"ProductionOrderOrigin": ((25, LCID, 4, 0),()),
		"ProductionOrderOriginEntry": ((23, LCID, 4, 0),()),
		"ProductionOrderStatus": ((16, LCID, 4, 0),()),
		"ProductionOrderType": ((17, LCID, 4, 0),()),
		"Project": ((39, LCID, 4, 0),()),
		"Remarks": ((27, LCID, 4, 0),()),
		"Series": ((14, LCID, 4, 0),()),
		"Warehouse": ((31, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProductionOrders_Lines(DispatchBaseClass):
	'IProductionOrders_Lines Interface'
	CLSID = IID('{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}')
	coclass_clsid = IID('{9AC69118-AA6E-44B4-ACDC-176426BCBA1C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseQuantity": (8, 2, (5, 0), (), "BaseQuantity", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"DistributionRule": (14, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (18, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (19, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (20, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (21, 2, (8, 0), (), "DistributionRule5", None),
		"DocumentAbsoluteEntry": (5, 2, (3, 0), (), "DocumentAbsoluteEntry", None),
		"IssuedQuantity": (10, 2, (5, 0), (), "IssuedQuantity", None),
		"ItemNo": (7, 2, (8, 0), (), "ItemNo", None),
		"LineNumber": (6, 2, (3, 0), (), "LineNumber", None),
		"LocationCode": (15, 2, (3, 0), (), "LocationCode", None),
		"PlannedQuantity": (9, 2, (5, 0), (), "PlannedQuantity", None),
		"ProductionOrderIssueType": (11, 2, (3, 0), (), "ProductionOrderIssueType", None),
		"Project": (17, 2, (8, 0), (), "Project", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VisualOrder": (13, 2, (3, 0), (), "VisualOrder", None),
		"Warehouse": (12, 2, (8, 0), (), "Warehouse", None),
	}
	_prop_map_put_ = {
		"BaseQuantity": ((8, LCID, 4, 0),()),
		"DistributionRule": ((14, LCID, 4, 0),()),
		"DistributionRule2": ((18, LCID, 4, 0),()),
		"DistributionRule3": ((19, LCID, 4, 0),()),
		"DistributionRule4": ((20, LCID, 4, 0),()),
		"DistributionRule5": ((21, LCID, 4, 0),()),
		"ItemNo": ((7, LCID, 4, 0),()),
		"LocationCode": ((15, LCID, 4, 0),()),
		"PlannedQuantity": ((9, LCID, 4, 0),()),
		"ProductionOrderIssueType": ((11, LCID, 4, 0),()),
		"Project": ((17, LCID, 4, 0),()),
		"Warehouse": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IProductionOrders_SalesOrderLines(DispatchBaseClass):
	'IProductionOrders_SalesOrderLines Interface'
	CLSID = IID('{DF6C475B-AD8D-4E52-A412-9500E69DB54B}')
	coclass_clsid = IID('{AEA80754-8283-49E8-A4A5-2523BA860D5F}')

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseAbsEntry": (6, 2, (3, 0), (), "BaseAbsEntry", None),
		"BaseLine": (7, 2, (3, 0), (), "BaseLine", None),
		"BaseNumber": (5, 2, (3, 0), (), "BaseNumber", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"DocEntry": (4, 2, (3, 0), (), "DocEntry", None),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IProfitCenter(DispatchBaseClass):
	'IProfitCenter Interface'
	CLSID = IID('{F29A5E07-7C8B-4706-99D7-9BFB85180358}')
	coclass_clsid = IID('{8DBC2FA6-D028-4CF6-9987-EE7EDFC91F71}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Active": (18, 2, (3, 0), (), "Active", None),
		"CenterCode": (10, 2, (8, 0), (), "CenterCode", None),
		"CenterName": (11, 2, (8, 0), (), "CenterName", None),
		"CostCenterType": (15, 2, (8, 0), (), "CostCenterType", None),
		"EffectiveTo": (17, 2, (7, 0), (), "EffectiveTo", None),
		"Effectivefrom": (16, 2, (7, 0), (), "Effectivefrom", None),
		"GroupCode": (12, 2, (8, 0), (), "GroupCode", None),
		"InWhichDimension": (13, 2, (3, 0), (), "InWhichDimension", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (14, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
	}
	_prop_map_put_ = {
		"Active": ((18, LCID, 4, 0),()),
		"CenterCode": ((10, LCID, 4, 0),()),
		"CenterName": ((11, LCID, 4, 0),()),
		"CostCenterType": ((15, LCID, 4, 0),()),
		"EffectiveTo": ((17, LCID, 4, 0),()),
		"Effectivefrom": ((16, LCID, 4, 0),()),
		"GroupCode": ((12, LCID, 4, 0),()),
		"InWhichDimension": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProfitCenterParams(DispatchBaseClass):
	'IProfitCenterParams Interface'
	CLSID = IID('{98F79F87-3825-465E-8E69-E7E416534B7B}')
	coclass_clsid = IID('{7FDEAE23-7D23-4F12-BA4A-02E65FD9C534}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CenterCode": (10, 2, (8, 0), (), "CenterCode", None),
		"CenterName": (11, 2, (8, 0), (), "CenterName", None),
	}
	_prop_map_put_ = {
		"CenterCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProfitCentersParams(DispatchBaseClass):
	'IProfitCentersParams Interface'
	CLSID = IID('{BF7FD103-23BD-401E-8A87-DBAFBBB7DB37}')
	coclass_clsid = IID('{5EE7C7ED-EEC8-48E4-A394-BBAECC769C43}')

	# Result is of type IProfitCenterParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{98F79F87-3825-465E-8E69-E7E416534B7B}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IProfitCenterParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{98F79F87-3825-465E-8E69-E7E416534B7B}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{98F79F87-3825-465E-8E69-E7E416534B7B}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{98F79F87-3825-465E-8E69-E7E416534B7B}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IProfitCentersService(DispatchBaseClass):
	'IProfitCentersService Interface'
	CLSID = IID('{0D3C05B0-0EF2-4FB1-8A75-345E3893A995}')
	coclass_clsid = IID('{F4F504EC-6960-4064-BC79-BD395CB495B7}')

	# Result is of type IProfitCenterParams
	def AddProfitCenter(self, pIProfitCenter=defaultNamedNotOptArg):
		'AddProfitCenter'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIProfitCenter
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddProfitCenter', '{98F79F87-3825-465E-8E69-E7E416534B7B}')
		return ret

	def DeleteProfitCenter(self, pIProfitCenterParams=defaultNamedNotOptArg):
		'DeleteProfitCenter'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIProfitCenterParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IProfitCenter
	def GetProfitCenter(self, pIProfitCenterParams=defaultNamedNotOptArg):
		'GetProfitCenter'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIProfitCenterParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetProfitCenter', '{F29A5E07-7C8B-4706-99D7-9BFB85180358}')
		return ret

	# Result is of type IProfitCentersParams
	def GetProfitCenterList(self):
		'GetProfitCenterList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetProfitCenterList', '{BF7FD103-23BD-401E-8A87-DBAFBBB7DB37}')
		return ret

	def UpdateProfitCenter(self, pIProfitCenter=defaultNamedNotOptArg):
		'UpdateProfitCenter'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIProfitCenter
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProject(DispatchBaseClass):
	'IProject Interface'
	CLSID = IID('{C7DF4768-56A6-45D9-9C2B-916008846E76}')
	coclass_clsid = IID('{1322FD3F-D88B-4321-9AC1-D9423CFBF06A}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Active": (14, 2, (3, 0), (), "Active", None),
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (7, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
		"ValidFrom": (12, 2, (7, 0), (), "ValidFrom", None),
		"ValidTo": (13, 2, (7, 0), (), "ValidTo", None),
	}
	_prop_map_put_ = {
		"Active": ((14, LCID, 4, 0),()),
		"Code": ((10, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"ValidFrom": ((12, LCID, 4, 0),()),
		"ValidTo": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProjectParams(DispatchBaseClass):
	'IProjectParams Interface'
	CLSID = IID('{563777FD-DD54-40BC-BC70-3DF2EA78F859}')
	coclass_clsid = IID('{88134489-A686-4E22-811B-40E0728F4497}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IProjectsParams(DispatchBaseClass):
	'IProjectsParams Interface'
	CLSID = IID('{44AB2C0B-390B-43A1-8BCD-529BA39C52C3}')
	coclass_clsid = IID('{5764FA3D-17B0-4CDC-80CD-6D6BB2ED446F}')

	# Result is of type IProjectParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{563777FD-DD54-40BC-BC70-3DF2EA78F859}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IProjectParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{563777FD-DD54-40BC-BC70-3DF2EA78F859}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{563777FD-DD54-40BC-BC70-3DF2EA78F859}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{563777FD-DD54-40BC-BC70-3DF2EA78F859}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IProjectsService(DispatchBaseClass):
	'IProjectsService Interface'
	CLSID = IID('{B1AB765A-A1F6-4365-BC25-D0C63B496C77}')
	coclass_clsid = IID('{74598C2A-7868-4A07-83CE-229328FD3A11}')

	# Result is of type IProjectParams
	def AddProject(self, pIProject=defaultNamedNotOptArg):
		'AddProject'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIProject
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddProject', '{563777FD-DD54-40BC-BC70-3DF2EA78F859}')
		return ret

	def DeleteProject(self, pIProjectParams=defaultNamedNotOptArg):
		'DeleteProject'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIProjectParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IProject
	def GetProject(self, pIProjectParams=defaultNamedNotOptArg):
		'GetProject'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((9, 1),),pIProjectParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetProject', '{C7DF4768-56A6-45D9-9C2B-916008846E76}')
		return ret

	# Result is of type IProjectsParams
	def GetProjectList(self):
		'GetProjectList'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetProjectList', '{44AB2C0B-390B-43A1-8BCD-529BA39C52C3}')
		return ret

	def UpdateProject(self, pIProject=defaultNamedNotOptArg):
		'UpdateProject'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIProject
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IQueryCategories(DispatchBaseClass):
	'IQueryCategories Interface'
	CLSID = IID('{78A768C9-EDA6-4798-AFC3-114DEC3DE8E5}')
	coclass_clsid = IID('{D89C1B1F-B7A1-4669-B80D-E3A041767ABE}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (1, 2, (3, 0), (), "Code", None),
		"Name": (2, 2, (8, 0), (), "Name", None),
		"Permissions": (12, 2, (8, 0), (), "Permissions", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Name": ((2, LCID, 4, 0),()),
		"Permissions": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IQueue(DispatchBaseClass):
	'IQueue Interface'
	CLSID = IID('{8C5510F0-AA36-4CBD-A5AC-7DCF29EE0249}')
	coclass_clsid = IID('{EA2133A7-F8D4-4444-834F-1129CE2081EB}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(14, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrQueueID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((8, 1),),bstrQueueID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(10, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (12, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Description": (2, 2, (8, 0), (), "Description", None),
		"Inactive": (3, 2, (3, 0), (), "Inactive", None),
		"QueueEmail": (5, 2, (8, 0), (), "QueueEmail", None),
		"QueueID": (1, 2, (8, 0), (), "QueueID", None),
		"QueueManager": (4, 2, (3, 0), (), "QueueManager", None),
		# Method 'QueueMembers' returns object of type 'IQueueMembers'
		"QueueMembers": (58, 2, (9, 0), (), "QueueMembers", '{A6D332DA-630B-44C7-AA91-69F2C1A2501D}'),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (11, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Description": ((2, LCID, 4, 0),()),
		"Inactive": ((3, LCID, 4, 0),()),
		"QueueEmail": ((5, LCID, 4, 0),()),
		"QueueID": ((1, LCID, 4, 0),()),
		"QueueManager": ((4, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IQueueMembers(DispatchBaseClass):
	'IQueueMembers Interface'
	CLSID = IID('{A6D332DA-630B-44C7-AA91-69F2C1A2501D}')
	coclass_clsid = IID('{79148B90-9790-418A-B904-DA8C72CCCDDF}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (4, 2, (3, 0), (), "Count", None),
		"MemberUserID": (2, 2, (3, 0), (), "MemberUserID", None),
		"QueueID": (1, 2, (8, 0), (), "QueueID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (3, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"MemberUserID": ((2, LCID, 4, 0),()),
		"QueueID": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(4, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IRecipient(DispatchBaseClass):
	'IRecipient Interface'
	CLSID = IID('{BFC32883-8D3F-49F9-A985-3F9B3B37260F}')
	coclass_clsid = IID('{5C9EBDA2-D0B1-487D-BEA0-DCDB44D6A56B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CellularNumber": (15, 2, (8, 0), (), "CellularNumber", None),
		"EmailAddress": (16, 2, (8, 0), (), "EmailAddress", None),
		"FaxNumber": (17, 2, (8, 0), (), "FaxNumber", None),
		"NameTo": (11, 2, (8, 0), (), "NameTo", None),
		"SendEmail": (12, 2, (3, 0), (), "SendEmail", None),
		"SendFax": (14, 2, (3, 0), (), "SendFax", None),
		"SendInternal": (19, 2, (3, 0), (), "SendInternal", None),
		"SendSMS": (13, 2, (3, 0), (), "SendSMS", None),
		"UserCode": (10, 2, (8, 0), (), "UserCode", None),
		"UserType": (18, 2, (3, 0), (), "UserType", None),
	}
	_prop_map_put_ = {
		"CellularNumber": ((15, LCID, 4, 0),()),
		"EmailAddress": ((16, LCID, 4, 0),()),
		"FaxNumber": ((17, LCID, 4, 0),()),
		"NameTo": ((11, LCID, 4, 0),()),
		"SendEmail": ((12, LCID, 4, 0),()),
		"SendFax": ((14, LCID, 4, 0),()),
		"SendInternal": ((19, LCID, 4, 0),()),
		"SendSMS": ((13, LCID, 4, 0),()),
		"UserCode": ((10, LCID, 4, 0),()),
		"UserType": ((18, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IRecipientCollection(DispatchBaseClass):
	'IRecipientCollection Interface'
	CLSID = IID('{2C728EFB-8BF9-4D0A-8135-E53AD4CDC064}')
	coclass_clsid = IID('{CE2AC3A6-339A-4F3B-9C70-600FC4A6F2DE}')

	# Result is of type IRecipient
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{BFC32883-8D3F-49F9-A985-3F9B3B37260F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IRecipient
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{BFC32883-8D3F-49F9-A985-3F9B3B37260F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{BFC32883-8D3F-49F9-A985-3F9B3B37260F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{BFC32883-8D3F-49F9-A985-3F9B3B37260F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IRecipients(DispatchBaseClass):
	'IRecipients Interface'
	CLSID = IID('{F408B086-B6E4-4EE0-9B95-710C117E56F0}')
	coclass_clsid = IID('{921DBA91-7B93-4AEB-859C-C4452CA0F739}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"CellularNumber": (9, 2, (8, 0), (), "CellularNumber", None),
		"Count": (1, 2, (3, 0), (), "Count", None),
		"EmailAddress": (10, 2, (8, 0), (), "EmailAddress", None),
		"FaxNumber": (11, 2, (8, 0), (), "FaxNumber", None),
		"NameTo": (5, 2, (8, 0), (), "NameTo", None),
		"SendEmail": (6, 2, (3, 0), (), "SendEmail", None),
		"SendFax": (8, 2, (3, 0), (), "SendFax", None),
		"SendInternal": (13, 2, (3, 0), (), "SendInternal", None),
		"SendSMS": (7, 2, (3, 0), (), "SendSMS", None),
		"UserCode": (4, 2, (8, 0), (), "UserCode", None),
		"UserType": (12, 2, (3, 0), (), "UserType", None),
	}
	_prop_map_put_ = {
		"CellularNumber": ((9, LCID, 4, 0),()),
		"EmailAddress": ((10, LCID, 4, 0),()),
		"FaxNumber": ((11, LCID, 4, 0),()),
		"NameTo": ((5, LCID, 4, 0),()),
		"SendEmail": ((6, LCID, 4, 0),()),
		"SendFax": ((8, LCID, 4, 0),()),
		"SendInternal": ((13, LCID, 4, 0),()),
		"SendSMS": ((7, LCID, 4, 0),()),
		"UserCode": ((4, LCID, 4, 0),()),
		"UserType": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IRecordset(DispatchBaseClass):
	'IRecordset Interface'
	CLSID = IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
	coclass_clsid = IID('{11FA87EF-9F44-4528-AE1D-DAF92AEA3545}')

	def DoQuery(self, QueryStr=defaultNamedNotOptArg):
		'Runs an SQL query'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((8, 0),),QueryStr
			)

	def GetAsXML(self):
		'Get records as XML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(13, LCID, 1, (8, 0), (),)

	def GetFixedSchema(self):
		'method GetFixedSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(16, LCID, 1, (8, 0), (),)

	def GetFixedXML(self, xmlMode=defaultNamedNotOptArg):
		'method GetFixedXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(15, LCID, 1, (8, 0), ((3, 1),),xmlMode
			)

	def MoveFirst(self):
		'method MoveFirst'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), (),)

	def MoveLast(self):
		'method MoveLast'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), (),)

	def MoveNext(self):
		'Move to the next record'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def MovePrevious(self):
		'Move to the previous record'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		'Save records as XML document'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'Save records as XML document'
		return self._ApplyTypes_(9, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		"BoF": (5, 2, (11, 0), (), "BoF", None),
		# Method 'Command' returns object of type 'ICommand'
		"Command": (12, 2, (9, 0), (), "Command", '{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}'),
		"EoF": (6, 2, (11, 0), (), "EoF", None),
		# Method 'Fields' returns object of type 'IFields'
		"Fields": (0, 2, (9, 0), (), "Fields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
		"RecordCount": (8, 2, (3, 0), (), "RecordCount", None),
	}
	_prop_map_put_ = {
	}
	# Default property for this class is 'Fields'
	def __call__(self):
		return self._ApplyTypes_(*(0, 2, (9, 0), (), "Fields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IRelationships(DispatchBaseClass):
	'IRelationships Interface'
	CLSID = IID('{BBB45A32-F446-4ED3-915B-C811BBA6C2C7}')
	coclass_clsid = IID('{097DDC08-E989-4426-87DB-9EFAD0FF64C3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(10, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (9, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"RelationshipCode": (2, 2, (3, 0), (), "RelationshipCode", None),
		"RelationshipDescription": (1, 2, (8, 0), (), "RelationshipDescription", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"RelationshipDescription": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportFilterService(DispatchBaseClass):
	'IReportFilterService Interface'
	CLSID = IID('{3C3E8D7B-D724-4ED0-BBE3-955F8711B716}')
	coclass_clsid = IID('{A2E1CAAE-481E-4DD3-A6D7-EEF4CC1A96E7}')

	# Result is of type ITaxReportFilterParams
	def AddTaxReportFilter(self, pITaxReportFilter=defaultNamedNotOptArg):
		'AddTaxReportFilter'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pITaxReportFilter
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddTaxReportFilter', '{A5CDC033-47D7-4019-801A-8443F14D52D0}')
		return ret

	def DeleteTaxReportFilter(self, pITaxReportFilterParams=defaultNamedNotOptArg):
		'DeleteTaxReportFilter'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((9, 1),),pITaxReportFilterParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ITaxReportFilter
	def GetTaxReportFilter(self, pITaxReportFilterParams=defaultNamedNotOptArg):
		'GetTaxReportFilter'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pITaxReportFilterParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetTaxReportFilter', '{3503F7F1-5A0C-4D08-A498-0D9619097C09}')
		return ret

	# Result is of type ITaxReportFiltersParams
	def GetTaxReportFilterList(self, pITaxReportFilterParams=defaultNamedNotOptArg):
		'GetTaxReportFilterList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((9, 1),),pITaxReportFilterParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetTaxReportFilterList', '{813B8F2A-F8BC-4C70-A043-CF099057F3B8}')
		return ret

	def UpdateTaxReportFilter(self, pITaxReportFilter=defaultNamedNotOptArg):
		'UpdateTaxReportFilter'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pITaxReportFilter
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportLayout(DispatchBaseClass):
	'IReportLayout Interface'
	CLSID = IID('{77C5B820-63C3-4825-9279-964224F7BE00}')
	coclass_clsid = IID('{17432CFA-F59A-4F5E-B58D-A2948523C77F}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AllignFooterToBottom": (46, 2, (3, 0), (), "AllignFooterToBottom", None),
		"Author": (11, 2, (8, 0), (), "Author", None),
		"B1Version": (55, 2, (8, 0), (), "B1Version", None),
		"BottomMargin": (18, 2, (3, 0), (), "BottomMargin", None),
		"CRVersion": (56, 2, (8, 0), (), "CRVersion", None),
		"Category": (49, 2, (3, 0), (), "Category", None),
		"ChangeFontSizeForEMail": (38, 2, (3, 0), (), "ChangeFontSizeForEMail", None),
		"ChangeFontSizeInPreview": (35, 2, (3, 0), (), "ChangeFontSizeInPreview", None),
		"ConvertFontForEMail": (36, 2, (3, 0), (), "ConvertFontForEMail", None),
		"ConvertFontInPrintPreview": (33, 2, (3, 0), (), "ConvertFontInPrintPreview", None),
		"EMailFont": (37, 2, (8, 0), (), "EMailFont", None),
		"Editable": (19, 2, (3, 0), (), "Editable", None),
		"ExtensionErrorAction": (44, 2, (3, 0), (), "ExtensionErrorAction", None),
		"ExtensionName": (43, 2, (8, 0), (), "ExtensionName", None),
		"FollowUpReport": (32, 2, (8, 0), (), "FollowUpReport", None),
		"ForeignLanguageReport": (29, 2, (3, 0), (), "ForeignLanguageReport", None),
		"GridSize": (23, 2, (3, 0), (), "GridSize", None),
		"GridType": (24, 2, (3, 0), (), "GridType", None),
		"Height": (14, 2, (3, 0), (), "Height", None),
		"ImpExpObjCode": (42, 2, (3, 0), (), "ImpExpObjCode", None),
		"LayoutCode": (48, 2, (8, 0), (), "LayoutCode", None),
		"LeaderReport": (31, 2, (8, 0), (), "LeaderReport", None),
		"LeftMargin": (15, 2, (3, 0), (), "LeftMargin", None),
		"Localization": (53, 2, (8, 0), (), "Localization", None),
		"Name": (10, 2, (8, 0), (), "Name", None),
		"NumberOfCopies": (52, 2, (3, 0), (), "NumberOfCopies", None),
		"Orientation": (22, 2, (3, 0), (), "Orientation", None),
		"PaperSize": (21, 2, (8, 0), (), "PaperSize", None),
		"Picture": (27, 2, (8, 0), (), "Picture", None),
		"PreviewPrintingFont": (34, 2, (8, 0), (), "PreviewPrintingFont", None),
		"Printer": (50, 2, (8, 0), (), "Printer", None),
		"PrinterFirstPage": (51, 2, (8, 0), (), "PrinterFirstPage", None),
		"Query": (39, 2, (8, 0), (), "Query", None),
		"QueryType": (40, 2, (3, 0), (), "QueryType", None),
		"Remarks": (12, 2, (8, 0), (), "Remarks", None),
		"RepetitiveAreasNumber": (45, 2, (3, 0), (), "RepetitiveAreasNumber", None),
		# Method 'ReportLayoutItems' returns object of type 'IReportLayoutItems'
		"ReportLayoutItems": (47, 2, (9, 0), (), "ReportLayoutItems", '{E7092C39-C3B3-4928-A5AB-B0FF9B885D5E}'),
		"RightMargin": (16, 2, (3, 0), (), "RightMargin", None),
		"ShowGrid": (25, 2, (3, 0), (), "ShowGrid", None),
		"SnapToGrid": (26, 2, (3, 0), (), "SnapToGrid", None),
		"Sortable": (30, 2, (3, 0), (), "Sortable", None),
		"TopMargin": (17, 2, (3, 0), (), "TopMargin", None),
		# Method 'TranslationLines' returns object of type 'IReportLayout_TranslationLines'
		"TranslationLines": (57, 2, (9, 0), (), "TranslationLines", '{33201180-255B-46DF-A8C4-E8A7E2855353}'),
		"TypeCode": (28, 2, (8, 0), (), "TypeCode", None),
		"TypeDetail": (58, 2, (8, 0), (), "TypeDetail", None),
		"UseFirstPrinter": (54, 2, (3, 0), (), "UseFirstPrinter", None),
		"Width": (13, 2, (3, 0), (), "Width", None),
		"language": (41, 2, (3, 0), (), "language", None),
	}
	_prop_map_put_ = {
		"AllignFooterToBottom": ((46, LCID, 4, 0),()),
		"Author": ((11, LCID, 4, 0),()),
		"B1Version": ((55, LCID, 4, 0),()),
		"BottomMargin": ((18, LCID, 4, 0),()),
		"CRVersion": ((56, LCID, 4, 0),()),
		"Category": ((49, LCID, 4, 0),()),
		"ChangeFontSizeForEMail": ((38, LCID, 4, 0),()),
		"ChangeFontSizeInPreview": ((35, LCID, 4, 0),()),
		"ConvertFontForEMail": ((36, LCID, 4, 0),()),
		"ConvertFontInPrintPreview": ((33, LCID, 4, 0),()),
		"EMailFont": ((37, LCID, 4, 0),()),
		"ExtensionErrorAction": ((44, LCID, 4, 0),()),
		"ExtensionName": ((43, LCID, 4, 0),()),
		"FollowUpReport": ((32, LCID, 4, 0),()),
		"ForeignLanguageReport": ((29, LCID, 4, 0),()),
		"GridSize": ((23, LCID, 4, 0),()),
		"GridType": ((24, LCID, 4, 0),()),
		"Height": ((14, LCID, 4, 0),()),
		"ImpExpObjCode": ((42, LCID, 4, 0),()),
		"LeaderReport": ((31, LCID, 4, 0),()),
		"LeftMargin": ((15, LCID, 4, 0),()),
		"Localization": ((53, LCID, 4, 0),()),
		"Name": ((10, LCID, 4, 0),()),
		"NumberOfCopies": ((52, LCID, 4, 0),()),
		"Orientation": ((22, LCID, 4, 0),()),
		"PaperSize": ((21, LCID, 4, 0),()),
		"Picture": ((27, LCID, 4, 0),()),
		"PreviewPrintingFont": ((34, LCID, 4, 0),()),
		"Printer": ((50, LCID, 4, 0),()),
		"PrinterFirstPage": ((51, LCID, 4, 0),()),
		"Query": ((39, LCID, 4, 0),()),
		"QueryType": ((40, LCID, 4, 0),()),
		"Remarks": ((12, LCID, 4, 0),()),
		"ReportLayoutItems": ((47, LCID, 4, 0),()),
		"RightMargin": ((16, LCID, 4, 0),()),
		"ShowGrid": ((25, LCID, 4, 0),()),
		"SnapToGrid": ((26, LCID, 4, 0),()),
		"TopMargin": ((17, LCID, 4, 0),()),
		"TypeCode": ((28, LCID, 4, 0),()),
		"TypeDetail": ((58, LCID, 4, 0),()),
		"UseFirstPrinter": ((54, LCID, 4, 0),()),
		"Width": ((13, LCID, 4, 0),()),
		"language": ((41, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportLayoutItem(DispatchBaseClass):
	'IReportLayoutItem Interface'
	CLSID = IID('{2691123A-50EC-4554-9180-490532131218}')
	coclass_clsid = IID('{94A52D5C-D174-4B52-9A5B-2E9E936226DF}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"BackgroundBlue": (30, 2, (3, 0), (), "BackgroundBlue", None),
		"BackgroundGreen": (29, 2, (3, 0), (), "BackgroundGreen", None),
		"BackgroundRed": (28, 2, (3, 0), (), "BackgroundRed", None),
		"BarCodeStandard": (72, 2, (3, 0), (), "BarCodeStandard", None),
		"BlockFontChange": (74, 2, (3, 0), (), "BlockFontChange", None),
		"BorderBlue": (39, 2, (3, 0), (), "BorderBlue", None),
		"BorderGreen": (38, 2, (3, 0), (), "BorderGreen", None),
		"BorderRed": (37, 2, (3, 0), (), "BorderRed", None),
		"BottomBorderLineThickness": (26, 2, (3, 0), (), "BottomBorderLineThickness", None),
		"BottomMargin": (22, 2, (3, 0), (), "BottomMargin", None),
		"DataSource": (49, 2, (3, 0), (), "DataSource", None),
		"DisplayDescription": (54, 2, (3, 0), (), "DisplayDescription", None),
		"DisplayRepetitiveAreaFooterOnAllPages": (88, 2, (3, 0), (), "DisplayRepetitiveAreaFooterOnAllPages", None),
		"DisplayTotalAsAWord": (73, 2, (3, 0), (), "DisplayTotalAsAWord", None),
		"DistanceToRepetitiveDuplicate": (85, 2, (3, 0), (), "DistanceToRepetitiveDuplicate", None),
		"DuplicateRepetitiveArea": (83, 2, (3, 0), (), "DuplicateRepetitiveArea", None),
		"Editable": (56, 2, (3, 0), (), "Editable", None),
		"FieldIdentifier": (86, 2, (8, 0), (), "FieldIdentifier", None),
		"FieldName": (53, 2, (8, 0), (), "FieldName", None),
		"FontName": (43, 2, (8, 0), (), "FontName", None),
		"FontSize": (44, 2, (3, 0), (), "FontSize", None),
		"GroupNumber": (42, 2, (3, 0), (), "GroupNumber", None),
		"Height": (18, 2, (3, 0), (), "Height", None),
		"HeightAdjustments": (82, 2, (3, 0), (), "HeightAdjustments", None),
		"HideRepetitiveAreaIfEmpty": (87, 2, (3, 0), (), "HideRepetitiveAreaIfEmpty", None),
		"HighlightBlue": (36, 2, (3, 0), (), "HighlightBlue", None),
		"HighlightGreen": (35, 2, (3, 0), (), "HighlightGreen", None),
		"HighlightRed": (34, 2, (3, 0), (), "HighlightRed", None),
		"HorizontalAlignment": (46, 2, (3, 0), (), "HorizontalAlignment", None),
		"ItemIndex": (77, 2, (3, 0), (), "ItemIndex", None),
		"ItemNumber": (57, 2, (3, 0), (), "ItemNumber", None),
		"Left": (15, 2, (3, 0), (), "Left", None),
		"LeftBorderLineThickness": (23, 2, (3, 0), (), "LeftBorderLineThickness", None),
		"LeftMargin": (19, 2, (3, 0), (), "LeftMargin", None),
		"LineBreak": (47, 2, (3, 0), (), "LineBreak", None),
		"LinkToField": (68, 2, (8, 0), (), "LinkToField", None),
		"NewPage": (65, 2, (3, 0), (), "NewPage", None),
		"NextSegmentItemNumber": (81, 2, (8, 0), (), "NextSegmentItemNumber", None),
		"NumberOfLinesInRepetitiveArea": (84, 2, (3, 0), (), "NumberOfLinesInRepetitiveArea", None),
		"ParentIndex": (76, 2, (3, 0), (), "ParentIndex", None),
		"ParentType": (11, 2, (3, 0), (), "ParentType", None),
		"PictureSize": (48, 2, (3, 0), (), "PictureSize", None),
		"PrintAsBarCode": (66, 2, (3, 0), (), "PrintAsBarCode", None),
		"RelateToField": (80, 2, (8, 0), (), "RelateToField", None),
		"ReverseSort": (61, 2, (3, 0), (), "ReverseSort", None),
		"RightBorderLineThickness": (24, 2, (3, 0), (), "RightBorderLineThickness", None),
		"RightMargin": (20, 2, (3, 0), (), "RightMargin", None),
		"SetAsGroup": (64, 2, (3, 0), (), "SetAsGroup", None),
		"ShadowThickness": (27, 2, (3, 0), (), "ShadowThickness", None),
		"SortLevel": (60, 2, (3, 0), (), "SortLevel", None),
		"SortType": (62, 2, (3, 0), (), "SortType", None),
		"String": (50, 2, (8, 0), (), "String", None),
		"StringFiller": (79, 2, (8, 0), (), "StringFiller", None),
		"StringLength": (78, 2, (3, 0), (), "StringLength", None),
		"SuppressZeros": (14, 2, (3, 0), (), "SuppressZeros", None),
		"TableName": (52, 2, (8, 0), (), "TableName", None),
		"TextBlue": (33, 2, (3, 0), (), "TextBlue", None),
		"TextGreen": (32, 2, (3, 0), (), "TextGreen", None),
		"TextRed": (31, 2, (3, 0), (), "TextRed", None),
		"TextStyle": (45, 2, (3, 0), (), "TextStyle", None),
		"Top": (16, 2, (3, 0), (), "Top", None),
		"TopBorderLineThickness": (25, 2, (3, 0), (), "TopBorderLineThickness", None),
		"TopMargin": (21, 2, (3, 0), (), "TopMargin", None),
		"Type": (12, 2, (3, 0), (), "Type", None),
		"Unique": (63, 2, (3, 0), (), "Unique", None),
		"VariableNumber": (51, 2, (3, 0), (), "VariableNumber", None),
		"VerticalAlignment": (59, 2, (3, 0), (), "VerticalAlignment", None),
		"Visible": (13, 2, (3, 0), (), "Visible", None),
		"Width": (17, 2, (3, 0), (), "Width", None),
	}
	_prop_map_put_ = {
		"BackgroundBlue": ((30, LCID, 4, 0),()),
		"BackgroundGreen": ((29, LCID, 4, 0),()),
		"BackgroundRed": ((28, LCID, 4, 0),()),
		"BarCodeStandard": ((72, LCID, 4, 0),()),
		"BlockFontChange": ((74, LCID, 4, 0),()),
		"BorderBlue": ((39, LCID, 4, 0),()),
		"BorderGreen": ((38, LCID, 4, 0),()),
		"BorderRed": ((37, LCID, 4, 0),()),
		"BottomBorderLineThickness": ((26, LCID, 4, 0),()),
		"BottomMargin": ((22, LCID, 4, 0),()),
		"DataSource": ((49, LCID, 4, 0),()),
		"DisplayDescription": ((54, LCID, 4, 0),()),
		"DisplayRepetitiveAreaFooterOnAllPages": ((88, LCID, 4, 0),()),
		"DisplayTotalAsAWord": ((73, LCID, 4, 0),()),
		"DistanceToRepetitiveDuplicate": ((85, LCID, 4, 0),()),
		"DuplicateRepetitiveArea": ((83, LCID, 4, 0),()),
		"Editable": ((56, LCID, 4, 0),()),
		"FieldIdentifier": ((86, LCID, 4, 0),()),
		"FieldName": ((53, LCID, 4, 0),()),
		"FontName": ((43, LCID, 4, 0),()),
		"FontSize": ((44, LCID, 4, 0),()),
		"GroupNumber": ((42, LCID, 4, 0),()),
		"Height": ((18, LCID, 4, 0),()),
		"HeightAdjustments": ((82, LCID, 4, 0),()),
		"HideRepetitiveAreaIfEmpty": ((87, LCID, 4, 0),()),
		"HighlightBlue": ((36, LCID, 4, 0),()),
		"HighlightGreen": ((35, LCID, 4, 0),()),
		"HighlightRed": ((34, LCID, 4, 0),()),
		"HorizontalAlignment": ((46, LCID, 4, 0),()),
		"ItemIndex": ((77, LCID, 4, 0),()),
		"ItemNumber": ((57, LCID, 4, 0),()),
		"Left": ((15, LCID, 4, 0),()),
		"LeftBorderLineThickness": ((23, LCID, 4, 0),()),
		"LeftMargin": ((19, LCID, 4, 0),()),
		"LineBreak": ((47, LCID, 4, 0),()),
		"LinkToField": ((68, LCID, 4, 0),()),
		"NewPage": ((65, LCID, 4, 0),()),
		"NextSegmentItemNumber": ((81, LCID, 4, 0),()),
		"NumberOfLinesInRepetitiveArea": ((84, LCID, 4, 0),()),
		"ParentIndex": ((76, LCID, 4, 0),()),
		"ParentType": ((11, LCID, 4, 0),()),
		"PictureSize": ((48, LCID, 4, 0),()),
		"PrintAsBarCode": ((66, LCID, 4, 0),()),
		"RelateToField": ((80, LCID, 4, 0),()),
		"ReverseSort": ((61, LCID, 4, 0),()),
		"RightBorderLineThickness": ((24, LCID, 4, 0),()),
		"RightMargin": ((20, LCID, 4, 0),()),
		"SetAsGroup": ((64, LCID, 4, 0),()),
		"ShadowThickness": ((27, LCID, 4, 0),()),
		"SortLevel": ((60, LCID, 4, 0),()),
		"SortType": ((62, LCID, 4, 0),()),
		"String": ((50, LCID, 4, 0),()),
		"StringFiller": ((79, LCID, 4, 0),()),
		"StringLength": ((78, LCID, 4, 0),()),
		"SuppressZeros": ((14, LCID, 4, 0),()),
		"TableName": ((52, LCID, 4, 0),()),
		"TextBlue": ((33, LCID, 4, 0),()),
		"TextGreen": ((32, LCID, 4, 0),()),
		"TextRed": ((31, LCID, 4, 0),()),
		"TextStyle": ((45, LCID, 4, 0),()),
		"Top": ((16, LCID, 4, 0),()),
		"TopBorderLineThickness": ((25, LCID, 4, 0),()),
		"TopMargin": ((21, LCID, 4, 0),()),
		"Type": ((12, LCID, 4, 0),()),
		"Unique": ((63, LCID, 4, 0),()),
		"VariableNumber": ((51, LCID, 4, 0),()),
		"VerticalAlignment": ((59, LCID, 4, 0),()),
		"Visible": ((13, LCID, 4, 0),()),
		"Width": ((17, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportLayoutItems(DispatchBaseClass):
	'IReportLayoutItems Interface'
	CLSID = IID('{E7092C39-C3B3-4928-A5AB-B0FF9B885D5E}')
	coclass_clsid = IID('{28729C80-FAA2-449D-8847-926D8A225E6A}')

	# Result is of type IReportLayoutItem
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{2691123A-50EC-4554-9180-490532131218}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IReportLayoutItem
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{2691123A-50EC-4554-9180-490532131218}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{2691123A-50EC-4554-9180-490532131218}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{2691123A-50EC-4554-9180-490532131218}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IReportLayoutParams(DispatchBaseClass):
	'IReportLayoutParams Interface'
	CLSID = IID('{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')
	coclass_clsid = IID('{AC6E5992-362B-4007-8C90-1AA8DF3B3BA2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Category": (13, 2, (3, 0), (), "Category", None),
		"LayoutCode": (11, 2, (8, 0), (), "LayoutCode", None),
		"LayoutName": (12, 2, (8, 0), (), "LayoutName", None),
	}
	_prop_map_put_ = {
		"LayoutCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportLayoutPrintParams(DispatchBaseClass):
	'IReportLayoutPrintParams Interface'
	CLSID = IID('{A86FB678-5037-4F08-AD65-6C281693C16F}')
	coclass_clsid = IID('{6162B662-5834-44EC-9A3A-6E36B4EB227F}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (12, 2, (3, 0), (), "DocEntry", None),
		"LayoutCode": (11, 2, (8, 0), (), "LayoutCode", None),
	}
	_prop_map_put_ = {
		"DocEntry": ((12, LCID, 4, 0),()),
		"LayoutCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportLayout_TranslationLine(DispatchBaseClass):
	'IReportLayout_TranslationLine Interface'
	CLSID = IID('{86A368F0-8603-466A-906F-9FC811B1B711}')
	coclass_clsid = IID('{E8F14B2A-6381-4A84-8BF2-A4DA70A9F684}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CreateDate": (14, 2, (7, 0), (), "CreateDate", None),
		"CreateTime": (16, 2, (3, 0), (), "CreateTime", None),
		"DocEntry": (10, 2, (8, 0), (), "DocEntry", None),
		"DocName": (12, 2, (8, 0), (), "DocName", None),
		"LanguageCode": (13, 2, (3, 0), (), "LanguageCode", None),
		"LineNumber": (11, 2, (3, 0), (), "LineNumber", None),
		"UpdateDate": (15, 2, (7, 0), (), "UpdateDate", None),
		"UpdateTime": (17, 2, (3, 0), (), "UpdateTime", None),
	}
	_prop_map_put_ = {
		"CreateDate": ((14, LCID, 4, 0),()),
		"CreateTime": ((16, LCID, 4, 0),()),
		"DocName": ((12, LCID, 4, 0),()),
		"LanguageCode": ((13, LCID, 4, 0),()),
		"UpdateDate": ((15, LCID, 4, 0),()),
		"UpdateTime": ((17, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportLayout_TranslationLines(DispatchBaseClass):
	'IReportLayout_TranslationLines Interface'
	CLSID = IID('{33201180-255B-46DF-A8C4-E8A7E2855353}')
	coclass_clsid = IID('{49ABC0B0-082C-4F04-913B-199D08444440}')

	# Result is of type IReportLayout_TranslationLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{86A368F0-8603-466A-906F-9FC811B1B711}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IReportLayout_TranslationLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{86A368F0-8603-466A-906F-9FC811B1B711}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{86A368F0-8603-466A-906F-9FC811B1B711}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{86A368F0-8603-466A-906F-9FC811B1B711}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IReportLayoutsParams(DispatchBaseClass):
	'IReportLayoutsParams Interface'
	CLSID = IID('{16209A8A-D1E6-4820-A4B4-DB43EBEE8BFA}')
	coclass_clsid = IID('{B9580913-6CE6-48EC-84CF-E22544326D60}')

	# Result is of type IReportLayoutParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IReportLayoutParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IReportLayoutsService(DispatchBaseClass):
	'IReportLayoutsService Interface'
	CLSID = IID('{E5CFF30C-8D7D-4F36-A505-B2BA0EC0CB21}')
	coclass_clsid = IID('{B11BE4C5-0512-4150-A932-336EBF71547F}')

	# Result is of type IReportLayoutParams
	def AddReportLayout(self, pIReportLayout=defaultNamedNotOptArg):
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((9, 1),),pIReportLayout
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddReportLayout', '{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')
		return ret

	# Result is of type IReportLayoutParams
	def AddReportLayoutToMenu(self, ppIReportLayout=defaultNamedNotOptArg, MenuID=defaultNamedNotOptArg):
		ret = self._oleobj_.InvokeTypes(18, LCID, 1, (9, 0), ((9, 1), (8, 1)),ppIReportLayout
			, MenuID)
		if ret is not None:
			ret = Dispatch(ret, u'AddReportLayoutToMenu', '{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')
		return ret

	def DeleteReportLayout(self, pIReportLayoutParams=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pIReportLayoutParams
			)

	def DeleteReportLayoutAndMenu(self, ppIReportLayoutParams=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(19, LCID, 1, (24, 0), ((9, 1),),ppIReportLayoutParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IDefaultReportParams
	def GetDefaultReport(self, pIReportParams=defaultNamedNotOptArg):
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIReportParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDefaultReport', '{90E9CFE3-0440-4E26-B8E7-975A9A4638B4}')
		return ret

	# Result is of type IReportLayout
	def GetDefaultReportLayout(self, pIReportParams=defaultNamedNotOptArg):
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), ((9, 1),),pIReportParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDefaultReportLayout', '{77C5B820-63C3-4825-9279-964224F7BE00}')
		return ret

	# Result is of type IReportLayout
	def GetReportLayout(self, pIReportLayoutParams=defaultNamedNotOptArg):
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((9, 1),),pIReportLayoutParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetReportLayout', '{77C5B820-63C3-4825-9279-964224F7BE00}')
		return ret

	# Result is of type IReportLayoutsParams
	def GetReportLayoutList(self, pIReportParams=defaultNamedNotOptArg):
		ret = self._oleobj_.InvokeTypes(16, LCID, 1, (9, 0), ((9, 1),),pIReportParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetReportLayoutList', '{16209A8A-D1E6-4820-A4B4-DB43EBEE8BFA}')
		return ret

	def Print(self, ppIReportLayoutPrintParams=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((9, 1),),ppIReportLayoutPrintParams
			)

	def SetDefaultReport(self, ppIDefaultReportParams=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((9, 1),),ppIDefaultReportParams
			)

	def UpdateLanguageReport(self, ppIReportLayout=defaultNamedNotOptArg):
		return self._oleobj_.InvokeTypes(17, LCID, 1, (24, 0), ((9, 1),),ppIReportLayout
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportParams(DispatchBaseClass):
	'IReportParams Interface'
	CLSID = IID('{0B4E873F-65FD-4638-9339-84D197CF8109}')
	coclass_clsid = IID('{5B9ECA1D-2E75-42EC-BCF2-FBD84756B8B1}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CardCode": (13, 2, (8, 0), (), "CardCode", None),
		"ReportCode": (11, 2, (8, 0), (), "ReportCode", None),
		"UserID": (12, 2, (3, 0), (), "UserID", None),
	}
	_prop_map_put_ = {
		"CardCode": ((13, LCID, 4, 0),()),
		"ReportCode": ((11, LCID, 4, 0),()),
		"UserID": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportType(DispatchBaseClass):
	'IReportType Interface'
	CLSID = IID('{41776B28-16AF-4699-B4FC-475989790FB8}')
	coclass_clsid = IID('{8FA3D085-7415-4301-8262-C977EB250400}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AddonFormType": (14, 2, (8, 0), (), "AddonFormType", None),
		"AddonName": (13, 2, (8, 0), (), "AddonName", None),
		"DefaultReportLayout": (12, 2, (8, 0), (), "DefaultReportLayout", None),
		"MenuID": (15, 2, (8, 0), (), "MenuID", None),
		"TypeCode": (10, 2, (8, 0), (), "TypeCode", None),
		"TypeName": (11, 2, (8, 0), (), "TypeName", None),
	}
	_prop_map_put_ = {
		"AddonFormType": ((14, LCID, 4, 0),()),
		"AddonName": ((13, LCID, 4, 0),()),
		"DefaultReportLayout": ((12, LCID, 4, 0),()),
		"MenuID": ((15, LCID, 4, 0),()),
		"TypeName": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportTypeParams(DispatchBaseClass):
	'IReportTypeParams Interface'
	CLSID = IID('{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')
	coclass_clsid = IID('{6A5583E4-CC36-4360-982B-135BAD6BBFD2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AddonFormType": (13, 2, (8, 0), (), "AddonFormType", None),
		"AddonName": (12, 2, (8, 0), (), "AddonName", None),
		"MenuID": (14, 2, (8, 0), (), "MenuID", None),
		"TypeCode": (10, 2, (8, 0), (), "TypeCode", None),
		"TypeName": (11, 2, (8, 0), (), "TypeName", None),
	}
	_prop_map_put_ = {
		"TypeCode": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IReportTypesParams(DispatchBaseClass):
	'IReportTypesParams Interface'
	CLSID = IID('{343A6016-2B36-4522-B0E9-477A062EF6DB}')
	coclass_clsid = IID('{0AE67F4C-4636-4B39-AB14-B5C669FB2DF0}')

	# Result is of type IReportTypeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IReportTypeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IReportTypesService(DispatchBaseClass):
	'IReportTypesService Interface'
	CLSID = IID('{2DC3C9A3-A237-4DB3-A0BC-AB92D24ED68E}')
	coclass_clsid = IID('{EEDDBCFE-7934-4DE6-9B67-F43B454D3336}')

	# Result is of type IReportTypeParams
	def AddReportType(self, pIReportType=defaultNamedNotOptArg):
		'AddReportType'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pIReportType
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddReportType', '{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')
		return ret

	def DeleteReportType(self, pIReportType=defaultNamedNotOptArg):
		'DeleteReportType'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pIReportType
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IReportType
	def GetReportType(self, pIReportTypeParams=defaultNamedNotOptArg):
		'GetReportType'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIReportTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetReportType', '{41776B28-16AF-4699-B4FC-475989790FB8}')
		return ret

	# Result is of type IReportTypesParams
	def GetReportTypeList(self):
		'GetReportTypeList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetReportTypeList', '{343A6016-2B36-4522-B0E9-477A062EF6DB}')
		return ret

	def UpdateReportType(self, pIReportType=defaultNamedNotOptArg):
		'UpdateReportType'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIReportType
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IRetornoCode(DispatchBaseClass):
	'IRetornoCode Interface'
	CLSID = IID('{2C08600E-B9F0-432D-9D95-F934DDC01165}')
	coclass_clsid = IID('{E57AA648-0ADC-4146-A01E-19E0AB5C0A2D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"BOEStatus": (13, 2, (3, 0), (), "BOEStatus", None),
		"BankCode": (17, 2, (8, 0), (), "BankCode", None),
		"Color": (15, 2, (3, 0), (), "Color", None),
		"Description": (14, 2, (8, 0), (), "Description", None),
		"FileFormat": (16, 2, (8, 0), (), "FileFormat", None),
		"MovementCode": (12, 2, (3, 0), (), "MovementCode", None),
		"OccurenceCode": (11, 2, (3, 0), (), "OccurenceCode", None),
	}
	_prop_map_put_ = {
		"BOEStatus": ((13, LCID, 4, 0),()),
		"BankCode": ((17, LCID, 4, 0),()),
		"Color": ((15, LCID, 4, 0),()),
		"Description": ((14, LCID, 4, 0),()),
		"FileFormat": ((16, LCID, 4, 0),()),
		"MovementCode": ((12, LCID, 4, 0),()),
		"OccurenceCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IRetornoCodeParams(DispatchBaseClass):
	'IRetornoCodeParams Interface'
	CLSID = IID('{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')
	coclass_clsid = IID('{3932D717-09BF-4109-BDBB-CBF31DEF5E34}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"BOEStatus": (13, 2, (3, 0), (), "BOEStatus", None),
		"BankCode": (17, 2, (8, 0), (), "BankCode", None),
		"Color": (15, 2, (3, 0), (), "Color", None),
		"Description": (14, 2, (8, 0), (), "Description", None),
		"FileFormat": (16, 2, (8, 0), (), "FileFormat", None),
		"MovementCode": (12, 2, (3, 0), (), "MovementCode", None),
		"OccurenceCode": (11, 2, (3, 0), (), "OccurenceCode", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IRetornoCodeParamsCollection(DispatchBaseClass):
	'IRetornoCodeParamsCollection Interface'
	CLSID = IID('{6692DB25-3CF4-44C4-932D-1F6D13DF6E7C}')
	coclass_clsid = IID('{E25C76F1-5CE3-4001-AAD4-525D50E4C294}')

	# Result is of type IRetornoCodeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IRetornoCodeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IRetornoCodesService(DispatchBaseClass):
	'IRetornoCodesService Interface'
	CLSID = IID('{EA19AA7D-6063-4C86-BC1C-27B0572209ED}')
	coclass_clsid = IID('{AFC4F081-3100-4940-88E0-E614C717E8A7}')

	# Result is of type IRetornoCodeParams
	def Add(self, pIRetornoCode=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIRetornoCode
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')
		return ret

	def Delete(self, pIRetornoCodeParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIRetornoCodeParams
			)

	# Result is of type IRetornoCode
	def Get(self, pIRetornoCodeParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIRetornoCodeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{2C08600E-B9F0-432D-9D95-F934DDC01165}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IRetornoCodeParamsCollection
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{6692DB25-3CF4-44C4-932D-1F6D13DF6E7C}')
		return ret

	def Update(self, pIRetornoCode=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIRetornoCode
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IRoundedData(DispatchBaseClass):
	'IRoundedData Interface'
	CLSID = IID('{EF86275D-924A-4AC9-9461-E9AAF80894B6}')
	coclass_clsid = IID('{142EBC48-A651-4AA5-831C-8A4DA3172194}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Value": (10, 2, (5, 0), (), "Value", None),
	}
	_prop_map_put_ = {
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(10, 2, (5, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISBObob(DispatchBaseClass):
	'ISBObob Interface'
	CLSID = IID('{268D6CC3-E244-4AD7-B009-16C8ED7F710A}')
	coclass_clsid = IID('{A740D0B2-649F-40A6-AF5E-77FF340AEEFD}')

	def ConvertEnumValueToValidValue(self, enumName=defaultNamedNotOptArg, enumValue=defaultNamedNotOptArg):
		'method ConvertEnumValueToValidValue'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(18, LCID, 1, (8, 0), ((8, 1), (3, 1)),enumName
			, enumValue)

	def ConvertValidValueToEnumValue(self, enumName=defaultNamedNotOptArg, ValidValue=defaultNamedNotOptArg):
		'method ConvertValidValueToEnumValue'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (3, 0), ((8, 1), (8, 1)),enumName
			, ValidValue)

	# Result is of type IRecordset
	def Format_DateToString(self, inDate=defaultNamedNotOptArg):
		'method Format_DateToString'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((7, 1),),inDate
			)
		if ret is not None:
			ret = Dispatch(ret, u'Format_DateToString', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def Format_MoneyToString(self, inMoney=defaultNamedNotOptArg, inPrecision=defaultNamedNotOptArg):
		'method Format_MoneyToString'
		ret = self._oleobj_.InvokeTypes(15, LCID, 1, (9, 0), ((5, 1), (3, 1)),inMoney
			, inPrecision)
		if ret is not None:
			ret = Dispatch(ret, u'Format_MoneyToString', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def Format_StringToDate(self, inStr=defaultNamedNotOptArg):
		'method Format_StringToDate'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), ((8, 1),),inStr
			)
		if ret is not None:
			ret = Dispatch(ret, u'Format_StringToDate', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetAccountSegmentsByCode(self, AccountCode=defaultNamedNotOptArg, AddSeperator=defaultNamedNotOptArg):
		'method GetAccountSegmentsByCode'
		ret = self._oleobj_.InvokeTypes(21, LCID, 1, (9, 0), ((8, 1), (11, 1)),AccountCode
			, AddSeperator)
		if ret is not None:
			ret = Dispatch(ret, u'GetAccountSegmentsByCode', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetBPList(self, CardType=defaultNamedNotOptArg):
		'method GetBPList'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 0),),CardType
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetBPList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetContactEmployees(self, CardCode=defaultNamedNotOptArg):
		'method GetContactEmployees'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), ((8, 1),),CardCode
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetContactEmployees', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetCurrencyRate(self, Currency=defaultNamedNotOptArg, Date=defaultNamedNotOptArg):
		'method GetCurrencyRate'
		ret = self._oleobj_.InvokeTypes(5, LCID, 1, (9, 0), ((8, 1), (7, 1)),Currency
			, Date)
		if ret is not None:
			ret = Dispatch(ret, u'GetCurrencyRate', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetDueDate(self, CardCode=defaultNamedNotOptArg, refDate=defaultNamedNotOptArg):
		'method GetDueDate'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1), (7, 1)),CardCode
			, refDate)
		if ret is not None:
			ret = Dispatch(ret, u'GetDueDate', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	def GetEwaParameters(self, bstrKey=defaultNamedNotOptArg, pbstrRsltEwaUserName=pythoncom.Missing, pbstrRsltEwaPassword=pythoncom.Missing):
		'method GetEwaParameters'
		return self._ApplyTypes_(28, 1, (24, 0), ((8, 1), (16392, 2), (16392, 2)), u'GetEwaParameters', None,bstrKey
			, pbstrRsltEwaUserName, pbstrRsltEwaPassword)

	# Result is of type IRecordset
	def GetFieldValidValues(self, TableName=defaultNamedNotOptArg, FieldName=defaultNamedNotOptArg):
		'method GetFieldValidValues'
		ret = self._oleobj_.InvokeTypes(23, LCID, 1, (9, 0), ((8, 1), (8, 1)),TableName
			, FieldName)
		if ret is not None:
			ret = Dispatch(ret, u'GetFieldValidValues', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetIndexRate(self, Index=defaultNamedNotOptArg, Date=defaultNamedNotOptArg):
		'method GetIndexRate'
		ret = self._oleobj_.InvokeTypes(6, LCID, 1, (9, 0), ((8, 1), (7, 1)),Index
			, Date)
		if ret is not None:
			ret = Dispatch(ret, u'GetIndexRate', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetItemList(self):
		'method GetItemList'
		ret = self._oleobj_.InvokeTypes(8, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetItemList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetItemPrice(self, CardCode=defaultNamedNotOptArg, ItemCode=defaultNamedNotOptArg, amount=defaultNamedNotOptArg, Date=defaultNamedNotOptArg):
		'method GetItemPrice'
		ret = self._oleobj_.InvokeTypes(7, LCID, 1, (9, 0), ((8, 1), (8, 1), (5, 1), (7, 1)),CardCode
			, ItemCode, amount, Date)
		if ret is not None:
			ret = Dispatch(ret, u'GetItemPrice', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetLocalCurrency(self):
		'method GetLocalCurrency'
		ret = self._oleobj_.InvokeTypes(4, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetLocalCurrency', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetObjectKeyBySingleValue(self, ObjNum=defaultNamedNotOptArg, PropName=defaultNamedNotOptArg, Value=defaultNamedNotOptArg, Condition=defaultNamedNotOptArg):
		'method GetObjectKeyBySingleValue'
		ret = self._oleobj_.InvokeTypes(17, LCID, 1, (9, 0), ((3, 1), (8, 1), (8, 1), (3, 1)),ObjNum
			, PropName, Value, Condition)
		if ret is not None:
			ret = Dispatch(ret, u'GetObjectKeyBySingleValue', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetObjectPermission(self, Object=defaultNamedNotOptArg):
		'method GetObjectPermission'
		ret = self._oleobj_.InvokeTypes(24, LCID, 1, (9, 0), ((3, 1),),Object
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetObjectPermission', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetSystemCurrency(self):
		'method GetSystemCurrency'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetSystemCurrency', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetSystemPermission(self, UserName=defaultNamedNotOptArg, PermissionID=defaultNamedNotOptArg):
		'method GetSystemPermission'
		ret = self._oleobj_.InvokeTypes(26, LCID, 1, (9, 0), ((8, 1), (8, 1)),UserName
			, PermissionID)
		if ret is not None:
			ret = Dispatch(ret, u'GetSystemPermission', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetTableFieldList(self, TableName=defaultNamedNotOptArg):
		'method GetTableFieldList'
		ret = self._oleobj_.InvokeTypes(22, LCID, 1, (9, 0), ((8, 1),),TableName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetTableFieldList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetTableList(self):
		'method GetTableList'
		ret = self._oleobj_.InvokeTypes(25, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetTableList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	# Result is of type IRecordset
	def GetUserList(self):
		'method GetUserList'
		ret = self._oleobj_.InvokeTypes(9, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetUserList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	def GetValidValueDescription(self, ObjNum=defaultNamedNotOptArg, ObjectName=defaultNamedNotOptArg, PropertyName=defaultNamedNotOptArg, enumValue=defaultNamedNotOptArg):
		'method GetValidValueDescription'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(20, LCID, 1, (8, 0), ((3, 1), (8, 1), (8, 1), (3, 1)),ObjNum
			, ObjectName, PropertyName, enumValue)

	# Result is of type IRecordset
	def GetWareHouseList(self):
		'method GetWareHouseList'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetWareHouseList', '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')
		return ret

	def PutEwaParameters(self, bstrKey=defaultNamedNotOptArg, bstrEwaUserName=defaultNamedNotOptArg, bstrEwaPassword=defaultNamedNotOptArg):
		'method PutEwaParameters'
		return self._oleobj_.InvokeTypes(29, LCID, 1, (24, 0), ((8, 1), (8, 1), (8, 1)),bstrKey
			, bstrEwaUserName, bstrEwaPassword)

	def SetCurrencyRate(self, Currency=defaultNamedNotOptArg, Date=defaultNamedNotOptArg, Value=defaultNamedNotOptArg, Update=False):
		'method SetCurrencyRate'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((8, 1), (7, 1), (5, 1), (11, 49)),Currency
			, Date, Value, Update)

	def SetSystemPermission(self, UserName=defaultNamedNotOptArg, PermissionID=defaultNamedNotOptArg, Permission=defaultNamedNotOptArg):
		'method SetSystemPermission'
		return self._oleobj_.InvokeTypes(27, LCID, 1, (24, 0), ((8, 1), (8, 1), (3, 1)),UserName
			, PermissionID, Permission)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesForecast(DispatchBaseClass):
	'ISalesForecast Interface'
	CLSID = IID('{0D31ADD3-85B1-40F1-979F-8612E10B8DD8}')
	coclass_clsid = IID('{3E6CC39D-A5A5-43E7-856E-4A1D4D97A77D}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(60, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(61, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(9, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (11, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ForecastCode": (3, 2, (8, 0), (), "ForecastCode", None),
		"ForecastEndDate": (2, 2, (7, 0), (), "ForecastEndDate", None),
		"ForecastName": (4, 2, (8, 0), (), "ForecastName", None),
		"ForecastStartDate": (1, 2, (7, 0), (), "ForecastStartDate", None),
		# Method 'Lines' returns object of type 'ISalesForecast_Lines'
		"Lines": (58, 2, (9, 0), (), "Lines", '{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}'),
		"Numerator": (59, 2, (3, 0), (), "Numerator", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (10, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"View": (12, 2, (3, 0), (), "View", None),
	}
	_prop_map_put_ = {
		"ForecastCode": ((3, LCID, 4, 0),()),
		"ForecastEndDate": ((2, LCID, 4, 0),()),
		"ForecastName": ((4, LCID, 4, 0),()),
		"ForecastStartDate": ((1, LCID, 4, 0),()),
		"View": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesForecast_Lines(DispatchBaseClass):
	'ISalesForecast_Lines Interface'
	CLSID = IID('{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}')
	coclass_clsid = IID('{8B560D21-5616-4D85-ACA9-BC8145B30A73}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"ForecastedDay": (2, 2, (7, 0), (), "ForecastedDay", None),
		"ItemNo": (3, 2, (8, 0), (), "ItemNo", None),
		"Quantity": (1, 2, (5, 0), (), "Quantity", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ForecastedDay": ((2, LCID, 4, 0),()),
		"ItemNo": ((3, LCID, 4, 0),()),
		"Quantity": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunities(DispatchBaseClass):
	'ISalesOpportunities Interface'
	CLSID = IID('{4F06C847-96F8-4421-B1C7-2FA41FCB0CFF}')
	coclass_clsid = IID('{E7843EA1-A67D-4C9A-B61D-EABDE49D4692}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(59, LCID, 1, (8, 0), (),)

	def GetByKey(self, OpprId=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),OpprId
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(60, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AttachmentEntry": (62, 2, (3, 0), (), "AttachmentEntry", None),
		"BPChanelCode": (55, 2, (8, 0), (), "BPChanelCode", None),
		"BPChanelName": (47, 2, (8, 0), (), "BPChanelName", None),
		"BPChannelContact": (54, 2, (3, 0), (), "BPChannelContact", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (10, 2, (8, 0), (), "CardCode", None),
		"ClosingDate": (53, 2, (7, 0), (), "ClosingDate", None),
		"ClosingGrossProfitLocal": (34, 2, (5, 0), (), "ClosingGrossProfitLocal", None),
		"ClosingGrossProfitSystem": (35, 2, (5, 0), (), "ClosingGrossProfitSystem", None),
		"ClosingPercentage": (36, 2, (5, 0), (), "ClosingPercentage", None),
		"ClosingType": (56, 2, (3, 0), (), "ClosingType", None),
		# Method 'Competition' returns object of type 'ISalesOpportunitiesCompetition'
		"Competition": (39, 2, (9, 0), (), "Competition", '{19E6540E-4E64-48C1-9525-29D5710D1FFD}'),
		"ContactPerson": (12, 2, (3, 0), (), "ContactPerson", None),
		"CurrentStageNo": (37, 2, (5, 0), (), "CurrentStageNo", None),
		"CurrentStageNumber": (63, 2, (3, 0), (), "CurrentStageNumber", None),
		"CustomerName": (49, 2, (8, 0), (), "CustomerName", None),
		"DataOwnershipfield": (44, 2, (3, 0), (), "DataOwnershipfield", None),
		"DocumentCheckbox": (50, 2, (8, 0), (), "DocumentCheckbox", None),
		"GrossProfit": (25, 2, (5, 0), (), "GrossProfit", None),
		"GrossProfitTotalLocal": (26, 2, (5, 0), (), "GrossProfitTotalLocal", None),
		"GrossProfitTotalSystem": (27, 2, (5, 0), (), "GrossProfitTotalSystem", None),
		"Industry": (42, 2, (3, 0), (), "Industry", None),
		"InterestField1": (14, 2, (3, 0), (), "InterestField1", None),
		"InterestField2": (15, 2, (3, 0), (), "InterestField2", None),
		"InterestField3": (16, 2, (3, 0), (), "InterestField3", None),
		"InterestLevel": (17, 2, (3, 0), (), "InterestLevel", None),
		# Method 'Interests' returns object of type 'ISalesOpportunitiesInterests'
		"Interests": (57, 2, (9, 0), (), "Interests", '{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}'),
		# Method 'Lines' returns object of type 'ISalesOpportunitiesLines'
		"Lines": (38, 2, (9, 0), (), "Lines", '{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}'),
		"LinkedDocumentNumber": (51, 2, (8, 0), (), "LinkedDocumentNumber", None),
		"LinkedDocumentType": (43, 2, (3, 0), (), "LinkedDocumentType", None),
		"MaxLocalTotal": (21, 2, (5, 0), (), "MaxLocalTotal", None),
		"MaxSystemTotal": (22, 2, (5, 0), (), "MaxSystemTotal", None),
		"OpportunityName": (41, 2, (8, 0), (), "OpportunityName", None),
		# Method 'Partners' returns object of type 'ISalesOpportunitiesPartners'
		"Partners": (40, 2, (9, 0), (), "Partners", '{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}'),
		"PredictedClosingDate": (20, 2, (7, 0), (), "PredictedClosingDate", None),
		"ProjectCode": (46, 2, (8, 0), (), "ProjectCode", None),
		"ReasonForClosing": (31, 2, (3, 0), (), "ReasonForClosing", None),
		# Method 'Reasons' returns object of type 'ISalesOpportunitiesReasons'
		"Reasons": (58, 2, (9, 0), (), "Reasons", '{D4A7CE6F-B909-4273-8499-C210F94ED2D1}'),
		"Remarks": (28, 2, (8, 0), (), "Remarks", None),
		"SalesPerson": (11, 2, (3, 0), (), "SalesPerson", None),
		"SequentialNo": (9, 2, (3, 0), (), "SequentialNo", None),
		"Source": (13, 2, (3, 0), (), "Source", None),
		"StartDate": (18, 2, (7, 0), (), "StartDate", None),
		"Status": (29, 2, (3, 0), (), "Status", None),
		"StatusRemarks": (45, 2, (8, 0), (), "StatusRemarks", None),
		"Territory": (52, 2, (3, 0), (), "Territory", None),
		"TotalAmounSystem": (33, 2, (5, 0), (), "TotalAmounSystem", None),
		"TotalAmountLocal": (32, 2, (5, 0), (), "TotalAmountLocal", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (48, 2, (3, 0), (), "UserSignature", None),
		"WeightedSumLC": (23, 2, (5, 0), (), "WeightedSumLC", None),
		"WeightedSumSC": (24, 2, (5, 0), (), "WeightedSumSC", None),
	}
	_prop_map_put_ = {
		"AttachmentEntry": ((62, LCID, 4, 0),()),
		"BPChanelCode": ((55, LCID, 4, 0),()),
		"BPChanelName": ((47, LCID, 4, 0),()),
		"BPChannelContact": ((54, LCID, 4, 0),()),
		"CardCode": ((10, LCID, 4, 0),()),
		"ClosingType": ((56, LCID, 4, 0),()),
		"ContactPerson": ((12, LCID, 4, 0),()),
		"CustomerName": ((49, LCID, 4, 0),()),
		"DataOwnershipfield": ((44, LCID, 4, 0),()),
		"GrossProfit": ((25, LCID, 4, 0),()),
		"GrossProfitTotalLocal": ((26, LCID, 4, 0),()),
		"Industry": ((42, LCID, 4, 0),()),
		"InterestField1": ((14, LCID, 4, 0),()),
		"InterestField2": ((15, LCID, 4, 0),()),
		"InterestField3": ((16, LCID, 4, 0),()),
		"InterestLevel": ((17, LCID, 4, 0),()),
		"OpportunityName": ((41, LCID, 4, 0),()),
		"PredictedClosingDate": ((20, LCID, 4, 0),()),
		"ProjectCode": ((46, LCID, 4, 0),()),
		"ReasonForClosing": ((31, LCID, 4, 0),()),
		"Remarks": ((28, LCID, 4, 0),()),
		"SalesPerson": ((11, LCID, 4, 0),()),
		"Source": ((13, LCID, 4, 0),()),
		"StartDate": ((18, LCID, 4, 0),()),
		"Status": ((29, LCID, 4, 0),()),
		"StatusRemarks": ((45, LCID, 4, 0),()),
		"Territory": ((52, LCID, 4, 0),()),
		"TotalAmountLocal": ((32, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunitiesCompetition(DispatchBaseClass):
	'ISalesOpportunitiesCompetition Interface'
	CLSID = IID('{19E6540E-4E64-48C1-9525-29D5710D1FFD}')
	coclass_clsid = IID('{C27CB0AA-2304-4D4E-B292-8ED9651F34A3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Competition": (6, 2, (3, 0), (), "Competition", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Details": (7, 2, (8, 0), (), "Details", None),
		"RowNo": (5, 2, (3, 0), (), "RowNo", None),
		"SequenceNo": (8, 2, (3, 0), (), "SequenceNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WonOrLost": (9, 2, (8, 0), (), "WonOrLost", None),
	}
	_prop_map_put_ = {
		"Competition": ((6, LCID, 4, 0),()),
		"Details": ((7, LCID, 4, 0),()),
		"WonOrLost": ((9, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunitiesInterests(DispatchBaseClass):
	'ISalesOpportunitiesInterests Interface'
	CLSID = IID('{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}')
	coclass_clsid = IID('{D48A6D0F-F063-4ED4-B1E1-59B6998EE91A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (6, 2, (3, 0), (), "Count", None),
		"InterestId": (4, 2, (3, 0), (), "InterestId", None),
		"PrimaryInterest": (3, 2, (3, 0), (), "PrimaryInterest", None),
		"RowNo": (1, 2, (3, 0), (), "RowNo", None),
		"SequenceNo": (2, 2, (3, 0), (), "SequenceNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"InterestId": ((4, LCID, 4, 0),()),
		"PrimaryInterest": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(6, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunitiesLines(DispatchBaseClass):
	'ISalesOpportunitiesLines Interface'
	CLSID = IID('{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}')
	coclass_clsid = IID('{B9FED360-AD27-45E1-AB8A-714FB217B022}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPChanelCode": (24, 2, (8, 0), (), "BPChanelCode", None),
		"BPChanelName": (23, 2, (8, 0), (), "BPChanelName", None),
		"BPChannelContact": (27, 2, (3, 0), (), "BPChannelContact", None),
		"ClosingDate": (9, 2, (7, 0), (), "ClosingDate", None),
		"Contact": (15, 2, (3, 0), (), "Contact", None),
		"ContactPerson": (22, 2, (3, 0), (), "ContactPerson", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"DataOwnershipfield": (26, 2, (3, 0), (), "DataOwnershipfield", None),
		"DocumentCheckbox": (21, 2, (3, 0), (), "DocumentCheckbox", None),
		"DocumentNumber": (19, 2, (3, 0), (), "DocumentNumber", None),
		"DocumentType": (20, 2, (3, 0), (), "DocumentType", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"MaxLocalTotal": (12, 2, (5, 0), (), "MaxLocalTotal", None),
		"MaxSystemTotal": (13, 2, (5, 0), (), "MaxSystemTotal", None),
		"PercentageRate": (11, 2, (5, 0), (), "PercentageRate", None),
		"Remarks": (14, 2, (8, 0), (), "Remarks", None),
		"SalesPerson": (6, 2, (3, 0), (), "SalesPerson", None),
		"SequenceNo": (25, 2, (3, 0), (), "SequenceNo", None),
		"StageKey": (10, 2, (3, 0), (), "StageKey", None),
		"StartDate": (8, 2, (7, 0), (), "StartDate", None),
		"Status": (16, 2, (3, 0), (), "Status", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WeightedAmountLocal": (17, 2, (5, 0), (), "WeightedAmountLocal", None),
		"WeightedAmountSystem": (18, 2, (5, 0), (), "WeightedAmountSystem", None),
	}
	_prop_map_put_ = {
		"BPChanelCode": ((24, LCID, 4, 0),()),
		"BPChanelName": ((23, LCID, 4, 0),()),
		"BPChannelContact": ((27, LCID, 4, 0),()),
		"ClosingDate": ((9, LCID, 4, 0),()),
		"ContactPerson": ((22, LCID, 4, 0),()),
		"DataOwnershipfield": ((26, LCID, 4, 0),()),
		"DocumentCheckbox": ((21, LCID, 4, 0),()),
		"DocumentNumber": ((19, LCID, 4, 0),()),
		"DocumentType": ((20, LCID, 4, 0),()),
		"MaxLocalTotal": ((12, LCID, 4, 0),()),
		"PercentageRate": ((11, LCID, 4, 0),()),
		"Remarks": ((14, LCID, 4, 0),()),
		"SalesPerson": ((6, LCID, 4, 0),()),
		"StageKey": ((10, LCID, 4, 0),()),
		"StartDate": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunitiesPartners(DispatchBaseClass):
	'ISalesOpportunitiesPartners Interface'
	CLSID = IID('{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}')
	coclass_clsid = IID('{0DA4D491-BDE7-4126-81E1-BCDA814B5332}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Details": (7, 2, (8, 0), (), "Details", None),
		"Partners": (6, 2, (3, 0), (), "Partners", None),
		"RelationshipCode": (8, 2, (3, 0), (), "RelationshipCode", None),
		"RowNo": (5, 2, (3, 0), (), "RowNo", None),
		"SequenceNo": (9, 2, (3, 0), (), "SequenceNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Details": ((7, LCID, 4, 0),()),
		"Partners": ((6, LCID, 4, 0),()),
		"RelationshipCode": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunitiesReasons(DispatchBaseClass):
	'ISalesOpportunitiesReasons Interface'
	CLSID = IID('{D4A7CE6F-B909-4273-8499-C210F94ED2D1}')
	coclass_clsid = IID('{C3B4DABB-A057-4D70-AE0C-7ABD7A4254B0}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"Reason": (3, 2, (3, 0), (), "Reason", None),
		"RowNo": (1, 2, (3, 0), (), "RowNo", None),
		"SequenceNo": (2, 2, (3, 0), (), "SequenceNo", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Reason": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunityCompetitorSetup(DispatchBaseClass):
	'ISalesOpportunityCompetitorSetup Interface'
	CLSID = IID('{BED262F2-5DAF-4D1B-91C6-B5DCABE54A90}')
	coclass_clsid = IID('{5CCE45B6-F63F-4CEE-9FF8-F05F0943C696}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Details": (13, 2, (8, 0), (), "Details", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"SequenceNo": (10, 2, (3, 0), (), "SequenceNo", None),
		"ThreatLevel": (12, 2, (3, 0), (), "ThreatLevel", None),
	}
	_prop_map_put_ = {
		"Details": ((13, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"ThreatLevel": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunityCompetitorSetupParams(DispatchBaseClass):
	'ISalesOpportunityCompetitorSetupParams Interface'
	CLSID = IID('{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')
	coclass_clsid = IID('{BB7C303A-1C58-4718-98BA-318FBCDB3502}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Name": (11, 2, (8, 0), (), "Name", None),
		"SequenceNo": (10, 2, (3, 0), (), "SequenceNo", None),
		"ThreatLevel": (12, 2, (3, 0), (), "ThreatLevel", None),
	}
	_prop_map_put_ = {
		"SequenceNo": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunityCompetitorSetupParamsCollection(DispatchBaseClass):
	'ISalesOpportunityCompetitorSetupParamsCollection Interface'
	CLSID = IID('{892F8759-3131-447C-804C-73A754C51B42}')
	coclass_clsid = IID('{2A1B975B-3697-472C-A9AA-57B400510C93}')

	# Result is of type ISalesOpportunityCompetitorSetupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ISalesOpportunityCompetitorSetupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunityCompetitorsSetupService(DispatchBaseClass):
	'ISalesOpportunityCompetitorsSetupService Interface'
	CLSID = IID('{247CDE70-F00E-4033-8EC1-3E173AEA8596}')
	coclass_clsid = IID('{64D39F13-2594-4AE9-A4C1-E32EA143C3C7}')

	# Result is of type ISalesOpportunityCompetitorSetupParams
	def AddSalesOpportunityCompetitorSetup(self, pISalesOpportunityCompetitorSetup=defaultNamedNotOptArg):
		'AddSalesOpportunityCompetitorSetup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pISalesOpportunityCompetitorSetup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddSalesOpportunityCompetitorSetup', '{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')
		return ret

	def DeleteSalesOpportunityCompetitorSetup(self, pISalesOpportunityCompetitorSetupParams=defaultNamedNotOptArg):
		'DeleteSalesOpportunityCompetitorSetup'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pISalesOpportunityCompetitorSetupParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ISalesOpportunityCompetitorSetup
	def GetSalesOpportunityCompetitorSetup(self, pISalesOpportunityCompetitorSetupParams=defaultNamedNotOptArg):
		'GetSalesOpportunityCompetitorSetup'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pISalesOpportunityCompetitorSetupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetSalesOpportunityCompetitorSetup', '{BED262F2-5DAF-4D1B-91C6-B5DCABE54A90}')
		return ret

	# Result is of type ISalesOpportunityCompetitorSetupParamsCollection
	def GetSalesOpportunityCompetitorSetupList(self):
		'GetSalesOpportunityCompetitorSetupList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetSalesOpportunityCompetitorSetupList', '{892F8759-3131-447C-804C-73A754C51B42}')
		return ret

	def UpdateSalesOpportunityCompetitorSetup(self, pISalesOpportunityCompetitorSetup=defaultNamedNotOptArg):
		'UpdateSalesOpportunityCompetitorSetup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pISalesOpportunityCompetitorSetup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunityInterestSetup(DispatchBaseClass):
	'ISalesOpportunityInterestSetup Interface'
	CLSID = IID('{C38D34A0-DA36-4B9A-9211-21F9228EC20D}')
	coclass_clsid = IID('{99D4BEE7-9E10-4C05-885B-4BEA6BFB1983}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (11, 2, (8, 0), (), "Description", None),
		"SequenceNo": (10, 2, (3, 0), (), "SequenceNo", None),
		"Sort": (12, 2, (3, 0), (), "Sort", None),
	}
	_prop_map_put_ = {
		"Description": ((11, LCID, 4, 0),()),
		"Sort": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunityInterestSetupParams(DispatchBaseClass):
	'ISalesOpportunityInterestSetupParams Interface'
	CLSID = IID('{61408D92-9E9A-4A1F-B5B0-A60332828007}')
	coclass_clsid = IID('{B6ED00E3-ECCF-40C1-A0EE-5B3C5C22BE8B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (11, 2, (8, 0), (), "Description", None),
		"SequenceNo": (10, 2, (3, 0), (), "SequenceNo", None),
	}
	_prop_map_put_ = {
		"SequenceNo": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunityInterestSetupParamsCollection(DispatchBaseClass):
	'ISalesOpportunityInterestSetupParamsCollection Interface'
	CLSID = IID('{BC177C74-40FA-4140-8374-ED45F9FCFF87}')
	coclass_clsid = IID('{DE04D890-B86A-47EF-AEFD-562E6187C25F}')

	# Result is of type ISalesOpportunityInterestSetupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{61408D92-9E9A-4A1F-B5B0-A60332828007}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ISalesOpportunityInterestSetupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{61408D92-9E9A-4A1F-B5B0-A60332828007}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{61408D92-9E9A-4A1F-B5B0-A60332828007}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{61408D92-9E9A-4A1F-B5B0-A60332828007}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunityInterestsSetupService(DispatchBaseClass):
	'ISalesOpportunityInterestsSetupService Interface'
	CLSID = IID('{445CC71E-29FC-41F0-ACC6-049A2CC3CF36}')
	coclass_clsid = IID('{108C5978-B8B4-452F-9C4E-67ECDE1AA94E}')

	# Result is of type ISalesOpportunityInterestSetupParams
	def AddSalesOpportunityInterestSetup(self, pISalesOpportunityInterestSetup=defaultNamedNotOptArg):
		'AddSalesOpportunityInterestSetup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pISalesOpportunityInterestSetup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddSalesOpportunityInterestSetup', '{61408D92-9E9A-4A1F-B5B0-A60332828007}')
		return ret

	def DeleteSalesOpportunityInterestSetup(self, pISalesOpportunityInterestSetupParams=defaultNamedNotOptArg):
		'DeleteSalesOpportunityInterestSetup'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pISalesOpportunityInterestSetupParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ISalesOpportunityInterestSetup
	def GetSalesOpportunityInterestSetup(self, pISalesOpportunityInterestSetupParams=defaultNamedNotOptArg):
		'GetSalesOpportunityInterestSetup'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pISalesOpportunityInterestSetupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetSalesOpportunityInterestSetup', '{C38D34A0-DA36-4B9A-9211-21F9228EC20D}')
		return ret

	# Result is of type ISalesOpportunityInterestSetupParamsCollection
	def GetSalesOpportunityInterestSetupList(self):
		'GetSalesOpportunityInterestSetupList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetSalesOpportunityInterestSetupList', '{BC177C74-40FA-4140-8374-ED45F9FCFF87}')
		return ret

	def UpdateSalesOpportunityInterestSetup(self, pISalesOpportunityInterestSetup=defaultNamedNotOptArg):
		'UpdateSalesOpportunityInterestSetup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pISalesOpportunityInterestSetup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunityReasonSetup(DispatchBaseClass):
	'ISalesOpportunityReasonSetup Interface'
	CLSID = IID('{5128D2EC-8CF5-47BD-A12F-B53211A1CE54}')
	coclass_clsid = IID('{5E789D08-DD00-438D-A3B0-91CAB1CEA247}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (11, 2, (8, 0), (), "Description", None),
		"SequenceNo": (10, 2, (3, 0), (), "SequenceNo", None),
		"Sort": (12, 2, (3, 0), (), "Sort", None),
	}
	_prop_map_put_ = {
		"Description": ((11, LCID, 4, 0),()),
		"Sort": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunityReasonSetupParams(DispatchBaseClass):
	'ISalesOpportunityReasonSetupParams Interface'
	CLSID = IID('{E60CDE47-FBBE-4719-BCFF-022E70710702}')
	coclass_clsid = IID('{969F9241-8C84-4966-B0D9-EC89E15E43B8}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (11, 2, (8, 0), (), "Description", None),
		"SequenceNo": (10, 2, (3, 0), (), "SequenceNo", None),
	}
	_prop_map_put_ = {
		"SequenceNo": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunityReasonSetupParamsCollection(DispatchBaseClass):
	'ISalesOpportunityReasonSetupParamsCollection Interface'
	CLSID = IID('{475F9BBF-F860-48CE-8FD7-71E461BD7D95}')
	coclass_clsid = IID('{F9FF31EB-6912-401D-91E5-ADDC459EBECA}')

	# Result is of type ISalesOpportunityReasonSetupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{E60CDE47-FBBE-4719-BCFF-022E70710702}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ISalesOpportunityReasonSetupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{E60CDE47-FBBE-4719-BCFF-022E70710702}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{E60CDE47-FBBE-4719-BCFF-022E70710702}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{E60CDE47-FBBE-4719-BCFF-022E70710702}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunityReasonsSetupService(DispatchBaseClass):
	'ISalesOpportunityReasonsSetupService Interface'
	CLSID = IID('{A95C4C3D-71D5-475B-B6D9-BB75D22E1931}')
	coclass_clsid = IID('{6AFDF201-9B72-4E70-B1B0-BECC5508D8FD}')

	# Result is of type ISalesOpportunityReasonSetupParams
	def AddSalesOpportunityReasonSetup(self, pISalesOpportunityReasonSetup=defaultNamedNotOptArg):
		'AddSalesOpportunityReasonSetup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pISalesOpportunityReasonSetup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddSalesOpportunityReasonSetup', '{E60CDE47-FBBE-4719-BCFF-022E70710702}')
		return ret

	def DeleteSalesOpportunityReasonSetup(self, pISalesOpportunityReasonSetupParams=defaultNamedNotOptArg):
		'DeleteSalesOpportunityReasonSetup'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pISalesOpportunityReasonSetupParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ISalesOpportunityReasonSetup
	def GetSalesOpportunityReasonSetup(self, pISalesOpportunityReasonSetupParams=defaultNamedNotOptArg):
		'GetSalesOpportunityReasonSetup'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pISalesOpportunityReasonSetupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetSalesOpportunityReasonSetup', '{5128D2EC-8CF5-47BD-A12F-B53211A1CE54}')
		return ret

	# Result is of type ISalesOpportunityReasonSetupParamsCollection
	def GetSalesOpportunityReasonSetupList(self):
		'GetSalesOpportunityReasonSetupList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetSalesOpportunityReasonSetupList', '{475F9BBF-F860-48CE-8FD7-71E461BD7D95}')
		return ret

	def UpdateSalesOpportunityReasonSetup(self, pISalesOpportunityReasonSetup=defaultNamedNotOptArg):
		'UpdateSalesOpportunityReasonSetup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pISalesOpportunityReasonSetup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunitySourceSetup(DispatchBaseClass):
	'ISalesOpportunitySourceSetup Interface'
	CLSID = IID('{6B52A2CD-C166-404E-9A92-A0D4B812488A}')
	coclass_clsid = IID('{F12BD69F-83F6-46F0-A602-3E374B2400FB}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (11, 2, (8, 0), (), "Description", None),
		"SequenceNo": (10, 2, (3, 0), (), "SequenceNo", None),
		"Sort": (12, 2, (3, 0), (), "Sort", None),
	}
	_prop_map_put_ = {
		"Description": ((11, LCID, 4, 0),()),
		"Sort": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunitySourceSetupParams(DispatchBaseClass):
	'ISalesOpportunitySourceSetupParams Interface'
	CLSID = IID('{AC935452-7934-4093-810F-D66BD350A247}')
	coclass_clsid = IID('{B8FFD2FD-01A8-404E-995F-B7C004675ADB}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (11, 2, (8, 0), (), "Description", None),
		"SequenceNo": (10, 2, (3, 0), (), "SequenceNo", None),
	}
	_prop_map_put_ = {
		"SequenceNo": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesOpportunitySourceSetupParamsCollection(DispatchBaseClass):
	'ISalesOpportunitySourceSetupParamsCollection Interface'
	CLSID = IID('{6C123256-BF67-4AA6-BE6B-4C085AB0731A}')
	coclass_clsid = IID('{35CD3214-7F63-4C98-8969-E1D83791B7BA}')

	# Result is of type ISalesOpportunitySourceSetupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{AC935452-7934-4093-810F-D66BD350A247}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ISalesOpportunitySourceSetupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{AC935452-7934-4093-810F-D66BD350A247}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{AC935452-7934-4093-810F-D66BD350A247}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{AC935452-7934-4093-810F-D66BD350A247}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISalesOpportunitySourcesSetupService(DispatchBaseClass):
	'ISalesOpportunitySourcesSetupService Interface'
	CLSID = IID('{B3D0E8B3-C0C8-4CC2-9D0B-121D6384E95E}')
	coclass_clsid = IID('{918EBBE1-6DBB-4B20-AF74-34A5CA1B5E21}')

	# Result is of type ISalesOpportunitySourceSetupParams
	def AddSalesOpportunitySourceSetup(self, pISalesOpportunitySourceSetup=defaultNamedNotOptArg):
		'AddSalesOpportunitySourceSetup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pISalesOpportunitySourceSetup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddSalesOpportunitySourceSetup', '{AC935452-7934-4093-810F-D66BD350A247}')
		return ret

	def DeleteSalesOpportunitySourceSetup(self, pISalesOpportunitySourceSetupParams=defaultNamedNotOptArg):
		'DeleteSalesOpportunitySourceSetup'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pISalesOpportunitySourceSetupParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ISalesOpportunitySourceSetup
	def GetSalesOpportunitySourceSetup(self, pISalesOpportunitySourceSetupParams=defaultNamedNotOptArg):
		'GetSalesOpportunitySourceSetup'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pISalesOpportunitySourceSetupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetSalesOpportunitySourceSetup', '{6B52A2CD-C166-404E-9A92-A0D4B812488A}')
		return ret

	# Result is of type ISalesOpportunitySourceSetupParamsCollection
	def GetSalesOpportunitySourceSetupList(self):
		'GetSalesOpportunitySourceSetupList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetSalesOpportunitySourceSetupList', '{6C123256-BF67-4AA6-BE6B-4C085AB0731A}')
		return ret

	def UpdateSalesOpportunitySourceSetup(self, pISalesOpportunitySourceSetup=defaultNamedNotOptArg):
		'UpdateSalesOpportunitySourceSetup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pISalesOpportunitySourceSetup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesPersons(DispatchBaseClass):
	'ISalesPersons Interface'
	CLSID = IID('{481D2A59-9B17-4C56-B245-04F85EA1C74E}')
	coclass_clsid = IID('{A3DFD03F-4F42-44A0-9EBD-ECA4370209DD}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lSlpCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lSlpCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Active": (17, 2, (3, 0), (), "Active", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CommissionForSalesEmployee": (13, 2, (5, 0), (), "CommissionForSalesEmployee", None),
		"CommissionGroup": (14, 2, (3, 0), (), "CommissionGroup", None),
		"EmployeeID": (16, 2, (3, 0), (), "EmployeeID", None),
		"Locked": (15, 2, (3, 0), (), "Locked", None),
		"Remarks": (12, 2, (8, 0), (), "Remarks", None),
		"SalesEmployeeCode": (10, 2, (3, 0), (), "SalesEmployeeCode", None),
		"SalesEmployeeName": (11, 2, (8, 0), (), "SalesEmployeeName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Active": ((17, LCID, 4, 0),()),
		"CommissionForSalesEmployee": ((13, LCID, 4, 0),()),
		"CommissionGroup": ((14, LCID, 4, 0),()),
		"Remarks": ((12, LCID, 4, 0),()),
		"SalesEmployeeName": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesStages(DispatchBaseClass):
	'ISalesStages Interface'
	CLSID = IID('{D2D6E703-7339-4D1A-BC4B-6BFF83622871}')
	coclass_clsid = IID('{180937C4-1314-4A9D-BFF2-27C3969681DC}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lNum=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lNum
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Cancelled": (13, 2, (3, 0), (), "Cancelled", None),
		"ClosingPercentage": (12, 2, (5, 0), (), "ClosingPercentage", None),
		"Name": (10, 2, (8, 0), (), "Name", None),
		"SequenceNo": (9, 2, (3, 0), (), "SequenceNo", None),
		"Stageno": (11, 2, (3, 0), (), "Stageno", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Cancelled": ((13, LCID, 4, 0),()),
		"ClosingPercentage": ((12, LCID, 4, 0),()),
		"Name": ((10, LCID, 4, 0),()),
		"Stageno": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesTaxAuthorities(DispatchBaseClass):
	'ISalesTaxAuthorities Interface'
	CLSID = IID('{0D446022-9A79-4535-9174-EEAE21DF924A}')
	coclass_clsid = IID('{7F146AF0-3304-4133-BC4F-48797C66B12F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(16, LCID, 1, (8, 0), (),)

	def GetByKey(self, Code=defaultNamedNotOptArg, Type=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (11, 0), ((8, 1), (3, 1)),Code
			, Type)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(17, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(14, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AOrPTaxAccount": (6, 2, (8, 0), (), "AOrPTaxAccount", None),
		"AOrRTaxAccount": (4, 2, (8, 0), (), "AOrRTaxAccount", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (18, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"DeferredTaxAccount": (10, 2, (8, 0), (), "DeferredTaxAccount", None),
		"FlatTaxAmount": (22, 2, (5, 0), (), "FlatTaxAmount", None),
		"MaxTaxableAmount": (21, 2, (5, 0), (), "MaxTaxableAmount", None),
		"MinTaxableAmount": (20, 2, (5, 0), (), "MinTaxableAmount", None),
		"Name": (9, 2, (8, 0), (), "Name", None),
		"NonDeductibleAccount": (8, 2, (8, 0), (), "NonDeductibleAccount", None),
		"NonDeductiblePrecent": (7, 2, (5, 0), (), "NonDeductiblePrecent", None),
		"Rate": (5, 2, (5, 0), (), "Rate", None),
		# Method 'TaxDefinitions' returns object of type 'ITaxDefinitions'
		"TaxDefinitions": (23, 2, (9, 0), (), "TaxDefinitions", '{9AA8D14C-3AB3-44F0-BEDD-0AB156BD2A9D}'),
		"Type": (3, 2, (3, 0), (), "Type", None),
		"UseTaxAccount": (1, 2, (8, 0), (), "UseTaxAccount", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (19, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (2, 2, (3, 0), (), "UserSignature", None),
	}
	_prop_map_put_ = {
		"AOrPTaxAccount": ((6, LCID, 4, 0),()),
		"AOrRTaxAccount": ((4, LCID, 4, 0),()),
		"Code": ((11, LCID, 4, 0),()),
		"DeferredTaxAccount": ((10, LCID, 4, 0),()),
		"FlatTaxAmount": ((22, LCID, 4, 0),()),
		"MaxTaxableAmount": ((21, LCID, 4, 0),()),
		"MinTaxableAmount": ((20, LCID, 4, 0),()),
		"Name": ((9, LCID, 4, 0),()),
		"NonDeductibleAccount": ((8, LCID, 4, 0),()),
		"NonDeductiblePrecent": ((7, LCID, 4, 0),()),
		"Rate": ((5, LCID, 4, 0),()),
		"Type": ((3, LCID, 4, 0),()),
		"UseTaxAccount": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesTaxAuthoritiesTypes(DispatchBaseClass):
	'ISalesTaxAuthoritiesTypes Interface'
	CLSID = IID('{450A7F0E-0D42-4720-907E-C672EE2F6382}')
	coclass_clsid = IID('{717F1B41-306E-4695-8F4E-7DACA54EA87B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(9, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),Key
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (11, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Name": (2, 2, (8, 0), (), "Name", None),
		"Numerator": (4, 2, (3, 0), (), "Numerator", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (12, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (1, 2, (3, 0), (), "UserSignature", None),
		"VAT": (3, 2, (3, 0), (), "VAT", None),
	}
	_prop_map_put_ = {
		"Name": ((2, LCID, 4, 0),()),
		"VAT": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesTaxCodes(DispatchBaseClass):
	'ISalesTaxCodes Interface'
	CLSID = IID('{A07F5790-711E-49FC-9843-935F7C8CDB85}')
	coclass_clsid = IID('{97C9DB0B-4DBF-4EEA-98A9-04EE1F5B031E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(13, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (11, 0), ((8, 1),),Key
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(11, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (15, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (7, 2, (8, 0), (), "Code", None),
		"Freight": (6, 2, (3, 0), (), "Freight", None),
		"Inactive": (18, 2, (3, 0), (), "Inactive", None),
		"IsItemLevel": (17, 2, (3, 0), (), "IsItemLevel", None),
		# Method 'Lines' returns object of type 'ISalesTaxCodes_Lines'
		"Lines": (8, 2, (9, 0), (), "Lines", '{98DF1BF3-2F28-46C7-8003-FB8D11276237}'),
		"Name": (5, 2, (8, 0), (), "Name", None),
		"Rate": (4, 2, (5, 0), (), "Rate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (16, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (3, 2, (3, 0), (), "UserSignature", None),
		"ValidForAP": (2, 2, (3, 0), (), "ValidForAP", None),
		"ValidForAR": (1, 2, (3, 0), (), "ValidForAR", None),
	}
	_prop_map_put_ = {
		"Code": ((7, LCID, 4, 0),()),
		"Freight": ((6, LCID, 4, 0),()),
		"Inactive": ((18, LCID, 4, 0),()),
		"IsItemLevel": ((17, LCID, 4, 0),()),
		"Name": ((5, LCID, 4, 0),()),
		"ValidForAP": ((2, LCID, 4, 0),()),
		"ValidForAR": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISalesTaxCodes_Lines(DispatchBaseClass):
	'ISalesTaxCodes_Lines Interface'
	CLSID = IID('{98DF1BF3-2F28-46C7-8003-FB8D11276237}')
	coclass_clsid = IID('{4385C84B-AE8C-424F-9071-546FF9E1D503}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (9, 2, (3, 0), (), "Count", None),
		"EffectiveRate": (7, 2, (5, 0), (), "EffectiveRate", None),
		"RowNumber": (6, 2, (3, 0), (), "RowNumber", None),
		"STACode": (5, 2, (8, 0), (), "STACode", None),
		"STATaxOnTaxType": (1, 2, (3, 0), (), "STATaxOnTaxType", None),
		"STATaxonTaxCode": (2, 2, (8, 0), (), "STATaxonTaxCode", None),
		"STAType": (4, 2, (3, 0), (), "STAType", None),
		"STCCode": (3, 2, (8, 0), (), "STCCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (8, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"STACode": ((5, LCID, 4, 0),()),
		"STATaxOnTaxType": ((1, LCID, 4, 0),()),
		"STATaxonTaxCode": ((2, LCID, 4, 0),()),
		"STAType": ((4, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(9, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISection(DispatchBaseClass):
	'ISection Interface'
	CLSID = IID('{D9D5A329-257D-45AE-8897-AFD53838C099}')
	coclass_clsid = IID('{978E2893-F916-456D-B318-0BDE27B4246E}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"ECode": (13, 2, (8, 0), (), "ECode", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"Description": ((12, LCID, 4, 0),()),
		"ECode": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISectionParams(DispatchBaseClass):
	'ISectionParams Interface'
	CLSID = IID('{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')
	coclass_clsid = IID('{2468326B-CAE1-42CA-8139-3D674F3E4875}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISectionsParams(DispatchBaseClass):
	'ISectionsParams Interface'
	CLSID = IID('{3EFBE347-7427-4459-A969-37AE80D0AFEF}')
	coclass_clsid = IID('{FE490117-D92F-4CFD-A046-641F27A4FD94}')

	# Result is of type ISectionParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ISectionParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISectionsService(DispatchBaseClass):
	'ISectionsService Interface'
	CLSID = IID('{E053D931-2878-44FD-88A0-2E572EA10DB0}')
	coclass_clsid = IID('{09BAC4F7-AA34-4417-8C7F-7451098A4D5D}')

	# Result is of type ISectionParams
	def AddSection(self, pISection=defaultNamedNotOptArg):
		'AddSection'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pISection
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddSection', '{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')
		return ret

	def DeleteSection(self, pISectionParams=defaultNamedNotOptArg):
		'DeleteSection'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pISectionParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ISection
	def GetSection(self, pISectionParams=defaultNamedNotOptArg):
		'GetSection'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pISectionParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetSection', '{D9D5A329-257D-45AE-8897-AFD53838C099}')
		return ret

	# Result is of type ISectionsParams
	def GetSectionList(self):
		'GetSectionList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetSectionList', '{3EFBE347-7427-4459-A969-37AE80D0AFEF}')
		return ret

	def UpdateSection(self, pISection=defaultNamedNotOptArg):
		'UpdateSection'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pISection
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISerialNumberDetail(DispatchBaseClass):
	'ISerialNumberDetail Interface'
	CLSID = IID('{43CA4B0F-FF52-4C9A-9BB9-601CDFE3AD6D}')
	coclass_clsid = IID('{8018B387-2D98-40E1-9983-365221335839}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AdmissionDate": (17, 2, (7, 0), (), "AdmissionDate", None),
		"Details": (23, 2, (8, 0), (), "Details", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"ExpirationDate": (19, 2, (7, 0), (), "ExpirationDate", None),
		"ItemCode": (11, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (12, 2, (8, 0), (), "ItemDescription", None),
		"Location": (22, 2, (8, 0), (), "Location", None),
		"LotNumber": (15, 2, (8, 0), (), "LotNumber", None),
		"MFrWarrantyEnd": (21, 2, (7, 0), (), "MFrWarrantyEnd", None),
		"ManufacturingDate": (18, 2, (7, 0), (), "ManufacturingDate", None),
		"MfrSerialNo": (13, 2, (8, 0), (), "MfrSerialNo", None),
		"MfrWarrantyStart": (20, 2, (7, 0), (), "MfrWarrantyStart", None),
		"SerialNumber": (14, 2, (8, 0), (), "SerialNumber", None),
		"SystemNumber": (16, 2, (3, 0), (), "SystemNumber", None),
		# Method 'UserFields' returns object of type 'IFields'
		"UserFields": (24, 2, (9, 0), (), "UserFields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
	}
	_prop_map_put_ = {
		"AdmissionDate": ((17, LCID, 4, 0),()),
		"Details": ((23, LCID, 4, 0),()),
		"ExpirationDate": ((19, LCID, 4, 0),()),
		"Location": ((22, LCID, 4, 0),()),
		"LotNumber": ((15, LCID, 4, 0),()),
		"MFrWarrantyEnd": ((21, LCID, 4, 0),()),
		"ManufacturingDate": ((18, LCID, 4, 0),()),
		"MfrSerialNo": ((13, LCID, 4, 0),()),
		"MfrWarrantyStart": ((20, LCID, 4, 0),()),
		"SerialNumber": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISerialNumberDetailParams(DispatchBaseClass):
	'ISerialNumberDetailParams Interface'
	CLSID = IID('{C392F1DC-DD79-4692-8FBA-7CAD03877993}')
	coclass_clsid = IID('{DF752E29-B42C-4FB2-8634-AC2F74DC9DEE}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
	}
	_prop_map_put_ = {
		"DocEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISerialNumberDetailsService(DispatchBaseClass):
	'ISerialNumberDetailsService Interface'
	CLSID = IID('{FE305F7C-1D01-4B99-AB83-BBB8503B8A95}')
	coclass_clsid = IID('{91C11377-CA6F-484B-9761-E7341517FD59}')

	# Result is of type ISerialNumberDetail
	def Get(self, pISerialNumberDetailParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pISerialNumberDetailParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{43CA4B0F-FF52-4C9A-9BB9-601CDFE3AD6D}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	def Update(self, pISerialNumberDetail=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((9, 1),),pISerialNumberDetail
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISerialNumbers(DispatchBaseClass):
	'ISerialNumbers Interface'
	CLSID = IID('{93E5E52B-181E-46B8-96CB-1C066AC04DCA}')
	coclass_clsid = IID('{6BA3F221-1146-4650-AE35-03C139F04C02}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseLineNumber": (15, 2, (3, 0), (), "BaseLineNumber", None),
		"BatchID": (13, 2, (8, 0), (), "BatchID", None),
		"Count": (1, 2, (3, 0), (), "Count", None),
		"ExpiryDate": (6, 2, (7, 0), (), "ExpiryDate", None),
		"InternalSerialNumber": (5, 2, (8, 0), (), "InternalSerialNumber", None),
		"Location": (11, 2, (8, 0), (), "Location", None),
		"ManufactureDate": (7, 2, (7, 0), (), "ManufactureDate", None),
		"ManufacturerSerialNumber": (4, 2, (8, 0), (), "ManufacturerSerialNumber", None),
		"Notes": (12, 2, (8, 0), (), "Notes", None),
		"Quantity": (17, 2, (5, 0), (), "Quantity", None),
		"ReceptionDate": (8, 2, (7, 0), (), "ReceptionDate", None),
		"SystemSerialNumber": (14, 2, (3, 0), (), "SystemSerialNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (16, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WarrantyEnd": (10, 2, (7, 0), (), "WarrantyEnd", None),
		"WarrantyStart": (9, 2, (7, 0), (), "WarrantyStart", None),
	}
	_prop_map_put_ = {
		"BaseLineNumber": ((15, LCID, 4, 0),()),
		"BatchID": ((13, LCID, 4, 0),()),
		"ExpiryDate": ((6, LCID, 4, 0),()),
		"InternalSerialNumber": ((5, LCID, 4, 0),()),
		"Location": ((11, LCID, 4, 0),()),
		"ManufactureDate": ((7, LCID, 4, 0),()),
		"ManufacturerSerialNumber": ((4, LCID, 4, 0),()),
		"Notes": ((12, LCID, 4, 0),()),
		"Quantity": ((17, LCID, 4, 0),()),
		"ReceptionDate": ((8, LCID, 4, 0),()),
		"SystemSerialNumber": ((14, LCID, 4, 0),()),
		"WarrantyEnd": ((10, LCID, 4, 0),()),
		"WarrantyStart": ((9, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISeries(DispatchBaseClass):
	'ISeries Interface'
	CLSID = IID('{21B9721D-5933-4547-A8F9-2AFB83B6735F}')
	coclass_clsid = IID('{9B92292E-B9FD-4317-B7FA-5E1BD04C8697}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"BPLID": (31, 2, (3, 0), (), "BPLID", None),
		"DigitNumber": (25, 2, (3, 0), (), "DigitNumber", None),
		"Document": (11, 2, (8, 0), (), "Document", None),
		"DocumentSubType": (23, 2, (8, 0), (), "DocumentSubType", None),
		"GroupCode": (20, 2, (3, 0), (), "GroupCode", None),
		"InitialNumber": (14, 2, (3, 0), (), "InitialNumber", None),
		"IsDigitalSeries": (24, 2, (3, 0), (), "IsDigitalSeries", None),
		"LastNumber": (15, 2, (3, 0), (), "LastNumber", None),
		"Locked": (21, 2, (3, 0), (), "Locked", None),
		"Name": (13, 2, (8, 0), (), "Name", None),
		"NextNumber": (16, 2, (3, 0), (), "NextNumber", None),
		"PeriodIndicator": (22, 2, (8, 0), (), "PeriodIndicator", None),
		"Prefix": (17, 2, (8, 0), (), "Prefix", None),
		"Remarks": (19, 2, (8, 0), (), "Remarks", None),
		"Series": (12, 2, (3, 0), (), "Series", None),
		"SeriesType": (26, 2, (3, 0), (), "SeriesType", None),
		"Suffix": (18, 2, (8, 0), (), "Suffix", None),
	}
	_prop_map_put_ = {
		"BPLID": ((31, LCID, 4, 0),()),
		"DigitNumber": ((25, LCID, 4, 0),()),
		"Document": ((11, LCID, 4, 0),()),
		"DocumentSubType": ((23, LCID, 4, 0),()),
		"GroupCode": ((20, LCID, 4, 0),()),
		"InitialNumber": ((14, LCID, 4, 0),()),
		"IsDigitalSeries": ((24, LCID, 4, 0),()),
		"LastNumber": ((15, LCID, 4, 0),()),
		"Locked": ((21, LCID, 4, 0),()),
		"Name": ((13, LCID, 4, 0),()),
		"NextNumber": ((16, LCID, 4, 0),()),
		"PeriodIndicator": ((22, LCID, 4, 0),()),
		"Prefix": ((17, LCID, 4, 0),()),
		"Remarks": ((19, LCID, 4, 0),()),
		"SeriesType": ((26, LCID, 4, 0),()),
		"Suffix": ((18, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISeriesCollection(DispatchBaseClass):
	'ISeriesCollection Interface'
	CLSID = IID('{D48F490F-CB1F-46B9-A941-D1A84FCE1DB2}')
	coclass_clsid = IID('{7D2E0C15-AC4A-4833-9567-F7167B71CA53}')

	# Result is of type ISeries
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{21B9721D-5933-4547-A8F9-2AFB83B6735F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ISeries
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{21B9721D-5933-4547-A8F9-2AFB83B6735F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{21B9721D-5933-4547-A8F9-2AFB83B6735F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{21B9721D-5933-4547-A8F9-2AFB83B6735F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISeriesLine(DispatchBaseClass):
	'ISeriesLine Interface'
	CLSID = IID('{022D793A-3706-459F-A7FE-4169894754D8}')
	coclass_clsid = IID('{793B4DFE-8628-4E29-BE9F-2C81E26FE82C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"FirstNum": (12, 2, (3, 0), (), "FirstNum", None),
		"LastNum": (14, 2, (3, 0), (), "LastNum", None),
		"NextNum": (13, 2, (3, 0), (), "NextNum", None),
		"Prefix": (11, 2, (8, 0), (), "Prefix", None),
		"Series": (10, 2, (3, 0), (), "Series", None),
	}
	_prop_map_put_ = {
		"FirstNum": ((12, LCID, 4, 0),()),
		"LastNum": ((14, LCID, 4, 0),()),
		"Prefix": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISeriesLines(DispatchBaseClass):
	'ISeriesLines Interface'
	CLSID = IID('{D5B65908-18C4-493A-B1F3-BC7987AF01DD}')
	coclass_clsid = IID('{D9811035-C659-4D43-B92F-56378C1CC50C}')

	# Result is of type ISeriesLine
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{022D793A-3706-459F-A7FE-4169894754D8}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ISeriesLine
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{022D793A-3706-459F-A7FE-4169894754D8}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{022D793A-3706-459F-A7FE-4169894754D8}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{022D793A-3706-459F-A7FE-4169894754D8}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISeriesParams(DispatchBaseClass):
	'ISeriesParams Interface'
	CLSID = IID('{DB4F4E62-87CD-4113-8EA9-4EAAC1555DBD}')
	coclass_clsid = IID('{BFFCB767-876B-4A47-BB72-7B8ECAD30228}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Series": (10, 2, (3, 0), (), "Series", None),
	}
	_prop_map_put_ = {
		"Series": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISeriesService(DispatchBaseClass):
	'ISeriesService Interface'
	CLSID = IID('{336661D7-9504-4915-9EAD-6DF66DBBA590}')
	coclass_clsid = IID('{6140412B-302D-4CC8-9B65-4D554892B2FF}')

	# Result is of type IElectronicSeriesParams
	def AddElectronicSeries(self, pIElectronicSeries=defaultNamedNotOptArg):
		'AddElectronicSeries'
		ret = self._oleobj_.InvokeTypes(24, LCID, 1, (9, 0), ((9, 1),),pIElectronicSeries
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddElectronicSeries', '{135ACD20-6799-42E5-8ECC-4077CEF72812}')
		return ret

	# Result is of type ISeriesParams
	def AddSeries(self, pISeries=defaultNamedNotOptArg):
		'AddSeries'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pISeries
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddSeries', '{DB4F4E62-87CD-4113-8EA9-4EAAC1555DBD}')
		return ret

	def AttachSeriesToDocument(self, pIDocumentSeriesParams=defaultNamedNotOptArg):
		'AttachSeriesToDocument'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIDocumentSeriesParams
			)

	def ChangeDocumentMenuName(self, pIDocumentChangeMenuName=defaultNamedNotOptArg):
		'ChangeDocumentMenuName'
		return self._oleobj_.InvokeTypes(22, LCID, 1, (24, 0), ((9, 1),),pIDocumentChangeMenuName
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IElectronicSeriesParams
	def GetDefaultElectronicSeries(self, pISeriesParams=defaultNamedNotOptArg):
		'GetDefaultElectronicSeries'
		ret = self._oleobj_.InvokeTypes(27, LCID, 1, (9, 0), ((9, 1),),pISeriesParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDefaultElectronicSeries', '{135ACD20-6799-42E5-8ECC-4077CEF72812}')
		return ret

	# Result is of type ISeries
	def GetDefaultSeries(self, pIDocumentTypeParams=defaultNamedNotOptArg):
		'GetDefaultSeries'
		ret = self._oleobj_.InvokeTypes(18, LCID, 1, (9, 0), ((9, 1),),pIDocumentTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDefaultSeries', '{21B9721D-5933-4547-A8F9-2AFB83B6735F}')
		return ret

	# Result is of type IDocumentChangeMenuName
	def GetDocumentChangedMenuName(self, pIDocumentTypeParams=defaultNamedNotOptArg):
		'GetDocumentChangedMenuName'
		ret = self._oleobj_.InvokeTypes(21, LCID, 1, (9, 0), ((9, 1),),pIDocumentTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDocumentChangedMenuName', '{9A5FCF99-FC73-47E0-A68D-A8156EB864E5}')
		return ret

	# Result is of type ISeriesCollection
	def GetDocumentSeries(self, pIDocumentTypeParams=defaultNamedNotOptArg):
		'GetDocumentSeries'
		ret = self._oleobj_.InvokeTypes(19, LCID, 1, (9, 0), ((9, 1),),pIDocumentTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDocumentSeries', '{D48F490F-CB1F-46B9-A941-D1A84FCE1DB2}')
		return ret

	# Result is of type IElectronicSeries
	def GetElectronicSeries(self, pElectronicSeriesParams=defaultNamedNotOptArg):
		'GetElectronicSeries'
		ret = self._oleobj_.InvokeTypes(23, LCID, 1, (9, 0), ((9, 1),),pElectronicSeriesParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetElectronicSeries', '{2309689C-63EA-4D8E-B675-E6459533E27A}')
		return ret

	# Result is of type ISeries
	def GetSeries(self, pSeriesParams=defaultNamedNotOptArg):
		'GetSeries'
		ret = self._oleobj_.InvokeTypes(20, LCID, 1, (9, 0), ((9, 1),),pSeriesParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetSeries', '{21B9721D-5933-4547-A8F9-2AFB83B6735F}')
		return ret

	def RemoveElectronicSeries(self, pIElectronicSeriesParam=defaultNamedNotOptArg):
		'RemoveElectronicSeries'
		return self._oleobj_.InvokeTypes(25, LCID, 1, (24, 0), ((9, 1),),pIElectronicSeriesParam
			)

	def RemoveSeries(self, pISeriesParam=defaultNamedNotOptArg):
		'RemoveSeries'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pISeriesParam
			)

	def SetDefaultElectronicSeries(self, pIDefaultElectronicSeriesParams=defaultNamedNotOptArg):
		'SetDefaultElectronicSeries'
		return self._oleobj_.InvokeTypes(28, LCID, 1, (24, 0), ((9, 1),),pIDefaultElectronicSeriesParams
			)

	def SetDefaultSeriesForAllUsers(self, pIDocumentSeriesParams=defaultNamedNotOptArg):
		'SetDefaultSeriesForAllUsers'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((9, 1),),pIDocumentSeriesParams
			)

	def SetDefaultSeriesForCurrentUser(self, pIDocumentSeriesParams=defaultNamedNotOptArg):
		'SetDefaultSeriesForCurrentUser'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((9, 1),),pIDocumentSeriesParams
			)

	def SetDefaultSeriesForUser(self, pIDocumentSeriesUserParams=defaultNamedNotOptArg):
		'SetDefaultSeriesForUser'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (24, 0), ((9, 1),),pIDocumentSeriesUserParams
			)

	def UnattachSeriesFromDocument(self, pIDocumentSeriesParams=defaultNamedNotOptArg):
		'UnattachSeriesFromDocument'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pIDocumentSeriesParams
			)

	def UpdateElectronicSeries(self, pIElectronicSeries=defaultNamedNotOptArg):
		'UpdateElectronicSeries'
		return self._oleobj_.InvokeTypes(26, LCID, 1, (24, 0), ((9, 1),),pIElectronicSeries
			)

	def UpdateSeries(self, pISeries=defaultNamedNotOptArg):
		'UpdateSeries'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (24, 0), ((9, 1),),pISeries
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallActivities(DispatchBaseClass):
	'IServiceCallActivities Interface'
	CLSID = IID('{0207412D-F955-46BA-AE96-E749573B4106}')
	coclass_clsid = IID('{0ED9BFD6-A5ED-40D2-8645-BE4ED8AC9CE5}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ActivityCode": (6, 2, (3, 0), (), "ActivityCode", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ActivityCode": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallInventoryExpenses(DispatchBaseClass):
	'IServiceCallInventoryExpenses Interface'
	CLSID = IID('{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}')
	coclass_clsid = IID('{692B8669-26B5-4D4F-A768-F92576E3EF85}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"DocEntry": (11, 2, (3, 0), (), "DocEntry", None),
		"DocumentNumber": (7, 2, (3, 0), (), "DocumentNumber", None),
		"DocumentPostingDate": (9, 2, (7, 0), (), "DocumentPostingDate", None),
		"DocumentType": (8, 2, (3, 0), (), "DocumentType", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"PartType": (6, 2, (3, 0), (), "PartType", None),
		"StockTransferDirection": (10, 2, (3, 0), (), "StockTransferDirection", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"DocEntry": ((11, LCID, 4, 0),()),
		"DocumentNumber": ((7, LCID, 4, 0),()),
		"DocumentType": ((8, LCID, 4, 0),()),
		"StockTransferDirection": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallOrigin(DispatchBaseClass):
	'IServiceCallOrigin Interface'
	CLSID = IID('{9FEF81F9-9C21-4B0B-9EDA-0EF9A5C98739}')
	coclass_clsid = IID('{AC388829-78AF-4297-973E-CC26057B737D}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"OriginID": (10, 2, (3, 0), (), "OriginID", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallOriginParams(DispatchBaseClass):
	'IServiceCallOriginParams Interface'
	CLSID = IID('{AC21F36A-556F-4374-AAB0-96949C7469FF}')
	coclass_clsid = IID('{0A65D039-CEA5-4AA4-8F48-F5D6DA35737A}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Name": (11, 2, (8, 0), (), "Name", None),
		"OriginID": (10, 2, (3, 0), (), "OriginID", None),
	}
	_prop_map_put_ = {
		"OriginID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallOriginParamsCollection(DispatchBaseClass):
	'IServiceCallOriginParamsCollection Interface'
	CLSID = IID('{13B1D6B4-A9ED-4787-8B8B-24AAE9525342}')
	coclass_clsid = IID('{6815F02A-AC31-4264-93DF-A403569495AC}')

	# Result is of type IServiceCallOriginParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{AC21F36A-556F-4374-AAB0-96949C7469FF}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IServiceCallOriginParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{AC21F36A-556F-4374-AAB0-96949C7469FF}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{AC21F36A-556F-4374-AAB0-96949C7469FF}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{AC21F36A-556F-4374-AAB0-96949C7469FF}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallOriginsService(DispatchBaseClass):
	'IServiceCallOriginsService Interface'
	CLSID = IID('{92C049DE-4E6A-47E8-8910-1C4C83E91780}')
	coclass_clsid = IID('{D6B048C3-D52A-4627-B4CF-81D0B203C076}')

	# Result is of type IServiceCallOriginParams
	def AddServiceCallOrigin(self, pIServiceCallOrigin=defaultNamedNotOptArg):
		'AddServiceCallOrigin'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIServiceCallOrigin
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddServiceCallOrigin', '{AC21F36A-556F-4374-AAB0-96949C7469FF}')
		return ret

	def DeleteServiceCallOrigin(self, pIServiceCallOriginParams=defaultNamedNotOptArg):
		'DeleteServiceCallOrigin'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIServiceCallOriginParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IServiceCallOrigin
	def GetServiceCallOrigin(self, pIServiceCallOriginParams=defaultNamedNotOptArg):
		'GetServiceCallOrigin'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIServiceCallOriginParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallOrigin', '{9FEF81F9-9C21-4B0B-9EDA-0EF9A5C98739}')
		return ret

	# Result is of type IServiceCallOriginParamsCollection
	def GetServiceCallOriginList(self):
		'GetServiceCallOriginList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallOriginList', '{13B1D6B4-A9ED-4787-8B8B-24AAE9525342}')
		return ret

	def UpdateServiceCallOrigin(self, pIServiceCallOrigin=defaultNamedNotOptArg):
		'UpdateServiceCallOrigin'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIServiceCallOrigin
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallProblemType(DispatchBaseClass):
	'IServiceCallProblemType Interface'
	CLSID = IID('{943EB4D4-ED2B-4815-B6D8-3CA50DF8D139}')
	coclass_clsid = IID('{F3F8DF1B-8D02-467D-AFFB-CCF42B3C168E}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"ProblemTypeID": (10, 2, (3, 0), (), "ProblemTypeID", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallProblemTypeParams(DispatchBaseClass):
	'IServiceCallProblemTypeParams Interface'
	CLSID = IID('{0B24F304-D586-4E29-8820-90E334D034D5}')
	coclass_clsid = IID('{ECE6964D-9F54-4552-9727-F31126FDE3F8}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Name": (11, 2, (8, 0), (), "Name", None),
		"ProblemTypeID": (10, 2, (3, 0), (), "ProblemTypeID", None),
	}
	_prop_map_put_ = {
		"ProblemTypeID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallProblemTypeParamsCollection(DispatchBaseClass):
	'IServiceCallProblemTypeParamsCollection Interface'
	CLSID = IID('{4DC9AE34-8FF4-4900-8021-D641EF898358}')
	coclass_clsid = IID('{B7DDAC79-1287-429E-B0C6-8D09A8F6A043}')

	# Result is of type IServiceCallProblemTypeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{0B24F304-D586-4E29-8820-90E334D034D5}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IServiceCallProblemTypeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{0B24F304-D586-4E29-8820-90E334D034D5}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{0B24F304-D586-4E29-8820-90E334D034D5}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{0B24F304-D586-4E29-8820-90E334D034D5}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallProblemTypesService(DispatchBaseClass):
	'IServiceCallProblemTypesService Interface'
	CLSID = IID('{B9DC5AFA-1DC2-4BCB-B2D3-B84A889A9B0E}')
	coclass_clsid = IID('{50CED8F8-E378-4B24-80C5-FFF89AE44EC7}')

	# Result is of type IServiceCallProblemTypeParams
	def AddServiceCallProblemType(self, pIServiceCallProblemType=defaultNamedNotOptArg):
		'AddServiceCallProblemType'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIServiceCallProblemType
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddServiceCallProblemType', '{0B24F304-D586-4E29-8820-90E334D034D5}')
		return ret

	def DeleteServiceCallProblemType(self, pIServiceCallProblemTypeParams=defaultNamedNotOptArg):
		'DeleteServiceCallProblemType'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIServiceCallProblemTypeParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IServiceCallProblemType
	def GetServiceCallProblemType(self, pIServiceCallProblemTypeParams=defaultNamedNotOptArg):
		'GetServiceCallProblemType'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIServiceCallProblemTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallProblemType', '{943EB4D4-ED2B-4815-B6D8-3CA50DF8D139}')
		return ret

	# Result is of type IServiceCallProblemTypeParamsCollection
	def GetServiceCallProblemTypeList(self):
		'GetServiceCallProblemTypeList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallProblemTypeList', '{4DC9AE34-8FF4-4900-8021-D641EF898358}')
		return ret

	def UpdateServiceCallProblemType(self, pIServiceCallProblemType=defaultNamedNotOptArg):
		'UpdateServiceCallProblemType'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIServiceCallProblemType
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallSolutionStatus(DispatchBaseClass):
	'IServiceCallSolutionStatus Interface'
	CLSID = IID('{22219181-9047-4C89-BAC3-4BB311AE77E4}')
	coclass_clsid = IID('{F0380309-A375-4E72-BEF1-D983C80D0F8C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"StatusId": (10, 2, (3, 0), (), "StatusId", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallSolutionStatusParams(DispatchBaseClass):
	'IServiceCallSolutionStatusParams Interface'
	CLSID = IID('{7276D73A-6B18-4F86-B517-6DB9363FC772}')
	coclass_clsid = IID('{08186613-A26E-4BC9-9832-3422FC4621D5}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Name": (11, 2, (8, 0), (), "Name", None),
		"StatusId": (10, 2, (3, 0), (), "StatusId", None),
	}
	_prop_map_put_ = {
		"StatusId": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallSolutionStatusParamsCollection(DispatchBaseClass):
	'IServiceCallSolutionStatusParamsCollection Interface'
	CLSID = IID('{9316E5DC-6A1E-4D66-A31D-40576A355AB9}')
	coclass_clsid = IID('{4E0DC009-5AF1-4931-92D5-B5C051C11800}')

	# Result is of type IServiceCallSolutionStatusParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7276D73A-6B18-4F86-B517-6DB9363FC772}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IServiceCallSolutionStatusParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{7276D73A-6B18-4F86-B517-6DB9363FC772}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{7276D73A-6B18-4F86-B517-6DB9363FC772}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{7276D73A-6B18-4F86-B517-6DB9363FC772}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallSolutionStatusService(DispatchBaseClass):
	'IServiceCallSolutionStatusService Interface'
	CLSID = IID('{AAC173E2-F851-4F94-AE33-00CC4F38FDCD}')
	coclass_clsid = IID('{BCCBA528-E381-4559-90D2-A242DE43AD60}')

	# Result is of type IServiceCallSolutionStatusParams
	def AddServiceCallSolutionStatus(self, pIServiceCallSolutionStatus=defaultNamedNotOptArg):
		'AddServiceCallSolutionStatus'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIServiceCallSolutionStatus
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddServiceCallSolutionStatus', '{7276D73A-6B18-4F86-B517-6DB9363FC772}')
		return ret

	def DeleteServiceCallSolutionStatus(self, pIServiceCallSolutionStatusParams=defaultNamedNotOptArg):
		'DeleteServiceCallSolutionStatus'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIServiceCallSolutionStatusParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IServiceCallSolutionStatus
	def GetServiceCallSolutionStatus(self, pIServiceCallSolutionStatusParams=defaultNamedNotOptArg):
		'GetServiceCallSolutionStatus'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIServiceCallSolutionStatusParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallSolutionStatus', '{22219181-9047-4C89-BAC3-4BB311AE77E4}')
		return ret

	# Result is of type IServiceCallSolutionStatusParamsCollection
	def GetServiceCallSolutionStatusList(self):
		'GetServiceCallSolutionStatusList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallSolutionStatusList', '{9316E5DC-6A1E-4D66-A31D-40576A355AB9}')
		return ret

	def UpdateServiceCallSolutionStatus(self, pIServiceCallSolutionStatus=defaultNamedNotOptArg):
		'UpdateServiceCallSolutionStatus'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIServiceCallSolutionStatus
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallSolutions(DispatchBaseClass):
	'IServiceCallSolutions Interface'
	CLSID = IID('{FA8FD318-6971-4E8B-B6E9-959A938455C6}')
	coclass_clsid = IID('{71ECA915-CB27-41B1-9E9F-DF819F1C52D6}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"SolutionID": (6, 2, (3, 0), (), "SolutionID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"SolutionID": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallStatus(DispatchBaseClass):
	'IServiceCallStatus Interface'
	CLSID = IID('{0E2CBAD1-1857-4E2F-8AE4-5246D1F6725E}')
	coclass_clsid = IID('{AB36A971-B92E-4C38-BA4B-2BE928C8C652}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"StatusId": (10, 2, (3, 0), (), "StatusId", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallStatusParams(DispatchBaseClass):
	'IServiceCallStatusParams Interface'
	CLSID = IID('{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')
	coclass_clsid = IID('{33A595E0-A668-490E-8D9F-5BBD94927FDA}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Name": (11, 2, (8, 0), (), "Name", None),
		"StatusId": (10, 2, (3, 0), (), "StatusId", None),
	}
	_prop_map_put_ = {
		"StatusId": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallStatusParamsCollection(DispatchBaseClass):
	'IServiceCallStatusParamsCollection Interface'
	CLSID = IID('{106B8134-EDB5-4417-BFAC-4A3A2A7B9419}')
	coclass_clsid = IID('{9D2F3E85-AF82-4AF9-AB62-9B210FA52B46}')

	# Result is of type IServiceCallStatusParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IServiceCallStatusParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallStatusService(DispatchBaseClass):
	'IServiceCallStatusService Interface'
	CLSID = IID('{AF0F5509-8F7B-402A-A7D5-2AC98461825F}')
	coclass_clsid = IID('{7F9581D3-34A6-4B9A-88E3-E518307C6FF6}')

	# Result is of type IServiceCallStatusParams
	def AddServiceCallStatus(self, pIServiceCallStatus=defaultNamedNotOptArg):
		'AddServiceCallStatus'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIServiceCallStatus
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddServiceCallStatus', '{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')
		return ret

	def DeleteServiceCallStatus(self, pIServiceCallStatusParams=defaultNamedNotOptArg):
		'DeleteServiceCallStatus'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIServiceCallStatusParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IServiceCallStatus
	def GetServiceCallStatus(self, pIServiceCallStatusParams=defaultNamedNotOptArg):
		'GetServiceCallStatus'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIServiceCallStatusParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallStatus', '{0E2CBAD1-1857-4E2F-8AE4-5246D1F6725E}')
		return ret

	# Result is of type IServiceCallStatusParamsCollection
	def GetServiceCallStatusList(self):
		'GetServiceCallStatusList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallStatusList', '{106B8134-EDB5-4417-BFAC-4A3A2A7B9419}')
		return ret

	def UpdateServiceCallStatus(self, pIServiceCallStatus=defaultNamedNotOptArg):
		'UpdateServiceCallStatus'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIServiceCallStatus
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallType(DispatchBaseClass):
	'IServiceCallType Interface'
	CLSID = IID('{A68554D5-F932-4B92-980E-6060777F59F4}')
	coclass_clsid = IID('{A59ECD2A-FD2C-47A5-8D59-BD3410E5E408}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CallTypeID": (10, 2, (3, 0), (), "CallTypeID", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallTypeParams(DispatchBaseClass):
	'IServiceCallTypeParams Interface'
	CLSID = IID('{72274C66-4457-4D17-8F61-014F5520C434}')
	coclass_clsid = IID('{9883D635-027D-472C-AAA6-AC346F3DF308}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"CallTypeID": (10, 2, (3, 0), (), "CallTypeID", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"CallTypeID": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCallTypeParamsCollection(DispatchBaseClass):
	'IServiceCallTypeParamsCollection Interface'
	CLSID = IID('{475E4307-5C54-4449-BFCA-2CCCBBEB6448}')
	coclass_clsid = IID('{62F0798F-B9DB-43CB-B3BA-5C499E271143}')

	# Result is of type IServiceCallTypeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{72274C66-4457-4D17-8F61-014F5520C434}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IServiceCallTypeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{72274C66-4457-4D17-8F61-014F5520C434}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{72274C66-4457-4D17-8F61-014F5520C434}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{72274C66-4457-4D17-8F61-014F5520C434}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceCallTypesService(DispatchBaseClass):
	'IServiceCallTypesService Interface'
	CLSID = IID('{B829E078-BAC8-4EC5-BFDD-7F4230AE8BF2}')
	coclass_clsid = IID('{D9DD7A40-DA9C-4ED0-A5B9-103650442A61}')

	# Result is of type IServiceCallTypeParams
	def AddServiceCallType(self, pIServiceCallType=defaultNamedNotOptArg):
		'AddServiceCallType'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIServiceCallType
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddServiceCallType', '{72274C66-4457-4D17-8F61-014F5520C434}')
		return ret

	def DeleteServiceCallType(self, pIServiceCallTypeParams=defaultNamedNotOptArg):
		'DeleteServiceCallType'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIServiceCallTypeParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IServiceCallType
	def GetServiceCallType(self, pIServiceCallTypeParams=defaultNamedNotOptArg):
		'GetServiceCallType'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIServiceCallTypeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallType', '{A68554D5-F932-4B92-980E-6060777F59F4}')
		return ret

	# Result is of type IServiceCallTypeParamsCollection
	def GetServiceCallTypeList(self):
		'GetServiceCallTypeList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceCallTypeList', '{475E4307-5C54-4449-BFCA-2CCCBBEB6448}')
		return ret

	def UpdateServiceCallType(self, pIServiceCallType=defaultNamedNotOptArg):
		'UpdateServiceCallType'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIServiceCallType
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceCalls(DispatchBaseClass):
	'IServiceCalls Interface'
	CLSID = IID('{A93CD1FA-F12F-47B0-8FAB-859692B8A653}')
	coclass_clsid = IID('{41501B90-66B9-49BC-920E-EAEF90F119B2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(57, LCID, 1, (8, 0), (),)

	def GetByKey(self, ServiceCallID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),ServiceCallID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(58, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Activities' returns object of type 'IServiceCallActivities'
		"Activities": (35, 2, (9, 0), (), "Activities", '{0207412D-F955-46BA-AE96-E749573B4106}'),
		"AddressName": (73, 2, (8, 0), (), "AddressName", None),
		"AddressType": (74, 2, (3, 0), (), "AddressType", None),
		"AssignedDate": (50, 2, (7, 0), (), "AssignedDate", None),
		"AssignedTime": (55, 2, (3, 0), (), "AssignedTime", None),
		"AssigneeCode": (30, 2, (3, 0), (), "AssigneeCode", None),
		"BelongsToAQueue": (43, 2, (3, 0), (), "BelongsToAQueue", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CallType": (28, 2, (3, 0), (), "CallType", None),
		"City": (76, 2, (8, 0), (), "City", None),
		"ClosingDate": (56, 2, (7, 0), (), "ClosingDate", None),
		"ClosingTime": (49, 2, (3, 0), (), "ClosingTime", None),
		"ContactCode": (13, 2, (3, 0), (), "ContactCode", None),
		"ContractEndDate": (17, 2, (7, 0), (), "ContractEndDate", None),
		"ContractID": (16, 2, (3, 0), (), "ContractID", None),
		"Country": (79, 2, (8, 0), (), "Country", None),
		"CreationDate": (38, 2, (7, 0), (), "CreationDate", None),
		"CreationTime": (39, 2, (7, 0), (), "CreationTime", None),
		"CustomerCode": (11, 2, (8, 0), (), "CustomerCode", None),
		"CustomerName": (12, 2, (8, 0), (), "CustomerName", None),
		"Description": (31, 2, (8, 0), (), "Description", None),
		"DisplayInCalendar": (80, 2, (3, 0), (), "DisplayInCalendar", None),
		"DocNum": (60, 2, (3, 0), (), "DocNum", None),
		"Duration": (67, 2, (5, 0), (), "Duration", None),
		"DurationType": (68, 2, (3, 0), (), "DurationType", None),
		"EndDuedate": (65, 2, (7, 0), (), "EndDuedate", None),
		"EndTime": (66, 2, (7, 0), (), "EndTime", None),
		"EntitledforService": (53, 2, (3, 0), (), "EntitledforService", None),
		# Method 'Expenses' returns object of type 'IServiceCallInventoryExpenses'
		"Expenses": (36, 2, (9, 0), (), "Expenses", '{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}'),
		"HandWritten": (61, 2, (3, 0), (), "HandWritten", None),
		"InternalSerialNum": (15, 2, (8, 0), (), "InternalSerialNum", None),
		"ItemCode": (23, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (24, 2, (8, 0), (), "ItemDescription", None),
		"ItemGroupCode": (25, 2, (3, 0), (), "ItemGroupCode", None),
		"Location": (72, 2, (3, 0), (), "Location", None),
		"ManufacturerSerialNum": (14, 2, (8, 0), (), "ManufacturerSerialNum", None),
		"Origin": (22, 2, (3, 0), (), "Origin", None),
		"PeriodIndicator": (62, 2, (8, 0), (), "PeriodIndicator", None),
		"Priority": (27, 2, (3, 0), (), "Priority", None),
		"ProblemType": (29, 2, (3, 0), (), "ProblemType", None),
		"Queue": (51, 2, (8, 0), (), "Queue", None),
		"Reminder": (69, 2, (3, 0), (), "Reminder", None),
		"ReminderPeriod": (70, 2, (5, 0), (), "ReminderPeriod", None),
		"ReminderType": (71, 2, (3, 0), (), "ReminderType", None),
		"Resolution": (34, 2, (8, 0), (), "Resolution", None),
		"ResolutionDate": (18, 2, (7, 0), (), "ResolutionDate", None),
		"ResolutionOnDate": (46, 2, (7, 0), (), "ResolutionOnDate", None),
		"ResolutionOnTime": (54, 2, (3, 0), (), "ResolutionOnTime", None),
		"ResolutionTime": (19, 2, (7, 0), (), "ResolutionTime", None),
		"Responder": (41, 2, (3, 0), (), "Responder", None),
		"ResponseAssignee": (52, 2, (3, 0), (), "ResponseAssignee", None),
		"ResponseByDate": (45, 2, (7, 0), (), "ResponseByDate", None),
		"ResponseByTime": (44, 2, (3, 0), (), "ResponseByTime", None),
		"ResponseOnDate": (48, 2, (7, 0), (), "ResponseOnDate", None),
		"ResponseOnTime": (47, 2, (3, 0), (), "ResponseOnTime", None),
		"Room": (77, 2, (8, 0), (), "Room", None),
		"Series": (59, 2, (3, 0), (), "Series", None),
		"ServiceCallID": (9, 2, (3, 0), (), "ServiceCallID", None),
		# Method 'Solutions' returns object of type 'IServiceCallSolutions'
		"Solutions": (37, 2, (9, 0), (), "Solutions", '{FA8FD318-6971-4E8B-B6E9-959A938455C6}'),
		"StartDate": (63, 2, (7, 0), (), "StartDate", None),
		"StartTime": (64, 2, (7, 0), (), "StartTime", None),
		"State": (78, 2, (8, 0), (), "State", None),
		"Status": (26, 2, (3, 0), (), "Status", None),
		"Street": (75, 2, (8, 0), (), "Street", None),
		"Subject": (10, 2, (8, 0), (), "Subject", None),
		"TechnicianCode": (33, 2, (3, 0), (), "TechnicianCode", None),
		"UpdatedTime": (42, 2, (3, 0), (), "UpdatedTime", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AddressName": ((73, LCID, 4, 0),()),
		"AddressType": ((74, LCID, 4, 0),()),
		"AssigneeCode": ((30, LCID, 4, 0),()),
		"BelongsToAQueue": ((43, LCID, 4, 0),()),
		"CallType": ((28, LCID, 4, 0),()),
		"City": ((76, LCID, 4, 0),()),
		"ContactCode": ((13, LCID, 4, 0),()),
		"ContractID": ((16, LCID, 4, 0),()),
		"Country": ((79, LCID, 4, 0),()),
		"CustomerCode": ((11, LCID, 4, 0),()),
		"CustomerName": ((12, LCID, 4, 0),()),
		"Description": ((31, LCID, 4, 0),()),
		"DisplayInCalendar": ((80, LCID, 4, 0),()),
		"DocNum": ((60, LCID, 4, 0),()),
		"Duration": ((67, LCID, 4, 0),()),
		"DurationType": ((68, LCID, 4, 0),()),
		"EndDuedate": ((65, LCID, 4, 0),()),
		"EndTime": ((66, LCID, 4, 0),()),
		"HandWritten": ((61, LCID, 4, 0),()),
		"InternalSerialNum": ((15, LCID, 4, 0),()),
		"ItemCode": ((23, LCID, 4, 0),()),
		"ItemDescription": ((24, LCID, 4, 0),()),
		"Location": ((72, LCID, 4, 0),()),
		"ManufacturerSerialNum": ((14, LCID, 4, 0),()),
		"Origin": ((22, LCID, 4, 0),()),
		"Priority": ((27, LCID, 4, 0),()),
		"ProblemType": ((29, LCID, 4, 0),()),
		"Queue": ((51, LCID, 4, 0),()),
		"Reminder": ((69, LCID, 4, 0),()),
		"ReminderPeriod": ((70, LCID, 4, 0),()),
		"ReminderType": ((71, LCID, 4, 0),()),
		"Resolution": ((34, LCID, 4, 0),()),
		"ResolutionDate": ((18, LCID, 4, 0),()),
		"ResolutionTime": ((19, LCID, 4, 0),()),
		"Room": ((77, LCID, 4, 0),()),
		"Series": ((59, LCID, 4, 0),()),
		"StartDate": ((63, LCID, 4, 0),()),
		"StartTime": ((64, LCID, 4, 0),()),
		"State": ((78, LCID, 4, 0),()),
		"Status": ((26, LCID, 4, 0),()),
		"Street": ((75, LCID, 4, 0),()),
		"Subject": ((10, LCID, 4, 0),()),
		"TechnicianCode": ((33, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceContract_Lines(DispatchBaseClass):
	'IServiceContract_Lines Interface'
	CLSID = IID('{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}')
	coclass_clsid = IID('{8F1131E9-C31E-4F6D-BC3A-1F94AE2CEACF}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"EndDate": (12, 2, (7, 0), (), "EndDate", None),
		"InternalSerialNum": (7, 2, (8, 0), (), "InternalSerialNum", None),
		"ItemCode": (8, 2, (8, 0), (), "ItemCode", None),
		"ItemGroup": (10, 2, (3, 0), (), "ItemGroup", None),
		"ItemGroupName": (13, 2, (8, 0), (), "ItemGroupName", None),
		"ItemName": (9, 2, (8, 0), (), "ItemName", None),
		"LineNum": (5, 2, (3, 0), (), "LineNum", None),
		"ManufacturerSerialNum": (6, 2, (8, 0), (), "ManufacturerSerialNum", None),
		"StartDate": (11, 2, (7, 0), (), "StartDate", None),
		"TerminationDate": (14, 2, (7, 0), (), "TerminationDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"EndDate": ((12, LCID, 4, 0),()),
		"InternalSerialNum": ((7, LCID, 4, 0),()),
		"ItemCode": ((8, LCID, 4, 0),()),
		"ItemGroup": ((10, LCID, 4, 0),()),
		"ItemName": ((9, LCID, 4, 0),()),
		"ManufacturerSerialNum": ((6, LCID, 4, 0),()),
		"StartDate": ((11, LCID, 4, 0),()),
		"TerminationDate": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceContracts(DispatchBaseClass):
	'IServiceContracts Interface'
	CLSID = IID('{5C594028-D730-4298-952E-4616C5047BC6}')
	coclass_clsid = IID('{3267FC28-5E07-4BA5-B072-C8F160D7C1C4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(54, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(61, LCID, 1, (8, 0), (),)

	def GetByKey(self, ContractID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),ContractID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(62, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AttachmentEntry": (63, 2, (3, 0), (), "AttachmentEntry", None),
		# Method 'Attachments' returns object of type 'IAttachments'
		"Attachments": (49, 2, (9, 0), (), "Attachments", '{B728546D-EA5F-4122-9FE0-759C89BF95D0}'),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (53, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"ContactCode": (10, 2, (3, 0), (), "ContactCode", None),
		"ContractID": (7, 2, (3, 0), (), "ContractID", None),
		"ContractTemplate": (13, 2, (8, 0), (), "ContractTemplate", None),
		"ContractType": (14, 2, (3, 0), (), "ContractType", None),
		"CustomerCode": (8, 2, (8, 0), (), "CustomerCode", None),
		"CustomerName": (9, 2, (8, 0), (), "CustomerName", None),
		"Description": (23, 2, (8, 0), (), "Description", None),
		"DurationOfCoverage": (18, 2, (3, 0), (), "DurationOfCoverage", None),
		"EndDate": (20, 2, (7, 0), (), "EndDate", None),
		"FridayEnabled": (29, 2, (3, 0), (), "FridayEnabled", None),
		"FridayEnd": (41, 2, (7, 0), (), "FridayEnd", None),
		"FridayStart": (40, 2, (7, 0), (), "FridayStart", None),
		"IncludeHolidays": (56, 2, (3, 0), (), "IncludeHolidays", None),
		"IncludeLabor": (47, 2, (3, 0), (), "IncludeLabor", None),
		"IncludeParts": (46, 2, (3, 0), (), "IncludeParts", None),
		"IncludeTravel": (48, 2, (3, 0), (), "IncludeTravel", None),
		# Method 'Lines' returns object of type 'IServiceContract_Lines'
		"Lines": (55, 2, (9, 0), (), "Lines", '{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}'),
		"MondayEnabled": (25, 2, (3, 0), (), "MondayEnabled", None),
		"MondayEnd": (33, 2, (7, 0), (), "MondayEnd", None),
		"MondayStart": (32, 2, (7, 0), (), "MondayStart", None),
		"Owner": (11, 2, (3, 0), (), "Owner", None),
		"Remarks": (51, 2, (8, 0), (), "Remarks", None),
		"RemindUnit": (17, 2, (3, 0), (), "RemindUnit", None),
		"ReminderTime": (16, 2, (3, 0), (), "ReminderTime", None),
		"Renewal": (15, 2, (3, 0), (), "Renewal", None),
		"ResolutionTime": (21, 2, (3, 0), (), "ResolutionTime", None),
		"ResolutionUnit": (22, 2, (3, 0), (), "ResolutionUnit", None),
		"ResponseTime": (59, 2, (3, 0), (), "ResponseTime", None),
		"ResponseUnit": (58, 2, (3, 0), (), "ResponseUnit", None),
		"SaturdayEnabled": (30, 2, (3, 0), (), "SaturdayEnabled", None),
		"SaturdayEnd": (43, 2, (7, 0), (), "SaturdayEnd", None),
		"SaturdayStart": (42, 2, (7, 0), (), "SaturdayStart", None),
		"ServiceType": (57, 2, (3, 0), (), "ServiceType", None),
		"StartDate": (19, 2, (7, 0), (), "StartDate", None),
		"Status": (12, 2, (3, 0), (), "Status", None),
		"SundayEnabled": (31, 2, (3, 0), (), "SundayEnabled", None),
		"SundayEnd": (45, 2, (7, 0), (), "SundayEnd", None),
		"SundayStart": (44, 2, (7, 0), (), "SundayStart", None),
		"TemplateRemarks": (50, 2, (8, 0), (), "TemplateRemarks", None),
		"TerminationDate": (60, 2, (7, 0), (), "TerminationDate", None),
		"ThursdayEnabled": (28, 2, (3, 0), (), "ThursdayEnabled", None),
		"ThursdayEnd": (39, 2, (7, 0), (), "ThursdayEnd", None),
		"ThursdayStart": (38, 2, (7, 0), (), "ThursdayStart", None),
		"TuesdayEnabled": (26, 2, (3, 0), (), "TuesdayEnabled", None),
		"TuesdayEnd": (35, 2, (7, 0), (), "TuesdayEnd", None),
		"TuesdayStart": (34, 2, (7, 0), (), "TuesdayStart", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WednesdayEnabled": (27, 2, (3, 0), (), "WednesdayEnabled", None),
		"WednesdayEnd": (37, 2, (7, 0), (), "WednesdayEnd", None),
		"WednesdayStart": (36, 2, (7, 0), (), "WednesdayStart", None),
	}
	_prop_map_put_ = {
		"AttachmentEntry": ((63, LCID, 4, 0),()),
		"ContactCode": ((10, LCID, 4, 0),()),
		"ContractTemplate": ((13, LCID, 4, 0),()),
		"ContractType": ((14, LCID, 4, 0),()),
		"CustomerCode": ((8, LCID, 4, 0),()),
		"CustomerName": ((9, LCID, 4, 0),()),
		"Description": ((23, LCID, 4, 0),()),
		"EndDate": ((20, LCID, 4, 0),()),
		"FridayEnabled": ((29, LCID, 4, 0),()),
		"FridayEnd": ((41, LCID, 4, 0),()),
		"FridayStart": ((40, LCID, 4, 0),()),
		"IncludeHolidays": ((56, LCID, 4, 0),()),
		"IncludeLabor": ((47, LCID, 4, 0),()),
		"IncludeParts": ((46, LCID, 4, 0),()),
		"IncludeTravel": ((48, LCID, 4, 0),()),
		"MondayEnabled": ((25, LCID, 4, 0),()),
		"MondayEnd": ((33, LCID, 4, 0),()),
		"MondayStart": ((32, LCID, 4, 0),()),
		"Owner": ((11, LCID, 4, 0),()),
		"Remarks": ((51, LCID, 4, 0),()),
		"RemindUnit": ((17, LCID, 4, 0),()),
		"ReminderTime": ((16, LCID, 4, 0),()),
		"Renewal": ((15, LCID, 4, 0),()),
		"ResolutionTime": ((21, LCID, 4, 0),()),
		"ResolutionUnit": ((22, LCID, 4, 0),()),
		"ResponseTime": ((59, LCID, 4, 0),()),
		"ResponseUnit": ((58, LCID, 4, 0),()),
		"SaturdayEnabled": ((30, LCID, 4, 0),()),
		"SaturdayEnd": ((43, LCID, 4, 0),()),
		"SaturdayStart": ((42, LCID, 4, 0),()),
		"ServiceType": ((57, LCID, 4, 0),()),
		"StartDate": ((19, LCID, 4, 0),()),
		"Status": ((12, LCID, 4, 0),()),
		"SundayEnabled": ((31, LCID, 4, 0),()),
		"SundayEnd": ((45, LCID, 4, 0),()),
		"SundayStart": ((44, LCID, 4, 0),()),
		"TerminationDate": ((60, LCID, 4, 0),()),
		"ThursdayEnabled": ((28, LCID, 4, 0),()),
		"ThursdayEnd": ((39, LCID, 4, 0),()),
		"ThursdayStart": ((38, LCID, 4, 0),()),
		"TuesdayEnabled": ((26, LCID, 4, 0),()),
		"TuesdayEnd": ((35, LCID, 4, 0),()),
		"TuesdayStart": ((34, LCID, 4, 0),()),
		"WednesdayEnabled": ((27, LCID, 4, 0),()),
		"WednesdayEnd": ((37, LCID, 4, 0),()),
		"WednesdayStart": ((36, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceGroup(DispatchBaseClass):
	'IServiceGroup Interface'
	CLSID = IID('{A55338A2-5402-41BB-9588-39EC814AB644}')
	coclass_clsid = IID('{036CFBA9-9D90-46D7-BCA2-5C1B028E56A4}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"ServiceGroupCode": (11, 2, (8, 0), (), "ServiceGroupCode", None),
	}
	_prop_map_put_ = {
		"Description": ((12, LCID, 4, 0),()),
		"ServiceGroupCode": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceGroupParams(DispatchBaseClass):
	'IServiceGroupParams Interface'
	CLSID = IID('{C9A336DC-4108-44D2-8161-5420E75E8475}')
	coclass_clsid = IID('{871BC4E7-9FB2-4847-8031-FF03A682F0D5}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"ServiceGroupCode": (11, 2, (8, 0), (), "ServiceGroupCode", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceGroupsParams(DispatchBaseClass):
	'IServiceGroupsParams Interface'
	CLSID = IID('{74490BE7-8344-4F48-90C9-2A811E54AA49}')
	coclass_clsid = IID('{1F27E785-8D39-4E94-9022-6EAF45962D86}')

	# Result is of type IServiceGroupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{C9A336DC-4108-44D2-8161-5420E75E8475}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IServiceGroupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{C9A336DC-4108-44D2-8161-5420E75E8475}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{C9A336DC-4108-44D2-8161-5420E75E8475}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{C9A336DC-4108-44D2-8161-5420E75E8475}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceGroupsService(DispatchBaseClass):
	'IServiceGroupsService Interface'
	CLSID = IID('{729A48C9-675C-4F2C-9A16-2C29D1825C05}')
	coclass_clsid = IID('{F2637576-718A-48FF-9B0E-355645D088E3}')

	# Result is of type IServiceGroupParams
	def AddServiceGroup(self, pIServiceGroup=defaultNamedNotOptArg):
		'AddServiceGroup'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIServiceGroup
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddServiceGroup', '{C9A336DC-4108-44D2-8161-5420E75E8475}')
		return ret

	def DeleteServiceGroup(self, pIServiceGroupParams=defaultNamedNotOptArg):
		'DeleteServiceGroup'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIServiceGroupParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IServiceGroup
	def GetServiceGroup(self, pIServiceGroupParams=defaultNamedNotOptArg):
		'GetServiceGroup'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIServiceGroupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceGroup', '{A55338A2-5402-41BB-9588-39EC814AB644}')
		return ret

	# Result is of type IServiceGroupsParams
	def GetServiceGroupList(self):
		'GetServiceGroupList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetServiceGroupList', '{74490BE7-8344-4F48-90C9-2A811E54AA49}')
		return ret

	def UpdateServiceGroup(self, pIServiceGroup=defaultNamedNotOptArg):
		'UpdateServiceGroup'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIServiceGroup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceTaxPostingParams(DispatchBaseClass):
	'IServiceTaxPostingParams Interface'
	CLSID = IID('{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}')
	coclass_clsid = IID('{001A7E87-FD95-421B-8F59-DBA53D45745B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
	}
	_prop_map_put_ = {
		"DocEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IServiceTaxPostingParamsCollection(DispatchBaseClass):
	'IServiceTaxPostingParamsCollection Interface'
	CLSID = IID('{16E2EB82-A981-4E4F-A378-6D4E53B17134}')
	coclass_clsid = IID('{B10E527A-7667-46CC-AA30-461F5D93FA99}')

	# Result is of type IServiceTaxPostingParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IServiceTaxPostingParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IServiceTaxPostingService(DispatchBaseClass):
	'IServiceTaxPostingService Interface'
	CLSID = IID('{4A2F8C9A-04AD-4CBA-842B-54BCF3927A35}')
	coclass_clsid = IID('{2FA94E31-95AE-4F97-BD68-90E1DCC414F5}')

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IServiceTaxPostingParamsCollection
	def GetTaxableDeliveries(self):
		'GetTaxableDeliveries'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetTaxableDeliveries', '{16E2EB82-A981-4E4F-A378-6D4E53B17134}')
		return ret

	def PostServiceTax(self, pIServiceTaxPostingParams=defaultNamedNotOptArg):
		'PostServiceTax'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((9, 1),),pIServiceTaxPostingParams
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IShippingTypes(DispatchBaseClass):
	'IShippingTypes Interface'
	CLSID = IID('{EE047C63-413F-4CEA-B8BC-A4223AA6B482}')
	coclass_clsid = IID('{AFB12D1C-F0C3-4FA6-BF53-CA858C1BE796}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (12, 2, (3, 0), (), "Code", None),
		"Name": (13, 2, (8, 0), (), "Name", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"Website": (14, 2, (8, 0), (), "Website", None),
	}
	_prop_map_put_ = {
		"Name": ((13, LCID, 4, 0),()),
		"Website": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IShowDifferenceParams(DispatchBaseClass):
	'IShowDifferenceParams Interface'
	CLSID = IID('{87447CCD-DE87-4992-A2FD-2B0E26460BCB}')
	coclass_clsid = IID('{EBCC9023-5BC9-4CA8-B28F-24E4E60F0965}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"LogInstance": (13, 2, (3, 0), (), "LogInstance", None),
		"LogInstance2": (12, 2, (3, 0), (), "LogInstance2", None),
		"Object": (11, 2, (3, 0), (), "Object", None),
		"PrimaryKey": (10, 2, (8, 0), (), "PrimaryKey", None),
		"UDOObjectCode": (14, 2, (8, 0), (), "UDOObjectCode", None),
	}
	_prop_map_put_ = {
		"LogInstance": ((13, LCID, 4, 0),()),
		"LogInstance2": ((12, LCID, 4, 0),()),
		"Object": ((11, LCID, 4, 0),()),
		"PrimaryKey": ((10, LCID, 4, 0),()),
		"UDOObjectCode": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISpecialPrices(DispatchBaseClass):
	'ISpecialPrices Interface'
	CLSID = IID('{2C1751BA-5CFF-4E47-8C1E-13CAF241A13F}')
	coclass_clsid = IID('{4F6D3681-33BD-41F5-BFEA-DE2059E4ADF4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(14, LCID, 1, (8, 0), (),)

	def GetByKey(self, ItemCode=defaultNamedNotOptArg, CardCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (11, 0), ((8, 1), (8, 1)),ItemCode
			, CardCode)

	def GetByKeyDiscounts(self, ItemCode=defaultNamedNotOptArg, PriceListNum=defaultNamedNotOptArg):
		'method GetByKeyDiscounts'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (11, 0), ((8, 1), (3, 1)),ItemCode
			, PriceListNum)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(12, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AutoUpdate": (11, 2, (3, 0), (), "AutoUpdate", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (16, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (3, 2, (8, 0), (), "CardCode", None),
		"Currency": (5, 2, (8, 0), (), "Currency", None),
		"DiscountPercent": (6, 2, (5, 0), (), "DiscountPercent", None),
		"ItemCode": (2, 2, (8, 0), (), "ItemCode", None),
		"Price": (4, 2, (5, 0), (), "Price", None),
		"PriceListNum": (7, 2, (3, 0), (), "PriceListNum", None),
		# Method 'SpecialPricesDataAreas' returns object of type 'ISpecialPricesDataAreas'
		"SpecialPricesDataAreas": (13, 2, (9, 0), (), "SpecialPricesDataAreas", '{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}'),
	}
	_prop_map_put_ = {
		"AutoUpdate": ((11, LCID, 4, 0),()),
		"CardCode": ((3, LCID, 4, 0),()),
		"Currency": ((5, LCID, 4, 0),()),
		"DiscountPercent": ((6, LCID, 4, 0),()),
		"ItemCode": ((2, LCID, 4, 0),()),
		"Price": ((4, LCID, 4, 0),()),
		"PriceListNum": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ISpecialPricesDataAreas(DispatchBaseClass):
	'ISpecialPricesDataAreas Interface'
	CLSID = IID('{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}')
	coclass_clsid = IID('{7A1326F7-9545-4AAC-B875-C317CF7D76B4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"AutoUpdate": (2, 2, (3, 0), (), "AutoUpdate", None),
		"BPCode": (7, 2, (8, 0), (), "BPCode", None),
		"Count": (12, 2, (3, 0), (), "Count", None),
		"DateFrom": (6, 2, (7, 0), (), "DateFrom", None),
		"Dateto": (3, 2, (7, 0), (), "Dateto", None),
		"Discount": (4, 2, (5, 0), (), "Discount", None),
		"ItemNo": (9, 2, (8, 0), (), "ItemNo", None),
		"PriceCurrency": (1, 2, (8, 0), (), "PriceCurrency", None),
		"PriceListNo": (8, 2, (3, 0), (), "PriceListNo", None),
		"RowNumber": (10, 2, (3, 0), (), "RowNumber", None),
		"SpecialPrice": (5, 2, (5, 0), (), "SpecialPrice", None),
		# Method 'SpecialPricesQuantityAreas' returns object of type 'ISpecialPricesQuantityAreas'
		"SpecialPricesQuantityAreas": (15, 2, (9, 0), (), "SpecialPricesQuantityAreas", '{34995651-4568-4AAE-B831-60693B932A35}'),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (11, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"AutoUpdate": ((2, LCID, 4, 0),()),
		"DateFrom": ((6, LCID, 4, 0),()),
		"Dateto": ((3, LCID, 4, 0),()),
		"Discount": ((4, LCID, 4, 0),()),
		"PriceCurrency": ((1, LCID, 4, 0),()),
		"PriceListNo": ((8, LCID, 4, 0),()),
		"SpecialPrice": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(12, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ISpecialPricesQuantityAreas(DispatchBaseClass):
	'ISpecialPricesQuantityAreas Interface'
	CLSID = IID('{34995651-4568-4AAE-B831-60693B932A35}')
	coclass_clsid = IID('{36E908CF-6A46-413F-8BD6-C027651A58EA}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPCode": (5, 2, (8, 0), (), "BPCode", None),
		"Count": (10, 2, (3, 0), (), "Count", None),
		"Discountin": (8, 2, (5, 0), (), "Discountin", None),
		"ItemNo": (4, 2, (8, 0), (), "ItemNo", None),
		"PriceCurrency": (7, 2, (8, 0), (), "PriceCurrency", None),
		"Quantity": (1, 2, (5, 0), (), "Quantity", None),
		"RowNumber": (6, 2, (3, 0), (), "RowNumber", None),
		"SPDARowNumber": (2, 2, (3, 0), (), "SPDARowNumber", None),
		"SpecialPrice": (3, 2, (5, 0), (), "SpecialPrice", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (9, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Discountin": ((8, LCID, 4, 0),()),
		"PriceCurrency": ((7, LCID, 4, 0),()),
		"Quantity": ((1, LCID, 4, 0),()),
		"SpecialPrice": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(10, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IState(DispatchBaseClass):
	'IState Interface'
	CLSID = IID('{9E37320F-F058-462C-9483-AD67BC65191B}')
	coclass_clsid = IID('{06ACC334-F4CD-4259-B2A8-149807E97E6C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Country": (11, 2, (8, 0), (), "Country", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
		"Country": ((11, LCID, 4, 0),()),
		"Name": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IStateParams(DispatchBaseClass):
	'IStateParams Interface'
	CLSID = IID('{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')
	coclass_clsid = IID('{9A92B21A-A70D-489C-86EC-47E379581650}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Country": (11, 2, (8, 0), (), "Country", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
		"Country": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IStatesParams(DispatchBaseClass):
	'IStatesParams Interface'
	CLSID = IID('{3443DB6C-7014-4BC3-A860-F4934E449818}')
	coclass_clsid = IID('{80DB1499-68B7-473B-B0A7-CE7F0F1FCECF}')

	# Result is of type IStateParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IStateParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IStatesService(DispatchBaseClass):
	'IStatesService Interface'
	CLSID = IID('{269D9A4D-1866-43A0-B5AB-B46035B1667F}')
	coclass_clsid = IID('{EA05A4CC-F1C8-41C4-8F84-64A9D9CA9883}')

	# Result is of type IStateParams
	def AddState(self, pIState=defaultNamedNotOptArg):
		'AddState'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIState
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddState', '{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')
		return ret

	def DeleteState(self, pIStateParams=defaultNamedNotOptArg):
		'DeleteState'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pIStateParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IState
	def GetState(self, pIStateParams=defaultNamedNotOptArg):
		'GetState'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pIStateParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetState', '{9E37320F-F058-462C-9483-AD67BC65191B}')
		return ret

	# Result is of type IStatesParams
	def GetStateList(self):
		'GetStateList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetStateList', '{3443DB6C-7014-4BC3-A860-F4934E449818}')
		return ret

	def UpdateState(self, pIState=defaultNamedNotOptArg):
		'UpdateState'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pIState
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IStockTaking(DispatchBaseClass):
	'IStockTaking Interface'
	CLSID = IID('{301718D4-11C9-4C5F-88DD-3609C5FA21FF}')
	coclass_clsid = IID('{CBC0A7DF-E458-45B8-B640-955215643708}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(8, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrItemCode=defaultNamedNotOptArg, bstrWhsCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (11, 0), ((8, 1), (8, 1)),bstrItemCode
			, bstrWhsCode)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(9, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(7, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (6, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Counted": (4, 2, (5, 0), (), "Counted", None),
		"ItemCode": (2, 2, (8, 0), (), "ItemCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WarehouseCode": (3, 2, (8, 0), (), "WarehouseCode", None),
	}
	_prop_map_put_ = {
		"Counted": ((4, LCID, 4, 0),()),
		"ItemCode": ((2, LCID, 4, 0),()),
		"WarehouseCode": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IStockTransfer(DispatchBaseClass):
	'IStockTransfer Interface'
	CLSID = IID('{8DD14B84-6D7B-49E9-8137-A3E7F9A3642F}')
	coclass_clsid = IID('{E2174012-44BF-4A47-B117-283D13C66C5E}')

	def Add(self):
		'Add'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(19, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (3, 0), (),)

	def GetApprovalTemplates(self):
		'method GetApprovalTemplates'
		return self._oleobj_.InvokeTypes(39, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(32, LCID, 1, (8, 0), (),)

	def GetByKey(self, AbsEntry=defaultNamedNotOptArg):
		'Get by key'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (11, 0), ((3, 0),),AbsEntry
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveDraftToDocument(self):
		'method SaveDraftToDocument'
		return self._oleobj_.InvokeTypes(40, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(33, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(28, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Address": (10, 2, (8, 0), (), "Address", None),
		"AuthorizationStatus": (42, 2, (3, 0), (), "AuthorizationStatus", None),
		"BPLID": (43, 2, (3, 0), (), "BPLID", None),
		"BPLName": (44, 2, (8, 0), (), "BPLName", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (21, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CardCode": (8, 2, (8, 0), (), "CardCode", None),
		"CardName": (9, 2, (8, 0), (), "CardName", None),
		"Comments": (13, 2, (8, 0), (), "Comments", None),
		"ContactPerson": (30, 2, (3, 0), (), "ContactPerson", None),
		"CreationDate": (23, 2, (7, 0), (), "CreationDate", None),
		"DocDate": (7, 2, (7, 0), (), "DocDate", None),
		"DocEntry": (22, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (27, 2, (3, 0), (), "DocNum", None),
		"DocObjectCode": (37, 2, (3, 0), (), "DocObjectCode", None),
		"DueDate": (38, 2, (7, 0), (), "DueDate", None),
		"FinancialPeriod": (25, 2, (3, 0), (), "FinancialPeriod", None),
		"FolioNumber": (35, 2, (3, 0), (), "FolioNumber", None),
		"FolioPrefixString": (34, 2, (8, 0), (), "FolioPrefixString", None),
		"FromWarehouse": (17, 2, (8, 0), (), "FromWarehouse", None),
		"JournalMemo": (14, 2, (8, 0), (), "JournalMemo", None),
		# Method 'Lines' returns object of type 'IStockTransfer_Lines'
		"Lines": (1, 2, (9, 0), (), "Lines", '{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}'),
		"PriceList": (15, 2, (3, 0), (), "PriceList", None),
		"Printed": (6, 2, (3, 0), (), "Printed", None),
		"Reference1": (11, 2, (8, 0), (), "Reference1", None),
		"Reference2": (12, 2, (8, 0), (), "Reference2", None),
		"SalesPersonCode": (16, 2, (3, 0), (), "SalesPersonCode", None),
		"Series": (5, 2, (3, 0), (), "Series", None),
		# Method 'StockTransfer_ApprovalRequests' returns object of type 'IStockTransfer_ApprovalRequests'
		"StockTransfer_ApprovalRequests": (41, 2, (9, 0), (), "StockTransfer_ApprovalRequests", '{DACFE08E-8A02-43ED-B762-5E664186FB0E}'),
		"TaxDate": (29, 2, (7, 0), (), "TaxDate", None),
		# Method 'TaxExtension' returns object of type 'IStockTransfer_TaxExtension'
		"TaxExtension": (36, 2, (9, 0), (), "TaxExtension", '{F510FF2B-D307-487F-9ECC-EE436A6EBF10}'),
		"TransNum": (26, 2, (3, 0), (), "TransNum", None),
		"UpdateDate": (24, 2, (7, 0), (), "UpdateDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (31, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATRegNum": (45, 2, (8, 0), (), "VATRegNum", None),
	}
	_prop_map_put_ = {
		"Address": ((10, LCID, 4, 0),()),
		"CardCode": ((8, LCID, 4, 0),()),
		"CardName": ((9, LCID, 4, 0),()),
		"Comments": ((13, LCID, 4, 0),()),
		"ContactPerson": ((30, LCID, 4, 0),()),
		"DocDate": ((7, LCID, 4, 0),()),
		"DocObjectCode": ((37, LCID, 4, 0),()),
		"DueDate": ((38, LCID, 4, 0),()),
		"FolioNumber": ((35, LCID, 4, 0),()),
		"FolioPrefixString": ((34, LCID, 4, 0),()),
		"FromWarehouse": ((17, LCID, 4, 0),()),
		"JournalMemo": ((14, LCID, 4, 0),()),
		"PriceList": ((15, LCID, 4, 0),()),
		"Reference1": ((11, LCID, 4, 0),()),
		"Reference2": ((12, LCID, 4, 0),()),
		"SalesPersonCode": ((16, LCID, 4, 0),()),
		"Series": ((5, LCID, 4, 0),()),
		"TaxDate": ((29, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IStockTransfer_ApprovalRequests(DispatchBaseClass):
	'IStockTransfer_ApprovalRequests Interface'
	CLSID = IID('{DACFE08E-8A02-43ED-B762-5E664186FB0E}')
	coclass_clsid = IID('{89BD7B04-5C1F-41DC-8B8C-4F8CFFA716CD}')

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ApprovalTemplatesID": (4, 2, (3, 0), (), "ApprovalTemplatesID", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"Remarks": (5, 2, (8, 0), (), "Remarks", None),
	}
	_prop_map_put_ = {
		"Remarks": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IStockTransfer_Lines(DispatchBaseClass):
	'IStockTransfer_Lines Interface'
	CLSID = IID('{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}')
	coclass_clsid = IID('{9C11E37D-538D-4819-85D1-00048E759E11}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(32, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseEntry": (39, 2, (3, 0), (), "BaseEntry", None),
		"BaseLine": (38, 2, (3, 0), (), "BaseLine", None),
		"BaseType": (37, 2, (3, 0), (), "BaseType", None),
		# Method 'BatchNumbers' returns object of type 'IBatchNumbers'
		"BatchNumbers": (21, 2, (9, 0), (), "BatchNumbers", '{1FEF5698-93E1-4167-AEA0-4BB151792623}'),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Currency": (9, 2, (8, 0), (), "Currency", None),
		"DiscountPercent": (11, 2, (5, 0), (), "DiscountPercent", None),
		"DistributionRule": (23, 2, (8, 0), (), "DistributionRule", None),
		"DistributionRule2": (33, 2, (8, 0), (), "DistributionRule2", None),
		"DistributionRule3": (34, 2, (8, 0), (), "DistributionRule3", None),
		"DistributionRule4": (35, 2, (8, 0), (), "DistributionRule4", None),
		"DistributionRule5": (36, 2, (8, 0), (), "DistributionRule5", None),
		"DocEntry": (40, 2, (3, 0), (), "DocEntry", None),
		"Factor": (16, 2, (5, 0), (), "Factor", None),
		"Factor2": (17, 2, (5, 0), (), "Factor2", None),
		"Factor3": (18, 2, (5, 0), (), "Factor3", None),
		"Factor4": (19, 2, (5, 0), (), "Factor4", None),
		"ItemCode": (5, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (6, 2, (8, 0), (), "ItemDescription", None),
		"LineNum": (4, 2, (3, 0), (), "LineNum", None),
		"MeasureUnit": (25, 2, (8, 0), (), "MeasureUnit", None),
		"Price": (8, 2, (5, 0), (), "Price", None),
		"ProjectCode": (15, 2, (8, 0), (), "ProjectCode", None),
		"Quantity": (7, 2, (5, 0), (), "Quantity", None),
		"Rate": (10, 2, (5, 0), (), "Rate", None),
		"SerialNumber": (13, 2, (8, 0), (), "SerialNumber", None),
		# Method 'SerialNumbers' returns object of type 'ISerialNumbers'
		"SerialNumbers": (20, 2, (9, 0), (), "SerialNumbers", '{93E5E52B-181E-46B8-96CB-1C066AC04DCA}'),
		"UnitPrice": (41, 2, (5, 0), (), "UnitPrice", None),
		"UnitsOfMeasurment": (26, 2, (5, 0), (), "UnitsOfMeasurment", None),
		"UseBaseUnits": (24, 2, (3, 0), (), "UseBaseUnits", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (22, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VendorNum": (12, 2, (8, 0), (), "VendorNum", None),
		"WarehouseCode": (14, 2, (8, 0), (), "WarehouseCode", None),
	}
	_prop_map_put_ = {
		"BaseEntry": ((39, LCID, 4, 0),()),
		"BaseLine": ((38, LCID, 4, 0),()),
		"BaseType": ((37, LCID, 4, 0),()),
		"Currency": ((9, LCID, 4, 0),()),
		"DiscountPercent": ((11, LCID, 4, 0),()),
		"DistributionRule": ((23, LCID, 4, 0),()),
		"DistributionRule2": ((33, LCID, 4, 0),()),
		"DistributionRule3": ((34, LCID, 4, 0),()),
		"DistributionRule4": ((35, LCID, 4, 0),()),
		"DistributionRule5": ((36, LCID, 4, 0),()),
		"Factor": ((16, LCID, 4, 0),()),
		"Factor2": ((17, LCID, 4, 0),()),
		"Factor3": ((18, LCID, 4, 0),()),
		"Factor4": ((19, LCID, 4, 0),()),
		"ItemCode": ((5, LCID, 4, 0),()),
		"ItemDescription": ((6, LCID, 4, 0),()),
		"MeasureUnit": ((25, LCID, 4, 0),()),
		"Price": ((8, LCID, 4, 0),()),
		"ProjectCode": ((15, LCID, 4, 0),()),
		"Quantity": ((7, LCID, 4, 0),()),
		"Rate": ((10, LCID, 4, 0),()),
		"SerialNumber": ((13, LCID, 4, 0),()),
		"UnitPrice": ((41, LCID, 4, 0),()),
		"UnitsOfMeasurment": ((26, LCID, 4, 0),()),
		"UseBaseUnits": ((24, LCID, 4, 0),()),
		"VendorNum": ((12, LCID, 4, 0),()),
		"WarehouseCode": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IStockTransfer_TaxExtension(DispatchBaseClass):
	'IStockTransfer_TaxExtension Interface'
	CLSID = IID('{F510FF2B-D307-487F-9ECC-EE436A6EBF10}')
	coclass_clsid = IID('{455B78FC-1F3F-4178-A67B-026130220693}')

	_prop_map_get_ = {
		"FormNumber": (2, 2, (8, 0), (), "FormNumber", None),
		"SupportVAT": (1, 2, (3, 0), (), "SupportVAT", None),
		"TransactionCategory": (3, 2, (8, 0), (), "TransactionCategory", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"FormNumber": ((2, LCID, 4, 0),()),
		"SupportVAT": ((1, LCID, 4, 0),()),
		"TransactionCategory": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITargetGroup(DispatchBaseClass):
	'ITargetGroup Interface'
	CLSID = IID('{5C87125B-3FCE-4FC7-9AD9-430D8E555426}')
	coclass_clsid = IID('{979EB99E-C8C7-4558-ADF5-DCB1BED01451}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"TargetGroupCode": (10, 2, (8, 0), (), "TargetGroupCode", None),
		"TargetGroupName": (11, 2, (8, 0), (), "TargetGroupName", None),
		# Method 'TargetGroupsDetails' returns object of type 'ITargetGroupsDetails'
		"TargetGroupsDetails": (12, 2, (9, 0), (), "TargetGroupsDetails", '{BC23E72E-CE89-4492-BEEC-6F5FE1D694A2}'),
	}
	_prop_map_put_ = {
		"TargetGroupCode": ((10, LCID, 4, 0),()),
		"TargetGroupName": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITargetGroupParams(DispatchBaseClass):
	'ITargetGroupParams Interface'
	CLSID = IID('{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')
	coclass_clsid = IID('{E1CFA100-9492-4B13-9AB1-4980DEC2DEB5}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"TargetGroupCode": (10, 2, (8, 0), (), "TargetGroupCode", None),
		"TargetGroupName": (11, 2, (8, 0), (), "TargetGroupName", None),
	}
	_prop_map_put_ = {
		"TargetGroupCode": ((10, LCID, 4, 0),()),
		"TargetGroupName": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITargetGroupsDetail(DispatchBaseClass):
	'ITargetGroupsDetail Interface'
	CLSID = IID('{6F49AA78-C540-44BD-B70F-050870C5BBF0}')
	coclass_clsid = IID('{82F30FF0-185D-4F73-8ECD-7CE2E4E77FEE}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"ActiveStatus": (15, 2, (3, 0), (), "ActiveStatus", None),
		"Address": (23, 2, (8, 0), (), "Address", None),
		"Block": (25, 2, (8, 0), (), "Block", None),
		"Building": (31, 2, (8, 0), (), "Building", None),
		"BusinessPartnerCode": (11, 2, (8, 0), (), "BusinessPartnerCode", None),
		"BusinessPartnerName": (12, 2, (8, 0), (), "BusinessPartnerName", None),
		"City": (26, 2, (8, 0), (), "City", None),
		"ContactPerson": (16, 2, (8, 0), (), "ContactPerson", None),
		"Country": (30, 2, (8, 0), (), "Country", None),
		"County": (28, 2, (8, 0), (), "County", None),
		"E_Mail": (19, 2, (8, 0), (), "E_Mail", None),
		"Fax": (22, 2, (8, 0), (), "Fax", None),
		"GroupCode": (13, 2, (8, 0), (), "GroupCode", None),
		"Industry": (14, 2, (8, 0), (), "Industry", None),
		"MobilePhone": (21, 2, (8, 0), (), "MobilePhone", None),
		"Position": (18, 2, (8, 0), (), "Position", None),
		"State": (29, 2, (8, 0), (), "State", None),
		"Street": (24, 2, (8, 0), (), "Street", None),
		"TargetGroupCode": (10, 2, (8, 0), (), "TargetGroupCode", None),
		"Telephone": (20, 2, (8, 0), (), "Telephone", None),
		"Title": (17, 2, (8, 0), (), "Title", None),
		"ZipCode": (27, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"Block": ((25, LCID, 4, 0),()),
		"Building": ((31, LCID, 4, 0),()),
		"BusinessPartnerCode": ((11, LCID, 4, 0),()),
		"BusinessPartnerName": ((12, LCID, 4, 0),()),
		"City": ((26, LCID, 4, 0),()),
		"ContactPerson": ((16, LCID, 4, 0),()),
		"Country": ((30, LCID, 4, 0),()),
		"County": ((28, LCID, 4, 0),()),
		"E_Mail": ((19, LCID, 4, 0),()),
		"Fax": ((22, LCID, 4, 0),()),
		"MobilePhone": ((21, LCID, 4, 0),()),
		"Position": ((18, LCID, 4, 0),()),
		"State": ((29, LCID, 4, 0),()),
		"Street": ((24, LCID, 4, 0),()),
		"Telephone": ((20, LCID, 4, 0),()),
		"Title": ((17, LCID, 4, 0),()),
		"ZipCode": ((27, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITargetGroupsDetails(DispatchBaseClass):
	'ITargetGroupsDetails Interface'
	CLSID = IID('{BC23E72E-CE89-4492-BEEC-6F5FE1D694A2}')
	coclass_clsid = IID('{400500D2-38E8-4EB9-9C7F-1843B8D2ED20}')

	# Result is of type ITargetGroupsDetail
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{6F49AA78-C540-44BD-B70F-050870C5BBF0}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITargetGroupsDetail
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{6F49AA78-C540-44BD-B70F-050870C5BBF0}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{6F49AA78-C540-44BD-B70F-050870C5BBF0}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{6F49AA78-C540-44BD-B70F-050870C5BBF0}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITargetGroupsParams(DispatchBaseClass):
	'ITargetGroupsParams Interface'
	CLSID = IID('{D1B282C5-C219-48C7-93E3-6BD01735EFD5}')
	coclass_clsid = IID('{6745AAF0-21A4-4999-B90F-0C5B8595DF18}')

	# Result is of type ITargetGroupParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITargetGroupParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITargetGroupsService(DispatchBaseClass):
	'ITargetGroupsService Interface'
	CLSID = IID('{67D0EFEB-7047-4726-98B7-C60B83F0F98D}')
	coclass_clsid = IID('{84A6DF78-FF80-4131-9A1E-742801212279}')

	# Result is of type ITargetGroupParams
	def Add(self, pITargetGroup=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pITargetGroup
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')
		return ret

	def Delete(self, pITargetGroupParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pITargetGroupParams
			)

	# Result is of type ITargetGroup
	def Get(self, pITargetGroupParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pITargetGroupParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{5C87125B-3FCE-4FC7-9AD9-430D8E555426}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ITargetGroupsParams
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{D1B282C5-C219-48C7-93E3-6BD01735EFD5}')
		return ret

	def Update(self, pITargetGroup=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pITargetGroup
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxCodeDetermination(DispatchBaseClass):
	'ITaxCodeDetermination Interface'
	CLSID = IID('{03111771-050A-41FF-A2EA-A17B8C7E99FE}')
	coclass_clsid = IID('{163BF46A-64A8-4757-A11B-B7958797CC85}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"BusinessArea": (13, 2, (3, 0), (), "BusinessArea", None),
		"Condition1": (14, 2, (3, 0), (), "Condition1", None),
		"Condition2": (19, 2, (3, 0), (), "Condition2", None),
		"Condition3": (24, 2, (3, 0), (), "Condition3", None),
		"Condition4": (29, 2, (3, 0), (), "Condition4", None),
		"Condition5": (34, 2, (3, 0), (), "Condition5", None),
		"Description": (39, 2, (8, 0), (), "Description", None),
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
		"DocumentType": (12, 2, (3, 0), (), "DocumentType", None),
		"FreightHeaderTax": (42, 2, (8, 0), (), "FreightHeaderTax", None),
		"FreightRowTax": (41, 2, (8, 0), (), "FreightRowTax", None),
		"LineNumber": (11, 2, (3, 0), (), "LineNumber", None),
		"MoneyValue1": (18, 2, (5, 0), (), "MoneyValue1", None),
		"MoneyValue2": (23, 2, (5, 0), (), "MoneyValue2", None),
		"MoneyValue3": (28, 2, (5, 0), (), "MoneyValue3", None),
		"MoneyValue4": (33, 2, (5, 0), (), "MoneyValue4", None),
		"MoneyValue5": (38, 2, (5, 0), (), "MoneyValue5", None),
		"NumberValue1": (16, 2, (3, 0), (), "NumberValue1", None),
		"NumberValue2": (21, 2, (3, 0), (), "NumberValue2", None),
		"NumberValue3": (26, 2, (3, 0), (), "NumberValue3", None),
		"NumberValue4": (31, 2, (3, 0), (), "NumberValue4", None),
		"NumberValue5": (36, 2, (3, 0), (), "NumberValue5", None),
		"StringValue1": (17, 2, (8, 0), (), "StringValue1", None),
		"StringValue2": (22, 2, (8, 0), (), "StringValue2", None),
		"StringValue3": (27, 2, (8, 0), (), "StringValue3", None),
		"StringValue4": (32, 2, (8, 0), (), "StringValue4", None),
		"StringValue5": (37, 2, (8, 0), (), "StringValue5", None),
		"TaxCode": (40, 2, (8, 0), (), "TaxCode", None),
		"UDFAlias1": (43, 2, (8, 0), (), "UDFAlias1", None),
		"UDFAlias2": (44, 2, (8, 0), (), "UDFAlias2", None),
		"UDFAlias3": (45, 2, (8, 0), (), "UDFAlias3", None),
		"UDFAlias4": (46, 2, (8, 0), (), "UDFAlias4", None),
		"UDFAlias5": (47, 2, (8, 0), (), "UDFAlias5", None),
		"UDFTable1": (15, 2, (8, 0), (), "UDFTable1", None),
		"UDFTable2": (20, 2, (8, 0), (), "UDFTable2", None),
		"UDFTable3": (25, 2, (8, 0), (), "UDFTable3", None),
		"UDFTable4": (30, 2, (8, 0), (), "UDFTable4", None),
		"UDFTable5": (35, 2, (8, 0), (), "UDFTable5", None),
	}
	_prop_map_put_ = {
		"BusinessArea": ((13, LCID, 4, 0),()),
		"Condition1": ((14, LCID, 4, 0),()),
		"Condition2": ((19, LCID, 4, 0),()),
		"Condition3": ((24, LCID, 4, 0),()),
		"Condition4": ((29, LCID, 4, 0),()),
		"Condition5": ((34, LCID, 4, 0),()),
		"Description": ((39, LCID, 4, 0),()),
		"DocumentType": ((12, LCID, 4, 0),()),
		"FreightHeaderTax": ((42, LCID, 4, 0),()),
		"FreightRowTax": ((41, LCID, 4, 0),()),
		"LineNumber": ((11, LCID, 4, 0),()),
		"MoneyValue1": ((18, LCID, 4, 0),()),
		"MoneyValue2": ((23, LCID, 4, 0),()),
		"MoneyValue3": ((28, LCID, 4, 0),()),
		"MoneyValue4": ((33, LCID, 4, 0),()),
		"MoneyValue5": ((38, LCID, 4, 0),()),
		"NumberValue1": ((16, LCID, 4, 0),()),
		"NumberValue2": ((21, LCID, 4, 0),()),
		"NumberValue3": ((26, LCID, 4, 0),()),
		"NumberValue4": ((31, LCID, 4, 0),()),
		"NumberValue5": ((36, LCID, 4, 0),()),
		"StringValue1": ((17, LCID, 4, 0),()),
		"StringValue2": ((22, LCID, 4, 0),()),
		"StringValue3": ((27, LCID, 4, 0),()),
		"StringValue4": ((32, LCID, 4, 0),()),
		"StringValue5": ((37, LCID, 4, 0),()),
		"TaxCode": ((40, LCID, 4, 0),()),
		"UDFAlias1": ((43, LCID, 4, 0),()),
		"UDFAlias2": ((44, LCID, 4, 0),()),
		"UDFAlias3": ((45, LCID, 4, 0),()),
		"UDFAlias4": ((46, LCID, 4, 0),()),
		"UDFAlias5": ((47, LCID, 4, 0),()),
		"UDFTable1": ((15, LCID, 4, 0),()),
		"UDFTable2": ((20, LCID, 4, 0),()),
		"UDFTable3": ((25, LCID, 4, 0),()),
		"UDFTable4": ((30, LCID, 4, 0),()),
		"UDFTable5": ((35, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxCodeDeterminationParams(DispatchBaseClass):
	'ITaxCodeDeterminationParams Interface'
	CLSID = IID('{7A54452F-A767-4700-B3B5-880084053C0C}')
	coclass_clsid = IID('{BD9CCFD9-ABF6-4596-AD04-363D8046FAA2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocEntry": (10, 2, (3, 0), (), "DocEntry", None),
	}
	_prop_map_put_ = {
		"DocEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxCodeDeterminationsParams(DispatchBaseClass):
	'ITaxCodeDeterminationsParams Interface'
	CLSID = IID('{A8AB919D-856C-4883-959D-57D7CB9C51F2}')
	coclass_clsid = IID('{FC78A30F-5B21-4311-B9C3-7C684E870590}')

	# Result is of type ITaxCodeDeterminationParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{7A54452F-A767-4700-B3B5-880084053C0C}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITaxCodeDeterminationParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{7A54452F-A767-4700-B3B5-880084053C0C}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{7A54452F-A767-4700-B3B5-880084053C0C}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{7A54452F-A767-4700-B3B5-880084053C0C}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxCodeDeterminationsService(DispatchBaseClass):
	'ITaxCodeDeterminationsService Interface'
	CLSID = IID('{68FA6F71-028F-434E-AAA4-32B8BBB67CC4}')
	coclass_clsid = IID('{4F0A05FF-FCE7-48C8-9F39-8768444639BF}')

	# Result is of type ITaxCodeDeterminationParams
	def AddTaxCodeDetermination(self, pITaxCodeDetermination=defaultNamedNotOptArg):
		'AddTaxCodeDetermination'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pITaxCodeDetermination
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddTaxCodeDetermination', '{7A54452F-A767-4700-B3B5-880084053C0C}')
		return ret

	def DeleteTaxCodeDetermination(self, pITaxCodeDeterminationParams=defaultNamedNotOptArg):
		'DeleteTaxCodeDetermination'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pITaxCodeDeterminationParams
			)

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ITaxCodeDetermination
	def GetTaxCodeDetermination(self, pITaxCodeDeterminationParams=defaultNamedNotOptArg):
		'GetTaxCodeDetermination'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pITaxCodeDeterminationParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetTaxCodeDetermination', '{03111771-050A-41FF-A2EA-A17B8C7E99FE}')
		return ret

	# Result is of type ITaxCodeDeterminationsParams
	def GetTaxCodeDeterminationList(self):
		'GetTaxCodeDeterminationList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetTaxCodeDeterminationList', '{A8AB919D-856C-4883-959D-57D7CB9C51F2}')
		return ret

	def UpdateTaxCodeDetermination(self, pITaxCodeDetermination=defaultNamedNotOptArg):
		'UpdateTaxCodeDetermination'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pITaxCodeDetermination
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxDefinitions(DispatchBaseClass):
	'ITaxDefinitions Interface'
	CLSID = IID('{9AA8D14C-3AB3-44F0-BEDD-0AB156BD2A9D}')
	coclass_clsid = IID('{63F814CA-BC06-4069-9B83-5A73B7BE911D}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 1),),LineNum
			)

	_prop_map_get_ = {
		"Effectivefrom": (4, 2, (7, 0), (), "Effectivefrom", None),
		"Rate": (5, 2, (5, 0), (), "Rate", None),
	}
	_prop_map_put_ = {
		"Effectivefrom": ((4, LCID, 4, 0),()),
		"Rate": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxExtension(DispatchBaseClass):
	'ITaxExtension Interface'
	CLSID = IID('{8CC29ECE-02C3-4C7B-851B-5533D2C83627}')
	coclass_clsid = IID('{94BACBC3-E916-4D1F-9469-F7F44F8E39F0}')

	_prop_map_get_ = {
		"BlockB": (34, 2, (8, 0), (), "BlockB", None),
		"BlockS": (26, 2, (8, 0), (), "BlockS", None),
		"Brand": (20, 2, (8, 0), (), "Brand", None),
		"BuildingB": (35, 2, (8, 0), (), "BuildingB", None),
		"BuildingS": (27, 2, (8, 0), (), "BuildingS", None),
		"Carrier": (17, 2, (8, 0), (), "Carrier", None),
		"CityB": (36, 2, (8, 0), (), "CityB", None),
		"CityS": (28, 2, (8, 0), (), "CityS", None),
		"CountryB": (40, 2, (8, 0), (), "CountryB", None),
		"CountryS": (32, 2, (8, 0), (), "CountryS", None),
		"County": (12, 2, (8, 0), (), "County", None),
		"CountyB": (38, 2, (8, 0), (), "CountyB", None),
		"CountyS": (30, 2, (8, 0), (), "CountyS", None),
		"GrossWeight": (23, 2, (5, 0), (), "GrossWeight", None),
		"ImportOrExport": (41, 2, (3, 0), (), "ImportOrExport", None),
		"Incoterms": (13, 2, (8, 0), (), "Incoterms", None),
		"MainUsage": (42, 2, (3, 0), (), "MainUsage", None),
		"NFRef": (16, 2, (8, 0), (), "NFRef", None),
		"NetWeight": (22, 2, (5, 0), (), "NetWeight", None),
		"PackDescription": (19, 2, (8, 0), (), "PackDescription", None),
		"PackQuantity": (18, 2, (3, 0), (), "PackQuantity", None),
		"ShipUnitNo": (21, 2, (3, 0), (), "ShipUnitNo", None),
		"State": (11, 2, (8, 0), (), "State", None),
		"StateB": (39, 2, (8, 0), (), "StateB", None),
		"StateS": (31, 2, (8, 0), (), "StateS", None),
		"StreetB": (33, 2, (8, 0), (), "StreetB", None),
		"StreetS": (25, 2, (8, 0), (), "StreetS", None),
		"TaxId0": (1, 2, (8, 0), (), "TaxId0", None),
		"TaxId1": (2, 2, (8, 0), (), "TaxId1", None),
		"TaxId2": (3, 2, (8, 0), (), "TaxId2", None),
		"TaxId3": (4, 2, (8, 0), (), "TaxId3", None),
		"TaxId4": (5, 2, (8, 0), (), "TaxId4", None),
		"TaxId5": (6, 2, (8, 0), (), "TaxId5", None),
		"TaxId6": (7, 2, (8, 0), (), "TaxId6", None),
		"TaxId7": (8, 2, (8, 0), (), "TaxId7", None),
		"TaxId8": (9, 2, (8, 0), (), "TaxId8", None),
		"TaxId9": (10, 2, (8, 0), (), "TaxId9", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (24, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"Vehicle": (14, 2, (8, 0), (), "Vehicle", None),
		"VehicleState": (15, 2, (8, 0), (), "VehicleState", None),
		"ZipCodeB": (37, 2, (8, 0), (), "ZipCodeB", None),
		"ZipCodeS": (29, 2, (8, 0), (), "ZipCodeS", None),
	}
	_prop_map_put_ = {
		"BlockB": ((34, LCID, 4, 0),()),
		"BlockS": ((26, LCID, 4, 0),()),
		"Brand": ((20, LCID, 4, 0),()),
		"BuildingB": ((35, LCID, 4, 0),()),
		"BuildingS": ((27, LCID, 4, 0),()),
		"Carrier": ((17, LCID, 4, 0),()),
		"CityB": ((36, LCID, 4, 0),()),
		"CityS": ((28, LCID, 4, 0),()),
		"CountryB": ((40, LCID, 4, 0),()),
		"CountryS": ((32, LCID, 4, 0),()),
		"County": ((12, LCID, 4, 0),()),
		"CountyB": ((38, LCID, 4, 0),()),
		"CountyS": ((30, LCID, 4, 0),()),
		"GrossWeight": ((23, LCID, 4, 0),()),
		"ImportOrExport": ((41, LCID, 4, 0),()),
		"Incoterms": ((13, LCID, 4, 0),()),
		"MainUsage": ((42, LCID, 4, 0),()),
		"NFRef": ((16, LCID, 4, 0),()),
		"NetWeight": ((22, LCID, 4, 0),()),
		"PackDescription": ((19, LCID, 4, 0),()),
		"PackQuantity": ((18, LCID, 4, 0),()),
		"ShipUnitNo": ((21, LCID, 4, 0),()),
		"State": ((11, LCID, 4, 0),()),
		"StateB": ((39, LCID, 4, 0),()),
		"StateS": ((31, LCID, 4, 0),()),
		"StreetB": ((33, LCID, 4, 0),()),
		"StreetS": ((25, LCID, 4, 0),()),
		"TaxId0": ((1, LCID, 4, 0),()),
		"TaxId1": ((2, LCID, 4, 0),()),
		"TaxId2": ((3, LCID, 4, 0),()),
		"TaxId3": ((4, LCID, 4, 0),()),
		"TaxId4": ((5, LCID, 4, 0),()),
		"TaxId5": ((6, LCID, 4, 0),()),
		"TaxId6": ((7, LCID, 4, 0),()),
		"TaxId7": ((8, LCID, 4, 0),()),
		"TaxId8": ((9, LCID, 4, 0),()),
		"TaxId9": ((10, LCID, 4, 0),()),
		"Vehicle": ((14, LCID, 4, 0),()),
		"VehicleState": ((15, LCID, 4, 0),()),
		"ZipCodeB": ((37, LCID, 4, 0),()),
		"ZipCodeS": ((29, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxInvoice_Lines(DispatchBaseClass):
	'ITaxInvoice_Lines Interface'
	CLSID = IID('{D1DD9101-9264-450A-9FAC-C9D899078775}')
	coclass_clsid = IID('{411526CA-B3C4-489C-B4FB-6539B5BF09C2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseEntry": (1, 2, (3, 0), (), "BaseEntry", None),
		"BaseType": (3, 2, (3, 0), (), "BaseType", None),
		"Count": (6, 2, (3, 0), (), "Count", None),
		"LineNum": (2, 2, (3, 0), (), "LineNum", None),
		"Reference": (4, 2, (3, 0), (), "Reference", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Reference": ((4, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(6, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxInvoice_OperationCodes(DispatchBaseClass):
	'ITaxInvoice_OperationCodes Interface'
	CLSID = IID('{5BCB48BA-A4A6-4087-B1FD-1E9F076EFD33}')
	coclass_clsid = IID('{A1A07E2A-270F-4C69-8D1A-68D5CEF00CD2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseEntry": (1, 2, (3, 0), (), "BaseEntry", None),
		"Count": (5, 2, (3, 0), (), "Count", None),
		"LineNum": (2, 2, (3, 0), (), "LineNum", None),
		"OpCode": (3, 2, (3, 0), (), "OpCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"LineNum": ((2, LCID, 4, 0),()),
		"OpCode": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxInvoices(DispatchBaseClass):
	'ITaxInvoices Interface'
	CLSID = IID('{9370956A-E63B-4B62-9AA0-EA32A0673B8A}')
	coclass_clsid = IID('{2393BA89-A02B-4E4E-8703-0412A8B757C4}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(28, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(29, LCID, 1, (8, 0), (),)

	def GetByKey(self, DocEntry=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(23, LCID, 1, (11, 0), ((3, 1),),DocEntry
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(30, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(24, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(25, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Address": (16, 2, (8, 0), (), "Address", None),
		"Address2": (17, 2, (8, 0), (), "Address2", None),
		"AlterationRevision": (39, 2, (3, 0), (), "AlterationRevision", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (27, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CancelDate": (33, 2, (7, 0), (), "CancelDate", None),
		"CardCode": (6, 2, (8, 0), (), "CardCode", None),
		"Comments": (14, 2, (8, 0), (), "Comments", None),
		"ContactPersonCode": (12, 2, (3, 0), (), "ContactPersonCode", None),
		"CreationDate": (7, 2, (7, 0), (), "CreationDate", None),
		"CurrencySource": (18, 2, (3, 0), (), "CurrencySource", None),
		"CustomerOrVendorName": (32, 2, (8, 0), (), "CustomerOrVendorName", None),
		"CustomerOrVendorRefNo": (31, 2, (8, 0), (), "CustomerOrVendorRefNo", None),
		"DocCurrency": (19, 2, (8, 0), (), "DocCurrency", None),
		"DocDate": (5, 2, (7, 0), (), "DocDate", None),
		"DocDueDate": (9, 2, (7, 0), (), "DocDueDate", None),
		"DocEntry": (1, 2, (3, 0), (), "DocEntry", None),
		"DocNum": (2, 2, (3, 0), (), "DocNum", None),
		"DocType": (3, 2, (3, 0), (), "DocType", None),
		"DocumentTotal": (34, 2, (5, 0), (), "DocumentTotal", None),
		# Method 'Lines' returns object of type 'ITaxInvoice_Lines'
		"Lines": (20, 2, (9, 0), (), "Lines", '{D1DD9101-9264-450A-9FAC-C9D899078775}'),
		# Method 'OperationCodes' returns object of type 'ITaxInvoice_OperationCodes'
		"OperationCodes": (38, 2, (9, 0), (), "OperationCodes", '{5BCB48BA-A4A6-4087-B1FD-1E9F076EFD33}'),
		"PaymentRefDate": (37, 2, (7, 0), (), "PaymentRefDate", None),
		"PaymentRefNo": (36, 2, (8, 0), (), "PaymentRefNo", None),
		"Printed": (4, 2, (3, 0), (), "Printed", None),
		"Segment": (11, 2, (3, 0), (), "Segment", None),
		"Series": (10, 2, (3, 0), (), "Series", None),
		"ShipToCode": (15, 2, (8, 0), (), "ShipToCode", None),
		"TaxDate": (13, 2, (7, 0), (), "TaxDate", None),
		"TaxTotal": (35, 2, (5, 0), (), "TaxTotal", None),
		"UpdateDate": (8, 2, (7, 0), (), "UpdateDate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (26, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Address": ((16, LCID, 4, 0),()),
		"Address2": ((17, LCID, 4, 0),()),
		"AlterationRevision": ((39, LCID, 4, 0),()),
		"CardCode": ((6, LCID, 4, 0),()),
		"Comments": ((14, LCID, 4, 0),()),
		"ContactPersonCode": ((12, LCID, 4, 0),()),
		"CurrencySource": ((18, LCID, 4, 0),()),
		"CustomerOrVendorName": ((32, LCID, 4, 0),()),
		"CustomerOrVendorRefNo": ((31, LCID, 4, 0),()),
		"DocCurrency": ((19, LCID, 4, 0),()),
		"DocDate": ((5, LCID, 4, 0),()),
		"DocDueDate": ((9, LCID, 4, 0),()),
		"DocType": ((3, LCID, 4, 0),()),
		"PaymentRefDate": ((37, LCID, 4, 0),()),
		"PaymentRefNo": ((36, LCID, 4, 0),()),
		"Series": ((10, LCID, 4, 0),()),
		"ShipToCode": ((15, LCID, 4, 0),()),
		"TaxDate": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxJurisdictions(DispatchBaseClass):
	'ITaxJurisdictions Interface'
	CLSID = IID('{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}')
	coclass_clsid = IID('{576DD096-1276-42C3-9BCA-25FBCEE2E3CD}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(102, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(101, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (100, 2, (3, 0), (), "Count", None),
		"DocEntry": (104, 2, (3, 0), (), "DocEntry", None),
		"JurisdictionCode": (1, 2, (8, 0), (), "JurisdictionCode", None),
		"JurisdictionType": (2, 2, (3, 0), (), "JurisdictionType", None),
		"LineNumber": (105, 2, (3, 0), (), "LineNumber", None),
		"RowSequence": (106, 2, (3, 0), (), "RowSequence", None),
		"TaxAmount": (3, 2, (5, 0), (), "TaxAmount", None),
		"TaxAmountFC": (5, 2, (5, 0), (), "TaxAmountFC", None),
		"TaxAmountSC": (4, 2, (5, 0), (), "TaxAmountSC", None),
		"TaxRate": (6, 2, (5, 0), (), "TaxRate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (103, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"JurisdictionCode": ((1, LCID, 4, 0),()),
		"JurisdictionType": ((2, LCID, 4, 0),()),
		"LineNumber": ((105, LCID, 4, 0),()),
		"TaxAmount": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(100, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxReportAccount(DispatchBaseClass):
	'ITaxReportAccount Interface'
	CLSID = IID('{32ABB501-14BB-4467-8D98-597A9420D8C6}')
	coclass_clsid = IID('{73B70E17-5D4B-4AD8-BF03-DBD596A6C4CC}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (8, 0), (), "Code", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxReportAccounts(DispatchBaseClass):
	'ITaxReportAccounts Interface'
	CLSID = IID('{009BFAE6-2701-4E63-B9EA-1335C9658CC0}')
	coclass_clsid = IID('{B7BB4C0A-4CE3-494B-B928-AA94004B0866}')

	# Result is of type ITaxReportAccount
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{32ABB501-14BB-4467-8D98-597A9420D8C6}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITaxReportAccount
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{32ABB501-14BB-4467-8D98-597A9420D8C6}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{32ABB501-14BB-4467-8D98-597A9420D8C6}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{32ABB501-14BB-4467-8D98-597A9420D8C6}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxReportBusinessPartner(DispatchBaseClass):
	'ITaxReportBusinessPartner Interface'
	CLSID = IID('{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}')
	coclass_clsid = IID('{7BFDBDE4-A073-448A-B89B-6300C5B8B8E5}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (8, 0), (), "Code", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxReportBusinessPartners(DispatchBaseClass):
	'ITaxReportBusinessPartners Interface'
	CLSID = IID('{CA7F3C6F-4074-46E9-8B96-3CBDDFC9C320}')
	coclass_clsid = IID('{48528290-6FDA-4F13-ABDE-8B3DE992ACCA}')

	# Result is of type ITaxReportBusinessPartner
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITaxReportBusinessPartner
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxReportDocument(DispatchBaseClass):
	'ITaxReportDocument Interface'
	CLSID = IID('{28DD7AE7-0602-49B2-80EB-827454AA99E7}')
	coclass_clsid = IID('{E6BBD705-997C-468F-924D-ABE0D1B96E8B}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocumentType": (11, 2, (3, 0), (), "DocumentType", None),
		"FromNumber": (12, 2, (3, 0), (), "FromNumber", None),
		"ToNumber": (13, 2, (3, 0), (), "ToNumber", None),
	}
	_prop_map_put_ = {
		"DocumentType": ((11, LCID, 4, 0),()),
		"FromNumber": ((12, LCID, 4, 0),()),
		"ToNumber": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxReportDocuments(DispatchBaseClass):
	'ITaxReportDocuments Interface'
	CLSID = IID('{FC030AB5-B942-4D71-A5BF-1EAA5D9BC808}')
	coclass_clsid = IID('{62EC03F0-1AC2-40AA-B3B4-CB7D3964E0BF}')

	# Result is of type ITaxReportDocument
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{28DD7AE7-0602-49B2-80EB-827454AA99E7}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITaxReportDocument
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{28DD7AE7-0602-49B2-80EB-827454AA99E7}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{28DD7AE7-0602-49B2-80EB-827454AA99E7}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{28DD7AE7-0602-49B2-80EB-827454AA99E7}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxReportFilter(DispatchBaseClass):
	'ITaxReportFilter Interface'
	CLSID = IID('{3503F7F1-5A0C-4D08-A498-0D9619097C09}')
	coclass_clsid = IID('{120471FC-3B19-4A4B-89DB-8999A7439A3C}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AppendixOorPSelection": (30, 2, (3, 0), (), "AppendixOorPSelection", None),
		"Cancellation": (34, 2, (3, 0), (), "Cancellation", None),
		"Code": (11, 2, (3, 0), (), "Code", None),
		"DeclarationType": (19, 2, (3, 0), (), "DeclarationType", None),
		"DiplayCreditMemosInSeparateColumn": (38, 2, (3, 0), (), "DiplayCreditMemosInSeparateColumn", None),
		"DocumentType": (27, 2, (3, 0), (), "DocumentType", None),
		"ExcludeWT": (21, 2, (3, 0), (), "ExcludeWT", None),
		"FilterType": (20, 2, (3, 0), (), "FilterType", None),
		"FirstPrintedNumber": (14, 2, (3, 0), (), "FirstPrintedNumber", None),
		"FirstRegisterNumber": (28, 2, (3, 0), (), "FirstRegisterNumber", None),
		"FromDate": (15, 2, (7, 0), (), "FromDate", None),
		"FromSeries": (32, 2, (3, 0), (), "FromSeries", None),
		"HideTaxWithoutTransaction": (35, 2, (3, 0), (), "HideTaxWithoutTransaction", None),
		"IncludeCustomers": (22, 2, (3, 0), (), "IncludeCustomers", None),
		"IncludeDocumentType": (37, 2, (3, 0), (), "IncludeDocumentType", None),
		"IncludeGLAccounts": (29, 2, (3, 0), (), "IncludeGLAccounts", None),
		"IncludeSeriesFilter": (36, 2, (3, 0), (), "IncludeSeriesFilter", None),
		"IncludeVendors": (23, 2, (3, 0), (), "IncludeVendors", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
		"OpeningAndClosingBalance": (31, 2, (3, 0), (), "OpeningAndClosingBalance", None),
		"Period": (24, 2, (3, 0), (), "Period", None),
		"Quarter": (25, 2, (3, 0), (), "Quarter", None),
		"QuarterOrDates": (40, 2, (3, 0), (), "QuarterOrDates", None),
		"ReportLayout": (13, 2, (3, 0), (), "ReportLayout", None),
		"RoundAmount": (18, 2, (3, 0), (), "RoundAmount", None),
		"ShowPaymentsWithDeferredTax": (39, 2, (3, 0), (), "ShowPaymentsWithDeferredTax", None),
		"TaxDate": (17, 2, (3, 0), (), "TaxDate", None),
		# Method 'TaxReportAccounts' returns object of type 'ITaxReportAccounts'
		"TaxReportAccounts": (45, 2, (9, 0), (), "TaxReportAccounts", '{009BFAE6-2701-4E63-B9EA-1335C9658CC0}'),
		# Method 'TaxReportBusinessPartners' returns object of type 'ITaxReportBusinessPartners'
		"TaxReportBusinessPartners": (42, 2, (9, 0), (), "TaxReportBusinessPartners", '{CA7F3C6F-4074-46E9-8B96-3CBDDFC9C320}'),
		# Method 'TaxReportDocuments' returns object of type 'ITaxReportDocuments'
		"TaxReportDocuments": (43, 2, (9, 0), (), "TaxReportDocuments", '{FC030AB5-B942-4D71-A5BF-1EAA5D9BC808}'),
		# Method 'TaxReportGroups' returns object of type 'ITaxReportGroups'
		"TaxReportGroups": (41, 2, (9, 0), (), "TaxReportGroups", '{5EE41EF0-1319-400C-807D-7CAA21FBA466}'),
		# Method 'TaxReportSeriesCollection' returns object of type 'ITaxReportSeriesCollection'
		"TaxReportSeriesCollection": (44, 2, (9, 0), (), "TaxReportSeriesCollection", '{71AE6937-9F02-409F-93D0-869D4E6DDE9A}'),
		"ToDate": (16, 2, (7, 0), (), "ToDate", None),
		"ToSeries": (33, 2, (3, 0), (), "ToSeries", None),
		"Year": (26, 2, (3, 0), (), "Year", None),
	}
	_prop_map_put_ = {
		"AppendixOorPSelection": ((30, LCID, 4, 0),()),
		"Cancellation": ((34, LCID, 4, 0),()),
		"DeclarationType": ((19, LCID, 4, 0),()),
		"DiplayCreditMemosInSeparateColumn": ((38, LCID, 4, 0),()),
		"DocumentType": ((27, LCID, 4, 0),()),
		"ExcludeWT": ((21, LCID, 4, 0),()),
		"FilterType": ((20, LCID, 4, 0),()),
		"FirstPrintedNumber": ((14, LCID, 4, 0),()),
		"FirstRegisterNumber": ((28, LCID, 4, 0),()),
		"FromDate": ((15, LCID, 4, 0),()),
		"FromSeries": ((32, LCID, 4, 0),()),
		"HideTaxWithoutTransaction": ((35, LCID, 4, 0),()),
		"IncludeCustomers": ((22, LCID, 4, 0),()),
		"IncludeDocumentType": ((37, LCID, 4, 0),()),
		"IncludeGLAccounts": ((29, LCID, 4, 0),()),
		"IncludeSeriesFilter": ((36, LCID, 4, 0),()),
		"IncludeVendors": ((23, LCID, 4, 0),()),
		"Name": ((12, LCID, 4, 0),()),
		"OpeningAndClosingBalance": ((31, LCID, 4, 0),()),
		"Period": ((24, LCID, 4, 0),()),
		"Quarter": ((25, LCID, 4, 0),()),
		"QuarterOrDates": ((40, LCID, 4, 0),()),
		"ReportLayout": ((13, LCID, 4, 0),()),
		"RoundAmount": ((18, LCID, 4, 0),()),
		"ShowPaymentsWithDeferredTax": ((39, LCID, 4, 0),()),
		"TaxDate": ((17, LCID, 4, 0),()),
		"ToDate": ((16, LCID, 4, 0),()),
		"ToSeries": ((33, LCID, 4, 0),()),
		"Year": ((26, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxReportFilterParams(DispatchBaseClass):
	'ITaxReportFilterParams Interface'
	CLSID = IID('{A5CDC033-47D7-4019-801A-8443F14D52D0}')
	coclass_clsid = IID('{44E44FE4-3855-4EEF-9854-D8FF22F4801E}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (3, 0), (), "Code", None),
		"FilterType": (13, 2, (3, 0), (), "FilterType", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"FilterType": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxReportFiltersParams(DispatchBaseClass):
	'ITaxReportFiltersParams Interface'
	CLSID = IID('{813B8F2A-F8BC-4C70-A043-CF099057F3B8}')
	coclass_clsid = IID('{F060E5FE-31B3-4480-8A4F-EB5BB0964C4B}')

	# Result is of type ITaxReportFilterParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{A5CDC033-47D7-4019-801A-8443F14D52D0}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITaxReportFilterParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{A5CDC033-47D7-4019-801A-8443F14D52D0}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{A5CDC033-47D7-4019-801A-8443F14D52D0}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{A5CDC033-47D7-4019-801A-8443F14D52D0}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxReportGroup(DispatchBaseClass):
	'ITaxReportGroup Interface'
	CLSID = IID('{6076F945-EB54-4BA8-B00C-891BB860356A}')
	coclass_clsid = IID('{360A35E4-0B22-4324-AA42-9DF442E64379}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Sum": (12, 2, (3, 0), (), "Sum", None),
	}
	_prop_map_put_ = {
		"Code": ((11, LCID, 4, 0),()),
		"Sum": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxReportGroups(DispatchBaseClass):
	'ITaxReportGroups Interface'
	CLSID = IID('{5EE41EF0-1319-400C-807D-7CAA21FBA466}')
	coclass_clsid = IID('{7FD8CD14-6E6B-4B4F-801A-0155E5389896}')

	# Result is of type ITaxReportGroup
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{6076F945-EB54-4BA8-B00C-891BB860356A}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITaxReportGroup
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{6076F945-EB54-4BA8-B00C-891BB860356A}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{6076F945-EB54-4BA8-B00C-891BB860356A}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{6076F945-EB54-4BA8-B00C-891BB860356A}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxReportSeries(DispatchBaseClass):
	'ITaxReportSeries Interface'
	CLSID = IID('{308CD5F0-5908-47B2-BE56-A1104C45FCF7}')
	coclass_clsid = IID('{9B4D2E09-CE62-49C7-BF5D-0D9BC6BD9F81}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"DocumentType": (11, 2, (3, 0), (), "DocumentType", None),
		"SeriesCode": (12, 2, (3, 0), (), "SeriesCode", None),
	}
	_prop_map_put_ = {
		"DocumentType": ((11, LCID, 4, 0),()),
		"SeriesCode": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxReportSeriesCollection(DispatchBaseClass):
	'ITaxReportSeriesCollection Interface'
	CLSID = IID('{71AE6937-9F02-409F-93D0-869D4E6DDE9A}')
	coclass_clsid = IID('{B69F1DD8-E760-42A1-8E55-C7078C936DB5}')

	# Result is of type ITaxReportSeries
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{308CD5F0-5908-47B2-BE56-A1104C45FCF7}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITaxReportSeries
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{308CD5F0-5908-47B2-BE56-A1104C45FCF7}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{308CD5F0-5908-47B2-BE56-A1104C45FCF7}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{308CD5F0-5908-47B2-BE56-A1104C45FCF7}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxWebSite(DispatchBaseClass):
	'ITaxWebSite Interface'
	CLSID = IID('{EE912DF0-9D0E-49BE-999D-B88AA59B305D}')
	coclass_clsid = IID('{051656EB-47C7-4435-B61D-D4135C235EA5}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"Description": (13, 2, (8, 0), (), "Description", None),
		"WebSiteName": (11, 2, (8, 0), (), "WebSiteName", None),
		"WebSiteURL": (12, 2, (8, 0), (), "WebSiteURL", None),
	}
	_prop_map_put_ = {
		"Description": ((13, LCID, 4, 0),()),
		"WebSiteName": ((11, LCID, 4, 0),()),
		"WebSiteURL": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxWebSiteParams(DispatchBaseClass):
	'ITaxWebSiteParams Interface'
	CLSID = IID('{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')
	coclass_clsid = IID('{6684E784-5C62-4636-B20E-8AAA5B20BBF2}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"AbsEntry": (10, 2, (3, 0), (), "AbsEntry", None),
		"WebSiteName": (11, 2, (8, 0), (), "WebSiteName", None),
	}
	_prop_map_put_ = {
		"AbsEntry": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITaxWebSitesParams(DispatchBaseClass):
	'ITaxWebSitesParams Interface'
	CLSID = IID('{AB9A1501-E84C-4EC2-9869-8A843FBCCBB6}')
	coclass_clsid = IID('{93780531-1F63-4CD5-9F32-2A232E2679C5}')

	# Result is of type ITaxWebSiteParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITaxWebSiteParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITaxWebSitesService(DispatchBaseClass):
	'ITaxWebSitesService Interface'
	CLSID = IID('{A7FDC596-1604-4DE8-841C-DADBA34B32E0}')
	coclass_clsid = IID('{1AF6323B-193A-4A12-A001-67993DA9310E}')

	# Result is of type ITaxWebSiteParams
	def AddTaxWebSite(self, pITaxWebSite=defaultNamedNotOptArg):
		'AddTaxWebSite'
		ret = self._oleobj_.InvokeTypes(11, LCID, 1, (9, 0), ((9, 1),),pITaxWebSite
			)
		if ret is not None:
			ret = Dispatch(ret, u'AddTaxWebSite', '{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ITaxWebSiteParams
	def GetDefaultWebSite(self):
		'GetDefaultWebSite'
		ret = self._oleobj_.InvokeTypes(16, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetDefaultWebSite', '{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')
		return ret

	# Result is of type ITaxWebSite
	def GetTaxWebSite(self, pITaxWebSiteParams=defaultNamedNotOptArg):
		'GetTaxWebSite'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pITaxWebSiteParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetTaxWebSite', '{EE912DF0-9D0E-49BE-999D-B88AA59B305D}')
		return ret

	# Result is of type ITaxWebSitesParams
	def GetTaxWebSiteList(self):
		'GetTaxWebSiteList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetTaxWebSiteList', '{AB9A1501-E84C-4EC2-9869-8A843FBCCBB6}')
		return ret

	def RemoveTaxWebSite(self, pITaxWebSiteParams=defaultNamedNotOptArg):
		'RemoveTaxWebSite'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pITaxWebSiteParams
			)

	def SetAsDefault(self, pITaxWebSiteParams=defaultNamedNotOptArg):
		'SetAsDefault'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((9, 1),),pITaxWebSiteParams
			)

	def UpdateTaxWebSite(self, pITaxWebSite=defaultNamedNotOptArg):
		'UpdateTaxWebSite'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pITaxWebSite
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITeamMembers(DispatchBaseClass):
	'ITeamMembers Interface'
	CLSID = IID('{09C6E920-908C-4FD2-9CBF-21C3F4329A33}')
	coclass_clsid = IID('{D562FBDC-788B-4D80-B9EB-9238CC4EF91C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"EmployeeID": (7, 2, (3, 0), (), "EmployeeID", None),
		"RoleInTeam": (8, 2, (3, 0), (), "RoleInTeam", None),
		"TeamID": (6, 2, (3, 0), (), "TeamID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (1, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"EmployeeID": ((7, LCID, 4, 0),()),
		"RoleInTeam": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITeams(DispatchBaseClass):
	'ITeams Interface'
	CLSID = IID('{BCA3F54F-34D2-4E1C-A700-AD1C35F0B415}')
	coclass_clsid = IID('{65ABB505-DD62-4C94-8E7B-BF63BC35E51E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lTeamID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((3, 1),),lTeamID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Description": (13, 2, (8, 0), (), "Description", None),
		"TeamID": (11, 2, (3, 0), (), "TeamID", None),
		# Method 'TeamMembers' returns object of type 'ITeamMembers'
		"TeamMembers": (15, 2, (9, 0), (), "TeamMembers", '{09C6E920-908C-4FD2-9CBF-21C3F4329A33}'),
		"TeamName": (12, 2, (8, 0), (), "TeamName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Description": ((13, LCID, 4, 0),()),
		"TeamName": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITerritories(DispatchBaseClass):
	'ITerritories Interface'
	CLSID = IID('{BEB8ACDC-E50B-4DA3-8281-EF5228E55099}')
	coclass_clsid = IID('{B03EE5C0-48D5-4E20-A33A-FF2DBE5AF478}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(13, LCID, 1, (8, 0), (),)

	def GetByKey(self, lID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (11, 0), ((3, 1),),lID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(14, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(10, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (12, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Description": (2, 2, (8, 0), (), "Description", None),
		"Inactive": (4, 2, (3, 0), (), "Inactive", None),
		"LocationIndex": (3, 2, (3, 0), (), "LocationIndex", None),
		"Parent": (5, 2, (3, 0), (), "Parent", None),
		"TerritoryID": (1, 2, (3, 0), (), "TerritoryID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (11, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Description": ((2, LCID, 4, 0),()),
		"Inactive": ((4, LCID, 4, 0),()),
		"LocationIndex": ((3, LCID, 4, 0),()),
		"Parent": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITransactionCode(DispatchBaseClass):
	'ITransactionCode Interface'
	CLSID = IID('{49703681-AAAE-49B5-B2AA-402D622EE537}')
	coclass_clsid = IID('{EACF6445-6CE2-41DA-AB6E-681B6BB6BA11}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Description": (11, 2, (8, 0), (), "Description", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
		"Description": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITransactionCodeParams(DispatchBaseClass):
	'ITransactionCodeParams Interface'
	CLSID = IID('{63A44BC7-2798-4F4A-B0C7-B407EA917702}')
	coclass_clsid = IID('{3FF0DED0-0DD1-4D92-85A8-6120FD8E3040}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Code": (10, 2, (8, 0), (), "Code", None),
		"Description": (11, 2, (8, 0), (), "Description", None),
	}
	_prop_map_put_ = {
		"Code": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITransactionCodeParamsCollection(DispatchBaseClass):
	'ITransactionCodeParamsCollection Interface'
	CLSID = IID('{12A99320-EEE7-4398-90E2-74BC014F5CE2}')
	coclass_clsid = IID('{DE0B0369-F5A1-4BCC-AD4A-47AE8F410EF4}')

	# Result is of type ITransactionCodeParams
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{63A44BC7-2798-4F4A-B0C7-B407EA917702}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type ITransactionCodeParams
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{63A44BC7-2798-4F4A-B0C7-B407EA917702}')
		return ret

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{63A44BC7-2798-4F4A-B0C7-B407EA917702}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{63A44BC7-2798-4F4A-B0C7-B407EA917702}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class ITransactionCodesService(DispatchBaseClass):
	'ITransactionCodesService Interface'
	CLSID = IID('{FE19123D-05AC-4D3F-8E3D-4A3155ECF43D}')
	coclass_clsid = IID('{C5649BC6-2AF9-4C88-B065-1D14E80A6B1E}')

	# Result is of type ITransactionCodeParams
	def Add(self, pITransactionCode=defaultNamedNotOptArg):
		'Add'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pITransactionCode
			)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{63A44BC7-2798-4F4A-B0C7-B407EA917702}')
		return ret

	def Delete(self, pITransactionCodeParams=defaultNamedNotOptArg):
		'Delete'
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((9, 1),),pITransactionCodeParams
			)

	# Result is of type ITransactionCode
	def Get(self, pITransactionCodeParams=defaultNamedNotOptArg):
		'Get'
		ret = self._oleobj_.InvokeTypes(13, LCID, 1, (9, 0), ((9, 1),),pITransactionCodeParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'Get', '{49703681-AAAE-49B5-B2AA-402D622EE537}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type ITransactionCodeParamsCollection
	def GetList(self):
		'GetList'
		ret = self._oleobj_.InvokeTypes(14, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetList', '{12A99320-EEE7-4398-90E2-74BC014F5CE2}')
		return ret

	def Update(self, pITransactionCode=defaultNamedNotOptArg):
		'Update'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1),),pITransactionCode
			)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class ITranslationsInUserLanguages(DispatchBaseClass):
	'ITranslationsInUserLanguages Interface'
	CLSID = IID('{2AC79865-8E0D-42CD-8A97-AA4ADF24B4EE}')
	coclass_clsid = IID('{5BD31F83-42C4-4D73-95D3-53AA2E45A16B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (3, 2, (3, 0), (), "Count", None),
		"KeyFromHeaderTable": (5, 2, (3, 0), (), "KeyFromHeaderTable", None),
		"LanguageCodeOfUserLanguage": (6, 2, (3, 0), (), "LanguageCodeOfUserLanguage", None),
		"Translationscontent": (7, 2, (8, 0), (), "Translationscontent", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"LanguageCodeOfUserLanguage": ((6, LCID, 4, 0),()),
		"Translationscontent": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserActionRecord(DispatchBaseClass):
	'IUserActionRecord Interface'
	CLSID = IID('{19F3C51D-AE7A-4293-A027-CEA9C9C20B98}')
	coclass_clsid = IID('{29A38C16-BE81-444A-B50B-6BAA2931CFC8}')

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Action": (3, 2, (3, 0), (), "Action", None),
		"ActionBy": (4, 2, (8, 0), (), "ActionBy", None),
		"ActionDate": (7, 2, (7, 0), (), "ActionDate", None),
		"ActionTime": (8, 2, (7, 0), (), "ActionTime", None),
		"ClientIP": (5, 2, (8, 0), (), "ClientIP", None),
		"ClientName": (6, 2, (8, 0), (), "ClientName", None),
		"Count": (10, 2, (3, 0), (), "Count", None),
		"UserCode": (2, 2, (8, 0), (), "UserCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (9, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(10, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserBranchAssignment(DispatchBaseClass):
	'IUserBranchAssignment Interface'
	CLSID = IID('{EC084090-ED29-4B85-BAF8-8058B245EA06}')
	coclass_clsid = IID('{0119B251-4EBE-410F-AD86-1F2D401D28F3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BPLID": (12, 2, (3, 0), (), "BPLID", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"UserCode": (11, 2, (8, 0), (), "UserCode", None),
	}
	_prop_map_put_ = {
		"BPLID": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserDefaultGroups(DispatchBaseClass):
	'IUserDefaultGroups Interface'
	CLSID = IID('{DD85FFF4-93C1-4673-9129-175B77C1CC4C}')
	coclass_clsid = IID('{DF69751C-704D-47C1-87DC-0F7D074BC516}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),bstrCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AdditionalIdNumber": (35, 2, (8, 0), (), "AdditionalIdNumber", None),
		"Address": (22, 2, (8, 0), (), "Address", None),
		"AddressinForeignLanguage": (29, 2, (8, 0), (), "AddressinForeignLanguage", None),
		"BPLID": (51, 2, (3, 0), (), "BPLID", None),
		"BPforInvoicePayment": (15, 2, (8, 0), (), "BPforInvoicePayment", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CashAccount": (16, 2, (8, 0), (), "CashAccount", None),
		"CheckingAcct": (17, 2, (8, 0), (), "CheckingAcct", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Country": (23, 2, (8, 0), (), "Country", None),
		# Method 'DefaultCreditCards' returns object of type 'IDefaultCreditCards'
		"DefaultCreditCards": (39, 2, (9, 0), (), "DefaultCreditCards", '{5923A153-B41F-4676-A5B6-1FAD645FDD7B}'),
		# Method 'DefaultDocuments' returns object of type 'IDefaultDocuments'
		"DefaultDocuments": (40, 2, (9, 0), (), "DefaultDocuments", '{38EFFD46-32F0-4190-A769-E13A5CCC3F47}'),
		"DefaultTaxCode": (34, 2, (8, 0), (), "DefaultTaxCode", None),
		"FaxNumber": (27, 2, (8, 0), (), "FaxNumber", None),
		"FaxNumberForeignLang": (33, 2, (8, 0), (), "FaxNumberForeignLang", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
		"PhoneNumber1": (25, 2, (8, 0), (), "PhoneNumber1", None),
		"PhoneNumber1ForeignLang": (31, 2, (8, 0), (), "PhoneNumber1ForeignLang", None),
		"PhoneNumber2": (26, 2, (8, 0), (), "PhoneNumber2", None),
		"PhoneNumber2ForeignLang": (32, 2, (8, 0), (), "PhoneNumber2ForeignLang", None),
		"PrintInvoiceandPaymentinS": (20, 2, (3, 0), (), "PrintInvoiceandPaymentinS", None),
		"PrintReceipt": (19, 2, (3, 0), (), "PrintReceipt", None),
		"PrintingHeader": (24, 2, (8, 0), (), "PrintingHeader", None),
		"PrintingHeaderInForeignLangu": (30, 2, (8, 0), (), "PrintingHeaderInForeignLangu", None),
		"SalesEmployee": (14, 2, (3, 0), (), "SalesEmployee", None),
		"UseTax": (37, 2, (3, 0), (), "UseTax", None),
		"UseWarehouseAddressinAPD": (38, 2, (3, 0), (), "UseWarehouseAddressinAPD", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (36, 2, (3, 0), (), "UserSignature", None),
		"Warehouse": (13, 2, (8, 0), (), "Warehouse", None),
		"WindowsColor": (21, 2, (3, 0), (), "WindowsColor", None),
		"eMail": (28, 2, (8, 0), (), "eMail", None),
	}
	_prop_map_put_ = {
		"AdditionalIdNumber": ((35, LCID, 4, 0),()),
		"Address": ((22, LCID, 4, 0),()),
		"AddressinForeignLanguage": ((29, LCID, 4, 0),()),
		"BPLID": ((51, LCID, 4, 0),()),
		"BPforInvoicePayment": ((15, LCID, 4, 0),()),
		"CashAccount": ((16, LCID, 4, 0),()),
		"CheckingAcct": ((17, LCID, 4, 0),()),
		"Code": ((11, LCID, 4, 0),()),
		"Country": ((23, LCID, 4, 0),()),
		"DefaultTaxCode": ((34, LCID, 4, 0),()),
		"FaxNumber": ((27, LCID, 4, 0),()),
		"FaxNumberForeignLang": ((33, LCID, 4, 0),()),
		"Name": ((12, LCID, 4, 0),()),
		"PhoneNumber1": ((25, LCID, 4, 0),()),
		"PhoneNumber1ForeignLang": ((31, LCID, 4, 0),()),
		"PhoneNumber2": ((26, LCID, 4, 0),()),
		"PhoneNumber2ForeignLang": ((32, LCID, 4, 0),()),
		"PrintInvoiceandPaymentinS": ((20, LCID, 4, 0),()),
		"PrintReceipt": ((19, LCID, 4, 0),()),
		"PrintingHeader": ((24, LCID, 4, 0),()),
		"PrintingHeaderInForeignLangu": ((30, LCID, 4, 0),()),
		"SalesEmployee": ((14, LCID, 4, 0),()),
		"UseTax": ((37, LCID, 4, 0),()),
		"UseWarehouseAddressinAPD": ((38, LCID, 4, 0),()),
		"Warehouse": ((13, LCID, 4, 0),()),
		"WindowsColor": ((21, LCID, 4, 0),()),
		"eMail": ((28, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserFields(DispatchBaseClass):
	'IUserFields Interface'
	CLSID = IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')
	coclass_clsid = IID('{A994F7F0-BF16-4C8E-B03C-74CE9EF2ECF5}')

	_prop_map_get_ = {
		# Method 'Fields' returns object of type 'IFields'
		"Fields": (0, 2, (9, 0), (), "Fields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'),
	}
	_prop_map_put_ = {
	}
	# Default property for this class is 'Fields'
	def __call__(self):
		return self._ApplyTypes_(*(0, 2, (9, 0), (), "Fields", '{DE680833-445E-4AF0-A7E3-377D5135268B}'))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserFieldsMD(DispatchBaseClass):
	'IUserFieldsMD Interface'
	CLSID = IID('{81D132DE-0549-460D-9BEC-2FEDEAB0A950}')
	coclass_clsid = IID('{E944AF70-E7E5-4414-833E-A62BFCF9EA65}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(19, LCID, 1, (8, 0), (),)

	def GetByKey(self, TableName=defaultNamedNotOptArg, FieldID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((8, 1), (3, 1)),TableName
			, FieldID)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (21, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"DefaultValue": (14, 2, (8, 0), (), "DefaultValue", None),
		"Description": (11, 2, (8, 0), (), "Description", None),
		"EditSize": (17, 2, (3, 0), (), "EditSize", None),
		"FieldID": (16, 2, (3, 0), (), "FieldID", None),
		"LinkedTable": (13, 2, (8, 0), (), "LinkedTable", None),
		"LinkedUDO": (22, 2, (8, 0), (), "LinkedUDO", None),
		"Mandatory": (18, 2, (3, 0), (), "Mandatory", None),
		"Name": (8, 2, (8, 0), (), "Name", None),
		"Size": (10, 2, (3, 0), (), "Size", None),
		"SubType": (12, 2, (3, 0), (), "SubType", None),
		"TableName": (15, 2, (8, 0), (), "TableName", None),
		"Type": (9, 2, (3, 0), (), "Type", None),
		# Method 'ValidValues' returns object of type 'IValidValuesMD'
		"ValidValues": (6, 2, (9, 0), (), "ValidValues", '{D435C006-B504-4847-B217-8AEA5439B779}'),
	}
	_prop_map_put_ = {
		"DefaultValue": ((14, LCID, 4, 0),()),
		"Description": ((11, LCID, 4, 0),()),
		"EditSize": ((17, LCID, 4, 0),()),
		"LinkedTable": ((13, LCID, 4, 0),()),
		"LinkedUDO": ((22, LCID, 4, 0),()),
		"Mandatory": ((18, LCID, 4, 0),()),
		"Name": ((8, LCID, 4, 0),()),
		"Size": ((10, LCID, 4, 0),()),
		"SubType": ((12, LCID, 4, 0),()),
		"TableName": ((15, LCID, 4, 0),()),
		"Type": ((9, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserKeysMD(DispatchBaseClass):
	'IUserKeysMD Interface'
	CLSID = IID('{913C6394-89AD-47A9-9390-1B8686E65312}')
	coclass_clsid = IID('{208C7E76-4919-4468-AE9E-13976C9BE255}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(14, LCID, 1, (8, 0), (),)

	def GetByKey(self, TableName=defaultNamedNotOptArg, KeyIndex=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((8, 1), (3, 1)),TableName
			, KeyIndex)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(15, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (16, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		# Method 'Elements' returns object of type 'IUserKeysMD_Elements'
		"Elements": (9, 2, (9, 0), (), "Elements", '{ED79A1AF-2F5B-418E-A90C-1F504B49E364}'),
		"KeyIndex": (11, 2, (3, 0), (), "KeyIndex", None),
		"KeyName": (12, 2, (8, 0), (), "KeyName", None),
		"TableName": (10, 2, (8, 0), (), "TableName", None),
		"Unique": (13, 2, (3, 0), (), "Unique", None),
	}
	_prop_map_put_ = {
		"KeyName": ((12, LCID, 4, 0),()),
		"TableName": ((10, LCID, 4, 0),()),
		"Unique": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserKeysMD_Elements(DispatchBaseClass):
	'IUserKeysMD_Elements Interface'
	CLSID = IID('{ED79A1AF-2F5B-418E-A90C-1F504B49E364}')
	coclass_clsid = IID('{A2120F6A-992A-4AAE-A98B-F573035921E8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentline'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ColumnAlias": (10, 2, (8, 0), (), "ColumnAlias", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"SubKeyIndex": (9, 2, (3, 0), (), "SubKeyIndex", None),
	}
	_prop_map_put_ = {
		"ColumnAlias": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserLanguages(DispatchBaseClass):
	'IUserLanguages Interface'
	CLSID = IID('{DF33FA96-E656-4AF6-A877-AAC7D5A8D586}')
	coclass_clsid = IID('{5004E453-F544-4559-BE4D-76D7C6E1278C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Code": (10, 2, (3, 0), (), "Code", None),
		"LanguageFullName": (12, 2, (8, 0), (), "LanguageFullName", None),
		"LanguageShortName": (11, 2, (8, 0), (), "LanguageShortName", None),
		"RelatedSystemLanguage": (13, 2, (3, 0), (), "RelatedSystemLanguage", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"LanguageFullName": ((12, LCID, 4, 0),()),
		"LanguageShortName": ((11, LCID, 4, 0),()),
		"RelatedSystemLanguage": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserLicenseParams(DispatchBaseClass):
	'IUserLicenseParams Interface'
	CLSID = IID('{91B68A10-74AD-4FAC-98F5-746FDD45D957}')
	coclass_clsid = IID('{EE5CC625-8EC4-42A3-B9A2-53B254F222DB}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"LicenseType": (11, 2, (3, 0), (), "LicenseType", None),
		"LicenseUpdateType": (12, 2, (3, 0), (), "LicenseUpdateType", None),
		"UserName": (10, 2, (8, 0), (), "UserName", None),
	}
	_prop_map_put_ = {
		"LicenseType": ((11, LCID, 4, 0),()),
		"LicenseUpdateType": ((12, LCID, 4, 0),()),
		"UserName": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserMenuItem(DispatchBaseClass):
	'IUserMenuItem Interface'
	CLSID = IID('{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}')
	coclass_clsid = IID('{E53F69BA-CA7A-4D3D-86BF-B36CC42A3646}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"LinkedFormMenuID": (16, 2, (3, 0), (), "LinkedFormMenuID", None),
		"LinkedFormNum": (17, 2, (3, 0), (), "LinkedFormNum", None),
		"LinkedObjKey": (15, 2, (8, 0), (), "LinkedObjKey", None),
		"LinkedObjType": (14, 2, (8, 0), (), "LinkedObjType", None),
		"Name": (11, 2, (8, 0), (), "Name", None),
		"Position": (12, 2, (3, 0), (), "Position", None),
		"ReportPath": (18, 2, (8, 0), (), "ReportPath", None),
		"Type": (13, 2, (3, 0), (), "Type", None),
		# Method 'UserMenuItems' returns object of type 'IUserMenuItems'
		"UserMenuItems": (21, 2, (9, 0), (), "UserMenuItems", '{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}'),
	}
	_prop_map_put_ = {
		"LinkedFormMenuID": ((16, LCID, 4, 0),()),
		"LinkedFormNum": ((17, LCID, 4, 0),()),
		"LinkedObjKey": ((15, LCID, 4, 0),()),
		"LinkedObjType": ((14, LCID, 4, 0),()),
		"Name": ((11, LCID, 4, 0),()),
		"Position": ((12, LCID, 4, 0),()),
		"ReportPath": ((18, LCID, 4, 0),()),
		"Type": ((13, LCID, 4, 0),()),
		"UserMenuItems": ((21, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserMenuItems(DispatchBaseClass):
	'IUserMenuItems Interface'
	CLSID = IID('{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}')
	coclass_clsid = IID('{43AFB8C0-18E3-4452-B1F0-CDA85C1F463F}')

	# Result is of type IUserMenuItem
	def Add(self):
		'method Add'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'Add', '{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}')
		return ret

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(5, LCID, 1, (8, 0), (),)

	# Result is of type IUserMenuItem
	def Item(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}')
		return ret

	def Remove(self, vtIndex=defaultNamedNotOptArg):
		'method Remove'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((12, 1),),vtIndex
			)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(4, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, vtIndex=defaultNamedNotOptArg):
		'DISPID_VALUE'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),vtIndex
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserMenuParams(DispatchBaseClass):
	'IUserMenuParams Interface'
	CLSID = IID('{6446D947-9BED-41FE-876C-B89334D5D85F}')
	coclass_clsid = IID('{722D7EF1-D469-4168-B435-F4434F1502A0}')

	def FromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method FromXMLFile'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def FromXMLString(self, bstrXML=defaultNamedNotOptArg):
		'method FromXMLString'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (24, 0), ((8, 1),),bstrXML
			)

	def GetXMLSchema(self):
		'method GetXMLSchema'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def ToXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'method ToXMLFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def ToXMLString(self):
		'method ToXMLString'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(2, LCID, 1, (8, 0), (),)

	_prop_map_get_ = {
		"UserID": (11, 2, (3, 0), (), "UserID", None),
	}
	_prop_map_put_ = {
		"UserID": ((11, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserMenuService(DispatchBaseClass):
	'IUserMenuService Interface'
	CLSID = IID('{FF87B29E-5D38-4901-A443-8672387A200A}')
	coclass_clsid = IID('{B0C0628F-DBC1-48C8-9E88-ADB8D7E8758C}')

	# Result is of type IUserMenuItems
	def GetCurrentUserMenu(self):
		'GetCurrentUserMenu'
		ret = self._oleobj_.InvokeTypes(12, LCID, 1, (9, 0), (),)
		if ret is not None:
			ret = Dispatch(ret, u'GetCurrentUserMenu', '{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}')
		return ret

	def GetDataInterface(self, enumMSDI=defaultNamedNotOptArg):
		'GetDataInterface'
		ret = self._oleobj_.InvokeTypes(1, LCID, 1, (9, 0), ((3, 1),),enumMSDI
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterface', None)
		return ret

	def GetDataInterfaceFromXMLFile(self, bstrFileName=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLFile'
		ret = self._oleobj_.InvokeTypes(2, LCID, 1, (9, 0), ((8, 1),),bstrFileName
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLFile', None)
		return ret

	def GetDataInterfaceFromXMLString(self, bstrXMLString=defaultNamedNotOptArg):
		'GetDataInterfaceFromXMLString'
		ret = self._oleobj_.InvokeTypes(3, LCID, 1, (9, 0), ((8, 1),),bstrXMLString
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetDataInterfaceFromXMLString', None)
		return ret

	# Result is of type IUserMenuItems
	def GetUserMenu(self, pIUserMenuParams=defaultNamedNotOptArg):
		'GetUserMenu'
		ret = self._oleobj_.InvokeTypes(10, LCID, 1, (9, 0), ((9, 1),),pIUserMenuParams
			)
		if ret is not None:
			ret = Dispatch(ret, u'GetUserMenu', '{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}')
		return ret

	def UpdateCurrentUserMenu(self, pIUserMenuItems=defaultNamedNotOptArg):
		'UpdateCurrentUserMenu'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (24, 0), ((9, 1),),pIUserMenuItems
			)

	def UpdateUserMenu(self, pIUserMenuParams=defaultNamedNotOptArg, pIUserMenuItems=defaultNamedNotOptArg):
		'UpdateUserMenu'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (24, 0), ((9, 1), (9, 1)),pIUserMenuParams
			, pIUserMenuItems)

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserObjectMD_ChildTables(DispatchBaseClass):
	'IUserObjectMD_ChildTables Interface'
	CLSID = IID('{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}')
	coclass_clsid = IID('{28F2FDF3-FCEC-4D90-983B-D4C805891EC0}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Code": (8, 2, (8, 0), (), "Code", None),
		"Count": (5, 2, (3, 0), (), "Count", None),
		"LogTableName": (3, 2, (8, 0), (), "LogTableName", None),
		"ObjectName": (9, 2, (8, 0), (), "ObjectName", None),
		"SonNumber": (1, 2, (3, 0), (), "SonNumber", None),
		"TableName": (2, 2, (8, 0), (), "TableName", None),
	}
	_prop_map_put_ = {
		"LogTableName": ((3, LCID, 4, 0),()),
		"ObjectName": ((9, LCID, 4, 0),()),
		"TableName": ((2, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserObjectMD_EnhancedFormColumns(DispatchBaseClass):
	'IUserObjectMD_EnhancedFormColumns Interface'
	CLSID = IID('{F09D2D1D-1BB3-4D09-946B-71AE1263D6AC}')
	coclass_clsid = IID('{128C44F7-92DA-4BCB-B864-107D02E1ECFB}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ChildNumber": (3, 2, (3, 0), (), "ChildNumber", None),
		"Code": (1, 2, (8, 0), (), "Code", None),
		"ColumnAlias": (4, 2, (8, 0), (), "ColumnAlias", None),
		"ColumnDescription": (5, 2, (8, 0), (), "ColumnDescription", None),
		"ColumnIsUsed": (6, 2, (3, 0), (), "ColumnIsUsed", None),
		"ColumnNumber": (2, 2, (3, 0), (), "ColumnNumber", None),
		"Count": (7, 2, (3, 0), (), "Count", None),
		"Editable": (10, 2, (3, 0), (), "Editable", None),
	}
	_prop_map_put_ = {
		"ChildNumber": ((3, LCID, 4, 0),()),
		"ColumnAlias": ((4, LCID, 4, 0),()),
		"ColumnDescription": ((5, LCID, 4, 0),()),
		"ColumnIsUsed": ((6, LCID, 4, 0),()),
		"ColumnNumber": ((2, LCID, 4, 0),()),
		"Editable": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(7, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserObjectMD_FindColumns(DispatchBaseClass):
	'IUserObjectMD_FindColumns Interface'
	CLSID = IID('{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}')
	coclass_clsid = IID('{1C59C249-B65E-472F-80BB-EE0A05F75666}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Code": (11, 2, (8, 0), (), "Code", None),
		"ColumnAlias": (2, 2, (8, 0), (), "ColumnAlias", None),
		"ColumnDescription": (3, 2, (8, 0), (), "ColumnDescription", None),
		"ColumnNumber": (1, 2, (3, 0), (), "ColumnNumber", None),
		"Count": (5, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
		"ColumnAlias": ((2, LCID, 4, 0),()),
		"ColumnDescription": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserObjectMD_FormColumns(DispatchBaseClass):
	'IUserObjectMD_FormColumns Interface'
	CLSID = IID('{0C607D21-E148-42CE-AF58-E8C38EB26275}')
	coclass_clsid = IID('{C1A276C6-FD68-4693-8D70-D9A7A3E69712}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Code": (9, 2, (8, 0), (), "Code", None),
		"Count": (6, 2, (3, 0), (), "Count", None),
		"Editable": (10, 2, (3, 0), (), "Editable", None),
		"FormColumnAlias": (1, 2, (8, 0), (), "FormColumnAlias", None),
		"FormColumnDescription": (2, 2, (8, 0), (), "FormColumnDescription", None),
		"FormColumnNumber": (4, 2, (3, 0), (), "FormColumnNumber", None),
		"SonNumber": (5, 2, (3, 0), (), "SonNumber", None),
	}
	_prop_map_put_ = {
		"Editable": ((10, LCID, 4, 0),()),
		"FormColumnAlias": ((1, LCID, 4, 0),()),
		"FormColumnDescription": ((2, LCID, 4, 0),()),
		"SonNumber": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(6, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserObjectsMD(DispatchBaseClass):
	'IUserObjectsMD Interface'
	CLSID = IID('{2E2720A5-8F7C-45D3-BF5A-DD5BE3769F84}')
	coclass_clsid = IID('{8AEF84A8-9762-4736-A6BC-778EA10CA4C2}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(15, LCID, 1, (3, 0), (),)

	def GetByKey(self, Code=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(16, LCID, 1, (11, 0), ((8, 1),),Code
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(17, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (26, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CanArchive": (28, 2, (3, 0), (), "CanArchive", None),
		"CanCancel": (7, 2, (3, 0), (), "CanCancel", None),
		"CanClose": (14, 2, (3, 0), (), "CanClose", None),
		"CanCreateDefaultForm": (4, 2, (3, 0), (), "CanCreateDefaultForm", None),
		"CanDelete": (8, 2, (3, 0), (), "CanDelete", None),
		"CanFind": (11, 2, (3, 0), (), "CanFind", None),
		"CanLog": (9, 2, (3, 0), (), "CanLog", None),
		"CanYearTransfer": (12, 2, (3, 0), (), "CanYearTransfer", None),
		# Method 'ChildTables' returns object of type 'IUserObjectMD_ChildTables'
		"ChildTables": (23, 2, (9, 0), (), "ChildTables", '{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}'),
		"Code": (2, 2, (8, 0), (), "Code", None),
		"EnableEnhancedForm": (34, 2, (3, 0), (), "EnableEnhancedForm", None),
		# Method 'EnhancedFormColumns' returns object of type 'IUserObjectMD_EnhancedFormColumns'
		"EnhancedFormColumns": (37, 2, (9, 0), (), "EnhancedFormColumns", '{F09D2D1D-1BB3-4D09-946B-71AE1263D6AC}'),
		"ExtensionName": (6, 2, (8, 0), (), "ExtensionName", None),
		"FatherMenuID": (31, 2, (3, 0), (), "FatherMenuID", None),
		# Method 'FindColumns' returns object of type 'IUserObjectMD_FindColumns'
		"FindColumns": (21, 2, (9, 0), (), "FindColumns", '{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}'),
		# Method 'FormColumns' returns object of type 'IUserObjectMD_FormColumns'
		"FormColumns": (22, 2, (9, 0), (), "FormColumns", '{0C607D21-E148-42CE-AF58-E8C38EB26275}'),
		"FormSRF": (36, 2, (8, 0), (), "FormSRF", None),
		"LogTableName": (3, 2, (8, 0), (), "LogTableName", None),
		"ManageSeries": (10, 2, (3, 0), (), "ManageSeries", None),
		"MenuCaption": (30, 2, (8, 0), (), "MenuCaption", None),
		"MenuItem": (29, 2, (3, 0), (), "MenuItem", None),
		"MenuUID": (33, 2, (8, 0), (), "MenuUID", None),
		"Name": (13, 2, (8, 0), (), "Name", None),
		"ObjectType": (5, 2, (3, 0), (), "ObjectType", None),
		"OverwriteDllfile": (25, 2, (3, 0), (), "OverwriteDllfile", None),
		"Position": (32, 2, (3, 0), (), "Position", None),
		"RebuildEnhancedForm": (35, 2, (3, 0), (), "RebuildEnhancedForm", None),
		"TableName": (1, 2, (8, 0), (), "TableName", None),
		"UseUniqueFormType": (27, 2, (3, 0), (), "UseUniqueFormType", None),
	}
	_prop_map_put_ = {
		"CanArchive": ((28, LCID, 4, 0),()),
		"CanCancel": ((7, LCID, 4, 0),()),
		"CanClose": ((14, LCID, 4, 0),()),
		"CanCreateDefaultForm": ((4, LCID, 4, 0),()),
		"CanDelete": ((8, LCID, 4, 0),()),
		"CanFind": ((11, LCID, 4, 0),()),
		"CanLog": ((9, LCID, 4, 0),()),
		"CanYearTransfer": ((12, LCID, 4, 0),()),
		"Code": ((2, LCID, 4, 0),()),
		"EnableEnhancedForm": ((34, LCID, 4, 0),()),
		"ExtensionName": ((6, LCID, 4, 0),()),
		"FatherMenuID": ((31, LCID, 4, 0),()),
		"FormSRF": ((36, LCID, 4, 0),()),
		"LogTableName": ((3, LCID, 4, 0),()),
		"ManageSeries": ((10, LCID, 4, 0),()),
		"MenuCaption": ((30, LCID, 4, 0),()),
		"MenuItem": ((29, LCID, 4, 0),()),
		"MenuUID": ((33, LCID, 4, 0),()),
		"Name": ((13, LCID, 4, 0),()),
		"ObjectType": ((5, LCID, 4, 0),()),
		"OverwriteDllfile": ((25, LCID, 4, 0),()),
		"Position": ((32, LCID, 4, 0),()),
		"RebuildEnhancedForm": ((35, LCID, 4, 0),()),
		"TableName": ((1, LCID, 4, 0),()),
		"UseUniqueFormType": ((27, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserPermission(DispatchBaseClass):
	'IUserPermission Interface'
	CLSID = IID('{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}')
	coclass_clsid = IID('{F9779E16-EDDF-4C59-B80D-A24F34EA1ECE}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (6, 2, (3, 0), (), "Count", None),
		"Permission": (4, 2, (3, 0), (), "Permission", None),
		"PermissionID": (3, 2, (8, 0), (), "PermissionID", None),
		"UserCode": (2, 2, (3, 0), (), "UserCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Permission": ((4, LCID, 4, 0),()),
		"PermissionID": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(6, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserPermissionForms(DispatchBaseClass):
	'IUserPermissionForms Interface'
	CLSID = IID('{24464254-073D-4148-A045-3CFDB71DE48C}')
	coclass_clsid = IID('{6D4864DD-75DF-4305-A8CB-C7E2381DD7B3}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (5, 2, (3, 0), (), "Count", None),
		"DisplayOrder": (2, 2, (3, 0), (), "DisplayOrder", None),
		"FormType": (1, 2, (8, 0), (), "FormType", None),
		"PermissionID": (3, 2, (8, 0), (), "PermissionID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"DisplayOrder": ((2, LCID, 4, 0),()),
		"FormType": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(5, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserPermissionTree(DispatchBaseClass):
	'IUserPermissionTree Interface'
	CLSID = IID('{55ACC8CD-3412-452A-9AF8-304A0A56FD3B}')
	coclass_clsid = IID('{950BE47C-4B36-49F3-A313-57146222DC3C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(10, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(16, LCID, 1, (8, 0), (),)

	def GetByKey(self, PermissionID=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(11, LCID, 1, (11, 0), ((8, 1),),PermissionID
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(18, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(17, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(12, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(13, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (15, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"DisplayOrder": (2, 2, (3, 0), (), "DisplayOrder", None),
		"IsItem": (7, 2, (3, 0), (), "IsItem", None),
		"Levels": (6, 2, (3, 0), (), "Levels", None),
		"Name": (5, 2, (8, 0), (), "Name", None),
		"Options": (4, 2, (3, 0), (), "Options", None),
		"ParentID": (8, 2, (8, 0), (), "ParentID", None),
		"PermissionID": (3, 2, (8, 0), (), "PermissionID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (14, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		# Method 'UserPermissionForms' returns object of type 'IUserPermissionForms'
		"UserPermissionForms": (9, 2, (9, 0), (), "UserPermissionForms", '{24464254-073D-4148-A045-3CFDB71DE48C}'),
		"UserSignature": (1, 2, (3, 0), (), "UserSignature", None),
	}
	_prop_map_put_ = {
		"IsItem": ((7, LCID, 4, 0),()),
		"Name": ((5, LCID, 4, 0),()),
		"Options": ((4, LCID, 4, 0),()),
		"ParentID": ((8, LCID, 4, 0),()),
		"PermissionID": ((3, LCID, 4, 0),()),
		"UserSignature": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserQueries(DispatchBaseClass):
	'IUserQueries Interface'
	CLSID = IID('{9057028D-894C-4F75-877F-A856F36DDEA5}')
	coclass_clsid = IID('{5881CB86-9E3A-403D-A3C8-D1B888F3C4F7}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lInternalKey=defaultNamedNotOptArg, lQcategory=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1), (3, 1)),lInternalKey
			, lQcategory)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"InternalKey": (10, 2, (3, 0), (), "InternalKey", None),
		"Query": (13, 2, (8, 0), (), "Query", None),
		"QueryCategory": (11, 2, (3, 0), (), "QueryCategory", None),
		"QueryDescription": (12, 2, (8, 0), (), "QueryDescription", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"Query": ((13, LCID, 4, 0),()),
		"QueryCategory": ((11, LCID, 4, 0),()),
		"QueryDescription": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserTable(DispatchBaseClass):
	'IUserTable Interface'
	CLSID = IID('{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')
	coclass_clsid = IID('{EBB0F6A6-D704-41FF-8D22-CC3B76407F5B}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get table's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(11, LCID, 1, (8, 0), (),)

	def GetByKey(self, Key=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (11, 0), ((8, 1),),Key
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the table's data in xml format."
		return self._oleobj_.InvokeTypes(12, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"ArchiveDate": (13, 2, (7, 0), (), "ArchiveDate", None),
		"Code": (9, 2, (8, 0), (), "Code", None),
		"Name": (10, 2, (8, 0), (), "Name", None),
		"TableDescription": (8, 2, (8, 0), (), "TableDescription", None),
		"TableName": (7, 2, (8, 0), (), "TableName", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (6, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"ArchiveDate": ((13, LCID, 4, 0),()),
		"Code": ((9, LCID, 4, 0),()),
		"Name": ((10, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserTables(DispatchBaseClass):
	'IUserTables Interface'
	CLSID = IID('{625162C1-3894-460F-94EC-72D6AFEA34D2}')
	coclass_clsid = IID('{CD793E21-582C-4408-8AF7-1B256D29BF5A}')

	# Result is of type IUserTable
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')
		return ret

	_prop_map_get_ = {
		"Count": (1, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(1, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUserTablesMD(DispatchBaseClass):
	'IUserTablesMD Interface'
	CLSID = IID('{FC571383-8375-4B7D-BDEF-4EF2B91B7751}')
	coclass_clsid = IID('{04A02F02-1211-4507-87DB-DBE6A4807718}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(9, LCID, 1, (8, 0), (),)

	def GetByKey(self, TableName=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((8, 1),),TableName
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(10, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Archivable": (12, 2, (3, 0), (), "Archivable", None),
		"ArchiveDateField": (13, 2, (8, 0), (), "ArchiveDateField", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (11, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"TableDescription": (7, 2, (8, 0), (), "TableDescription", None),
		"TableName": (6, 2, (8, 0), (), "TableName", None),
		"TableType": (8, 2, (3, 0), (), "TableType", None),
	}
	_prop_map_put_ = {
		"Archivable": ((12, LCID, 4, 0),()),
		"ArchiveDateField": ((13, LCID, 4, 0),()),
		"TableDescription": ((7, LCID, 4, 0),()),
		"TableName": ((6, LCID, 4, 0),()),
		"TableType": ((8, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IUserValidValues(DispatchBaseClass):
	'IUserValidValues Interface'
	CLSID = IID('{280836CC-E077-4487-8759-D06DC3E31076}')
	coclass_clsid = IID('{A912A61F-CCFA-450D-9B6C-CA22F88D1FE8}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (3, 2, (3, 0), (), "Count", None),
		"FieldValue": (5, 2, (8, 0), (), "FieldValue", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"FieldValue": ((5, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IUsers(DispatchBaseClass):
	'IUsers Interface'
	CLSID = IID('{ED256951-E65E-40BF-A2E9-2A21741D8720}')
	coclass_clsid = IID('{1B0F044E-5955-4426-8CEE-885A8388A8F9}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Close(self):
		'method Close'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(22, LCID, 1, (8, 0), (),)

	def GetByKey(self, InternalKey=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (11, 0), ((3, 1),),InternalKey
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(4, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(23, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Branch": (18, 2, (3, 0), (), "Branch", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (7, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CashLimit": (29, 2, (3, 0), (), "CashLimit", None),
		"Defaults": (16, 2, (8, 0), (), "Defaults", None),
		"Department": (19, 2, (3, 0), (), "Department", None),
		"FaxNumber": (17, 2, (8, 0), (), "FaxNumber", None),
		"Group": (25, 2, (3, 0), (), "Group", None),
		"InternalKey": (9, 2, (3, 0), (), "InternalKey", None),
		"LastLoginTime": (42, 2, (7, 0), (), "LastLoginTime", None),
		"LastLogoutDate": (41, 2, (7, 0), (), "LastLogoutDate", None),
		"LastLogoutTime": (43, 2, (7, 0), (), "LastLogoutTime", None),
		"LastPasswordChangeTime": (44, 2, (7, 0), (), "LastPasswordChangeTime", None),
		"LastPasswordChangedBy": (45, 2, (8, 0), (), "LastPasswordChangedBy", None),
		"Locked": (24, 2, (3, 0), (), "Locked", None),
		"MaxCashAmtForIncmngPayts": (30, 2, (5, 0), (), "MaxCashAmtForIncmngPayts", None),
		"MaxDiscountGeneral": (26, 2, (5, 0), (), "MaxDiscountGeneral", None),
		"MaxDiscountPurchase": (28, 2, (5, 0), (), "MaxDiscountPurchase", None),
		"MaxDiscountSales": (27, 2, (5, 0), (), "MaxDiscountSales", None),
		"MobilePhoneNumber": (15, 2, (8, 0), (), "MobilePhoneNumber", None),
		"Superuser": (13, 2, (3, 0), (), "Superuser", None),
		# Method 'UserActionRecord' returns object of type 'IUserActionRecord'
		"UserActionRecord": (46, 2, (9, 0), (), "UserActionRecord", '{19F3C51D-AE7A-4293-A027-CEA9C9C20B98}'),
		# Method 'UserBranchAssignment' returns object of type 'IUserBranchAssignment'
		"UserBranchAssignment": (61, 2, (9, 0), (), "UserBranchAssignment", '{EC084090-ED29-4B85-BAF8-8058B245EA06}'),
		"UserCode": (11, 2, (8, 0), (), "UserCode", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (20, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserName": (12, 2, (8, 0), (), "UserName", None),
		"UserPassword": (10, 2, (8, 0), (), "UserPassword", None),
		# Method 'UserPermission' returns object of type 'IUserPermission'
		"UserPermission": (21, 2, (9, 0), (), "UserPermission", '{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}'),
		"eMail": (14, 2, (8, 0), (), "eMail", None),
	}
	_prop_map_put_ = {
		"Branch": ((18, LCID, 4, 0),()),
		"CashLimit": ((29, LCID, 4, 0),()),
		"Defaults": ((16, LCID, 4, 0),()),
		"Department": ((19, LCID, 4, 0),()),
		"FaxNumber": ((17, LCID, 4, 0),()),
		"Locked": ((24, LCID, 4, 0),()),
		"MaxCashAmtForIncmngPayts": ((30, LCID, 4, 0),()),
		"MaxDiscountGeneral": ((26, LCID, 4, 0),()),
		"MaxDiscountPurchase": ((28, LCID, 4, 0),()),
		"MaxDiscountSales": ((27, LCID, 4, 0),()),
		"MobilePhoneNumber": ((15, LCID, 4, 0),()),
		"Superuser": ((13, LCID, 4, 0),()),
		"UserCode": ((11, LCID, 4, 0),()),
		"UserName": ((12, LCID, 4, 0),()),
		"UserPassword": ((10, LCID, 4, 0),()),
		"eMail": ((14, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IValidValue(DispatchBaseClass):
	'IValidValue Interface'
	CLSID = IID('{013F0389-85E2-4B8B-9285-18843E4236F3}')
	coclass_clsid = IID('{4838BBDC-5B48-44EF-A7F7-A705BB07B24F}')

	_prop_map_get_ = {
		"Description": (2, 2, (8, 0), (), "Description", None),
		"Value": (1, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(1, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IValidValues(DispatchBaseClass):
	'IValidValues Interface'
	CLSID = IID('{48B89C08-2AE9-435F-B7C4-D7219E938E46}')
	coclass_clsid = IID('{C54F7212-C3DC-4E35-B61C-73E6297F1AD6}')

	# Result is of type IValidValue
	def Item(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, u'Item', '{013F0389-85E2-4B8B-9285-18843E4236F3}')
		return ret

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
	}
	_prop_map_put_ = {
	}
	# Default method for this class is 'Item'
	def __call__(self, Index=defaultNamedNotOptArg):
		'Retrives the item object.'
		ret = self._oleobj_.InvokeTypes(0, LCID, 1, (9, 0), ((12, 1),),Index
			)
		if ret is not None:
			ret = Dispatch(ret, '__call__', '{013F0389-85E2-4B8B-9285-18843E4236F3}')
		return ret

	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,2,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, '{013F0389-85E2-4B8B-9285-18843E4236F3}')
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IValidValuesMD(DispatchBaseClass):
	'IValidValuesMD Interface'
	CLSID = IID('{D435C006-B504-4847-B217-8AEA5439B779}')
	coclass_clsid = IID('{C868B9F4-6EC8-4A28-81AF-546DD81B1083}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def Delete(self):
		'method Delete'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (2, 2, (3, 0), (), "Count", None),
		"Description": (5, 2, (8, 0), (), "Description", None),
		"Value": (4, 2, (8, 0), (), "Value", None),
	}
	_prop_map_put_ = {
		"Description": ((5, LCID, 4, 0),()),
		"Value": ((4, LCID, 4, 0),()),
	}
	# Default property for this class is 'Value'
	def __call__(self):
		return self._ApplyTypes_(*(4, 2, (8, 0), (), "Value", None))
	def __unicode__(self, *args):
		try:
			return unicode(self.__call__(*args))
		except pythoncom.com_error:
			return repr(self)
	def __str__(self, *args):
		return str(self.__unicode__(*args))
	def __int__(self, *args):
		return int(self.__call__(*args))
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IVatGroups(DispatchBaseClass):
	'IVatGroups Interface'
	CLSID = IID('{8F4727F1-1991-4F80-8363-F7E1ABD6AF5E}')
	coclass_clsid = IID('{C8D20CC8-E622-4D4A-8EE8-AE014B6271DF}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(5, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(27, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrGroupCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (11, 0), ((8, 1),),bstrGroupCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(28, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AcquisitionReverse": (18, 2, (3, 0), (), "AcquisitionReverse", None),
		"AcquisitionTax": (20, 2, (8, 0), (), "AcquisitionTax", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CashDiscountAccount": (36, 2, (8, 0), (), "CashDiscountAccount", None),
		"Category": (14, 2, (3, 0), (), "Category", None),
		"Code": (11, 2, (8, 0), (), "Code", None),
		"Correction": (24, 2, (3, 0), (), "Correction", None),
		"DeferredTaxAcc": (23, 2, (8, 0), (), "DeferredTaxAcc", None),
		"DownPaymentTaxOffsetAccount": (35, 2, (8, 0), (), "DownPaymentTaxOffsetAccount", None),
		"EU": (16, 2, (3, 0), (), "EU", None),
		"EqualizationTaxAccount": (29, 2, (8, 0), (), "EqualizationTaxAccount", None),
		"GoodsShipment": (21, 2, (8, 0), (), "GoodsShipment", None),
		"Inactive": (31, 2, (3, 0), (), "Inactive", None),
		"Name": (12, 2, (8, 0), (), "Name", None),
		"NonDeduct": (19, 2, (5, 0), (), "NonDeduct", None),
		"NonDeductAcc": (22, 2, (8, 0), (), "NonDeductAcc", None),
		"Report349Code": (33, 2, (3, 0), (), "Report349Code", None),
		"ServiceSupply": (30, 2, (8, 0), (), "ServiceSupply", None),
		"TaxAccount": (15, 2, (8, 0), (), "TaxAccount", None),
		"TaxTypeBlackList": (32, 2, (3, 0), (), "TaxTypeBlackList", None),
		"TriangularDeal": (17, 2, (8, 0), (), "TriangularDeal", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (3, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATInRevenueAccount": (34, 2, (8, 0), (), "VATInRevenueAccount", None),
		"VatCorrection": (25, 2, (8, 0), (), "VatCorrection", None),
		# Method 'VatGroups_Lines' returns object of type 'IVatGroups_Lines'
		"VatGroups_Lines": (26, 2, (9, 0), (), "VatGroups_Lines", '{6AA927D2-EF50-4064-AE3F-A65ADF1026B1}'),
	}
	_prop_map_put_ = {
		"AcquisitionReverse": ((18, LCID, 4, 0),()),
		"AcquisitionTax": ((20, LCID, 4, 0),()),
		"CashDiscountAccount": ((36, LCID, 4, 0),()),
		"Category": ((14, LCID, 4, 0),()),
		"Code": ((11, LCID, 4, 0),()),
		"Correction": ((24, LCID, 4, 0),()),
		"DeferredTaxAcc": ((23, LCID, 4, 0),()),
		"DownPaymentTaxOffsetAccount": ((35, LCID, 4, 0),()),
		"EU": ((16, LCID, 4, 0),()),
		"EqualizationTaxAccount": ((29, LCID, 4, 0),()),
		"GoodsShipment": ((21, LCID, 4, 0),()),
		"Inactive": ((31, LCID, 4, 0),()),
		"Name": ((12, LCID, 4, 0),()),
		"NonDeduct": ((19, LCID, 4, 0),()),
		"NonDeductAcc": ((22, LCID, 4, 0),()),
		"Report349Code": ((33, LCID, 4, 0),()),
		"ServiceSupply": ((30, LCID, 4, 0),()),
		"TaxAccount": ((15, LCID, 4, 0),()),
		"TaxTypeBlackList": ((32, LCID, 4, 0),()),
		"TriangularDeal": ((17, LCID, 4, 0),()),
		"VATInRevenueAccount": ((34, LCID, 4, 0),()),
		"VatCorrection": ((25, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IVatGroups_Lines(DispatchBaseClass):
	'IVatGroups_Lines Interface'
	CLSID = IID('{6AA927D2-EF50-4064-AE3F-A65ADF1026B1}')
	coclass_clsid = IID('{68D4BD48-09E9-4F7E-B8FC-43E3FA23F86F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"Count": (4, 2, (3, 0), (), "Count", None),
		"DatevCode": (8, 2, (3, 0), (), "DatevCode", None),
		"Effectivefrom": (5, 2, (7, 0), (), "Effectivefrom", None),
		"EqualizationTax": (7, 2, (5, 0), (), "EqualizationTax", None),
		"Rate": (6, 2, (5, 0), (), "Rate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (3, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"DatevCode": ((8, LCID, 4, 0),()),
		"Effectivefrom": ((5, LCID, 4, 0),()),
		"EqualizationTax": ((7, LCID, 4, 0),()),
		"Rate": ((6, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(4, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IWarehouseLocations(DispatchBaseClass):
	'IWarehouseLocations Interface'
	CLSID = IID('{18E244C5-2925-44E3-9DF7-3D8E38583DE0}')
	coclass_clsid = IID('{000DE7D3-9F70-4BA6-BDE0-F4FFFDD7813E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lCode
			)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AssesseeType": (16, 2, (8, 0), (), "AssesseeType", None),
		"Block": (28, 2, (8, 0), (), "Block", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BuildingFloorRoom": (36, 2, (8, 0), (), "BuildingFloorRoom", None),
		"CECommissionerate": (24, 2, (8, 0), (), "CECommissionerate", None),
		"CEDivision": (23, 2, (8, 0), (), "CEDivision", None),
		"CERange": (22, 2, (8, 0), (), "CERange", None),
		"CERegisterNumber": (35, 2, (8, 0), (), "CERegisterNumber", None),
		"CSTNumber": (12, 2, (8, 0), (), "CSTNumber", None),
		"City": (30, 2, (8, 0), (), "City", None),
		"Code": (9, 2, (3, 0), (), "Code", None),
		"CompanyType": (17, 2, (8, 0), (), "CompanyType", None),
		"Country": (32, 2, (8, 0), (), "Country", None),
		"County": (31, 2, (8, 0), (), "County", None),
		"EccNumber": (21, 2, (8, 0), (), "EccNumber", None),
		"ExemptionNumber": (13, 2, (8, 0), (), "ExemptionNumber", None),
		"Jurisdiction": (26, 2, (8, 0), (), "Jurisdiction", None),
		"LSTVATNumber": (11, 2, (8, 0), (), "LSTVATNumber", None),
		"ManufacturerCode": (25, 2, (8, 0), (), "ManufacturerCode", None),
		"Name": (10, 2, (8, 0), (), "Name", None),
		"NatureOfBusiness": (18, 2, (8, 0), (), "NatureOfBusiness", None),
		"PANNumber": (34, 2, (8, 0), (), "PANNumber", None),
		"RegistrationType": (20, 2, (8, 0), (), "RegistrationType", None),
		"ServiceTaxNumber": (15, 2, (8, 0), (), "ServiceTaxNumber", None),
		"State": (33, 2, (8, 0), (), "State", None),
		"Street": (27, 2, (8, 0), (), "Street", None),
		"TANNumber": (14, 2, (8, 0), (), "TANNumber", None),
		"TINNumber": (19, 2, (8, 0), (), "TINNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"ZipCode": (29, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AssesseeType": ((16, LCID, 4, 0),()),
		"Block": ((28, LCID, 4, 0),()),
		"BuildingFloorRoom": ((36, LCID, 4, 0),()),
		"CECommissionerate": ((24, LCID, 4, 0),()),
		"CEDivision": ((23, LCID, 4, 0),()),
		"CERange": ((22, LCID, 4, 0),()),
		"CERegisterNumber": ((35, LCID, 4, 0),()),
		"CSTNumber": ((12, LCID, 4, 0),()),
		"City": ((30, LCID, 4, 0),()),
		"CompanyType": ((17, LCID, 4, 0),()),
		"Country": ((32, LCID, 4, 0),()),
		"County": ((31, LCID, 4, 0),()),
		"EccNumber": ((21, LCID, 4, 0),()),
		"ExemptionNumber": ((13, LCID, 4, 0),()),
		"Jurisdiction": ((26, LCID, 4, 0),()),
		"LSTVATNumber": ((11, LCID, 4, 0),()),
		"ManufacturerCode": ((25, LCID, 4, 0),()),
		"Name": ((10, LCID, 4, 0),()),
		"NatureOfBusiness": ((18, LCID, 4, 0),()),
		"PANNumber": ((34, LCID, 4, 0),()),
		"ServiceTaxNumber": ((15, LCID, 4, 0),()),
		"State": ((33, LCID, 4, 0),()),
		"Street": ((27, LCID, 4, 0),()),
		"TANNumber": ((14, LCID, 4, 0),()),
		"TINNumber": ((19, LCID, 4, 0),()),
		"ZipCode": ((29, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IWarehouses(DispatchBaseClass):
	'IWarehouses Interface'
	CLSID = IID('{43AC045C-DCA2-4150-B937-AB205DCA22E6}')
	coclass_clsid = IID('{57544A70-71BC-4A35-B018-BB43DD24941A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(50, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(57, LCID, 1, (8, 0), (),)

	def GetByKey(self, WhsCode=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(53, LCID, 1, (11, 0), ((8, 1),),WhsCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(52, LCID, 1, (3, 0), (),)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(58, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(54, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(51, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"AddressType": (101, 2, (8, 0), (), "AddressType", None),
		"AllowUseTax": (10, 2, (3, 0), (), "AllowUseTax", None),
		"Block": (20, 2, (8, 0), (), "Block", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (56, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"BuildingFloorRoom": (43, 2, (8, 0), (), "BuildingFloorRoom", None),
		"BusinessPlaceID": (59, 2, (3, 0), (), "BusinessPlaceID", None),
		"City": (30, 2, (8, 0), (), "City", None),
		"CostInflationAccount": (11, 2, (8, 0), (), "CostInflationAccount", None),
		"CostInflationOffsetAccount": (14, 2, (8, 0), (), "CostInflationOffsetAccount", None),
		"CostOfGoodsSold": (27, 2, (8, 0), (), "CostOfGoodsSold", None),
		"Country": (33, 2, (8, 0), (), "Country", None),
		"County": (44, 2, (8, 0), (), "County", None),
		"DecreaseGLAccount": (22, 2, (8, 0), (), "DecreaseGLAccount", None),
		"DecreasingAccount": (4, 2, (8, 0), (), "DecreasingAccount", None),
		"DropShip": (38, 2, (3, 0), (), "DropShip", None),
		"EUExpensesAccount": (13, 2, (8, 0), (), "EUExpensesAccount", None),
		"EUPurchaseCreditAcc": (61, 2, (8, 0), (), "EUPurchaseCreditAcc", None),
		"EURevenuesAccount": (6, 2, (8, 0), (), "EURevenuesAccount", None),
		"ExchangeRateDifferencesAccount": (35, 2, (8, 0), (), "ExchangeRateDifferencesAccount", None),
		"Excisable": (69, 2, (3, 0), (), "Excisable", None),
		"ExemptRevenuesAccount": (25, 2, (8, 0), (), "ExemptRevenuesAccount", None),
		"ExemptedCredits": (65, 2, (8, 0), (), "ExemptedCredits", None),
		"ExpenseAccount": (21, 2, (8, 0), (), "ExpenseAccount", None),
		"ExpenseOffsetingAct": (47, 2, (8, 0), (), "ExpenseOffsetingAct", None),
		"ExpensesClearingAccount": (15, 2, (8, 0), (), "ExpensesClearingAccount", None),
		"FederalTaxID": (18, 2, (8, 0), (), "FederalTaxID", None),
		"ForeignExpensesAccount": (12, 2, (8, 0), (), "ForeignExpensesAccount", None),
		"ForeignPurchaseCreditAcc": (62, 2, (8, 0), (), "ForeignPurchaseCreditAcc", None),
		"ForeignRevenuesAcc": (42, 2, (8, 0), (), "ForeignRevenuesAcc", None),
		"GoodsClearingAcc": (48, 2, (8, 0), (), "GoodsClearingAcc", None),
		"IncreaseGLAccount": (34, 2, (8, 0), (), "IncreaseGLAccount", None),
		"IncreasingAcc": (46, 2, (8, 0), (), "IncreasingAcc", None),
		"InternalKey": (41, 2, (3, 0), (), "InternalKey", None),
		"InventoryOffsetProfitAndLossAccount": (92, 2, (8, 0), (), "InventoryOffsetProfitAndLossAccount", None),
		"Location": (19, 2, (3, 0), (), "Location", None),
		"NegativeInventoryAdjustmentAccount": (67, 2, (8, 0), (), "NegativeInventoryAdjustmentAccount", None),
		"Nettable": (45, 2, (3, 0), (), "Nettable", None),
		"PriceDifferencesAccount": (31, 2, (8, 0), (), "PriceDifferencesAccount", None),
		"PurchaseAccount": (5, 2, (8, 0), (), "PurchaseAccount", None),
		"PurchaseCreditAcc": (60, 2, (8, 0), (), "PurchaseCreditAcc", None),
		"PurchaseOffsetAccount": (26, 2, (8, 0), (), "PurchaseOffsetAccount", None),
		"PurchaseReturningAccount": (16, 2, (8, 0), (), "PurchaseReturningAccount", None),
		"ReturningAccount": (7, 2, (8, 0), (), "ReturningAccount", None),
		"RevenuesAccount": (23, 2, (8, 0), (), "RevenuesAccount", None),
		"SalesCreditAcc": (63, 2, (8, 0), (), "SalesCreditAcc", None),
		"SalesCreditEUAcc": (64, 2, (8, 0), (), "SalesCreditEUAcc", None),
		"SalesCreditForeignAcc": (66, 2, (8, 0), (), "SalesCreditForeignAcc", None),
		"ShippedGoodsAccount": (8, 2, (8, 0), (), "ShippedGoodsAccount", None),
		"Shipper": (104, 2, (8, 0), (), "Shipper", None),
		"State": (29, 2, (8, 0), (), "State", None),
		"StockAccount": (49, 2, (8, 0), (), "StockAccount", None),
		"StockInTransitAccount": (72, 2, (8, 0), (), "StockInTransitAccount", None),
		"StockInflationAdjustAccount": (9, 2, (8, 0), (), "StockInflationAdjustAccount", None),
		"StockInflationOffsetAccount": (2, 2, (8, 0), (), "StockInflationOffsetAccount", None),
		"Storekeeper": (103, 2, (3, 0), (), "Storekeeper", None),
		"Street": (1, 2, (8, 0), (), "Street", None),
		"StreetNo": (102, 2, (8, 0), (), "StreetNo", None),
		"TaxGroup": (24, 2, (8, 0), (), "TaxGroup", None),
		"TransfersAcc": (40, 2, (8, 0), (), "TransfersAcc", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (55, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"VATInRevenueAccount": (17, 2, (8, 0), (), "VATInRevenueAccount", None),
		"VarianceAccount": (32, 2, (8, 0), (), "VarianceAccount", None),
		"WHIncomingCenvatAccount": (70, 2, (8, 0), (), "WHIncomingCenvatAccount", None),
		"WHOutgoingCenvatAccount": (71, 2, (8, 0), (), "WHOutgoingCenvatAccount", None),
		"WHShipToName": (68, 2, (8, 0), (), "WHShipToName", None),
		"WIPMaterialAccount": (36, 2, (8, 0), (), "WIPMaterialAccount", None),
		"WIPMaterialVarianceAccount": (39, 2, (8, 0), (), "WIPMaterialVarianceAccount", None),
		"WarehouseCode": (28, 2, (8, 0), (), "WarehouseCode", None),
		"WarehouseName": (37, 2, (8, 0), (), "WarehouseName", None),
		"WipOffsetProfitAndLossAccount": (91, 2, (8, 0), (), "WipOffsetProfitAndLossAccount", None),
		"ZipCode": (3, 2, (8, 0), (), "ZipCode", None),
	}
	_prop_map_put_ = {
		"AddressType": ((101, LCID, 4, 0),()),
		"AllowUseTax": ((10, LCID, 4, 0),()),
		"Block": ((20, LCID, 4, 0),()),
		"BuildingFloorRoom": ((43, LCID, 4, 0),()),
		"BusinessPlaceID": ((59, LCID, 4, 0),()),
		"City": ((30, LCID, 4, 0),()),
		"CostInflationAccount": ((11, LCID, 4, 0),()),
		"CostInflationOffsetAccount": ((14, LCID, 4, 0),()),
		"CostOfGoodsSold": ((27, LCID, 4, 0),()),
		"Country": ((33, LCID, 4, 0),()),
		"County": ((44, LCID, 4, 0),()),
		"DecreaseGLAccount": ((22, LCID, 4, 0),()),
		"DecreasingAccount": ((4, LCID, 4, 0),()),
		"DropShip": ((38, LCID, 4, 0),()),
		"EUExpensesAccount": ((13, LCID, 4, 0),()),
		"EUPurchaseCreditAcc": ((61, LCID, 4, 0),()),
		"EURevenuesAccount": ((6, LCID, 4, 0),()),
		"ExchangeRateDifferencesAccount": ((35, LCID, 4, 0),()),
		"Excisable": ((69, LCID, 4, 0),()),
		"ExemptRevenuesAccount": ((25, LCID, 4, 0),()),
		"ExemptedCredits": ((65, LCID, 4, 0),()),
		"ExpenseAccount": ((21, LCID, 4, 0),()),
		"ExpenseOffsetingAct": ((47, LCID, 4, 0),()),
		"ExpensesClearingAccount": ((15, LCID, 4, 0),()),
		"FederalTaxID": ((18, LCID, 4, 0),()),
		"ForeignExpensesAccount": ((12, LCID, 4, 0),()),
		"ForeignPurchaseCreditAcc": ((62, LCID, 4, 0),()),
		"ForeignRevenuesAcc": ((42, LCID, 4, 0),()),
		"GoodsClearingAcc": ((48, LCID, 4, 0),()),
		"IncreaseGLAccount": ((34, LCID, 4, 0),()),
		"IncreasingAcc": ((46, LCID, 4, 0),()),
		"InventoryOffsetProfitAndLossAccount": ((92, LCID, 4, 0),()),
		"Location": ((19, LCID, 4, 0),()),
		"NegativeInventoryAdjustmentAccount": ((67, LCID, 4, 0),()),
		"Nettable": ((45, LCID, 4, 0),()),
		"PriceDifferencesAccount": ((31, LCID, 4, 0),()),
		"PurchaseAccount": ((5, LCID, 4, 0),()),
		"PurchaseCreditAcc": ((60, LCID, 4, 0),()),
		"PurchaseOffsetAccount": ((26, LCID, 4, 0),()),
		"PurchaseReturningAccount": ((16, LCID, 4, 0),()),
		"ReturningAccount": ((7, LCID, 4, 0),()),
		"RevenuesAccount": ((23, LCID, 4, 0),()),
		"SalesCreditAcc": ((63, LCID, 4, 0),()),
		"SalesCreditEUAcc": ((64, LCID, 4, 0),()),
		"SalesCreditForeignAcc": ((66, LCID, 4, 0),()),
		"ShippedGoodsAccount": ((8, LCID, 4, 0),()),
		"Shipper": ((104, LCID, 4, 0),()),
		"State": ((29, LCID, 4, 0),()),
		"StockAccount": ((49, LCID, 4, 0),()),
		"StockInTransitAccount": ((72, LCID, 4, 0),()),
		"StockInflationAdjustAccount": ((9, LCID, 4, 0),()),
		"StockInflationOffsetAccount": ((2, LCID, 4, 0),()),
		"Storekeeper": ((103, LCID, 4, 0),()),
		"Street": ((1, LCID, 4, 0),()),
		"StreetNo": ((102, LCID, 4, 0),()),
		"TaxGroup": ((24, LCID, 4, 0),()),
		"TransfersAcc": ((40, LCID, 4, 0),()),
		"VATInRevenueAccount": ((17, LCID, 4, 0),()),
		"VarianceAccount": ((32, LCID, 4, 0),()),
		"WHIncomingCenvatAccount": ((70, LCID, 4, 0),()),
		"WHOutgoingCenvatAccount": ((71, LCID, 4, 0),()),
		"WHShipToName": ((68, LCID, 4, 0),()),
		"WIPMaterialAccount": ((36, LCID, 4, 0),()),
		"WIPMaterialVarianceAccount": ((39, LCID, 4, 0),()),
		"WarehouseCode": ((28, LCID, 4, 0),()),
		"WarehouseName": ((37, LCID, 4, 0),()),
		"WipOffsetProfitAndLossAccount": ((91, LCID, 4, 0),()),
		"ZipCode": ((3, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IWeightMeasures(DispatchBaseClass):
	'IWeightMeasures Interface'
	CLSID = IID('{505427E7-5F80-437F-A4DD-972DA3F1C9C9}')
	coclass_clsid = IID('{701AB128-130F-4ECA-B477-EDAC4B7C875A}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, lUnitCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((3, 1),),lUnitCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"UnitCode": (10, 2, (3, 0), (), "UnitCode", None),
		"UnitDisplay": (11, 2, (8, 0), (), "UnitDisplay", None),
		"UnitName": (12, 2, (8, 0), (), "UnitName", None),
		"UnitWeightinmg": (13, 2, (5, 0), (), "UnitWeightinmg", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"UnitDisplay": ((11, LCID, 4, 0),()),
		"UnitName": ((12, LCID, 4, 0),()),
		"UnitWeightinmg": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IWithholdingTaxCodes(DispatchBaseClass):
	'IWithholdingTaxCodes Interface'
	CLSID = IID('{1B31BF62-5F56-4A20-876D-1B7BC75824C9}')
	coclass_clsid = IID('{DB78F75E-A7AB-4DEC-A2CF-62ACE2A3E27F}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrWtCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),bstrWtCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"APCessAccount": (27, 2, (8, 0), (), "APCessAccount", None),
		"APHSCAccount": (28, 2, (8, 0), (), "APHSCAccount", None),
		"APSurchargeAccount": (26, 2, (8, 0), (), "APSurchargeAccount", None),
		"APTDSAccount": (25, 2, (8, 0), (), "APTDSAccount", None),
		"ARCessAccount": (31, 2, (8, 0), (), "ARCessAccount", None),
		"ARHSCAccount": (32, 2, (8, 0), (), "ARHSCAccount", None),
		"ARSurchargeAccount": (30, 2, (8, 0), (), "ARSurchargeAccount", None),
		"ARTDSAccount": (29, 2, (8, 0), (), "ARTDSAccount", None),
		"Account": (16, 2, (8, 0), (), "Account", None),
		"Assessee": (24, 2, (3, 0), (), "Assessee", None),
		"BaseAmount": (14, 2, (5, 0), (), "BaseAmount", None),
		"BaseType": (13, 2, (3, 0), (), "BaseType", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CSTCodeIncomingID": (36, 2, (3, 0), (), "CSTCodeIncomingID", None),
		"CSTCodeOutgoingID": (37, 2, (3, 0), (), "CSTCodeOutgoingID", None),
		"Category": (12, 2, (3, 0), (), "Category", None),
		"Concessional": (23, 2, (3, 0), (), "Concessional", None),
		"Inactive": (35, 2, (3, 0), (), "Inactive", None),
		# Method 'Lines' returns object of type 'IWithholdingTaxCodes_Lines'
		"Lines": (19, 2, (9, 0), (), "Lines", '{3302B4B4-1F71-4D62-8D6E-85DEAB64B4EB}'),
		"Location": (33, 2, (3, 0), (), "Location", None),
		"NatureOfCalculationBaseCode": (38, 2, (8, 0), (), "NatureOfCalculationBaseCode", None),
		"OfficialCode": (15, 2, (8, 0), (), "OfficialCode", None),
		"ReturnType": (34, 2, (3, 0), (), "ReturnType", None),
		"RoundingType": (18, 2, (3, 0), (), "RoundingType", None),
		"Section": (20, 2, (3, 0), (), "Section", None),
		"Surcharge": (22, 2, (5, 0), (), "Surcharge", None),
		"Threshold": (21, 2, (5, 0), (), "Threshold", None),
		"TypeID": (39, 2, (3, 0), (), "TypeID", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WTCode": (10, 2, (8, 0), (), "WTCode", None),
		"WTName": (11, 2, (8, 0), (), "WTName", None),
		"WithholdingType": (17, 2, (3, 0), (), "WithholdingType", None),
	}
	_prop_map_put_ = {
		"APCessAccount": ((27, LCID, 4, 0),()),
		"APHSCAccount": ((28, LCID, 4, 0),()),
		"APSurchargeAccount": ((26, LCID, 4, 0),()),
		"APTDSAccount": ((25, LCID, 4, 0),()),
		"ARCessAccount": ((31, LCID, 4, 0),()),
		"ARHSCAccount": ((32, LCID, 4, 0),()),
		"ARSurchargeAccount": ((30, LCID, 4, 0),()),
		"ARTDSAccount": ((29, LCID, 4, 0),()),
		"Account": ((16, LCID, 4, 0),()),
		"Assessee": ((24, LCID, 4, 0),()),
		"BaseAmount": ((14, LCID, 4, 0),()),
		"BaseType": ((13, LCID, 4, 0),()),
		"CSTCodeIncomingID": ((36, LCID, 4, 0),()),
		"CSTCodeOutgoingID": ((37, LCID, 4, 0),()),
		"Category": ((12, LCID, 4, 0),()),
		"Concessional": ((23, LCID, 4, 0),()),
		"Inactive": ((35, LCID, 4, 0),()),
		"Location": ((33, LCID, 4, 0),()),
		"NatureOfCalculationBaseCode": ((38, LCID, 4, 0),()),
		"OfficialCode": ((15, LCID, 4, 0),()),
		"ReturnType": ((34, LCID, 4, 0),()),
		"RoundingType": ((18, LCID, 4, 0),()),
		"Section": ((20, LCID, 4, 0),()),
		"Surcharge": ((22, LCID, 4, 0),()),
		"Threshold": ((21, LCID, 4, 0),()),
		"TypeID": ((39, LCID, 4, 0),()),
		"WTCode": ((10, LCID, 4, 0),()),
		"WTName": ((11, LCID, 4, 0),()),
		"WithholdingType": ((17, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IWithholdingTaxCodes_Lines(DispatchBaseClass):
	'IWithholdingTaxCodes_Lines Interface'
	CLSID = IID('{3302B4B4-1F71-4D62-8D6E-85DEAB64B4EB}')
	coclass_clsid = IID('{68C30771-F870-4567-8F0A-D7E21756D2BB}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"CessRate": (9, 2, (5, 0), (), "CessRate", None),
		"Count": (3, 2, (3, 0), (), "Count", None),
		"Effectivefrom": (5, 2, (7, 0), (), "Effectivefrom", None),
		"HSCRate": (10, 2, (5, 0), (), "HSCRate", None),
		"LineNum": (11, 2, (3, 0), (), "LineNum", None),
		"Rate": (6, 2, (5, 0), (), "Rate", None),
		"SurchargeRate": (8, 2, (5, 0), (), "SurchargeRate", None),
		"TDSRate": (7, 2, (5, 0), (), "TDSRate", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (4, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
	}
	_prop_map_put_ = {
		"CessRate": ((9, LCID, 4, 0),()),
		"Effectivefrom": ((5, LCID, 4, 0),()),
		"HSCRate": ((10, LCID, 4, 0),()),
		"Rate": ((6, LCID, 4, 0),()),
		"SurchargeRate": ((8, LCID, 4, 0),()),
		"TDSRate": ((7, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(3, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IWithholdingTaxData(DispatchBaseClass):
	'IWithholdingTaxData Interface'
	CLSID = IID('{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}')
	coclass_clsid = IID('{F00B2064-7046-4E6A-9286-1284170CFA80}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseDocEntry": (23, 2, (3, 0), (), "BaseDocEntry", None),
		"BaseDocLine": (24, 2, (3, 0), (), "BaseDocLine", None),
		"BaseDocType": (25, 2, (3, 0), (), "BaseDocType", None),
		"BaseDocumentReference": (28, 2, (3, 0), (), "BaseDocumentReference", None),
		"BaseType": (13, 2, (8, 0), (), "BaseType", None),
		"Category": (12, 2, (8, 0), (), "Category", None),
		"Count": (19, 2, (3, 0), (), "Count", None),
		"Criteria": (11, 2, (8, 0), (), "Criteria", None),
		"GLAccount": (17, 2, (8, 0), (), "GLAccount", None),
		"LineNum": (22, 2, (3, 0), (), "LineNum", None),
		"Rate": (10, 2, (5, 0), (), "Rate", None),
		"RoundingType": (9, 2, (8, 0), (), "RoundingType", None),
		"Status": (29, 2, (3, 0), (), "Status", None),
		"TargetAbsEntry": (30, 2, (3, 0), (), "TargetAbsEntry", None),
		"TargetDocumentType": (31, 2, (3, 0), (), "TargetDocumentType", None),
		"TaxableAmount": (8, 2, (5, 0), (), "TaxableAmount", None),
		"TaxableAmountFC": (7, 2, (5, 0), (), "TaxableAmountFC", None),
		"TaxableAmountinSys": (6, 2, (5, 0), (), "TaxableAmountinSys", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (18, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WTAmount": (4, 2, (5, 0), (), "WTAmount", None),
		"WTAmountFC": (3, 2, (5, 0), (), "WTAmountFC", None),
		"WTAmountSys": (2, 2, (5, 0), (), "WTAmountSys", None),
		"WTCode": (1, 2, (8, 0), (), "WTCode", None),
		"WithholdingType": (5, 2, (8, 0), (), "WithholdingType", None),
	}
	_prop_map_put_ = {
		"BaseDocEntry": ((23, LCID, 4, 0),()),
		"BaseDocLine": ((24, LCID, 4, 0),()),
		"BaseDocType": ((25, LCID, 4, 0),()),
		"TaxableAmount": ((8, LCID, 4, 0),()),
		"TaxableAmountFC": ((7, LCID, 4, 0),()),
		"TaxableAmountinSys": ((6, LCID, 4, 0),()),
		"WTAmount": ((4, LCID, 4, 0),()),
		"WTAmountFC": ((3, LCID, 4, 0),()),
		"WTAmountSys": ((2, LCID, 4, 0),()),
		"WTCode": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(19, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IWithholdingTaxLines(DispatchBaseClass):
	'IWithholdingTaxLines Interface'
	CLSID = IID('{458A15A5-B980-4543-A289-F6477A36EB24}')
	coclass_clsid = IID('{95AF3307-477A-4189-A934-CC32F18264F7}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(21, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'method SetCurrentLine'
		return self._oleobj_.InvokeTypes(20, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"BaseDocEntry": (23, 2, (3, 0), (), "BaseDocEntry", None),
		"BaseDocLine": (24, 2, (3, 0), (), "BaseDocLine", None),
		"BaseDocType": (25, 2, (3, 0), (), "BaseDocType", None),
		"BaseType": (13, 2, (8, 0), (), "BaseType", None),
		"CSTCodeIncoming": (26, 2, (8, 0), (), "CSTCodeIncoming", None),
		"CSTCodeOutgoing": (27, 2, (8, 0), (), "CSTCodeOutgoing", None),
		"Category": (12, 2, (8, 0), (), "Category", None),
		"Count": (19, 2, (3, 0), (), "Count", None),
		"Criteria": (11, 2, (8, 0), (), "Criteria", None),
		"GLAccount": (17, 2, (8, 0), (), "GLAccount", None),
		"LineNum": (22, 2, (3, 0), (), "LineNum", None),
		"Rate": (10, 2, (5, 0), (), "Rate", None),
		"RoundingType": (9, 2, (8, 0), (), "RoundingType", None),
		"TaxableAmount": (8, 2, (5, 0), (), "TaxableAmount", None),
		"TaxableAmountFC": (7, 2, (5, 0), (), "TaxableAmountFC", None),
		"TaxableAmountinSys": (6, 2, (5, 0), (), "TaxableAmountinSys", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (18, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WTAmount": (4, 2, (5, 0), (), "WTAmount", None),
		"WTAmountFC": (3, 2, (5, 0), (), "WTAmountFC", None),
		"WTAmountSys": (2, 2, (5, 0), (), "WTAmountSys", None),
		"WTCode": (1, 2, (8, 0), (), "WTCode", None),
		"WithholdingType": (5, 2, (8, 0), (), "WithholdingType", None),
	}
	_prop_map_put_ = {
		"BaseDocEntry": ((23, LCID, 4, 0),()),
		"BaseDocLine": ((24, LCID, 4, 0),()),
		"BaseDocType": ((25, LCID, 4, 0),()),
		"CSTCodeIncoming": ((26, LCID, 4, 0),()),
		"CSTCodeOutgoing": ((27, LCID, 4, 0),()),
		"TaxableAmount": ((8, LCID, 4, 0),()),
		"TaxableAmountFC": ((7, LCID, 4, 0),()),
		"TaxableAmountinSys": ((6, LCID, 4, 0),()),
		"WTAmount": ((4, LCID, 4, 0),()),
		"WTAmountFC": ((3, LCID, 4, 0),()),
		"WTAmountSys": ((2, LCID, 4, 0),()),
		"WTCode": ((1, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(19, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IWizardPaymentMethods(DispatchBaseClass):
	'IWizardPaymentMethods Interface'
	CLSID = IID('{54B31C27-C3D0-41DE-89BA-5E8800D0361D}')
	coclass_clsid = IID('{B5BF5462-BCF6-49F4-925B-510460F45EFC}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(7, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		'GetAsXML'
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(3, LCID, 1, (8, 0), (),)

	def GetByKey(self, bstrCode=defaultNamedNotOptArg):
		'GetByKey'
		return self._oleobj_.InvokeTypes(6, LCID, 1, (11, 0), ((8, 1),),bstrCode
			)

	def Remove(self):
		'method Remove'
		return self._oleobj_.InvokeTypes(9, LCID, 1, (3, 0), (),)

	def SaveToFile(self, bstrFileName=defaultNamedNotOptArg):
		'SaveToFile'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), ((8, 1),),bstrFileName
			)

	def SaveXML(self, pbstrFileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(2, 1, (24, 0), ((16392, 3),), u'SaveXML', None,pbstrFileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(8, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"Accepted": (48, 2, (8, 0), (), "Accepted", None),
		"Active": (55, 2, (3, 0), (), "Active", None),
		"AgentCollection": (34, 2, (3, 0), (), "AgentCollection", None),
		"BankAccountKey": (44, 2, (3, 0), (), "BankAccountKey", None),
		"BankChargeRate": (58, 2, (5, 0), (), "BankChargeRate", None),
		"BankCountry": (27, 2, (8, 0), (), "BankCountry", None),
		"BarcodeDll": (54, 2, (8, 0), (), "BarcodeDll", None),
		"BlockForeignBank": (19, 2, (3, 0), (), "BlockForeignBank", None),
		"BlockForeignPayment": (18, 2, (3, 0), (), "BlockForeignPayment", None),
		"Branch": (30, 2, (8, 0), (), "Branch", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (4, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"CancelInstruction": (60, 2, (8, 0), (), "CancelInstruction", None),
		"CheckAddress": (15, 2, (3, 0), (), "CheckAddress", None),
		"CheckBankDetails": (16, 2, (3, 0), (), "CheckBankDetails", None),
		"CollectionAuthorizationCheck": (17, 2, (3, 0), (), "CollectionAuthorizationCheck", None),
		"CreationDate": (26, 2, (7, 0), (), "CreationDate", None),
		"CurCode": (50, 2, (8, 0), (), "CurCode", None),
		"CurrencyRestriction": (20, 2, (3, 0), (), "CurrencyRestriction", None),
		# Method 'CurrencyRestrictions' returns object of type 'ICurrencyRestrictions'
		"CurrencyRestrictions": (46, 2, (9, 0), (), "CurrencyRestrictions", '{E6144A85-69CC-4178-A0B2-BDC8BED4930E}'),
		"DebitMemo": (38, 2, (3, 0), (), "DebitMemo", None),
		"DefaultAccount": (28, 2, (8, 0), (), "DefaultAccount", None),
		"DefaultBank": (24, 2, (8, 0), (), "DefaultBank", None),
		"DepositNorm": (37, 2, (8, 0), (), "DepositNorm", None),
		"Description": (12, 2, (8, 0), (), "Description", None),
		"DocType": (47, 2, (8, 0), (), "DocType", None),
		"DueDateSelection": (41, 2, (3, 0), (), "DueDateSelection", None),
		"Format": (33, 2, (8, 0), (), "Format", None),
		"GLAccount": (29, 2, (8, 0), (), "GLAccount", None),
		"GroupByDate": (36, 2, (3, 0), (), "GroupByDate", None),
		"GroupByPaymentReference": (39, 2, (3, 0), (), "GroupByPaymentReference", None),
		"GroupInvoicesByCurrency": (57, 2, (3, 0), (), "GroupInvoicesByCurrency", None),
		"GroupInvoicesByPayToBank": (56, 2, (3, 0), (), "GroupInvoicesByPayToBank", None),
		"GroupInvoicesbyPay": (40, 2, (3, 0), (), "GroupInvoicesbyPay", None),
		"Instruction1": (51, 2, (8, 0), (), "Instruction1", None),
		"Instruction2": (52, 2, (8, 0), (), "Instruction2", None),
		"KeyCode": (31, 2, (8, 0), (), "KeyCode", None),
		"MaximumAmount": (23, 2, (5, 0), (), "MaximumAmount", None),
		"MinimumAmount": (22, 2, (5, 0), (), "MinimumAmount", None),
		"MovementCode": (62, 2, (8, 0), (), "MovementCode", None),
		"OccurenceCode": (61, 2, (8, 0), (), "OccurenceCode", None),
		"PaymentMeans": (14, 2, (3, 0), (), "PaymentMeans", None),
		"PaymentMethodCode": (11, 2, (8, 0), (), "PaymentMethodCode", None),
		"PaymentPlace": (53, 2, (8, 0), (), "PaymentPlace", None),
		"PaymentTermsCode": (42, 2, (3, 0), (), "PaymentTermsCode", None),
		"PortfolioID": (49, 2, (8, 0), (), "PortfolioID", None),
		"PostOfficeBank": (21, 2, (3, 0), (), "PostOfficeBank", None),
		"PosttoGLInterimAccount": (43, 2, (3, 0), (), "PosttoGLInterimAccount", None),
		"ReportCode": (59, 2, (8, 0), (), "ReportCode", None),
		"SendforAcceptance": (35, 2, (3, 0), (), "SendforAcceptance", None),
		"TransactionType": (32, 2, (8, 0), (), "TransactionType", None),
		"Type": (13, 2, (3, 0), (), "Type", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (5, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"UserSignature": (25, 2, (3, 0), (), "UserSignature", None),
	}
	_prop_map_put_ = {
		"Accepted": ((48, LCID, 4, 0),()),
		"Active": ((55, LCID, 4, 0),()),
		"AgentCollection": ((34, LCID, 4, 0),()),
		"BankChargeRate": ((58, LCID, 4, 0),()),
		"BankCountry": ((27, LCID, 4, 0),()),
		"BarcodeDll": ((54, LCID, 4, 0),()),
		"BlockForeignBank": ((19, LCID, 4, 0),()),
		"BlockForeignPayment": ((18, LCID, 4, 0),()),
		"CancelInstruction": ((60, LCID, 4, 0),()),
		"CheckAddress": ((15, LCID, 4, 0),()),
		"CheckBankDetails": ((16, LCID, 4, 0),()),
		"CollectionAuthorizationCheck": ((17, LCID, 4, 0),()),
		"CurCode": ((50, LCID, 4, 0),()),
		"CurrencyRestriction": ((20, LCID, 4, 0),()),
		"DebitMemo": ((38, LCID, 4, 0),()),
		"DefaultAccount": ((28, LCID, 4, 0),()),
		"DefaultBank": ((24, LCID, 4, 0),()),
		"DepositNorm": ((37, LCID, 4, 0),()),
		"Description": ((12, LCID, 4, 0),()),
		"DocType": ((47, LCID, 4, 0),()),
		"DueDateSelection": ((41, LCID, 4, 0),()),
		"Format": ((33, LCID, 4, 0),()),
		"GroupByDate": ((36, LCID, 4, 0),()),
		"GroupByPaymentReference": ((39, LCID, 4, 0),()),
		"GroupInvoicesByCurrency": ((57, LCID, 4, 0),()),
		"GroupInvoicesByPayToBank": ((56, LCID, 4, 0),()),
		"GroupInvoicesbyPay": ((40, LCID, 4, 0),()),
		"Instruction1": ((51, LCID, 4, 0),()),
		"Instruction2": ((52, LCID, 4, 0),()),
		"KeyCode": ((31, LCID, 4, 0),()),
		"MaximumAmount": ((23, LCID, 4, 0),()),
		"MinimumAmount": ((22, LCID, 4, 0),()),
		"MovementCode": ((62, LCID, 4, 0),()),
		"OccurenceCode": ((61, LCID, 4, 0),()),
		"PaymentMeans": ((14, LCID, 4, 0),()),
		"PaymentMethodCode": ((11, LCID, 4, 0),()),
		"PaymentPlace": ((53, LCID, 4, 0),()),
		"PaymentTermsCode": ((42, LCID, 4, 0),()),
		"PortfolioID": ((49, LCID, 4, 0),()),
		"PostOfficeBank": ((21, LCID, 4, 0),()),
		"PosttoGLInterimAccount": ((43, LCID, 4, 0),()),
		"ReportCode": ((59, LCID, 4, 0),()),
		"SendforAcceptance": ((35, LCID, 4, 0),()),
		"TransactionType": ((32, LCID, 4, 0),()),
		"Type": ((13, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class IWorkOrder_Lines(DispatchBaseClass):
	'IWorkOrder_Lines Interface'
	CLSID = IID('{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}')
	coclass_clsid = IID('{457F56A9-7F85-4ABF-91A4-5384A0CED40C}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (24, 0), (),)

	def SetCurrentLine(self, LineNum=defaultNamedNotOptArg):
		'Set the current line'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (24, 0), ((3, 0),),LineNum
			)

	_prop_map_get_ = {
		"ActiveAccountCode": (11, 2, (8, 0), (), "ActiveAccountCode", None),
		"Count": (2, 2, (3, 0), (), "Count", None),
		"ItemCode": (5, 2, (8, 0), (), "ItemCode", None),
		"ItemDescription": (6, 2, (8, 0), (), "ItemDescription", None),
		"ItemPrice": (8, 2, (5, 0), (), "ItemPrice", None),
		"ItemQuantity": (7, 2, (5, 0), (), "ItemQuantity", None),
		"ItemWarehouse": (10, 2, (8, 0), (), "ItemWarehouse", None),
		"PriceCurrency": (9, 2, (8, 0), (), "PriceCurrency", None),
		"RowNumber": (4, 2, (3, 0), (), "RowNumber", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (15, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WorkSum": (12, 2, (5, 0), (), "WorkSum", None),
	}
	_prop_map_put_ = {
		"ActiveAccountCode": ((11, LCID, 4, 0),()),
		"ItemCode": ((5, LCID, 4, 0),()),
		"ItemPrice": ((8, LCID, 4, 0),()),
		"ItemQuantity": ((7, LCID, 4, 0),()),
		"ItemWarehouse": ((10, LCID, 4, 0),()),
		"PriceCurrency": ((9, LCID, 4, 0),()),
		"WorkSum": ((12, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)
	#This class has Count() property - allow len(ob) to provide this
	def __len__(self):
		return self._ApplyTypes_(*(2, 2, (3, 0), (), "Count", None))
	#This class has a __len__ - this is needed so 'if object:' always returns TRUE.
	def __nonzero__(self):
		return True

class IWorkOrders(DispatchBaseClass):
	'IWorkOrders Interface'
	CLSID = IID('{7615E097-E207-4E8D-A114-74031034136B}')
	coclass_clsid = IID('{0C610415-1BAF-4B92-B485-23D9F3E5AA9E}')

	def Add(self):
		'method Add'
		return self._oleobj_.InvokeTypes(1, LCID, 1, (3, 0), (),)

	def Cancel(self):
		'method Cancel'
		return self._oleobj_.InvokeTypes(30, LCID, 1, (3, 0), (),)

	def GetAsXML(self):
		"Get the object's data in xml format."
		# Result is a Unicode object
		return self._oleobj_.InvokeTypes(34, LCID, 1, (8, 0), (),)

	def GetByKey(self, WkoKey=defaultNamedNotOptArg):
		'method GetByKey'
		return self._oleobj_.InvokeTypes(2, LCID, 1, (11, 0), ((3, 0),),WkoKey
			)

	def SaveToFile(self, FileName=defaultNamedNotOptArg):
		"Save the object's data in xml format."
		return self._oleobj_.InvokeTypes(35, LCID, 1, (24, 0), ((8, 1),),FileName
			)

	def SaveXML(self, FileName=defaultNamedNotOptArg):
		'method SaveXML'
		return self._ApplyTypes_(5, 1, (24, 0), ((16392, 3),), u'SaveXML', None,FileName
			)

	def Update(self):
		'method Update'
		return self._oleobj_.InvokeTypes(3, LCID, 1, (3, 0), (),)

	_prop_map_get_ = {
		"ActiveAccountCode": (25, 2, (8, 0), (), "ActiveAccountCode", None),
		# Method 'Browser' returns object of type 'IDataBrowser'
		"Browser": (6, 2, (9, 0), (), "Browser", '{A52E0922-634E-4827-9B4A-10D6D46ECE74}'),
		"Canceled": (9, 2, (3, 0), (), "Canceled", None),
		"Comment": (21, 2, (8, 0), (), "Comment", None),
		"ContactPerson": (23, 2, (3, 0), (), "ContactPerson", None),
		"CustomerRefNo": (17, 2, (8, 0), (), "CustomerRefNo", None),
		"ExpectedCompletionDate": (12, 2, (7, 0), (), "ExpectedCompletionDate", None),
		"FinancialPeriod": (29, 2, (3, 0), (), "FinancialPeriod", None),
		"GenerationTime": (20, 2, (7, 0), (), "GenerationTime", None),
		"InstructionNumber": (22, 2, (3, 0), (), "InstructionNumber", None),
		"JournalRemarks": (27, 2, (8, 0), (), "JournalRemarks", None),
		# Method 'Lines' returns object of type 'IWorkOrder_Lines'
		"Lines": (7, 2, (9, 0), (), "Lines", '{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}'),
		"OrderDate": (10, 2, (7, 0), (), "OrderDate", None),
		"OrderNum": (33, 2, (3, 0), (), "OrderNum", None),
		"OrderTotal": (18, 2, (5, 0), (), "OrderTotal", None),
		"OrdererCode": (15, 2, (8, 0), (), "OrdererCode", None),
		"OrdererName": (16, 2, (8, 0), (), "OrdererName", None),
		"PriceListNum": (28, 2, (3, 0), (), "PriceListNum", None),
		"ReceiverName": (14, 2, (8, 0), (), "ReceiverName", None),
		"Series": (24, 2, (3, 0), (), "Series", None),
		"Status": (8, 2, (3, 0), (), "Status", None),
		"TotalCurrency": (19, 2, (8, 0), (), "TotalCurrency", None),
		# Method 'UserFields' returns object of type 'IUserFields'
		"UserFields": (32, 2, (9, 0), (), "UserFields", '{CC279FBE-7088-42E9-A579-EB2E3E971076}'),
		"WorkFinishDate": (13, 2, (7, 0), (), "WorkFinishDate", None),
		"WorkStartDate": (11, 2, (7, 0), (), "WorkStartDate", None),
		"WorkSum": (26, 2, (5, 0), (), "WorkSum", None),
	}
	_prop_map_put_ = {
		"ActiveAccountCode": ((25, LCID, 4, 0),()),
		"Comment": ((21, LCID, 4, 0),()),
		"ContactPerson": ((23, LCID, 4, 0),()),
		"CustomerRefNo": ((17, LCID, 4, 0),()),
		"ExpectedCompletionDate": ((12, LCID, 4, 0),()),
		"GenerationTime": ((20, LCID, 4, 0),()),
		"JournalRemarks": ((27, LCID, 4, 0),()),
		"OrderDate": ((10, LCID, 4, 0),()),
		"OrdererCode": ((15, LCID, 4, 0),()),
		"OrdererName": ((16, LCID, 4, 0),()),
		"PriceListNum": ((28, LCID, 4, 0),()),
		"ReceiverName": ((14, LCID, 4, 0),()),
		"Series": ((24, LCID, 4, 0),()),
		"Status": ((8, LCID, 4, 0),()),
		"WorkFinishDate": ((13, LCID, 4, 0),()),
		"WorkStartDate": ((11, LCID, 4, 0),()),
		"WorkSum": ((26, LCID, 4, 0),()),
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class I_GenArrObj(DispatchBaseClass):
	'I_GenArrObj Interface'
	CLSID = IID('{D919D79B-2CE9-4A88-9C3D-59A67A334D81}')
	coclass_clsid = IID('{D3259ECE-289F-4B9B-9C81-AD71D8EACE67}')

	_prop_map_get_ = {
	}
	_prop_map_put_ = {
	}
	def __iter__(self):
		"Return a Python iterator for this object"
		try:
			ob = self._oleobj_.InvokeTypes(-4,LCID,3,(13, 10),())
		except pythoncom.error:
			raise TypeError("This object does not support enumeration")
		return win32com.client.util.Iterator(ob, None)

class _ICompanyEvents:
	'_ICompanyEvents Interface'
	CLSID = CLSID_Sink = IID('{57B97799-106E-4EA3-8203-1B30B6B7D463}')
	coclass_clsid = IID('{632F4591-AA62-4219-8FB6-22BCF5F60088}')
	_public_methods_ = [] # For COM Server support
	_dispid_to_func_ = {
		        1 : "OnProgressIndicator",
		}

	def __init__(self, oobj = None):
		if oobj is None:
			self._olecp = None
		else:
			import win32com.server.util
			from win32com.server.policy import EventHandlerPolicy
			cpc=oobj._oleobj_.QueryInterface(pythoncom.IID_IConnectionPointContainer)
			cp=cpc.FindConnectionPoint(self.CLSID_Sink)
			cookie=cp.Advise(win32com.server.util.wrap(self, usePolicy=EventHandlerPolicy))
			self._olecp,self._olecp_cookie = cp,cookie
	def __del__(self):
		try:
			self.close()
		except pythoncom.com_error:
			pass
	def close(self):
		if self._olecp is not None:
			cp,cookie,self._olecp,self._olecp_cookie = self._olecp,self._olecp_cookie,None,None
			cp.Unadvise(cookie)
	def _query_interface_(self, iid):
		import win32com.server.util
		if iid==self.CLSID_Sink: return win32com.server.util.wrap(self)

	# Event Handlers
	# If you create handlers, they should have the following prototypes:
#	def OnProgressIndicator(self, MaxValue=defaultNamedNotOptArg, CurrentValue=defaultNamedNotOptArg):
#		'Progress Indicator'


from win32com.client import CoClassBaseClass
# This CoClass is known by the name 'SapBobsCom.AccountCategoriesParams.88.0'
class AccountCategoriesParams(CoClassBaseClass): # A CoClass
	# AccountCategoriesParams Class
	CLSID = IID('{F20289AA-1F5D-421F-A23A-0A50FE3BBEE7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccountCategoriesParams,
	]
	default_interface = IAccountCategoriesParams

# This CoClass is known by the name 'SapBobsCom.AccountCategory.88.0'
class AccountCategory(CoClassBaseClass): # A CoClass
	# AccountCategory Class
	CLSID = IID('{B4F1CCC6-85B4-48D1-9E4D-E068CE6D681B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccountCategory,
	]
	default_interface = IAccountCategory

# This CoClass is known by the name 'SapBobsCom.AccountCategoryParams.88.0'
class AccountCategoryParams(CoClassBaseClass): # A CoClass
	# AccountCategoryParams Class
	CLSID = IID('{449F96E1-0BA8-4C26-BD2F-DB0139B6ADBA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccountCategoryParams,
	]
	default_interface = IAccountCategoryParams

# This CoClass is known by the name 'SapBobsCom.AccountCategoryService.88.0'
class AccountCategoryService(CoClassBaseClass): # A CoClass
	# AccountCategoryService Class
	CLSID = IID('{D9C8E19C-6F74-4457-BEC3-332EABE6D013}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccountCategoryService,
	]
	default_interface = IAccountCategoryService

# This CoClass is known by the name 'SapBobsCom.AccountSegmentationCategories.88.0'
class AccountSegmentationCategories(CoClassBaseClass): # A CoClass
	# AccountSegmentationCategories Class
	CLSID = IID('{6398CC93-68AB-4886-9C3A-0EAC9F5814AA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccountSegmentationCategories,
	]
	default_interface = IAccountSegmentationCategories

# This CoClass is known by the name 'SapBobsCom.AccountSegmentations.88.0'
class AccountSegmentations(CoClassBaseClass): # A CoClass
	# AccountSegmentations Class
	CLSID = IID('{1688D816-29DF-4BF3-89A8-D6312DF351AB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccountSegmentations,
	]
	default_interface = IAccountSegmentations

# This CoClass is known by the name 'SapBobsCom.AccountsService.88.0'
class AccountsService(CoClassBaseClass): # A CoClass
	# AccountsService Class
	CLSID = IID('{0104D235-3B56-47AF-ADEE-352BA7538035}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccountsService,
	]
	default_interface = IAccountsService

# This CoClass is known by the name 'SAPbobsCOM.AccrualType.88.0'
class AccrualType(CoClassBaseClass): # A CoClass
	# AccrualType Class
	CLSID = IID('{ED08E4CF-0DC1-40F4-9769-770663082515}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccrualType,
	]
	default_interface = IAccrualType

# This CoClass is known by the name 'SAPbobsCOM.AccrualTypeParams.88.0'
class AccrualTypeParams(CoClassBaseClass): # A CoClass
	# AccrualTypeParams Class
	CLSID = IID('{B1E97A7D-C850-4253-BF24-D946B20A13A3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccrualTypeParams,
	]
	default_interface = IAccrualTypeParams

# This CoClass is known by the name 'SAPbobsCOM.AccrualTypes.88.0'
class AccrualTypes(CoClassBaseClass): # A CoClass
	# AccrualTypes Class
	CLSID = IID('{03B794A4-682F-46BD-B17D-5373BEADF08D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccrualTypes,
	]
	default_interface = IAccrualTypes

# This CoClass is known by the name 'SAPbobsCOM.AccrualTypesParams.88.0'
class AccrualTypesParams(CoClassBaseClass): # A CoClass
	# AccrualTypesParams Class
	CLSID = IID('{6437CFC6-20AE-456A-8CD1-0F98D6F2CAF9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccrualTypesParams,
	]
	default_interface = IAccrualTypesParams

# This CoClass is known by the name 'SAPbobsCOM.AccrualTypesService.88.0'
class AccrualTypesService(CoClassBaseClass): # A CoClass
	# AccrualTypesService Class
	CLSID = IID('{99A581A7-0EC0-41CB-A273-D205125DB608}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAccrualTypesService,
	]
	default_interface = IAccrualTypesService

class AcctSegmnt_Categories(CoClassBaseClass): # A CoClass
	# AcctSegmnt_Categories Class
	CLSID = IID('{81735331-E9E5-4A93-9772-BA20A8027E7A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAcctSegmnt_Categories,
	]
	default_interface = IAcctSegmnt_Categories

# This CoClass is known by the name 'SAPbobsCOM.ActivitiesParams.88.0'
class ActivitiesParams(CoClassBaseClass): # A CoClass
	# ActivitiesParams Class
	CLSID = IID('{0274D5B9-311A-4D13-A665-E981B9E43491}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivitiesParams,
	]
	default_interface = IActivitiesParams

# This CoClass is known by the name 'SAPbobsCOM.ActivitiesService.88.0'
class ActivitiesService(CoClassBaseClass): # A CoClass
	# ActivitiesService Class
	CLSID = IID('{6C40800B-AFDB-4B88-947B-128F32F24EC9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivitiesService,
	]
	default_interface = IActivitiesService

# This CoClass is known by the name 'SAPbobsCOM.Activity.88.0'
class Activity(CoClassBaseClass): # A CoClass
	# Activity Class
	CLSID = IID('{5EC86D5B-840B-4676-8D5B-6154AD738D09}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivity,
	]
	default_interface = IActivity

# This CoClass is known by the name 'SAPbobsCOM.ActivityInstanceParams.88.0'
class ActivityInstanceParams(CoClassBaseClass): # A CoClass
	# ActivityInstanceParams Class
	CLSID = IID('{869F134B-E012-418A-B519-FC5CBAC4E5F4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityInstanceParams,
	]
	default_interface = IActivityInstanceParams

# This CoClass is known by the name 'SAPbobsCOM.ActivityInstancesListParams.88.0'
class ActivityInstancesListParams(CoClassBaseClass): # A CoClass
	# ActivityInstancesListParams Class
	CLSID = IID('{8D12B6FF-AA47-441C-BA2F-C02A10890DCE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityInstancesListParams,
	]
	default_interface = IActivityInstancesListParams

# This CoClass is known by the name 'SAPbobsCOM.ActivityInstancesParams.88.0'
class ActivityInstancesParams(CoClassBaseClass): # A CoClass
	# ActivityInstancesParams Class
	CLSID = IID('{90F5B36A-4621-44F8-BB72-8FC83DC756F2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityInstancesParams,
	]
	default_interface = IActivityInstancesParams

# This CoClass is known by the name 'SAPbobsCOM.ActivityLocations.1'
class ActivityLocations(CoClassBaseClass): # A CoClass
	# ActivityLocations Class
	CLSID = IID('{1FE6EEB5-6D21-4EE0-AC7C-8A2B181080C8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityLocations,
	]
	default_interface = IActivityLocations

# This CoClass is known by the name 'SAPbobsCOM.ActivityParams.88.0'
class ActivityParams(CoClassBaseClass): # A CoClass
	# ActivityParams Class
	CLSID = IID('{A7420F65-B537-47B4-870C-CE7E3D98CB29}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityParams,
	]
	default_interface = IActivityParams

# This CoClass is known by the name 'SAPbobsCOM.ActivityStatus.88.0'
class ActivityStatus(CoClassBaseClass): # A CoClass
	# ActivityStatus Class
	CLSID = IID('{07B255E1-6AF8-4615-BAC4-D258D316BF1B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityStatus,
	]
	default_interface = IActivityStatus

# This CoClass is known by the name 'SAPbobsCOM.ActivityTypes.1'
class ActivityTypes(CoClassBaseClass): # A CoClass
	# ActivityTypes Class
	CLSID = IID('{094BA05B-B730-4D86-8BCF-91F788C16057}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IActivityTypes,
	]
	default_interface = IActivityTypes

# This CoClass is known by the name 'SAPbobsCOM.AdditionalExpenses.88.0'
class AdditionalExpenses(CoClassBaseClass): # A CoClass
	# AdditionalExpenses Class
	CLSID = IID('{F68150E3-371A-4D4F-990C-16CDFF1A04FA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAdditionalExpenses,
	]
	default_interface = IAdditionalExpenses

# This CoClass is known by the name 'SAPbobsCOM.AddressExtension.88.0'
class AddressExtension(CoClassBaseClass): # A CoClass
	# AddressExtension Class
	CLSID = IID('{8FDEBBA0-2EDA-4AFE-9EC1-3A45913C68DA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAddressExtension,
	]
	default_interface = IAddressExtension

# This CoClass is known by the name 'SapBobsCom.AdminInfo.88.0'
class AdminInfo(CoClassBaseClass): # A CoClass
	# AdminInfo Class
	CLSID = IID('{16521FC3-2B92-47B4-89E1-3145EE333649}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAdminInfo,
	]
	default_interface = IAdminInfo

# This CoClass is known by the name 'SapBobsCom.AlertManagement.88.0'
class AlertManagement(CoClassBaseClass): # A CoClass
	# AlertManagement Class
	CLSID = IID('{B52CCF14-E084-48A9-AE48-2E1B38CAD704}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlertManagement,
	]
	default_interface = IAlertManagement

# This CoClass is known by the name 'SapBobsCom.AlertManagementDocument.88.0'
class AlertManagementDocument(CoClassBaseClass): # A CoClass
	# AlertManagementDocument Class
	CLSID = IID('{2FA0FB01-DCC0-436C-8677-44654831D6E6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlertManagementDocument,
	]
	default_interface = IAlertManagementDocument

# This CoClass is known by the name 'SapBobsCom.AlertManagementDocuments.88.0'
class AlertManagementDocuments(CoClassBaseClass): # A CoClass
	# AlertManagementDocuments Class
	CLSID = IID('{453C97AF-4491-4776-A6BA-52F8739A96D9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlertManagementDocuments,
	]
	default_interface = IAlertManagementDocuments

# This CoClass is known by the name 'SapBobsCom.AlertManagementParams.88.0'
class AlertManagementParams(CoClassBaseClass): # A CoClass
	# AlertManagementParams Class
	CLSID = IID('{6D6214D8-5ABD-4DAD-9F9C-E2F69EFEBA8D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlertManagementParams,
	]
	default_interface = IAlertManagementParams

# This CoClass is known by the name 'SapBobsCom.AlertManagementParamsCollection.88.0'
class AlertManagementParamsCollection(CoClassBaseClass): # A CoClass
	# AlertManagementParamsCollection Class
	CLSID = IID('{7DB5BDE8-AC90-4159-8B34-33A41A886FCE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlertManagementParamsCollection,
	]
	default_interface = IAlertManagementParamsCollection

# This CoClass is known by the name 'SapBobsCom.AlertManagementRecipient.88.0'
class AlertManagementRecipient(CoClassBaseClass): # A CoClass
	# AlertManagementRecipient Class
	CLSID = IID('{F59180EC-0D39-40F6-894E-3444F552732D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlertManagementRecipient,
	]
	default_interface = IAlertManagementRecipient

# This CoClass is known by the name 'SapBobsCom.AlertManagementRecipients.88.0'
class AlertManagementRecipients(CoClassBaseClass): # A CoClass
	# AlertManagementRecipients Class
	CLSID = IID('{4701FCE6-F62A-47EC-BF1A-FA9894901984}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlertManagementRecipients,
	]
	default_interface = IAlertManagementRecipients

# This CoClass is known by the name 'SapBobsCom.AlertManagementService.88.0'
class AlertManagementService(CoClassBaseClass): # A CoClass
	# AlertManagementService Class
	CLSID = IID('{4EF2A7BE-CB39-473A-977B-C2AAE73210AF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlertManagementService,
	]
	default_interface = IAlertManagementService

# This CoClass is known by the name 'SAPbobsCOM.AlternateCatNum.88.0'
class AlternateCatNum(CoClassBaseClass): # A CoClass
	# AlternateCatNum Class
	CLSID = IID('{BBC625E2-17DA-4434-83D6-56FE0401D9A6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlternateCatNum,
	]
	default_interface = IAlternateCatNum

# This CoClass is known by the name 'SapBobsCom.AlternativeItem.88.0'
class AlternativeItem(CoClassBaseClass): # A CoClass
	# AlternativeItem Class
	CLSID = IID('{35CF9AB5-A66B-46EC-805A-E5192414BD4A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlternativeItem,
	]
	default_interface = IAlternativeItem

# This CoClass is known by the name 'SapBobsCom.AlternativeItems.88.0'
class AlternativeItems(CoClassBaseClass): # A CoClass
	# AlternativeItems Class
	CLSID = IID('{FFDDAD10-AEC3-4717-B909-2C409EA9859E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlternativeItems,
	]
	default_interface = IAlternativeItems

# This CoClass is known by the name 'SapBobsCom.AlternativeItemsService.88.0'
class AlternativeItemsService(CoClassBaseClass): # A CoClass
	# AlternativeItemsService Class
	CLSID = IID('{1CFBF8AA-ED92-4452-9DBE-4E8BCA68731C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAlternativeItemsService,
	]
	default_interface = IAlternativeItemsService

# This CoClass is known by the name 'SAPbobsCOM.ApprovalRequest.88.0'
class ApprovalRequest(CoClassBaseClass): # A CoClass
	# ApprovalRequest Class
	CLSID = IID('{7F873201-71DD-4678-AFEB-8EB4D0ED45A4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalRequest,
	]
	default_interface = IApprovalRequest

# This CoClass is known by the name 'SAPbobsCOM.ApprovalRequestDecision.88.0'
class ApprovalRequestDecision(CoClassBaseClass): # A CoClass
	# ApprovalRequestDecision Class
	CLSID = IID('{FAB3EB8B-22A5-4530-908D-9ADBBD88774D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalRequestDecision,
	]
	default_interface = IApprovalRequestDecision

# This CoClass is known by the name 'SAPbobsCOM.ApprovalRequestDecisions.88.0'
class ApprovalRequestDecisions(CoClassBaseClass): # A CoClass
	# ApprovalRequestDecisions Class
	CLSID = IID('{297C40ED-92B6-4DB9-9304-CF9350F3FE8C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalRequestDecisions,
	]
	default_interface = IApprovalRequestDecisions

# This CoClass is known by the name 'SAPbobsCOM.ApprovalRequestLine.88.0'
class ApprovalRequestLine(CoClassBaseClass): # A CoClass
	# ApprovalRequestLine Class
	CLSID = IID('{2704D884-C30C-42FF-8D33-D1D7E3FE039A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalRequestLine,
	]
	default_interface = IApprovalRequestLine

# This CoClass is known by the name 'SAPbobsCOM.ApprovalRequestLines.88.0'
class ApprovalRequestLines(CoClassBaseClass): # A CoClass
	# ApprovalRequestLines Class
	CLSID = IID('{FD7AA643-4DD4-4E5C-AC36-C0B782A6A3E4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalRequestLines,
	]
	default_interface = IApprovalRequestLines

# This CoClass is known by the name 'SAPbobsCOM.ApprovalRequestParams.88.0'
class ApprovalRequestParams(CoClassBaseClass): # A CoClass
	# ApprovalRequestParams Class
	CLSID = IID('{BD849811-3C0D-4850-8E56-26C12823E15C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalRequestParams,
	]
	default_interface = IApprovalRequestParams

# This CoClass is known by the name 'SAPbobsCOM.ApprovalRequestsParams.88.0'
class ApprovalRequestsParams(CoClassBaseClass): # A CoClass
	# ApprovalRequestsParams Class
	CLSID = IID('{FB0CD2F1-E744-4CC6-8D1C-9A9ED9F533F1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalRequestsParams,
	]
	default_interface = IApprovalRequestsParams

# This CoClass is known by the name 'SAPbobsCOM.ApprovalRequestsService.88.0'
class ApprovalRequestsService(CoClassBaseClass): # A CoClass
	# ApprovalRequestsService Class
	CLSID = IID('{FA50FE8D-9DFF-44CD-A0D2-6FE8315B2393}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalRequestsService,
	]
	default_interface = IApprovalRequestsService

# This CoClass is known by the name 'SapBobsCom.ApprovalStage.88.0'
class ApprovalStage(CoClassBaseClass): # A CoClass
	# ApprovalStage Class
	CLSID = IID('{2DC337EF-DA9D-4A0B-AA09-34795D4CA674}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalStage,
	]
	default_interface = IApprovalStage

# This CoClass is known by the name 'SapBobsCom.ApprovalStageApprover.88.0'
class ApprovalStageApprover(CoClassBaseClass): # A CoClass
	# ApprovalStageApprover Class
	CLSID = IID('{DC399818-11FD-4FC3-A46C-B9A3F35E5CD1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalStageApprover,
	]
	default_interface = IApprovalStageApprover

# This CoClass is known by the name 'SapBobsCom.ApprovalStageApprovers.88.0'
class ApprovalStageApprovers(CoClassBaseClass): # A CoClass
	# ApprovalStageApprovers Class
	CLSID = IID('{1BB54C50-66D7-4907-807C-92F58119C21D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalStageApprovers,
	]
	default_interface = IApprovalStageApprovers

# This CoClass is known by the name 'SapBobsCom.ApprovalStageParams.88.0'
class ApprovalStageParams(CoClassBaseClass): # A CoClass
	# ApprovalStageParams Class
	CLSID = IID('{6410A92E-B2C4-432B-B421-01FDD7835CEF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalStageParams,
	]
	default_interface = IApprovalStageParams

# This CoClass is known by the name 'SapBobsCom.ApprovalStages.88.0'
class ApprovalStages(CoClassBaseClass): # A CoClass
	# ApprovalStages Class
	CLSID = IID('{A0B0F43B-427F-4744-ABD3-0684090D3470}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalStages,
	]
	default_interface = IApprovalStages

# This CoClass is known by the name 'SapBobsCom.ApprovalStagesParams.88.0'
class ApprovalStagesParams(CoClassBaseClass): # A CoClass
	# ApprovalStagesParams Class
	CLSID = IID('{E07E71EA-0DEF-4990-A99D-C6B7407995C9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalStagesParams,
	]
	default_interface = IApprovalStagesParams

# This CoClass is known by the name 'SapBobsCom.ApprovalStagesService.88.0'
class ApprovalStagesService(CoClassBaseClass): # A CoClass
	# ApprovalStagesService Class
	CLSID = IID('{4DEFA778-37C3-4F67-9EF9-2675EEE468F8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalStagesService,
	]
	default_interface = IApprovalStagesService

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplate.88.0'
class ApprovalTemplate(CoClassBaseClass): # A CoClass
	# ApprovalTemplate Class
	CLSID = IID('{E0718E09-A6F5-4221-84C5-EB8A28F4F741}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplate,
	]
	default_interface = IApprovalTemplate

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateDocument.88.0'
class ApprovalTemplateDocument(CoClassBaseClass): # A CoClass
	# ApprovalTemplateDocument Class
	CLSID = IID('{10449DDE-FB95-4E0E-B699-D13949A808CF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateDocument,
	]
	default_interface = IApprovalTemplateDocument

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateDocuments.88.0'
class ApprovalTemplateDocuments(CoClassBaseClass): # A CoClass
	# ApprovalTemplateDocuments Class
	CLSID = IID('{F44DCA1A-C2B4-4CD3-9536-1471ADBA10E0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateDocuments,
	]
	default_interface = IApprovalTemplateDocuments

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateParams.88.0'
class ApprovalTemplateParams(CoClassBaseClass): # A CoClass
	# ApprovalTemplateParams Class
	CLSID = IID('{56AE7782-A205-4EBB-ADFD-FE4CE27B9201}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateParams,
	]
	default_interface = IApprovalTemplateParams

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateQueries.88.0'
class ApprovalTemplateQueries(CoClassBaseClass): # A CoClass
	# ApprovalTemplateQueries Class
	CLSID = IID('{3B62767B-45B8-4997-B249-F989A0C4AB8E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateQueries,
	]
	default_interface = IApprovalTemplateQueries

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateQuery.88.0'
class ApprovalTemplateQuery(CoClassBaseClass): # A CoClass
	# ApprovalTemplateQuery Class
	CLSID = IID('{46CBA2F6-0319-4C81-8D08-407EB184F732}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateQuery,
	]
	default_interface = IApprovalTemplateQuery

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateStage.88.0'
class ApprovalTemplateStage(CoClassBaseClass): # A CoClass
	# ApprovalTemplateStage Class
	CLSID = IID('{F72514BA-4388-4D35-821A-CF58DA7F7C10}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateStage,
	]
	default_interface = IApprovalTemplateStage

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateStages.88.0'
class ApprovalTemplateStages(CoClassBaseClass): # A CoClass
	# ApprovalTemplateStages Class
	CLSID = IID('{7649AEBB-4217-4944-9DC2-1426C38113C7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateStages,
	]
	default_interface = IApprovalTemplateStages

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateTerm.88.0'
class ApprovalTemplateTerm(CoClassBaseClass): # A CoClass
	# ApprovalTemplateTerm Class
	CLSID = IID('{AA803CCD-C262-45A7-B9C6-FC034D4938CE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateTerm,
	]
	default_interface = IApprovalTemplateTerm

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateTerms.88.0'
class ApprovalTemplateTerms(CoClassBaseClass): # A CoClass
	# ApprovalTemplateTerms Class
	CLSID = IID('{B9DE72FD-C04A-4585-9850-73B6E3E58ADB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateTerms,
	]
	default_interface = IApprovalTemplateTerms

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateUser.88.0'
class ApprovalTemplateUser(CoClassBaseClass): # A CoClass
	# ApprovalTemplateUser Class
	CLSID = IID('{C636E409-2B25-451B-90CE-B34F4C700180}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateUser,
	]
	default_interface = IApprovalTemplateUser

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplateUsers.88.0'
class ApprovalTemplateUsers(CoClassBaseClass): # A CoClass
	# ApprovalTemplateUsers Class
	CLSID = IID('{EE8E76CB-5ABF-4220-B5A9-DC11A34F042F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplateUsers,
	]
	default_interface = IApprovalTemplateUsers

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplates.88.0'
class ApprovalTemplates(CoClassBaseClass): # A CoClass
	# ApprovalTemplates Class
	CLSID = IID('{AA5DB4F6-0C6C-4453-B5C5-EC21CBC719A7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplates,
	]
	default_interface = IApprovalTemplates

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplatesParams.88.0'
class ApprovalTemplatesParams(CoClassBaseClass): # A CoClass
	# ApprovalTemplatesParams Class
	CLSID = IID('{3984330B-A277-496F-9926-EBAA43351154}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplatesParams,
	]
	default_interface = IApprovalTemplatesParams

# This CoClass is known by the name 'SapBobsCom.ApprovalTemplatesService.88.0'
class ApprovalTemplatesService(CoClassBaseClass): # A CoClass
	# ApprovalTemplatesService Class
	CLSID = IID('{E4B8D471-9672-41D7-B340-E8DF455FE90D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IApprovalTemplatesService,
	]
	default_interface = IApprovalTemplatesService

# This CoClass is known by the name 'SAPbobsCOM.Attachment.88.0'
class Attachment(CoClassBaseClass): # A CoClass
	# Attachment Class
	CLSID = IID('{054C0B23-FE27-46A4-990C-901A4906BEB5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAttachment,
	]
	default_interface = IAttachment

# This CoClass is known by the name 'SAPbobsCOM.Attachments.88.0'
class Attachments(CoClassBaseClass): # A CoClass
	# Attachments Class
	CLSID = IID('{3C447394-4D07-46E5-8ADE-0E5973F97CF7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAttachments,
	]
	default_interface = IAttachments

# This CoClass is known by the name 'SapBobsCom.Attachments2.88.0'
class Attachments2(CoClassBaseClass): # A CoClass
	# Attachments2 Class
	CLSID = IID('{3AFC5084-1838-4196-BAEF-7C16635E8068}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAttachments2,
	]
	default_interface = IAttachments2

# This CoClass is known by the name 'SapBobsCom.Attachments2_Lines.88.0'
class Attachments2_Lines(CoClassBaseClass): # A CoClass
	# Attachments2_Lines Class
	CLSID = IID('{AE9073B1-59FF-423E-B562-BEFE747D2D5C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IAttachments2_Lines,
	]
	default_interface = IAttachments2_Lines

# This CoClass is known by the name 'SapBobsCom.BOEDocumentType.88.0'
class BOEDocumentType(CoClassBaseClass): # A CoClass
	# BOEDocumentType Class
	CLSID = IID('{5D08DA01-1E53-4A29-BDCC-5CE3FDFEC343}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEDocumentType,
	]
	default_interface = IBOEDocumentType

# This CoClass is known by the name 'SapBobsCom.BOEDocumentTypeParams.88.0'
class BOEDocumentTypeParams(CoClassBaseClass): # A CoClass
	# BOEDocumentTypeParams Class
	CLSID = IID('{4B445959-4085-4FCE-8832-58AD489D81D1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEDocumentTypeParams,
	]
	default_interface = IBOEDocumentTypeParams

# This CoClass is known by the name 'SapBobsCom.BOEDocumentTypes.88.0'
class BOEDocumentTypes(CoClassBaseClass): # A CoClass
	# BOEDocumentTypes Class
	CLSID = IID('{1DB2C7ED-919B-49BA-9A7F-35E9F3262C3E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEDocumentTypes,
	]
	default_interface = IBOEDocumentTypes

# This CoClass is known by the name 'SapBobsCom.BOEDocumentTypesParams.88.0'
class BOEDocumentTypesParams(CoClassBaseClass): # A CoClass
	# BOEDocumentTypesParams Class
	CLSID = IID('{F7CB66FA-3F53-4B0F-818C-259C599CFE15}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEDocumentTypesParams,
	]
	default_interface = IBOEDocumentTypesParams

# This CoClass is known by the name 'SapBobsCom.BOEDocumentTypesService.88.0'
class BOEDocumentTypesService(CoClassBaseClass): # A CoClass
	# BOEDocumentTypesService Class
	CLSID = IID('{302CB444-8F72-40F4-A8A7-457500892805}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEDocumentTypesService,
	]
	default_interface = IBOEDocumentTypesService

# This CoClass is known by the name 'SapBobsCom.BOEInstruction.88.0'
class BOEInstruction(CoClassBaseClass): # A CoClass
	# BOEInstruction Class
	CLSID = IID('{A3029CAF-054C-4339-ADDD-87F60B113023}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEInstruction,
	]
	default_interface = IBOEInstruction

# This CoClass is known by the name 'SapBobsCom.BOEInstructionParams.88.0'
class BOEInstructionParams(CoClassBaseClass): # A CoClass
	# BOEInstructionParams Class
	CLSID = IID('{A9C6DFCF-1FFD-46AF-89FC-5618ECAF2441}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEInstructionParams,
	]
	default_interface = IBOEInstructionParams

# This CoClass is known by the name 'SapBobsCom.BOEInstructions.88.0'
class BOEInstructions(CoClassBaseClass): # A CoClass
	# BOEInstructions Class
	CLSID = IID('{FD7ECEE2-5FA5-4054-9769-B86A8096D9BA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEInstructions,
	]
	default_interface = IBOEInstructions

# This CoClass is known by the name 'SapBobsCom.BOEInstructionsParams.88.0'
class BOEInstructionsParams(CoClassBaseClass): # A CoClass
	# BOEInstructionsParams Class
	CLSID = IID('{82C004A0-40F6-460F-8581-E34747E9CF01}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEInstructionsParams,
	]
	default_interface = IBOEInstructionsParams

# This CoClass is known by the name 'SapBobsCom.BOEInstructionsService.88.0'
class BOEInstructionsService(CoClassBaseClass): # A CoClass
	# BOEInstructionsService Class
	CLSID = IID('{EC78D9AA-6CA6-427C-9D33-38A4EAD168AB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEInstructionsService,
	]
	default_interface = IBOEInstructionsService

# This CoClass is known by the name 'SAPbobsCOM.BOELine.88.0'
class BOELine(CoClassBaseClass): # A CoClass
	# BOELine Class
	CLSID = IID('{F6E76C2D-0F98-4358-B0F3-BE632E6CC9F7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOELine,
	]
	default_interface = IBOELine

# This CoClass is known by the name 'SAPbobsCOM.BOELineParams.88.0'
class BOELineParams(CoClassBaseClass): # A CoClass
	# BOELineParams Class
	CLSID = IID('{F0070DD3-7081-46DD-A17E-0DCAF223D213}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOELineParams,
	]
	default_interface = IBOELineParams

# This CoClass is known by the name 'SAPbobsCOM.BOELines.88.0'
class BOELines(CoClassBaseClass): # A CoClass
	# BOELines Class
	CLSID = IID('{969FE83E-F0A8-47E9-811E-C8B03F67253A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOELines,
	]
	default_interface = IBOELines

# This CoClass is known by the name 'SAPbobsCOM.BOELinesParams.88.0'
class BOELinesParams(CoClassBaseClass): # A CoClass
	# BOELinesParams Class
	CLSID = IID('{2FC28FB9-7376-41BE-9CCE-50FCB69D8ECF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOELinesParams,
	]
	default_interface = IBOELinesParams

# This CoClass is known by the name 'SAPbobsCOM.BOELinesService.88.0'
class BOELinesService(CoClassBaseClass): # A CoClass
	# BOELinesService Class
	CLSID = IID('{C0E3FD16-7EC1-462F-BF9E-5524665C2E22}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOELinesService,
	]
	default_interface = IBOELinesService

# This CoClass is known by the name 'SapBobsCom.BOEPortfolio.88.0'
class BOEPortfolio(CoClassBaseClass): # A CoClass
	# BOEPortfolio Class
	CLSID = IID('{DFED3449-35B2-4A0A-B789-20EE627AE347}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEPortfolio,
	]
	default_interface = IBOEPortfolio

# This CoClass is known by the name 'SapBobsCom.BOEPortfolioParams.88.0'
class BOEPortfolioParams(CoClassBaseClass): # A CoClass
	# BOEPortfolioParams Class
	CLSID = IID('{5016BA26-6D6D-47B7-9B13-558EC0B1B916}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEPortfolioParams,
	]
	default_interface = IBOEPortfolioParams

# This CoClass is known by the name 'SapBobsCom.BOEPortfolios.88.0'
class BOEPortfolios(CoClassBaseClass): # A CoClass
	# BOEPortfolios Class
	CLSID = IID('{CDF64DE9-D2B8-4180-983C-457ABAA5EFB1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEPortfolios,
	]
	default_interface = IBOEPortfolios

# This CoClass is known by the name 'SapBobsCom.BOEPortfoliosParams.88.0'
class BOEPortfoliosParams(CoClassBaseClass): # A CoClass
	# BOEPortfoliosParams Class
	CLSID = IID('{2760F015-04C7-40D5-88DD-499BFD8B6CD1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEPortfoliosParams,
	]
	default_interface = IBOEPortfoliosParams

# This CoClass is known by the name 'SapBobsCom.BOEPortfoliosService.88.0'
class BOEPortfoliosService(CoClassBaseClass): # A CoClass
	# BOEPortfoliosService Class
	CLSID = IID('{877ACA0D-FA03-41F8-8B84-E4090B053532}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBOEPortfoliosService,
	]
	default_interface = IBOEPortfoliosService

# This CoClass is known by the name 'SAPbobsCOM.BPAccountReceivablePayble.88.0'
class BPAccountReceivablePayble(CoClassBaseClass): # A CoClass
	# BPAccountReceivablePayble Class
	CLSID = IID('{2795C6A1-A943-411B-BE58-A062A0E4711A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPAccountReceivablePayble,
	]
	default_interface = IBPAccountReceivablePayble

# This CoClass is known by the name 'SAPbobsCOM.BPAddresses.88.0'
class BPAddresses(CoClassBaseClass): # A CoClass
	# BPAddresses Class
	CLSID = IID('{1520690D-0D25-415A-B290-66DF277561FE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPAddresses,
	]
	default_interface = IBPAddresses

# This CoClass is known by the name 'SAPbobsCOM.BPBankAccounts.88.0'
class BPBankAccounts(CoClassBaseClass): # A CoClass
	# BPBankAccounts Class
	CLSID = IID('{0C9CE0A9-AA16-4C81-A474-9D960E735AA5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPBankAccounts,
	]
	default_interface = IBPBankAccounts

class BPBranchAssignment(CoClassBaseClass): # A CoClass
	# BPBranchAssignment Class
	CLSID = IID('{FC23201F-196D-40E5-A3CA-C8DA72FC63B2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPBranchAssignment,
	]
	default_interface = IBPBranchAssignment

# This CoClass is known by the name 'SapBobsCom.BPCode.88.0'
class BPCode(CoClassBaseClass): # A CoClass
	# BPCode Class
	CLSID = IID('{3026EE2A-44C8-433C-AE19-0C9EBD1C6285}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPCode,
	]
	default_interface = IBPCode

# This CoClass is known by the name 'SapBobsCom.BPCodes.88.0'
class BPCodes(CoClassBaseClass): # A CoClass
	# BPCodes Class
	CLSID = IID('{CB6DE5B7-50B1-4068-A778-CD08EEA34DC4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPCodes,
	]
	default_interface = IBPCodes

# This CoClass is known by the name 'SapBobsCom.BPFiscalRegistryID.88.0'
class BPFiscalRegistryID(CoClassBaseClass): # A CoClass
	# BPFiscalRegistryID Class
	CLSID = IID('{F2BCB557-408E-4D6C-B46D-7E5517D939B2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPFiscalRegistryID,
	]
	default_interface = IBPFiscalRegistryID

# This CoClass is known by the name 'SapBobsCom.BPFiscalTaxID.88.0'
class BPFiscalTaxID(CoClassBaseClass): # A CoClass
	# BPFiscalTaxID Class
	CLSID = IID('{578B1918-60ED-440F-9729-7C59AEE459E8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPFiscalTaxID,
	]
	default_interface = IBPFiscalTaxID

# This CoClass is known by the name 'SAPbobsCOM.BPPaymentDates.88.0'
class BPPaymentDates(CoClassBaseClass): # A CoClass
	# BPPaymentDates Class
	CLSID = IID('{727B34C7-DD01-4B31-9213-F5B02C5E3276}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPPaymentDates,
	]
	default_interface = IBPPaymentDates

# This CoClass is known by the name 'SAPbobsCOM.BPPaymentMethods.88.0'
class BPPaymentMethods(CoClassBaseClass): # A CoClass
	# BPPaymentMethods Class
	CLSID = IID('{9091A78F-FCC8-4399-88F3-53E1631F100F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPPaymentMethods,
	]
	default_interface = IBPPaymentMethods

# This CoClass is known by the name 'SapBobsCom.BPPriorities.88.0'
class BPPriorities(CoClassBaseClass): # A CoClass
	# BPPriorities Class
	CLSID = IID('{3A1E1C0F-EEA6-43A5-893C-280A50D37410}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPPriorities,
	]
	default_interface = IBPPriorities

# This CoClass is known by the name 'SAPbobsCOM.BPWithholdingTax.88.0'
class BPWithholdingTax(CoClassBaseClass): # A CoClass
	# BPWithholdingTax Class
	CLSID = IID('{740243E4-B946-4D50-94D9-7F7E3EC04FE9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBPWithholdingTax,
	]
	default_interface = IBPWithholdingTax

# This CoClass is known by the name 'SAPbobsCOM.BankChargesAllocationCode.88.0'
class BankChargesAllocationCode(CoClassBaseClass): # A CoClass
	# BankChargesAllocationCode Class
	CLSID = IID('{D7CA14AD-9A60-48D8-857B-441F3102B1AC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankChargesAllocationCode,
	]
	default_interface = IBankChargesAllocationCode

# This CoClass is known by the name 'SAPbobsCOM.BankChargesAllocationCodeParams.88.0'
class BankChargesAllocationCodeParams(CoClassBaseClass): # A CoClass
	# BankChargesAllocationCodeParams Class
	CLSID = IID('{BACE2904-08D9-41F7-A963-FA3E550D9BF9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankChargesAllocationCodeParams,
	]
	default_interface = IBankChargesAllocationCodeParams

# This CoClass is known by the name 'SAPbobsCOM.BankChargesAllocationCodesParams.88.0'
class BankChargesAllocationCodesParams(CoClassBaseClass): # A CoClass
	# BankChargesAllocationCodesParams Class
	CLSID = IID('{4B310591-7DB5-48EE-BB34-A2F954D41897}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankChargesAllocationCodesParams,
	]
	default_interface = IBankChargesAllocationCodesParams

# This CoClass is known by the name 'SAPbobsCOM.BankChargesAllocationCodesService.88.0'
class BankChargesAllocationCodesService(CoClassBaseClass): # A CoClass
	# BankChargesAllocationCodesService Class
	CLSID = IID('{1CBABC7A-347F-48EA-A6F6-FCA17C04A159}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankChargesAllocationCodesService,
	]
	default_interface = IBankChargesAllocationCodesService

class BankPages(CoClassBaseClass): # A CoClass
	# BankPages Class
	CLSID = IID('{842BE793-D5A4-4C52-B7C1-99E189D39B8D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankPages,
	]
	default_interface = IBankPages

# This CoClass is known by the name 'SapBobsCom.BankStatement.88.0'
class BankStatement(CoClassBaseClass): # A CoClass
	# BankStatement Class
	CLSID = IID('{D68B336E-19AF-4033-8308-BA6A03D3C535}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankStatement,
	]
	default_interface = IBankStatement

# This CoClass is known by the name 'SapBobsCom.BankStatementParams.88.0'
class BankStatementParams(CoClassBaseClass): # A CoClass
	# BankStatementParams Class
	CLSID = IID('{DAB0264E-58F1-4024-BA03-EE55FE4BB12E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankStatementParams,
	]
	default_interface = IBankStatementParams

# This CoClass is known by the name 'SapBobsCom.BankStatementRow.88.0'
class BankStatementRow(CoClassBaseClass): # A CoClass
	# BankStatementRow Class
	CLSID = IID('{5BD5C9AB-52F6-411E-992F-1D507D70F6C1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankStatementRow,
	]
	default_interface = IBankStatementRow

# This CoClass is known by the name 'SapBobsCom.BankStatementRows.88.0'
class BankStatementRows(CoClassBaseClass): # A CoClass
	# BankStatementRows Class
	CLSID = IID('{19A76A7C-7D0A-43FB-B70C-2338FCAA6453}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankStatementRows,
	]
	default_interface = IBankStatementRows

# This CoClass is known by the name 'SapBobsCom.BankStatements.88.0'
class BankStatements(CoClassBaseClass): # A CoClass
	# BankStatements Class
	CLSID = IID('{1D2BD23C-C2FC-447C-B63E-4D4A321ECEED}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankStatements,
	]
	default_interface = IBankStatements

# This CoClass is known by the name 'SapBobsCom.BankStatementsFilter.88.0'
class BankStatementsFilter(CoClassBaseClass): # A CoClass
	# BankStatementsFilter Class
	CLSID = IID('{B6D42A3B-BAEB-4A65-BA49-E5A89BC8EAFA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankStatementsFilter,
	]
	default_interface = IBankStatementsFilter

# This CoClass is known by the name 'SapBobsCom.BankStatementsImportFile.88.0'
class BankStatementsImportFile(CoClassBaseClass): # A CoClass
	# BankStatementsImportFile Class
	CLSID = IID('{24323C3C-1853-425E-96F9-1D441B2D462F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankStatementsImportFile,
	]
	default_interface = IBankStatementsImportFile

# This CoClass is known by the name 'SapBobsCom.BankStatementsParams.88.0'
class BankStatementsParams(CoClassBaseClass): # A CoClass
	# BankStatementsParams Class
	CLSID = IID('{02FD29A2-2B9E-4D9E-936C-5DE5A115C180}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankStatementsParams,
	]
	default_interface = IBankStatementsParams

# This CoClass is known by the name 'SapBobsCom.BankStatementsService.88.0'
class BankStatementsService(CoClassBaseClass): # A CoClass
	# BankStatementsService Class
	CLSID = IID('{8EBC49BF-EDA5-4B08-B93A-5B4A81045176}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBankStatementsService,
	]
	default_interface = IBankStatementsService

# This CoClass is known by the name 'SapBobsCom.Banks.88.0'
class Banks(CoClassBaseClass): # A CoClass
	# Banks Class
	CLSID = IID('{24AD49CD-DD3F-42CB-B745-5D6329BD0EDA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBanks,
	]
	default_interface = IBanks

# This CoClass is known by the name 'SAPbobsCOM.BatchNumberDetail.88.0'
class BatchNumberDetail(CoClassBaseClass): # A CoClass
	# BatchNumberDetail Class
	CLSID = IID('{D8FB6CAE-94FF-49EB-9B87-0FDDAAA8C165}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBatchNumberDetail,
	]
	default_interface = IBatchNumberDetail

# This CoClass is known by the name 'SAPbobsCOM.BatchNumberDetailParams.88.0'
class BatchNumberDetailParams(CoClassBaseClass): # A CoClass
	# BatchNumberDetailParams Class
	CLSID = IID('{0362FE87-4255-455E-A6C8-A356C252767B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBatchNumberDetailParams,
	]
	default_interface = IBatchNumberDetailParams

# This CoClass is known by the name 'SAPbobsCOM.BatchNumberDetailsService.88.0'
class BatchNumberDetailsService(CoClassBaseClass): # A CoClass
	# BatchNumberDetailsService Class
	CLSID = IID('{60469EFE-3F0E-4B28-B387-6F6ADFB367DF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBatchNumberDetailsService,
	]
	default_interface = IBatchNumberDetailsService

# This CoClass is known by the name 'SAPbobsCOM.BatchNumbers.88.0'
class BatchNumbers(CoClassBaseClass): # A CoClass
	# BatchNumbers Class
	CLSID = IID('{41172218-C619-4E35-9D03-59EAF1E0F300}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBatchNumbers,
	]
	default_interface = IBatchNumbers

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchange.88.0'
class BillOfExchange(CoClassBaseClass): # A CoClass
	# BillOfExchange Class
	CLSID = IID('{EA7AF142-F7C4-4E1A-BA6A-B5DBFCB71C3C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchange,
	]
	default_interface = IBillOfExchange

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchangeTrans_BankPages.88.0'
class BillOfExchangeTrans_BankPages(CoClassBaseClass): # A CoClass
	# BillOfExchangeTrans_BankPages Class
	CLSID = IID('{C057A0F5-A755-4C5E-A410-D4C4D1379487}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchangeTrans_BankPages,
	]
	default_interface = IBillOfExchangeTrans_BankPages

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchangeTrans_Deposits.88.0'
class BillOfExchangeTrans_Deposits(CoClassBaseClass): # A CoClass
	# BillOfExchangeTrans_Deposits Class
	CLSID = IID('{94DA073B-4599-4BC9-A22B-87D912159247}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchangeTrans_Deposits,
	]
	default_interface = IBillOfExchangeTrans_Deposits

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchangeTransaction.88.0'
class BillOfExchangeTransaction(CoClassBaseClass): # A CoClass
	# BillOfExchangeTransaction Class
	CLSID = IID('{CFAA1E6C-53D8-4C8E-A7DE-78ABE1601F30}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchangeTransaction,
	]
	default_interface = IBillOfExchangeTransaction

# This CoClass is known by the name 'SAPbobsCOM.BillOfExchangeTransaction_Lines.88.0'
class BillOfExchangeTransaction_Lines(CoClassBaseClass): # A CoClass
	# BillOfExchangeTransaction_Lines Class
	CLSID = IID('{A8A658F8-0A8A-4CEF-B5F4-481C3D4652FA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBillOfExchangeTransaction_Lines,
	]
	default_interface = IBillOfExchangeTransaction_Lines

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreement.88.0'
class BlanketAgreement(CoClassBaseClass): # A CoClass
	# BlanketAgreement Class
	CLSID = IID('{FB23BF90-F362-4CE6-AD2B-B5F45DE7EAC2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreement,
	]
	default_interface = IBlanketAgreement

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreementParams.88.0'
class BlanketAgreementParams(CoClassBaseClass): # A CoClass
	# BlanketAgreementParams Class
	CLSID = IID('{1A4FDB5D-78F8-4BC7-BBDD-3854B3B374BF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreementParams,
	]
	default_interface = IBlanketAgreementParams

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreementsDocument.88.0'
class BlanketAgreementsDocument(CoClassBaseClass): # A CoClass
	# BlanketAgreementsDocument Class
	CLSID = IID('{5D02917C-8423-418A-8BC7-7D1631742444}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreementsDocument,
	]
	default_interface = IBlanketAgreementsDocument

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreementsDocuments.88.0'
class BlanketAgreementsDocuments(CoClassBaseClass): # A CoClass
	# BlanketAgreementsDocuments Class
	CLSID = IID('{4B0217F3-1748-4E90-B442-C83DF84BF4B5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreementsDocuments,
	]
	default_interface = IBlanketAgreementsDocuments

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreementsParams.88.0'
class BlanketAgreementsParams(CoClassBaseClass): # A CoClass
	# BlanketAgreementsParams Class
	CLSID = IID('{8BC443FC-F05C-40F1-A27E-BCCB4A568CB2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreementsParams,
	]
	default_interface = IBlanketAgreementsParams

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreementsService.88.0'
class BlanketAgreementsService(CoClassBaseClass): # A CoClass
	# BlanketAgreementsService Class
	CLSID = IID('{B9614205-7D1D-4EEC-9E2E-B1F6F1ACE50F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreementsService,
	]
	default_interface = IBlanketAgreementsService

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreements_DetailsLine.88.0'
class BlanketAgreements_DetailsLine(CoClassBaseClass): # A CoClass
	# BlanketAgreements_DetailsLine Class
	CLSID = IID('{B4BD2994-B72F-4AEE-8A80-8B94E2E34E4A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreements_DetailsLine,
	]
	default_interface = IBlanketAgreements_DetailsLine

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreements_DetailsLines.88.0'
class BlanketAgreements_DetailsLines(CoClassBaseClass): # A CoClass
	# BlanketAgreements_DetailsLines Class
	CLSID = IID('{066F2531-FDDC-46CF-9795-BD09D7E3A4C9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreements_DetailsLines,
	]
	default_interface = IBlanketAgreements_DetailsLines

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreements_ItemsLine.88.0'
class BlanketAgreements_ItemsLine(CoClassBaseClass): # A CoClass
	# BlanketAgreements_ItemsLine Class
	CLSID = IID('{1C485004-89C3-4E4F-A043-697986E0D571}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreements_ItemsLine,
	]
	default_interface = IBlanketAgreements_ItemsLine

# This CoClass is known by the name 'SAPbobsCOM.BlanketAgreements_ItemsLines.88.0'
class BlanketAgreements_ItemsLines(CoClassBaseClass): # A CoClass
	# BlanketAgreements_ItemsLines Class
	CLSID = IID('{B139E51C-5D68-4216-969D-7511566847B2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlanketAgreements_ItemsLines,
	]
	default_interface = IBlanketAgreements_ItemsLines

# This CoClass is known by the name 'SapBobsCom.Blob.88.0'
class Blob(CoClassBaseClass): # A CoClass
	# Blob Class
	CLSID = IID('{4E7D63F0-1341-4517-8F19-2EBC03A2D875}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlob,
	]
	default_interface = IBlob

# This CoClass is known by the name 'SapBobsCom.BlobParams.88.0'
class BlobParams(CoClassBaseClass): # A CoClass
	# BlobParams Class
	CLSID = IID('{3C0844B7-EFC9-4F84-99C7-EE736EDF6A89}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlobParams,
	]
	default_interface = IBlobParams

# This CoClass is known by the name 'SapBobsCom.BlobTableKeySegment.88.0'
class BlobTableKeySegment(CoClassBaseClass): # A CoClass
	# BlobTableKeySegment Class
	CLSID = IID('{52065704-057D-4B2B-A301-40F252371DA3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlobTableKeySegment,
	]
	default_interface = IBlobTableKeySegment

# This CoClass is known by the name 'SapBobsCom.BlobTableKeySegments.88.0'
class BlobTableKeySegments(CoClassBaseClass): # A CoClass
	# BlobTableKeySegments Class
	CLSID = IID('{AB946B33-0679-4E78-92EE-BAFFC4DAA9AE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBlobTableKeySegments,
	]
	default_interface = IBlobTableKeySegments

# This CoClass is known by the name 'SapBobsCom.Boxes1099.88.0'
class Boxes1099(CoClassBaseClass): # A CoClass
	# Boxes1099 Class
	CLSID = IID('{7444C348-853B-4932-924E-14D1314F9D32}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBoxes1099,
	]
	default_interface = IBoxes1099

# This CoClass is known by the name 'SapBobsCom.Branch.88.0'
class Branch(CoClassBaseClass): # A CoClass
	# Branch Class
	CLSID = IID('{84AA649E-44F2-4988-8CDF-53FFD270933C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBranch,
	]
	default_interface = IBranch

# This CoClass is known by the name 'SapBobsCom.BranchParams.88.0'
class BranchParams(CoClassBaseClass): # A CoClass
	# BranchParams Class
	CLSID = IID('{171C2811-0B09-46D2-B716-50A0FF4CB5AE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBranchParams,
	]
	default_interface = IBranchParams

# This CoClass is known by the name 'SapBobsCom.BranchesParams.88.0'
class BranchesParams(CoClassBaseClass): # A CoClass
	# BranchesParams Class
	CLSID = IID('{303AD037-92AA-4508-8FD3-08C4A6D4CFAF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBranchesParams,
	]
	default_interface = IBranchesParams

# This CoClass is known by the name 'SapBobsCom.BranchesService.88.0'
class BranchesService(CoClassBaseClass): # A CoClass
	# BranchesService Class
	CLSID = IID('{26C5C696-EC20-43DC-BCD9-010F00F40843}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBranchesService,
	]
	default_interface = IBranchesService

# This CoClass is known by the name 'SAPbobsCOM.BrazilBeverageIndexer.88.0'
class BrazilBeverageIndexer(CoClassBaseClass): # A CoClass
	# BrazilBeverageIndexer Class
	CLSID = IID('{EEC2D22B-97A3-4AC4-9823-7DBC2A9A1C53}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilBeverageIndexer,
	]
	default_interface = IBrazilBeverageIndexer

# This CoClass is known by the name 'SAPbobsCOM.BrazilBeverageIndexerParams.88.0'
class BrazilBeverageIndexerParams(CoClassBaseClass): # A CoClass
	# BrazilBeverageIndexerParams Class
	CLSID = IID('{C7678A96-E53C-402A-B298-8104D810EDE5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilBeverageIndexerParams,
	]
	default_interface = IBrazilBeverageIndexerParams

# This CoClass is known by the name 'SAPbobsCOM.BrazilBeverageIndexersParams.88.0'
class BrazilBeverageIndexersParams(CoClassBaseClass): # A CoClass
	# BrazilBeverageIndexersParams Class
	CLSID = IID('{FD5860AF-4409-4BE0-87A2-51FB438E08BF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilBeverageIndexersParams,
	]
	default_interface = IBrazilBeverageIndexersParams

# This CoClass is known by the name 'SAPbobsCOM.BrazilBeverageIndexersService.88.0'
class BrazilBeverageIndexersService(CoClassBaseClass): # A CoClass
	# BrazilBeverageIndexersService Class
	CLSID = IID('{83EEB8EC-F354-45A8-A55B-4C2EF2511F9C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilBeverageIndexersService,
	]
	default_interface = IBrazilBeverageIndexersService

# This CoClass is known by the name 'SAPbobsCOM.BrazilFuelIndexer.88.0'
class BrazilFuelIndexer(CoClassBaseClass): # A CoClass
	# BrazilFuelIndexer Class
	CLSID = IID('{3BDD39A5-7A7A-4DD1-963A-5C3500A6B262}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilFuelIndexer,
	]
	default_interface = IBrazilFuelIndexer

# This CoClass is known by the name 'SAPbobsCOM.BrazilFuelIndexerParams.88.0'
class BrazilFuelIndexerParams(CoClassBaseClass): # A CoClass
	# BrazilFuelIndexerParams Class
	CLSID = IID('{819AD6EF-E5DB-4FBA-8387-17863BEFE018}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilFuelIndexerParams,
	]
	default_interface = IBrazilFuelIndexerParams

# This CoClass is known by the name 'SAPbobsCOM.BrazilFuelIndexersParams.88.0'
class BrazilFuelIndexersParams(CoClassBaseClass): # A CoClass
	# BrazilFuelIndexersParams Class
	CLSID = IID('{6D9D8D62-8831-45B0-814A-BF7EB5AA63DD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilFuelIndexersParams,
	]
	default_interface = IBrazilFuelIndexersParams

# This CoClass is known by the name 'SAPbobsCOM.BrazilFuelIndexersService.88.0'
class BrazilFuelIndexersService(CoClassBaseClass): # A CoClass
	# BrazilFuelIndexersService Class
	CLSID = IID('{77166E02-41E6-47C8-9EBE-66348C1C9D9E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilFuelIndexersService,
	]
	default_interface = IBrazilFuelIndexersService

class BrazilMultiIndexer(CoClassBaseClass): # A CoClass
	# BrazilMultiIndexer Class
	CLSID = IID('{03811867-1D7D-4ED8-B42B-040839C0EC4C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilMultiIndexer,
	]
	default_interface = IBrazilMultiIndexer

class BrazilMultiIndexerParams(CoClassBaseClass): # A CoClass
	# BrazilMultiIndexerParams Class
	CLSID = IID('{58FCDC2F-A0BF-4211-A2F9-D21C0E13AEDF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilMultiIndexerParams,
	]
	default_interface = IBrazilMultiIndexerParams

class BrazilMultiIndexersParams(CoClassBaseClass): # A CoClass
	# BrazilMultiIndexersParams Class
	CLSID = IID('{F69530F1-7AD5-4496-807B-6911ED2E5363}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilMultiIndexersParams,
	]
	default_interface = IBrazilMultiIndexersParams

class BrazilMultiIndexersService(CoClassBaseClass): # A CoClass
	# BrazilMultiIndexersService Class
	CLSID = IID('{6AD3FECD-43C9-4993-B8F5-0340C8299AEE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilMultiIndexersService,
	]
	default_interface = IBrazilMultiIndexersService

# This CoClass is known by the name 'SAPbobsCOM.BrazilNumericIndexer.88.0'
class BrazilNumericIndexer(CoClassBaseClass): # A CoClass
	# BrazilNumericIndexer Class
	CLSID = IID('{3CFFABA9-A29B-4D64-8344-17073542C395}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilNumericIndexer,
	]
	default_interface = IBrazilNumericIndexer

# This CoClass is known by the name 'SAPbobsCOM.BrazilNumericIndexerParams.88.0'
class BrazilNumericIndexerParams(CoClassBaseClass): # A CoClass
	# BrazilNumericIndexerParams Class
	CLSID = IID('{9E538356-9693-4627-A806-D01D07823616}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilNumericIndexerParams,
	]
	default_interface = IBrazilNumericIndexerParams

# This CoClass is known by the name 'SAPbobsCOM.BrazilNumericIndexersParams.88.0'
class BrazilNumericIndexersParams(CoClassBaseClass): # A CoClass
	# BrazilNumericIndexersParams Class
	CLSID = IID('{3F0B1146-0F25-4198-A84C-BBA0CEB0FACF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilNumericIndexersParams,
	]
	default_interface = IBrazilNumericIndexersParams

# This CoClass is known by the name 'SAPbobsCOM.BrazilNumericIndexersService.88.0'
class BrazilNumericIndexersService(CoClassBaseClass): # A CoClass
	# BrazilNumericIndexersService Class
	CLSID = IID('{B65E1962-E1A8-4BD0-83D6-6F159503C18E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilNumericIndexersService,
	]
	default_interface = IBrazilNumericIndexersService

# This CoClass is known by the name 'SAPbobsCOM.BrazilStringIndexer.88.0'
class BrazilStringIndexer(CoClassBaseClass): # A CoClass
	# BrazilStringIndexer Class
	CLSID = IID('{E8DA612B-3A4E-4186-B127-DAF785480B47}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilStringIndexer,
	]
	default_interface = IBrazilStringIndexer

# This CoClass is known by the name 'SAPbobsCOM.BrazilStringIndexerParams.88.0'
class BrazilStringIndexerParams(CoClassBaseClass): # A CoClass
	# BrazilStringIndexerParams Class
	CLSID = IID('{638D8662-F163-4574-B69D-11B5C6696733}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilStringIndexerParams,
	]
	default_interface = IBrazilStringIndexerParams

# This CoClass is known by the name 'SAPbobsCOM.BrazilStringIndexersParams.88.0'
class BrazilStringIndexersParams(CoClassBaseClass): # A CoClass
	# BrazilStringIndexersParams Class
	CLSID = IID('{DC66A989-A072-41C9-959F-B9525E8AFC1B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilStringIndexersParams,
	]
	default_interface = IBrazilStringIndexersParams

# This CoClass is known by the name 'SAPbobsCOM.BrazilStringIndexersService.88.0'
class BrazilStringIndexersService(CoClassBaseClass): # A CoClass
	# BrazilStringIndexersService Class
	CLSID = IID('{BD51601F-CF1B-4F4E-A99A-A8642C241815}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBrazilStringIndexersService,
	]
	default_interface = IBrazilStringIndexersService

# This CoClass is known by the name 'SAPbobsCOM.Budget.88.0'
class Budget(CoClassBaseClass): # A CoClass
	# Budget Class
	CLSID = IID('{11067A79-5484-43A2-945C-7408CDCF01E6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBudget,
	]
	default_interface = IBudget

# This CoClass is known by the name 'SAPbobsCOM.BudgetCostAccounting_Lines.88.0'
class BudgetCostAccounting_Lines(CoClassBaseClass): # A CoClass
	# BudgetCostAccounting_Lines Class
	CLSID = IID('{E8AB066D-E193-4433-AD85-0E1AA6F490A3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBudgetCostAccounting_Lines,
	]
	default_interface = IBudgetCostAccounting_Lines

# This CoClass is known by the name 'SAPbobsCOM.BudgetDistribution.88.0'
class BudgetDistribution(CoClassBaseClass): # A CoClass
	# BudgetDistribution Class
	CLSID = IID('{16F466DA-6A22-46AE-A5B2-5934A0194D7A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBudgetDistribution,
	]
	default_interface = IBudgetDistribution

# This CoClass is known by the name 'SAPbobsCOM.BudgetScenarios.88.0'
class BudgetScenarios(CoClassBaseClass): # A CoClass
	# BudgetScenarios Class
	CLSID = IID('{8DCD076F-BF30-45C6-822A-B23FDA1B37F5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBudgetScenarios,
	]
	default_interface = IBudgetScenarios

# This CoClass is known by the name 'SAPbobsCOM.Budget_Lines.88.0'
class Budget_Lines(CoClassBaseClass): # A CoClass
	# Budget_Lines Class
	CLSID = IID('{F105494C-B48F-4E8A-B6E7-C1947194E835}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBudget_Lines,
	]
	default_interface = IBudget_Lines

# This CoClass is known by the name 'SapBobsCom.BusinessPartnerGroups.88.0'
class BusinessPartnerGroups(CoClassBaseClass): # A CoClass
	# BusinessPartnerGroups Class
	CLSID = IID('{A3C87BAE-49A3-4A53-A50B-D20716733709}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPartnerGroups,
	]
	default_interface = IBusinessPartnerGroups

# This CoClass is known by the name 'SapBobsCom.BusinessPartnerPropertiesParams.88.0'
class BusinessPartnerPropertiesParams(CoClassBaseClass): # A CoClass
	# BusinessPartnerPropertiesParams Class
	CLSID = IID('{AC817068-3E5F-49B3-A301-189558534ED5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPartnerPropertiesParams,
	]
	default_interface = IBusinessPartnerPropertiesParams

# This CoClass is known by the name 'SapBobsCom.BusinessPartnerPropertiesService.88.0'
class BusinessPartnerPropertiesService(CoClassBaseClass): # A CoClass
	# BusinessPartnerPropertiesService Class
	CLSID = IID('{38038B4E-6B7A-441F-81C6-9B699CC4DE6A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPartnerPropertiesService,
	]
	default_interface = IBusinessPartnerPropertiesService

# This CoClass is known by the name 'SapBobsCom.BusinessPartnerProperty.88.0'
class BusinessPartnerProperty(CoClassBaseClass): # A CoClass
	# BusinessPartnerProperty Class
	CLSID = IID('{3329D652-8FFF-4076-B051-A4B503878986}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPartnerProperty,
	]
	default_interface = IBusinessPartnerProperty

# This CoClass is known by the name 'SapBobsCom.BusinessPartnerPropertyParams.88.0'
class BusinessPartnerPropertyParams(CoClassBaseClass): # A CoClass
	# BusinessPartnerPropertyParams Class
	CLSID = IID('{51090998-B57D-4A0B-A634-4664FE76FA57}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPartnerPropertyParams,
	]
	default_interface = IBusinessPartnerPropertyParams

# This CoClass is known by the name 'SAPbobsCOM.BusinessPartners.88.0'
class BusinessPartners(CoClassBaseClass): # A CoClass
	# BusinessPartners Class
	CLSID = IID('{4A1DF035-9612-4CCC-B9B8-C58511D0D705}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPartners,
	]
	default_interface = IBusinessPartners

# This CoClass is known by the name 'SapBobsCom.BusinessPartnersService.88.0'
class BusinessPartnersService(CoClassBaseClass): # A CoClass
	# BusinessPartnersService Class
	CLSID = IID('{EEA5B4B4-F1E5-4CC2-9514-C80EE92DF9C2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPartnersService,
	]
	default_interface = IBusinessPartnersService

class BusinessPlaceIENumbers(CoClassBaseClass): # A CoClass
	# BusinessPlaceIENumbers Class
	CLSID = IID('{EF78E12B-50D7-424C-9314-1275E4EEAF23}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPlaceIENumbers,
	]
	default_interface = IBusinessPlaceIENumbers

class BusinessPlaceTributaryInfos(CoClassBaseClass): # A CoClass
	# BusinessPlaceTributaryInfos Class
	CLSID = IID('{08F4BA3C-A72A-4612-B5D4-F3E1C120004E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPlaceTributaryInfos,
	]
	default_interface = IBusinessPlaceTributaryInfos

# This CoClass is known by the name 'SapBobsCom.BusinessPlaces.88.0'
class BusinessPlaces(CoClassBaseClass): # A CoClass
	# BusinessPlaces Class
	CLSID = IID('{ADDFFAB7-1BA1-4C06-8229-D3CE76605700}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IBusinessPlaces,
	]
	default_interface = IBusinessPlaces

# This CoClass is known by the name 'SapBobsCom.CallArgument.88.0'
class CallArgument(CoClassBaseClass): # A CoClass
	# CallArgument Class
	CLSID = IID('{4DC221EF-0E47-4EB3-A14C-A92F31E956DD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICallArgument,
	]
	default_interface = ICallArgument

# This CoClass is known by the name 'SapBobsCom.CallArguments.88.0'
class CallArguments(CoClassBaseClass): # A CoClass
	# CallArguments Class
	CLSID = IID('{C8A713C7-A32D-46CC-87FC-EF65827B1E49}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICallArguments,
	]
	default_interface = ICallArguments

# This CoClass is known by the name 'SapBobsCom.CallMessage.88.0'
class CallMessage(CoClassBaseClass): # A CoClass
	# CallMessage Class
	CLSID = IID('{9028E41B-53F3-4D7F-8A0E-FFD5F9923664}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICallMessage,
	]
	default_interface = ICallMessage

# This CoClass is known by the name 'SapBobsCom.CallMessageArgument.88.0'
class CallMessageArgument(CoClassBaseClass): # A CoClass
	# CallMessageArgument Class
	CLSID = IID('{0278D428-E7EE-4F0D-ACE4-1CBADAE17BC2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICallMessageArgument,
	]
	default_interface = ICallMessageArgument

# This CoClass is known by the name 'SapBobsCom.CallMessageArguments.88.0'
class CallMessageArguments(CoClassBaseClass): # A CoClass
	# CallMessageArguments Class
	CLSID = IID('{5AB3CD70-9DFD-4904-A6FC-AE99578C58BF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICallMessageArguments,
	]
	default_interface = ICallMessageArguments

# This CoClass is known by the name 'SapBobsCom.CallMessages.88.0'
class CallMessages(CoClassBaseClass): # A CoClass
	# CallMessages Class
	CLSID = IID('{914845C0-9411-4A9C-9D0D-DC85177ACFA9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICallMessages,
	]
	default_interface = ICallMessages

# This CoClass is known by the name 'SAPbobsCOM.Campaign.88.0'
class Campaign(CoClassBaseClass): # A CoClass
	# Campaign Class
	CLSID = IID('{7918DE8E-296C-4D36-9BB5-AE66DC9A466D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaign,
	]
	default_interface = ICampaign

# This CoClass is known by the name 'SAPbobsCOM.CampaignBusinessPartner.88.0'
class CampaignBusinessPartner(CoClassBaseClass): # A CoClass
	# CampaignBusinessPartner Class
	CLSID = IID('{E41626ED-6A4E-4C2A-8E60-7010C443F3F9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaignBusinessPartner,
	]
	default_interface = ICampaignBusinessPartner

# This CoClass is known by the name 'SAPbobsCOM.CampaignBusinessPartners.88.0'
class CampaignBusinessPartners(CoClassBaseClass): # A CoClass
	# CampaignBusinessPartners Class
	CLSID = IID('{F9528D0C-E227-4693-B99E-E481C2B90BB7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaignBusinessPartners,
	]
	default_interface = ICampaignBusinessPartners

# This CoClass is known by the name 'SAPbobsCOM.CampaignItem.88.0'
class CampaignItem(CoClassBaseClass): # A CoClass
	# CampaignItem Class
	CLSID = IID('{66F66F95-FC79-49B3-8B71-F80CFC73EAD0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaignItem,
	]
	default_interface = ICampaignItem

# This CoClass is known by the name 'SAPbobsCOM.CampaignItems.88.0'
class CampaignItems(CoClassBaseClass): # A CoClass
	# CampaignItems Class
	CLSID = IID('{DCC7C980-6F3B-4823-872C-5DAD0BBA3A42}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaignItems,
	]
	default_interface = ICampaignItems

# This CoClass is known by the name 'SAPbobsCOM.CampaignParams.88.0'
class CampaignParams(CoClassBaseClass): # A CoClass
	# CampaignParams Class
	CLSID = IID('{E04751E5-F944-4A94-B580-320744878FDA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaignParams,
	]
	default_interface = ICampaignParams

# This CoClass is known by the name 'SAPbobsCOM.CampaignPartner.88.0'
class CampaignPartner(CoClassBaseClass): # A CoClass
	# CampaignPartner Class
	CLSID = IID('{2167C74B-B692-4B1C-AE1E-721CA61EA8A1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaignPartner,
	]
	default_interface = ICampaignPartner

# This CoClass is known by the name 'SAPbobsCOM.CampaignPartners.88.0'
class CampaignPartners(CoClassBaseClass): # A CoClass
	# CampaignPartners Class
	CLSID = IID('{91155E58-DB6A-4817-ABA0-657B09C05471}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaignPartners,
	]
	default_interface = ICampaignPartners

# This CoClass is known by the name 'SAPbobsCOM.CampaignsParams.88.0'
class CampaignsParams(CoClassBaseClass): # A CoClass
	# CampaignsParams Class
	CLSID = IID('{215A5610-7BBC-4D8A-B41F-33EF4BFBEF9F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaignsParams,
	]
	default_interface = ICampaignsParams

# This CoClass is known by the name 'SAPbobsCOM.CampaignsService.88.0'
class CampaignsService(CoClassBaseClass): # A CoClass
	# CampaignsService Class
	CLSID = IID('{3288D1F6-6EA4-4FA3-82E5-53943D2DA511}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICampaignsService,
	]
	default_interface = ICampaignsService

# This CoClass is known by the name 'SapBobsCom.CashDiscount.88.0'
class CashDiscount(CoClassBaseClass): # A CoClass
	# CashDiscount Class
	CLSID = IID('{91D09078-1DA3-4320-BDAF-AFCD977F7E83}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICashDiscount,
	]
	default_interface = ICashDiscount

# This CoClass is known by the name 'SapBobsCom.CashDiscountParams.88.0'
class CashDiscountParams(CoClassBaseClass): # A CoClass
	# CashDiscountParams Class
	CLSID = IID('{4600E0D8-E8C5-4CC3-93CB-68DB78774B44}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICashDiscountParams,
	]
	default_interface = ICashDiscountParams

# This CoClass is known by the name 'SapBobsCom.CashDiscountsParams.88.0'
class CashDiscountsParams(CoClassBaseClass): # A CoClass
	# CashDiscountsParams Class
	CLSID = IID('{04A588AD-9FA8-4238-8044-D70C1988BFD2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICashDiscountsParams,
	]
	default_interface = ICashDiscountsParams

# This CoClass is known by the name 'SapBobsCom.CashDiscountsService.88.0'
class CashDiscountsService(CoClassBaseClass): # A CoClass
	# CashDiscountsService Class
	CLSID = IID('{A46D497B-B625-4043-B6E6-988E544336BE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICashDiscountsService,
	]
	default_interface = ICashDiscountsService

class CashFlowAssignments(CoClassBaseClass): # A CoClass
	# CashFlowAssignments Class
	CLSID = IID('{920385DA-2BF3-41E5-BB01-EFDE51C104E6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICashFlowAssignments,
	]
	default_interface = ICashFlowAssignments

# This CoClass is known by the name 'SAPbobsCOM.CashFlowLineItem.88.0'
class CashFlowLineItem(CoClassBaseClass): # A CoClass
	# CashFlowLineItem Class
	CLSID = IID('{3B3E22F6-114F-4F15-9864-319ABBEF75EB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICashFlowLineItem,
	]
	default_interface = ICashFlowLineItem

# This CoClass is known by the name 'SAPbobsCOM.CashFlowLineItemParams.88.0'
class CashFlowLineItemParams(CoClassBaseClass): # A CoClass
	# CashFlowLineItemParams Class
	CLSID = IID('{65CA8D95-BE2F-4E7E-9E56-42BA0FE0FB49}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICashFlowLineItemParams,
	]
	default_interface = ICashFlowLineItemParams

# This CoClass is known by the name 'SAPbobsCOM.CashFlowLineItemsParams.88.0'
class CashFlowLineItemsParams(CoClassBaseClass): # A CoClass
	# CashFlowLineItemsParams Class
	CLSID = IID('{78A66A76-1B6F-44EC-B0FD-5C5CDC2752F4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICashFlowLineItemsParams,
	]
	default_interface = ICashFlowLineItemsParams

# This CoClass is known by the name 'SAPbobsCOM.CashFlowLineItemsService.88.0'
class CashFlowLineItemsService(CoClassBaseClass): # A CoClass
	# CashFlowLineItemsService Class
	CLSID = IID('{F0DA88A7-72BE-4DF7-9A0A-05600C784DE8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICashFlowLineItemsService,
	]
	default_interface = ICashFlowLineItemsService

# This CoClass is known by the name 'SAPbobsCOM.CertificateSeries.88.0'
class CertificateSeries(CoClassBaseClass): # A CoClass
	# CertificateSeries Class
	CLSID = IID('{2BDDDD4B-2399-48E0-A9E1-7BC3DE1324A0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICertificateSeries,
	]
	default_interface = ICertificateSeries

# This CoClass is known by the name 'SAPbobsCOM.CertificateSeriesParams.88.0'
class CertificateSeriesParams(CoClassBaseClass): # A CoClass
	# CertificateSeriesParams Class
	CLSID = IID('{6C88DC52-9869-4BB8-8DBB-C2F536138943}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICertificateSeriesParams,
	]
	default_interface = ICertificateSeriesParams

# This CoClass is known by the name 'SAPbobsCOM.CertificateSeriesParamsCollection.88.0'
class CertificateSeriesParamsCollection(CoClassBaseClass): # A CoClass
	# CertificateSeriesParamsCollection Class
	CLSID = IID('{E097B000-F885-401A-A265-5E46F074A5F4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICertificateSeriesParamsCollection,
	]
	default_interface = ICertificateSeriesParamsCollection

# This CoClass is known by the name 'SAPbobsCOM.CertificateSeriesService.88.0'
class CertificateSeriesService(CoClassBaseClass): # A CoClass
	# CertificateSeriesService Class
	CLSID = IID('{C4E7259B-2770-4451-9C0F-0757F5BE9FD7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICertificateSeriesService,
	]
	default_interface = ICertificateSeriesService

# This CoClass is known by the name 'SAPbobsCOM.ChangeLogDifferenceParams.88.0'
class ChangeLogDifferenceParams(CoClassBaseClass): # A CoClass
	# ChangeLogDifferenceParams Class
	CLSID = IID('{43A684B0-5463-4FD9-9F52-A2E57909EAF2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChangeLogDifferenceParams,
	]
	default_interface = IChangeLogDifferenceParams

# This CoClass is known by the name 'SAPbobsCOM.ChangeLogDifferencesParams.88.0'
class ChangeLogDifferencesParams(CoClassBaseClass): # A CoClass
	# ChangeLogDifferencesParams Class
	CLSID = IID('{45B16468-2569-43A8-A330-D6E7F5275CAD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChangeLogDifferencesParams,
	]
	default_interface = IChangeLogDifferencesParams

# This CoClass is known by the name 'SAPbobsCOM.ChangeLogParams.88.0'
class ChangeLogParams(CoClassBaseClass): # A CoClass
	# ChangeLogParams Class
	CLSID = IID('{7C51D9D4-DDBA-4057-BC03-AEE13B22CD64}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChangeLogParams,
	]
	default_interface = IChangeLogParams

# This CoClass is known by the name 'SAPbobsCOM.ChangeLogsParams.88.0'
class ChangeLogsParams(CoClassBaseClass): # A CoClass
	# ChangeLogsParams Class
	CLSID = IID('{AE08D2F8-6EBB-42BA-9226-FD68AC457294}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChangeLogsParams,
	]
	default_interface = IChangeLogsParams

# This CoClass is known by the name 'SAPbobsCOM.ChangeLogsService.88.0'
class ChangeLogsService(CoClassBaseClass): # A CoClass
	# ChangeLogsService Class
	CLSID = IID('{5751679D-4E34-4E74-B169-03D440F1F9D1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChangeLogsService,
	]
	default_interface = IChangeLogsService

# This CoClass is known by the name 'SAPbobsCOM.ChartOfAccounts.88.0'
class ChartOfAccounts(CoClassBaseClass): # A CoClass
	# ChartOfAccounts Class
	CLSID = IID('{85EBDF2E-252D-4489-9E2F-FE17C36ACE86}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChartOfAccounts,
	]
	default_interface = IChartOfAccounts

# This CoClass is known by the name 'SAPbobsCOM.CheckLine.88.0'
class CheckLine(CoClassBaseClass): # A CoClass
	# CheckLine Class
	CLSID = IID('{5F9B7943-CA8C-482F-A5EB-B412ADB51007}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICheckLine,
	]
	default_interface = ICheckLine

# This CoClass is known by the name 'SAPbobsCOM.CheckLineParams.88.0'
class CheckLineParams(CoClassBaseClass): # A CoClass
	# CheckLineParams Class
	CLSID = IID('{A0324965-FF3F-43FA-BE6B-63DE64C9991F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICheckLineParams,
	]
	default_interface = ICheckLineParams

# This CoClass is known by the name 'SAPbobsCOM.CheckLines.88.0'
class CheckLines(CoClassBaseClass): # A CoClass
	# CheckLines Class
	CLSID = IID('{6719EA66-D6B5-4509-ABC0-E16BDC730623}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICheckLines,
	]
	default_interface = ICheckLines

# This CoClass is known by the name 'SAPbobsCOM.CheckLinesParams.88.0'
class CheckLinesParams(CoClassBaseClass): # A CoClass
	# CheckLinesParams Class
	CLSID = IID('{81460BB2-567C-447B-9606-1C70FCF4F204}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICheckLinesParams,
	]
	default_interface = ICheckLinesParams

# This CoClass is known by the name 'SAPbobsCOM.CheckLinesService.88.0'
class CheckLinesService(CoClassBaseClass): # A CoClass
	# CheckLinesService Class
	CLSID = IID('{3F5CE8F3-380C-4E97-A303-342EF66DE0DC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICheckLinesService,
	]
	default_interface = ICheckLinesService

# This CoClass is known by the name 'SAPbobsCOM.ChecksforPayment.88.0'
class ChecksforPayment(CoClassBaseClass): # A CoClass
	# ChecksforPayment Class
	CLSID = IID('{31341DF9-0A1F-4B75-BBAB-50B96478E579}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChecksforPayment,
	]
	default_interface = IChecksforPayment

# This CoClass is known by the name 'SAPbobsCOM.ChecksforPaymentLines.88.0'
class ChecksforPaymentLines(CoClassBaseClass): # A CoClass
	# ChecksforPaymentLines Class
	CLSID = IID('{36360587-E2A6-4BF4-BFED-92F2CEDDF03D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChecksforPaymentLines,
	]
	default_interface = IChecksforPaymentLines

# This CoClass is known by the name 'SapBobsCom.ChooseFromList.88.0'
class ChooseFromList(CoClassBaseClass): # A CoClass
	# ChooseFromList Class
	CLSID = IID('{3D623D04-749A-46B6-B0A2-AAC17B3FAEC8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChooseFromList,
	]
	default_interface = IChooseFromList

# This CoClass is known by the name 'SapBobsCom.ChooseFromList_Lines.88.0'
class ChooseFromList_Lines(CoClassBaseClass): # A CoClass
	# ChooseFromList_Lines Class
	CLSID = IID('{53651CC7-0892-4713-AE45-FE246FCA0F07}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IChooseFromList_Lines,
	]
	default_interface = IChooseFromList_Lines

# This CoClass is known by the name 'SAPbobsCOM.ClosingDateProcedure.88.0'
class ClosingDateProcedure(CoClassBaseClass): # A CoClass
	# ClosingDateProcedure Class
	CLSID = IID('{B50BD947-38AC-4ACE-97F4-8EA9ECD9AB77}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IClosingDateProcedure,
	]
	default_interface = IClosingDateProcedure

# This CoClass is known by the name 'SAPbobsCOM.Cockpit.88.0'
class Cockpit(CoClassBaseClass): # A CoClass
	# Cockpit Class
	CLSID = IID('{594B9D4F-6946-40E7-9E69-2DC0F506A823}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICockpit,
	]
	default_interface = ICockpit

# This CoClass is known by the name 'SAPbobsCOM.CockpitParams.88.0'
class CockpitParams(CoClassBaseClass): # A CoClass
	# CockpitParams Class
	CLSID = IID('{50A5CCB1-6509-462A-8A81-B9A11DA1C4DA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICockpitParams,
	]
	default_interface = ICockpitParams

# This CoClass is known by the name 'SAPbobsCOM.CockpitsParams.88.0'
class CockpitsParams(CoClassBaseClass): # A CoClass
	# CockpitsParams Class
	CLSID = IID('{EE92D21D-B6D8-4BD2-B481-EF2FE7C6E731}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICockpitsParams,
	]
	default_interface = ICockpitsParams

# This CoClass is known by the name 'SAPbobsCOM.CockpitsService.88.0'
class CockpitsService(CoClassBaseClass): # A CoClass
	# CockpitsService Class
	CLSID = IID('{D0DD241B-FDFC-4D57-ACD0-CBCB01611BF9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICockpitsService,
	]
	default_interface = ICockpitsService

# This CoClass is known by the name 'SapBobsCom.ColumnPreferences.88.0'
class ColumnPreferences(CoClassBaseClass): # A CoClass
	# ColumnPreferences Class
	CLSID = IID('{5E97458D-A97E-4369-B747-9AFD1A04A0D9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IColumnPreferences,
	]
	default_interface = IColumnPreferences

# This CoClass is known by the name 'SapBobsCom.ColumnsPreferences.88.0'
class ColumnsPreferences(CoClassBaseClass): # A CoClass
	# ColumnsPreferences Class
	CLSID = IID('{6751B54D-0896-4E23-9511-D4BE79AB78B4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IColumnsPreferences,
	]
	default_interface = IColumnsPreferences

# This CoClass is known by the name 'SapBobsCom.ColumnsPreferencesParams.88.0'
class ColumnsPreferencesParams(CoClassBaseClass): # A CoClass
	# ColumnsPreferencesParams Class
	CLSID = IID('{FD65E5A4-2232-452B-8541-5BC1EC3FF9C6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IColumnsPreferencesParams,
	]
	default_interface = IColumnsPreferencesParams

# This CoClass is known by the name 'SAPbobsCOM.Command.88.0'
class Command(CoClassBaseClass): # A CoClass
	# Command Class
	CLSID = IID('{15BD344C-48ED-4A6A-8A31-AFBD7A2ED57B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICommand,
	]
	default_interface = ICommand

# This CoClass is known by the name 'SAPbobsCOM.CommandParam.88.0'
class CommandParam(CoClassBaseClass): # A CoClass
	# CommandParam Class
	CLSID = IID('{13CC4089-F2FA-4B28-9BD9-75F6DC0E44B3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICommandParam,
	]
	default_interface = ICommandParam

# This CoClass is known by the name 'SAPbobsCOM.CommandParams.88.0'
class CommandParams(CoClassBaseClass): # A CoClass
	# CommandParams Class
	CLSID = IID('{9C536750-5FC9-45DF-AF6E-62DB9ACCAEA8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICommandParams,
	]
	default_interface = ICommandParams

# This CoClass is known by the name 'SapBobsCom.CommissionGroups.88.0'
class CommissionGroups(CoClassBaseClass): # A CoClass
	# CommissionGroups Class
	CLSID = IID('{661FDCA5-1B1D-4EBA-8DC9-EB75F2E506AD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICommissionGroups,
	]
	default_interface = ICommissionGroups

# This CoClass is known by the name 'SAPbobsCOM.Company.88.0'
class Company(CoClassBaseClass): # A CoClass
	# Company Class
	CLSID = IID('{632F4591-AA62-4219-8FB6-22BCF5F60088}')
	coclass_sources = [
		_ICompanyEvents,
	]
	default_source = _ICompanyEvents
	coclass_interfaces = [
		ICompany,
	]
	default_interface = ICompany

# This CoClass is known by the name 'SapBobsCom.CompanyInfo.88.0'
class CompanyInfo(CoClassBaseClass): # A CoClass
	# CompanyInfo Class
	CLSID = IID('{930EBAD5-80E3-46B6-9DCB-BB6F73541C5D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICompanyInfo,
	]
	default_interface = ICompanyInfo

# This CoClass is known by the name 'SAPbobsCOM.CompaniesService.88.0'
class CompanyService(CoClassBaseClass): # A CoClass
	# CompanyService Class
	CLSID = IID('{99074C83-3748-491D-AD31-7EDE65691225}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICompanyService,
	]
	default_interface = ICompanyService

# This CoClass is known by the name 'SAPbobsCOM.ContactEmployees.88.0'
class ContactEmployees(CoClassBaseClass): # A CoClass
	# ContactEmployees Class
	CLSID = IID('{22DCA799-2F7B-4B31-ABB6-74F3C07CB367}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IContactEmployees,
	]
	default_interface = IContactEmployees

# This CoClass is known by the name 'SAPbobsCOM.Contacts.88.0'
class Contacts(CoClassBaseClass): # A CoClass
	# Contacts Class
	CLSID = IID('{161C44B9-9DAC-4D31-AB92-EED776B8C745}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IContacts,
	]
	default_interface = IContacts

# This CoClass is known by the name 'SAPbobsCOM.ContractTemplates.88.0'
class ContractTemplates(CoClassBaseClass): # A CoClass
	# ContractTemplates Class
	CLSID = IID('{835F6104-3A36-4122-8AE8-C4E1D7B15453}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IContractTemplates,
	]
	default_interface = IContractTemplates

# This CoClass is known by the name 'SAPbobsCOM.CostCenterType.88.0'
class CostCenterType(CoClassBaseClass): # A CoClass
	# CostCenterType Class
	CLSID = IID('{AECE9766-707E-4C6C-86BA-FD9ABE43B67A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICostCenterType,
	]
	default_interface = ICostCenterType

# This CoClass is known by the name 'SAPbobsCOM.CostCenterTypeParams.88.0'
class CostCenterTypeParams(CoClassBaseClass): # A CoClass
	# CostCenterTypeParams Class
	CLSID = IID('{C81FD047-A4A2-4EF6-9538-65D9F381CB03}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICostCenterTypeParams,
	]
	default_interface = ICostCenterTypeParams

# This CoClass is known by the name 'SAPbobsCOM.CostCenterTypes.88.0'
class CostCenterTypes(CoClassBaseClass): # A CoClass
	# CostCenterTypes Class
	CLSID = IID('{9B732959-2A6C-46D0-B082-DF0FD03D7EE0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICostCenterTypes,
	]
	default_interface = ICostCenterTypes

# This CoClass is known by the name 'SAPbobsCOM.CostCenterTypesParams.88.0'
class CostCenterTypesParams(CoClassBaseClass): # A CoClass
	# CostCenterTypesParams Class
	CLSID = IID('{F018FAC9-48EF-435B-9D4A-0EFE1337EABB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICostCenterTypesParams,
	]
	default_interface = ICostCenterTypesParams

# This CoClass is known by the name 'SAPbobsCOM.CostCenterTypesService.88.0'
class CostCenterTypesService(CoClassBaseClass): # A CoClass
	# CostCenterTypesService Class
	CLSID = IID('{E00CB643-DBC7-492C-8D65-FE84540E425A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICostCenterTypesService,
	]
	default_interface = ICostCenterTypesService

# This CoClass is known by the name 'SapBobsCom.CountriesParams.88.0'
class CountriesParams(CoClassBaseClass): # A CoClass
	# CountriesParams Class
	CLSID = IID('{A9030345-42BE-4206-8236-DF97C0B60529}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICountriesParams,
	]
	default_interface = ICountriesParams

# This CoClass is known by the name 'SapBobsCom.CountriesService.88.0'
class CountriesService(CoClassBaseClass): # A CoClass
	# CountriesService Class
	CLSID = IID('{174DC159-9A9A-46AC-9A78-EAA35119F267}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICountriesService,
	]
	default_interface = ICountriesService

# This CoClass is known by the name 'SapBobsCom.Country.88.0'
class Country(CoClassBaseClass): # A CoClass
	# Country Class
	CLSID = IID('{C2920491-21F1-4CB6-B7FF-C638324F1234}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICountry,
	]
	default_interface = ICountry

# This CoClass is known by the name 'SapBobsCom.CountryParams.88.0'
class CountryParams(CoClassBaseClass): # A CoClass
	# CountryParams Class
	CLSID = IID('{EA66002F-549F-4B15-BD0E-7AB565D29B5F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICountryParams,
	]
	default_interface = ICountryParams

# This CoClass is known by the name 'SapBobsCom.CreditCardPayments.88.0'
class CreditCardPayments(CoClassBaseClass): # A CoClass
	# CreditCardPayments Class
	CLSID = IID('{EC857C0B-EFEB-43D5-92CF-8EFAC1D138F7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICreditCardPayments,
	]
	default_interface = ICreditCardPayments

# This CoClass is known by the name 'SapBobsCom.CreditCards.88.0'
class CreditCards(CoClassBaseClass): # A CoClass
	# CreditCards Class
	CLSID = IID('{F31F3841-559A-4CF2-B26C-17AA566FA21F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICreditCards,
	]
	default_interface = ICreditCards

# This CoClass is known by the name 'SAPbobsCOM.CreditLine.88.0'
class CreditLine(CoClassBaseClass): # A CoClass
	# CreditLine Class
	CLSID = IID('{2B38E868-B135-40FE-9174-5C258F8638DB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICreditLine,
	]
	default_interface = ICreditLine

# This CoClass is known by the name 'SAPbobsCOM.CreditLineParams.88.0'
class CreditLineParams(CoClassBaseClass): # A CoClass
	# CreditLineParams Class
	CLSID = IID('{45D4B1C7-FB50-4628-94F5-78006AD1EFAC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICreditLineParams,
	]
	default_interface = ICreditLineParams

# This CoClass is known by the name 'SAPbobsCOM.CreditLines.88.0'
class CreditLines(CoClassBaseClass): # A CoClass
	# CreditLines Class
	CLSID = IID('{1442D59A-3803-4A00-B991-1652819C0E7E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICreditLines,
	]
	default_interface = ICreditLines

# This CoClass is known by the name 'SAPbobsCOM.CreditLinesParams.88.0'
class CreditLinesParams(CoClassBaseClass): # A CoClass
	# CreditLinesParams Class
	CLSID = IID('{3B27BECB-507C-43E6-8FDF-080EC3810C1E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICreditLinesParams,
	]
	default_interface = ICreditLinesParams

# This CoClass is known by the name 'SAPbobsCOM.CreditLinesService.88.0'
class CreditLinesService(CoClassBaseClass): # A CoClass
	# CreditLinesService Class
	CLSID = IID('{D110EAAC-B59D-499D-9936-67F70B616026}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICreditLinesService,
	]
	default_interface = ICreditLinesService

# This CoClass is known by the name 'SapBobsCom.CreditPaymentMethods.88.0'
class CreditPaymentMethods(CoClassBaseClass): # A CoClass
	# CreditPaymentMethods Class
	CLSID = IID('{ED5A21FE-3751-472D-B058-198D6E2FEB9F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICreditPaymentMethods,
	]
	default_interface = ICreditPaymentMethods

# This CoClass is known by the name 'SAPbobsCOM.Currencies.88.0'
class Currencies(CoClassBaseClass): # A CoClass
	# Currencies Class
	CLSID = IID('{12788346-93BB-4D1C-8649-A3266A413D3F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICurrencies,
	]
	default_interface = ICurrencies

# This CoClass is known by the name 'SapBobsCom.CurrencyRestrictions.88.0'
class CurrencyRestrictions(CoClassBaseClass): # A CoClass
	# CurrencyRestrictions Class
	CLSID = IID('{C02B3449-252C-42AD-A6AA-05513188EA84}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICurrencyRestrictions,
	]
	default_interface = ICurrencyRestrictions

# This CoClass is known by the name 'SAPbobsCOM.CustomerEquipmentCards.88.0'
class CustomerEquipmentCards(CoClassBaseClass): # A CoClass
	# CustomerEquipmentCards Class
	CLSID = IID('{6EF2D0B5-8580-41AD-B879-42738445BE03}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICustomerEquipmentCards,
	]
	default_interface = ICustomerEquipmentCards

# This CoClass is known by the name 'SapBobsCom.CustomsDeclaration.88.0'
class CustomsDeclaration(CoClassBaseClass): # A CoClass
	# CustomsDeclaration Class
	CLSID = IID('{B476320F-636F-42C4-9BA9-2D6CE71D3CBC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICustomsDeclaration,
	]
	default_interface = ICustomsDeclaration

# This CoClass is known by the name 'SapBobsCom.CustomsDeclarationParams.88.0'
class CustomsDeclarationParams(CoClassBaseClass): # A CoClass
	# CustomsDeclarationParams Class
	CLSID = IID('{C49DD31B-4B54-43B9-9E44-119635A4759A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICustomsDeclarationParams,
	]
	default_interface = ICustomsDeclarationParams

# This CoClass is known by the name 'SapBobsCom.CustomsDeclarationService.88.0'
class CustomsDeclarationService(CoClassBaseClass): # A CoClass
	# CustomsDeclarationService Class
	CLSID = IID('{9992E219-AAB5-48C8-B749-9D13289B4111}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICustomsDeclarationService,
	]
	default_interface = ICustomsDeclarationService

# This CoClass is known by the name 'SapBobsCom.CustomsGroups.88.0'
class CustomsGroups(CoClassBaseClass): # A CoClass
	# CustomsGroups Class
	CLSID = IID('{C7224CA0-BA56-4141-84AA-9E45D75208EF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ICustomsGroups,
	]
	default_interface = ICustomsGroups

# This CoClass is known by the name 'SapBobsCom.DNFCodeSetup.88.0'
class DNFCodeSetup(CoClassBaseClass): # A CoClass
	# DNFCodeSetup Class
	CLSID = IID('{24242AF5-F1A3-4688-9AB3-6CC76EB08D78}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDNFCodeSetup,
	]
	default_interface = IDNFCodeSetup

# This CoClass is known by the name 'SapBobsCom.DNFCodeSetupParams.88.0'
class DNFCodeSetupParams(CoClassBaseClass): # A CoClass
	# DNFCodeSetupParams Class
	CLSID = IID('{F4B554B0-CBF3-4258-89E5-F94FB08E463C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDNFCodeSetupParams,
	]
	default_interface = IDNFCodeSetupParams

# This CoClass is known by the name 'SapBobsCom.DNFCodeSetupParamsCollection.88.0'
class DNFCodeSetupParamsCollection(CoClassBaseClass): # A CoClass
	# DNFCodeSetupParamsCollection Class
	CLSID = IID('{6A7BB82D-309D-4A45-818A-6FAB750C449C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDNFCodeSetupParamsCollection,
	]
	default_interface = IDNFCodeSetupParamsCollection

# This CoClass is known by the name 'SapBobsCom.DNFCodeSetupService.88.0'
class DNFCodeSetupService(CoClassBaseClass): # A CoClass
	# DNFCodeSetupService Class
	CLSID = IID('{0B0ADBC6-6CCA-48DF-92A9-2D0633AED84B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDNFCodeSetupService,
	]
	default_interface = IDNFCodeSetupService

# This CoClass is known by the name 'SAPbobsCOM.DashboardPackageImportParams.88.0'
class DashboardPackageImportParams(CoClassBaseClass): # A CoClass
	# DashboardPackageImportParams Class
	CLSID = IID('{F563A16D-0B24-4D00-A668-C12DF72F6EE9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDashboardPackageImportParams,
	]
	default_interface = IDashboardPackageImportParams

# This CoClass is known by the name 'SAPbobsCOM.DashboardPackageParams.88.0'
class DashboardPackageParams(CoClassBaseClass): # A CoClass
	# DashboardPackageParams Class
	CLSID = IID('{B18C2498-6343-4620-87B9-6C298AE9BFD9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDashboardPackageParams,
	]
	default_interface = IDashboardPackageParams

# This CoClass is known by the name 'SAPbobsCOM.DashboardPackagesParams.88.0'
class DashboardPackagesParams(CoClassBaseClass): # A CoClass
	# DashboardPackagesParams Class
	CLSID = IID('{20971C52-C8A9-4B34-B882-A2B3D0826E32}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDashboardPackagesParams,
	]
	default_interface = IDashboardPackagesParams

# This CoClass is known by the name 'SAPbobsCOM.DashboardPackagesService.88.0'
class DashboardPackagesService(CoClassBaseClass): # A CoClass
	# DashboardPackagesService Class
	CLSID = IID('{DB836AB0-9F22-422C-BA3A-873208689C81}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDashboardPackagesService,
	]
	default_interface = IDashboardPackagesService

# This CoClass is known by the name 'SAPbobsCOM.DataBrowser.88.0'
class DataBrowser(CoClassBaseClass): # A CoClass
	# DataBrowser Class
	CLSID = IID('{0D5D4022-6FCC-49A4-AB69-7F4304B47EC9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDataBrowser,
	]
	default_interface = IDataBrowser

# This CoClass is known by the name 'SapBobsCom.DecimalData.88.0'
class DecimalData(CoClassBaseClass): # A CoClass
	# DecimalData Class
	CLSID = IID('{748FD7AC-AA7D-4D4D-A206-8E5898BDF94F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDecimalData,
	]
	default_interface = IDecimalData

# This CoClass is known by the name 'SapBobsCom.DeductionTaxGroups.88.0'
class DeductionTaxGroups(CoClassBaseClass): # A CoClass
	# DeductionTaxGroups Class
	CLSID = IID('{2D582F5D-2BE6-408A-A03A-ED37F5C30491}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDeductionTaxGroups,
	]
	default_interface = IDeductionTaxGroups

# This CoClass is known by the name 'SapBobsCom.DeductionTaxHierarchies.88.0'
class DeductionTaxHierarchies(CoClassBaseClass): # A CoClass
	# DeductionTaxHierarchies Class
	CLSID = IID('{57DED1E0-70C3-46C1-97BC-69B0F683D66C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDeductionTaxHierarchies,
	]
	default_interface = IDeductionTaxHierarchies

# This CoClass is known by the name 'SapBobsCom.DeductionTaxHierarchies_Lines.88.0'
class DeductionTaxHierarchies_Lines(CoClassBaseClass): # A CoClass
	# DeductionTaxHierarchies_Lines Class
	CLSID = IID('{20C0F904-66E3-4784-965E-65FC991D8FE8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDeductionTaxHierarchies_Lines,
	]
	default_interface = IDeductionTaxHierarchies_Lines

# This CoClass is known by the name 'SapBobsCom.DeductionTaxSubGroup.88.0'
class DeductionTaxSubGroup(CoClassBaseClass): # A CoClass
	# DeductionTaxSubGroup Class
	CLSID = IID('{FEC7996F-BF4C-4850-9576-FF3B3AF66851}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDeductionTaxSubGroup,
	]
	default_interface = IDeductionTaxSubGroup

# This CoClass is known by the name 'SapBobsCom.DeductionTaxSubGroupParams.88.0'
class DeductionTaxSubGroupParams(CoClassBaseClass): # A CoClass
	# DeductionTaxSubGroupParams Class
	CLSID = IID('{975B187C-4395-4FE4-ABEB-B347B279215B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDeductionTaxSubGroupParams,
	]
	default_interface = IDeductionTaxSubGroupParams

# This CoClass is known by the name 'SapBobsCom.DeductionTaxSubGroupsParams.88.0'
class DeductionTaxSubGroupsParams(CoClassBaseClass): # A CoClass
	# DeductionTaxSubGroupsParams Class
	CLSID = IID('{AF74F44A-F8C1-4A3E-B390-01D61430ED8A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDeductionTaxSubGroupsParams,
	]
	default_interface = IDeductionTaxSubGroupsParams

# This CoClass is known by the name 'SapBobsCom.DeductionTaxSubGroupsService.88.0'
class DeductionTaxSubGroupsService(CoClassBaseClass): # A CoClass
	# DeductionTaxSubGroupsService Class
	CLSID = IID('{F63CDC3F-A87E-4BEF-99DD-8F1540BD524D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDeductionTaxSubGroupsService,
	]
	default_interface = IDeductionTaxSubGroupsService

# This CoClass is known by the name 'SapBobsCom.DefaultCreditCards.88.0'
class DefaultCreditCards(CoClassBaseClass): # A CoClass
	# DefaultCreditCards Class
	CLSID = IID('{BE8AA2E1-EFFD-4AD5-AC95-47CB1C20BA57}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDefaultCreditCards,
	]
	default_interface = IDefaultCreditCards

# This CoClass is known by the name 'SapBobsCom.DefaultDocuments.88.0'
class DefaultDocuments(CoClassBaseClass): # A CoClass
	# DefaultDocuments Class
	CLSID = IID('{84920F8B-AB22-4ECF-997E-DDEDEDA235B3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDefaultDocuments,
	]
	default_interface = IDefaultDocuments

class DefaultElectronicSeriesParams(CoClassBaseClass): # A CoClass
	# DefaultElectronicSeriesParams Class
	CLSID = IID('{D5F33B11-D467-4234-AE58-63E6D70E6E26}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDefaultElectronicSeriesParams,
	]
	default_interface = IDefaultElectronicSeriesParams

# This CoClass is known by the name 'SapBobsCom.DefaultReportParams.88.0'
class DefaultReportParams(CoClassBaseClass): # A CoClass
	# DefaultReportParams Class
	CLSID = IID('{A67C6121-4F92-41C5-9517-38E9D760A0C0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDefaultReportParams,
	]
	default_interface = IDefaultReportParams

# This CoClass is known by the name 'SapBobsCom.Department.88.0'
class Department(CoClassBaseClass): # A CoClass
	# Department Class
	CLSID = IID('{2BFFCB89-7037-4E72-AA73-9E5667B51A78}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDepartment,
	]
	default_interface = IDepartment

# This CoClass is known by the name 'SapBobsCom.DepartmentParams.88.0'
class DepartmentParams(CoClassBaseClass): # A CoClass
	# DepartmentParams Class
	CLSID = IID('{8C6FB6CA-693A-4647-9F88-B0427A245D60}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDepartmentParams,
	]
	default_interface = IDepartmentParams

# This CoClass is known by the name 'SapBobsCom.DepartmentsParams.88.0'
class DepartmentsParams(CoClassBaseClass): # A CoClass
	# DepartmentsParams Class
	CLSID = IID('{D70469B5-F299-4F3E-9417-527D9BFEF649}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDepartmentsParams,
	]
	default_interface = IDepartmentsParams

# This CoClass is known by the name 'SapBobsCom.DepartmentsService.88.0'
class DepartmentsService(CoClassBaseClass): # A CoClass
	# DepartmentsService Class
	CLSID = IID('{C50A9BDA-E5A7-4458-A7CE-0029E035B1B7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDepartmentsService,
	]
	default_interface = IDepartmentsService

# This CoClass is known by the name 'SAPbobsCOM.Deposit.88.0'
class Deposit(CoClassBaseClass): # A CoClass
	# Deposit Class
	CLSID = IID('{77B8BCD1-46B3-41EF-92DD-F1F6680159DA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDeposit,
	]
	default_interface = IDeposit

# This CoClass is known by the name 'SAPbobsCOM.DepositParams.88.0'
class DepositParams(CoClassBaseClass): # A CoClass
	# DepositParams Class
	CLSID = IID('{93BF348F-60F8-4803-8621-9E3DB48B1852}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDepositParams,
	]
	default_interface = IDepositParams

# This CoClass is known by the name 'SAPbobsCOM.DepositsParams.88.0'
class DepositsParams(CoClassBaseClass): # A CoClass
	# DepositsParams Class
	CLSID = IID('{CD72781D-9EE9-4A21-8953-C5721F506955}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDepositsParams,
	]
	default_interface = IDepositsParams

# This CoClass is known by the name 'SAPbobsCOM.DepositsService.88.0'
class DepositsService(CoClassBaseClass): # A CoClass
	# DepositsService Class
	CLSID = IID('{1A645E6A-B777-419D-84A6-6074EB069C86}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDepositsService,
	]
	default_interface = IDepositsService

# This CoClass is known by the name 'SapBobsCom.Dimension.88.0'
class Dimension(CoClassBaseClass): # A CoClass
	# Dimension Class
	CLSID = IID('{63E62D10-4344-4575-9C8C-FCEE9779316C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDimension,
	]
	default_interface = IDimension

# This CoClass is known by the name 'SapBobsCom.DimensionParams.88.0'
class DimensionParams(CoClassBaseClass): # A CoClass
	# DimensionParams Class
	CLSID = IID('{F63FB1C7-CC5F-4FBD-AF7A-A1686D1BCD64}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDimensionParams,
	]
	default_interface = IDimensionParams

# This CoClass is known by the name 'SapBobsCom.DimensionsParams.88.0'
class DimensionsParams(CoClassBaseClass): # A CoClass
	# DimensionsParams Class
	CLSID = IID('{8C66EF53-C778-466A-AC1C-6BEB8605425D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDimensionsParams,
	]
	default_interface = IDimensionsParams

# This CoClass is known by the name 'SapBobsCom.DimensionsService.88.0'
class DimensionsService(CoClassBaseClass): # A CoClass
	# DimensionsService Class
	CLSID = IID('{9E01385A-524C-4A76-87AD-9FF9058E0185}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDimensionsService,
	]
	default_interface = IDimensionsService

class DiscountGroups(CoClassBaseClass): # A CoClass
	# DiscountGroups Class
	CLSID = IID('{63F3E235-30B2-4C42-8A9A-5953779F0C4E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDiscountGroups,
	]
	default_interface = IDiscountGroups

# This CoClass is known by the name 'SapBobsCom.DiscountLine.88.0'
class DiscountLine(CoClassBaseClass): # A CoClass
	# DiscountLine Class
	CLSID = IID('{4821A00E-CC17-4B2F-99A7-61D49901AC89}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDiscountLine,
	]
	default_interface = IDiscountLine

# This CoClass is known by the name 'SapBobsCom.DiscountLines.88.0'
class DiscountLines(CoClassBaseClass): # A CoClass
	# DiscountLines Class
	CLSID = IID('{C15B6D2B-EA40-48FC-990E-6CE5EB32B7E4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDiscountLines,
	]
	default_interface = IDiscountLines

# This CoClass is known by the name 'SapBobsCom.DistributionRule.88.0'
class DistributionRule(CoClassBaseClass): # A CoClass
	# DistributionRule Class
	CLSID = IID('{07E15DBA-2CB3-40D0-BE23-686EBE7F192D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDistributionRule,
	]
	default_interface = IDistributionRule

# This CoClass is known by the name 'SapBobsCom.DistributionRuleLine.88.0'
class DistributionRuleLine(CoClassBaseClass): # A CoClass
	# DistributionRuleLine Class
	CLSID = IID('{01EC1A1A-17D7-4A77-BCD5-2AE1B2FE4385}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDistributionRuleLine,
	]
	default_interface = IDistributionRuleLine

# This CoClass is known by the name 'SapBobsCom.DistributionRuleLines.88.0'
class DistributionRuleLines(CoClassBaseClass): # A CoClass
	# DistributionRuleLines Class
	CLSID = IID('{635ED325-EEA5-4340-AA1A-5845D97CFCC1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDistributionRuleLines,
	]
	default_interface = IDistributionRuleLines

# This CoClass is known by the name 'SapBobsCom.DistributionRuleParams.88.0'
class DistributionRuleParams(CoClassBaseClass): # A CoClass
	# DistributionRuleParams Class
	CLSID = IID('{DB0B495A-9C94-4B49-8DB1-DEA4B58C73C2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDistributionRuleParams,
	]
	default_interface = IDistributionRuleParams

# This CoClass is known by the name 'SapBobsCom.DistributionRulesParams.88.0'
class DistributionRulesParams(CoClassBaseClass): # A CoClass
	# DistributionRulesParams Class
	CLSID = IID('{22F927F7-9B09-4F79-8D9E-564CB2047BCE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDistributionRulesParams,
	]
	default_interface = IDistributionRulesParams

# This CoClass is known by the name 'SapBobsCom.DistributionRulesService.88.0'
class DistributionRulesService(CoClassBaseClass): # A CoClass
	# DistributionRulesService Class
	CLSID = IID('{D30C3CFB-358F-45C2-9F62-9CE26AF80E13}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDistributionRulesService,
	]
	default_interface = IDistributionRulesService

class DocumentChangeMenuName(CoClassBaseClass): # A CoClass
	# DocumentChangeMenuName Class
	CLSID = IID('{2E4A01AF-5881-4F33-8D91-A4EBBFADBADA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocumentChangeMenuName,
	]
	default_interface = IDocumentChangeMenuName

# This CoClass is known by the name 'SAPbobsCOM.DocumentPackageItems.88.0'
class DocumentPackageItems(CoClassBaseClass): # A CoClass
	# DocumentPackageItems Class
	CLSID = IID('{061EDFD2-1326-4FC7-B95A-CD30593B6448}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocumentPackageItems,
	]
	default_interface = IDocumentPackageItems

# This CoClass is known by the name 'SAPbobsCOM.DocumentPackages.88.0'
class DocumentPackages(CoClassBaseClass): # A CoClass
	# DocumentPackages Class
	CLSID = IID('{46BED4FA-A7F1-4067-8FC7-A6303F0F3A5C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocumentPackages,
	]
	default_interface = IDocumentPackages

# This CoClass is known by the name 'SapBobsCom.DocumentSeriesParams.88.0'
class DocumentSeriesParams(CoClassBaseClass): # A CoClass
	# DocumentSeriesParams Class
	CLSID = IID('{284C40A5-FADD-4910-90EF-21825F75E6FD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocumentSeriesParams,
	]
	default_interface = IDocumentSeriesParams

# This CoClass is known by the name 'SapBobsCom.DocumentSeriesUserParams.88.0'
class DocumentSeriesUserParams(CoClassBaseClass): # A CoClass
	# DocumentSeriesUserParams Class
	CLSID = IID('{CA9C97EF-439D-4040-B1A1-39F83CBC2CD5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocumentSeriesUserParams,
	]
	default_interface = IDocumentSeriesUserParams

# This CoClass is known by the name 'SapBobsCom.DocumentTypeParams.88.0'
class DocumentTypeParams(CoClassBaseClass): # A CoClass
	# DocumentTypeParams Class
	CLSID = IID('{A04457CF-8DB7-477B-9298-374E7CDAA9D8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocumentTypeParams,
	]
	default_interface = IDocumentTypeParams

class Document_ApprovalRequests(CoClassBaseClass): # A CoClass
	# Document_ApprovalRequests Class
	CLSID = IID('{1BB46BE0-4ECB-44DB-B6ED-64356031568E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocument_ApprovalRequests,
	]
	default_interface = IDocument_ApprovalRequests

# This CoClass is known by the name 'SAPbobsCOM.Document_Installments.88.0'
class Document_Installments(CoClassBaseClass): # A CoClass
	# Document_Installments Class
	CLSID = IID('{1EFBEFDD-F21B-44B1-B275-3091E89031B7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocument_Installments,
	]
	default_interface = IDocument_Installments

# This CoClass is known by the name 'SAPbobsCOM.Document_Lines.88.0'
class Document_Lines(CoClassBaseClass): # A CoClass
	# Document_Lines Class
	CLSID = IID('{E9B749CA-045B-4BDD-A5BD-143458EBA752}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocument_Lines,
	]
	default_interface = IDocument_Lines

# This CoClass is known by the name 'SAPbobsCOM.Document_LinesAdditionalExpenses.88.0'
class Document_LinesAdditionalExpenses(CoClassBaseClass): # A CoClass
	# Document_LinesAdditionalExpenses Class
	CLSID = IID('{7F3611B7-822C-41C3-82DB-2D8909B59C7A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocument_LinesAdditionalExpenses,
	]
	default_interface = IDocument_LinesAdditionalExpenses

# This CoClass is known by the name 'SAPbobsCOM.Document_SpecialLines.88.0'
class Document_SpecialLines(CoClassBaseClass): # A CoClass
	# Document_SpecialLines Class
	CLSID = IID('{E0F9420B-02BE-490B-BE28-1216726EF3FD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocument_SpecialLines,
	]
	default_interface = IDocument_SpecialLines

# This CoClass is known by the name 'SAPbobsCOM.Documents.88.0'
class Documents(CoClassBaseClass): # A CoClass
	# Documents Class
	CLSID = IID('{4AFE074D-4F31-4E7B-87DF-64D55098DA5E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocuments,
	]
	default_interface = IDocuments

# This CoClass is known by the name 'SAPbobsCOM.DocumentsAdditionalExpenses.88.0'
class DocumentsAdditionalExpenses(CoClassBaseClass): # A CoClass
	# DocumentsAdditionalExpenses Class
	CLSID = IID('{5E9FC07C-E9A5-465A-A532-F12DC65304D4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDocumentsAdditionalExpenses,
	]
	default_interface = IDocumentsAdditionalExpenses

class DownPaymentsToDraw(CoClassBaseClass): # A CoClass
	# DownPaymentsToDraw Class
	CLSID = IID('{BD563FC1-66EC-4D79-AFF0-CB3057D01161}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDownPaymentsToDraw,
	]
	default_interface = IDownPaymentsToDraw

# This CoClass is known by the name 'SAPbobsCOM.DownPaymentsToDrawDetails.2007.0'
class DownPaymentsToDrawDetails(CoClassBaseClass): # A CoClass
	# DownPaymentsToDrawDetails Class
	CLSID = IID('{986A5D5D-8D68-40EF-B579-C5A4CBAC0CFE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDownPaymentsToDrawDetails,
	]
	default_interface = IDownPaymentsToDrawDetails

# This CoClass is known by the name 'SAPbobsCOM.DunningLetters.88.0'
class DunningLetters(CoClassBaseClass): # A CoClass
	# DunningLetters Class
	CLSID = IID('{8C9A31B4-0BEA-4A72-8D4E-F4C00F683E6B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDunningLetters,
	]
	default_interface = IDunningLetters

# This CoClass is known by the name 'SAPbobsCOM.DunningTerm.88.0'
class DunningTerm(CoClassBaseClass): # A CoClass
	# DunningTerm Class
	CLSID = IID('{C56982FE-CF84-47FD-9FE3-5E983ED0C419}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDunningTerm,
	]
	default_interface = IDunningTerm

# This CoClass is known by the name 'SAPbobsCOM.DunningTermLine.88.0'
class DunningTermLine(CoClassBaseClass): # A CoClass
	# DunningTermLine Class
	CLSID = IID('{AEDDBC24-5587-4895-A37D-E41F54A42A44}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDunningTermLine,
	]
	default_interface = IDunningTermLine

# This CoClass is known by the name 'SAPbobsCOM.DunningTermLines.88.0'
class DunningTermLines(CoClassBaseClass): # A CoClass
	# DunningTermLines Class
	CLSID = IID('{8529DA4C-CD2E-4D6B-95F9-E4BE53D72883}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDunningTermLines,
	]
	default_interface = IDunningTermLines

# This CoClass is known by the name 'SAPbobsCOM.DunningTermParams.88.0'
class DunningTermParams(CoClassBaseClass): # A CoClass
	# DunningTermParams Class
	CLSID = IID('{7BD692D0-D375-4754-AC78-310F1035CEF8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDunningTermParams,
	]
	default_interface = IDunningTermParams

# This CoClass is known by the name 'SAPbobsCOM.DunningTermsParams.88.0'
class DunningTermsParams(CoClassBaseClass): # A CoClass
	# DunningTermsParams Class
	CLSID = IID('{FB73DAFB-EA3A-4D1B-9EFC-57F68BF26A2E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDunningTermsParams,
	]
	default_interface = IDunningTermsParams

# This CoClass is known by the name 'SAPbobsCOM.DunningTermsService.88.0'
class DunningTermsService(CoClassBaseClass): # A CoClass
	# DunningTermsService Class
	CLSID = IID('{C18E808F-F2E2-4D1D-8F5F-5CCE8C2D274B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDunningTermsService,
	]
	default_interface = IDunningTermsService

# This CoClass is known by the name 'SapBobsCom.DynamicSystemStrings.88.0'
class DynamicSystemStrings(CoClassBaseClass): # A CoClass
	# DynamicSystemStrings Class
	CLSID = IID('{EAA25EB5-36C7-4AC8-936E-6AA6CF421FDD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IDynamicSystemStrings,
	]
	default_interface = IDynamicSystemStrings

# This CoClass is known by the name 'SAPbobsCOM.ElectronicFileFormat.88.0'
class ElectronicFileFormat(CoClassBaseClass): # A CoClass
	# ElectronicFileFormat Class
	CLSID = IID('{D63B7918-80EA-4553-A01E-A574620DCEF6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IElectronicFileFormat,
	]
	default_interface = IElectronicFileFormat

# This CoClass is known by the name 'SAPbobsCOM.ElectronicFileFormatParams.88.0'
class ElectronicFileFormatParams(CoClassBaseClass): # A CoClass
	# ElectronicFileFormatParams Class
	CLSID = IID('{417DC595-38A9-48E4-ABC1-AD08B2C0070B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IElectronicFileFormatParams,
	]
	default_interface = IElectronicFileFormatParams

# This CoClass is known by the name 'SAPbobsCOM.ElectronicFileFormatsParams.88.0'
class ElectronicFileFormatsParams(CoClassBaseClass): # A CoClass
	# ElectronicFileFormatsParams Class
	CLSID = IID('{12E82740-BADE-4630-8BDB-2C3073D27F45}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IElectronicFileFormatsParams,
	]
	default_interface = IElectronicFileFormatsParams

# This CoClass is known by the name 'SAPbobsCOM.ElectronicFileFormatsService.88.0'
class ElectronicFileFormatsService(CoClassBaseClass): # A CoClass
	# ElectronicFileFormatsService Class
	CLSID = IID('{ADFCD5D9-B501-4CB5-892C-61FE7FB225B3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IElectronicFileFormatsService,
	]
	default_interface = IElectronicFileFormatsService

class ElectronicSeries(CoClassBaseClass): # A CoClass
	# ElectronicSeries Class
	CLSID = IID('{96C491DF-52C0-42C6-802A-5890F273BE5A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IElectronicSeries,
	]
	default_interface = IElectronicSeries

class ElectronicSeriesCollection(CoClassBaseClass): # A CoClass
	# ElectronicSeriesCollection Class
	CLSID = IID('{0561126D-01CD-453B-A5FB-6AC3C11E05D5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IElectronicSeriesCollection,
	]
	default_interface = IElectronicSeriesCollection

class ElectronicSeriesParams(CoClassBaseClass): # A CoClass
	# ElectronicSeriesParams Class
	CLSID = IID('{026951FA-5BBD-4559-BA2D-771C19E66BBD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IElectronicSeriesParams,
	]
	default_interface = IElectronicSeriesParams

# This CoClass is known by the name 'SAPbobsCOM.EmployeeAbsenceInfo.88.0'
class EmployeeAbsenceInfo(CoClassBaseClass): # A CoClass
	# EmployeeAbsenceInfo Class
	CLSID = IID('{A574B4DA-F87A-414B-AC49-ED8C6BF84B2C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeAbsenceInfo,
	]
	default_interface = IEmployeeAbsenceInfo

# This CoClass is known by the name 'SAPbobsCOM.EmployeeEducationInfo.88.0'
class EmployeeEducationInfo(CoClassBaseClass): # A CoClass
	# EmployeeEducationInfo Class
	CLSID = IID('{8D158412-BA39-4046-8326-2E22EE49F8C1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeEducationInfo,
	]
	default_interface = IEmployeeEducationInfo

# This CoClass is known by the name 'SAPbobsCOM.EmployeeIDType.88.0'
class EmployeeIDType(CoClassBaseClass): # A CoClass
	# EmployeeIDType Class
	CLSID = IID('{5C3925BA-87A6-4C77-B1DE-ABB68B9814FA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeIDType,
	]
	default_interface = IEmployeeIDType

# This CoClass is known by the name 'SAPbobsCOM.EmployeeIDTypeParams.88.0'
class EmployeeIDTypeParams(CoClassBaseClass): # A CoClass
	# EmployeeIDTypeParams Class
	CLSID = IID('{2C6522F2-47AE-4707-B34C-A4973216808E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeIDTypeParams,
	]
	default_interface = IEmployeeIDTypeParams

# This CoClass is known by the name 'SAPbobsCOM.EmployeeIDTypeParamsCollection.88.0'
class EmployeeIDTypeParamsCollection(CoClassBaseClass): # A CoClass
	# EmployeeIDTypeParamsCollection Class
	CLSID = IID('{E2AABE75-E867-4BE2-8E09-AD1EE61C62BC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeIDTypeParamsCollection,
	]
	default_interface = IEmployeeIDTypeParamsCollection

# This CoClass is known by the name 'SAPbobsCOM.EmployeeIDTypeService.88.0'
class EmployeeIDTypeService(CoClassBaseClass): # A CoClass
	# EmployeeIDTypeService Class
	CLSID = IID('{F574C00A-3CAE-4269-84D7-E77A6237CAE0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeIDTypeService,
	]
	default_interface = IEmployeeIDTypeService

# This CoClass is known by the name 'SAPbobsCOM.EmployeePrevEmpoymentInfo.88.0'
class EmployeePrevEmpoymentInfo(CoClassBaseClass): # A CoClass
	# EmployeePrevEmpoymentInfo Class
	CLSID = IID('{9E334DDA-DD14-48A7-8482-292392B27A13}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeePrevEmpoymentInfo,
	]
	default_interface = IEmployeePrevEmpoymentInfo

# This CoClass is known by the name 'SAPbobsCOM.EmployeeReviewsInfo.88.0'
class EmployeeReviewsInfo(CoClassBaseClass): # A CoClass
	# EmployeeReviewsInfo Class
	CLSID = IID('{3FF527E2-2FBB-4F74-BBF9-C0EDBF44E63C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeReviewsInfo,
	]
	default_interface = IEmployeeReviewsInfo

# This CoClass is known by the name 'SapBobsCom.EmployeeRoleSetup.88.0'
class EmployeeRoleSetup(CoClassBaseClass): # A CoClass
	# EmployeeRoleSetup Class
	CLSID = IID('{1D5336D5-065A-44D3-AFCC-D8BBEFB03234}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeRoleSetup,
	]
	default_interface = IEmployeeRoleSetup

# This CoClass is known by the name 'SapBobsCom.EmployeeRoleSetupParams.88.0'
class EmployeeRoleSetupParams(CoClassBaseClass): # A CoClass
	# EmployeeRoleSetupParams Class
	CLSID = IID('{C04822E7-C6E2-46D3-94FC-712AFB757912}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeRoleSetupParams,
	]
	default_interface = IEmployeeRoleSetupParams

# This CoClass is known by the name 'SapBobsCom.EmployeeRoleSetupParamsCollection.88.0'
class EmployeeRoleSetupParamsCollection(CoClassBaseClass): # A CoClass
	# EmployeeRoleSetupParamsCollection Class
	CLSID = IID('{879F8B93-27BD-48D8-BFB9-34F47B572F48}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeRoleSetupParamsCollection,
	]
	default_interface = IEmployeeRoleSetupParamsCollection

class EmployeeRolesInfo(CoClassBaseClass): # A CoClass
	# EmployeeRolesInfo Class
	CLSID = IID('{E644A5ED-C97E-4EE8-8191-E20EBC9508AB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeRolesInfo,
	]
	default_interface = IEmployeeRolesInfo

# This CoClass is known by the name 'SapBobsCom.EmployeeRolesSetupService.88.0'
class EmployeeRolesSetupService(CoClassBaseClass): # A CoClass
	# EmployeeRolesSetupService Class
	CLSID = IID('{1E3842BA-EAE5-4CAC-A134-0328B7986BBC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeRolesSetupService,
	]
	default_interface = IEmployeeRolesSetupService

# This CoClass is known by the name 'SAPbobsCOM.EmployeeSavingsPaymentInfo.88.0'
class EmployeeSavingsPaymentInfo(CoClassBaseClass): # A CoClass
	# EmployeeSavingsPaymentInfo Class
	CLSID = IID('{9AF2EEA5-78E2-4CE5-A748-29C849AD9096}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeSavingsPaymentInfo,
	]
	default_interface = IEmployeeSavingsPaymentInfo

# This CoClass is known by the name 'SAPbobsCOM.EmployeeTransfer.88.0'
class EmployeeTransfer(CoClassBaseClass): # A CoClass
	# EmployeeTransfer Class
	CLSID = IID('{38DFDAC8-1F86-4E1D-9CDE-00425A5143BA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeTransfer,
	]
	default_interface = IEmployeeTransfer

# This CoClass is known by the name 'SAPbobsCOM.EmployeeTransferDetail.88.0'
class EmployeeTransferDetail(CoClassBaseClass): # A CoClass
	# EmployeeTransferDetail Class
	CLSID = IID('{05F0D981-435B-46CE-B13D-25D4A87B8088}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeTransferDetail,
	]
	default_interface = IEmployeeTransferDetail

# This CoClass is known by the name 'SAPbobsCOM.EmployeeTransferDetails.88.0'
class EmployeeTransferDetails(CoClassBaseClass): # A CoClass
	# EmployeeTransferDetails Class
	CLSID = IID('{AAD58C85-8182-4A48-AC46-3D29F6E02F83}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeTransferDetails,
	]
	default_interface = IEmployeeTransferDetails

# This CoClass is known by the name 'SAPbobsCOM.EmployeeTransferParams.88.0'
class EmployeeTransferParams(CoClassBaseClass): # A CoClass
	# EmployeeTransferParams Class
	CLSID = IID('{BDDB80DE-CB4A-44DC-8BAC-1F1169E23805}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeTransferParams,
	]
	default_interface = IEmployeeTransferParams

# This CoClass is known by the name 'SAPbobsCOM.EmployeeTransfersParams.88.0'
class EmployeeTransfersParams(CoClassBaseClass): # A CoClass
	# EmployeeTransfersParams Class
	CLSID = IID('{2FCB8823-03A3-47F9-BC0B-EEC815138967}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeTransfersParams,
	]
	default_interface = IEmployeeTransfersParams

# This CoClass is known by the name 'SAPbobsCOM.EmployeeTransfersService.88.0'
class EmployeeTransfersService(CoClassBaseClass): # A CoClass
	# EmployeeTransfersService Class
	CLSID = IID('{E8E96048-6DF2-4DE2-8311-72582D7F4512}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeeTransfersService,
	]
	default_interface = IEmployeeTransfersService

# This CoClass is known by the name 'SAPbobsCOM.EmployeesInfo.88.0'
class EmployeesInfo(CoClassBaseClass): # A CoClass
	# EmployeesInfo Class
	CLSID = IID('{EB49B71E-C20E-4D6D-8ECD-A641B0BAAA35}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IEmployeesInfo,
	]
	default_interface = IEmployeesInfo

# This CoClass is known by the name 'SAPbobsCOM.ExportProcesses.88.0'
class ExportProcesses(CoClassBaseClass): # A CoClass
	# ExportProcesses Class
	CLSID = IID('{DF1B1704-3860-4602-914C-71D3A9789748}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExportProcesses,
	]
	default_interface = IExportProcesses

class ExtendedAdminInfo(CoClassBaseClass): # A CoClass
	# ExtendedAdminInfo Class
	CLSID = IID('{3E8F0EBB-ED4D-4C8D-B14C-5012989DC570}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExtendedAdminInfo,
	]
	default_interface = IExtendedAdminInfo

# This CoClass is known by the name 'SAPbobsCOM.ExtendedTranslation.88.0'
class ExtendedTranslation(CoClassBaseClass): # A CoClass
	# ExtendedTranslation Class
	CLSID = IID('{F8306AD8-D5B1-4CBE-A36B-ECF55FF2D3FE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExtendedTranslation,
	]
	default_interface = IExtendedTranslation

# This CoClass is known by the name 'SAPbobsCOM.ExtendedTranslationParams.88.0'
class ExtendedTranslationParams(CoClassBaseClass): # A CoClass
	# ExtendedTranslationParams Class
	CLSID = IID('{0CA3C6AF-091A-4C96-9F9D-F9B99F868AB7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExtendedTranslationParams,
	]
	default_interface = IExtendedTranslationParams

# This CoClass is known by the name 'SAPbobsCOM.ExtendedTranslation_ItemLine.88.0'
class ExtendedTranslation_ItemLine(CoClassBaseClass): # A CoClass
	# ExtendedTranslation_ItemLine Class
	CLSID = IID('{58CF80CD-7170-4036-93FC-C43C324FE006}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExtendedTranslation_ItemLine,
	]
	default_interface = IExtendedTranslation_ItemLine

# This CoClass is known by the name 'SAPbobsCOM.ExtendedTranslation_ItemLines.88.0'
class ExtendedTranslation_ItemLines(CoClassBaseClass): # A CoClass
	# ExtendedTranslation_ItemLines Class
	CLSID = IID('{E08287E7-64BE-4C4F-B25D-78EEEB40A94C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExtendedTranslation_ItemLines,
	]
	default_interface = IExtendedTranslation_ItemLines

# This CoClass is known by the name 'SAPbobsCOM.ExtendedTranslation_ResultLine.88.0'
class ExtendedTranslation_ResultLine(CoClassBaseClass): # A CoClass
	# ExtendedTranslation_ResultLine Class
	CLSID = IID('{4CD3DB89-C622-42EF-BEBD-7BB1CF9F5E54}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExtendedTranslation_ResultLine,
	]
	default_interface = IExtendedTranslation_ResultLine

# This CoClass is known by the name 'SAPbobsCOM.ExtendedTranslation_ResultLines.88.0'
class ExtendedTranslation_ResultLines(CoClassBaseClass): # A CoClass
	# ExtendedTranslation_ResultLines Class
	CLSID = IID('{23CD8BD9-08A1-469B-936F-6C468F37B31A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExtendedTranslation_ResultLines,
	]
	default_interface = IExtendedTranslation_ResultLines

# This CoClass is known by the name 'SAPbobsCOM.ExtendedTranslationsParams.88.0'
class ExtendedTranslationsParams(CoClassBaseClass): # A CoClass
	# ExtendedTranslationsParams Class
	CLSID = IID('{C24AF27A-8F41-42CD-8881-98F964EDF2C1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExtendedTranslationsParams,
	]
	default_interface = IExtendedTranslationsParams

# This CoClass is known by the name 'SAPbobsCOM.ExtendedTranslationsService.88.0'
class ExtendedTranslationsService(CoClassBaseClass): # A CoClass
	# ExtendedTranslationsService Class
	CLSID = IID('{E7011745-D89C-48AA-AC84-93CFC315B5CC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExtendedTranslationsService,
	]
	default_interface = IExtendedTranslationsService

# This CoClass is known by the name 'SapBobsCom.ExternalCall.88.0'
class ExternalCall(CoClassBaseClass): # A CoClass
	# ExternalCall Class
	CLSID = IID('{0247151C-E23B-4C8A-B5BB-3BC1203A04EC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExternalCall,
	]
	default_interface = IExternalCall

# This CoClass is known by the name 'SapBobsCom.ExternalCallParams.88.0'
class ExternalCallParams(CoClassBaseClass): # A CoClass
	# ExternalCallParams Class
	CLSID = IID('{42D4F1DC-5789-4594-A1D7-601CAFBBA6C9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExternalCallParams,
	]
	default_interface = IExternalCallParams

# This CoClass is known by the name 'SapBobsCom.ExternalCallsService.88.0'
class ExternalCallsService(CoClassBaseClass): # A CoClass
	# ExternalCallsService Class
	CLSID = IID('{215D7856-947B-49AC-BE80-CF521824D692}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IExternalCallsService,
	]
	default_interface = IExternalCallsService

# This CoClass is known by the name 'SAPbobsCOM.FIFOLayers.88.0'
class FIFOLayers(CoClassBaseClass): # A CoClass
	# FIFOLayers Class
	CLSID = IID('{4FE2A366-A423-4720-967D-4227EC04B8DE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFIFOLayers,
	]
	default_interface = IFIFOLayers

# This CoClass is known by the name 'SapBobsCom.FactoringIndicators.88.0'
class FactoringIndicators(CoClassBaseClass): # A CoClass
	# FactoringIndicators Class
	CLSID = IID('{7178EF0A-1740-4B4C-89A2-779BB1E618D9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFactoringIndicators,
	]
	default_interface = IFactoringIndicators

# This CoClass is known by the name 'SapBobsCom.FeatureStatus.88.0'
class FeatureStatus(CoClassBaseClass): # A CoClass
	# FeatureStatus Class
	CLSID = IID('{605E409B-D305-4DB4-8FC2-FFE8E3AD8EE9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFeatureStatus,
	]
	default_interface = IFeatureStatus

# This CoClass is known by the name 'SapBobsCom.FeatureStatusCollection.88.0'
class FeatureStatusCollection(CoClassBaseClass): # A CoClass
	# FeatureStatusCollection Class
	CLSID = IID('{384B70CF-CF41-42B7-8599-B65597837C3F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFeatureStatusCollection,
	]
	default_interface = IFeatureStatusCollection

# This CoClass is known by the name 'SAPbobsCOM.Field.88.0'
class Field(CoClassBaseClass): # A CoClass
	# Field Class
	CLSID = IID('{0B6BCB38-6594-4EAB-88A8-5EEB856FF1EB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IField,
	]
	default_interface = IField

# This CoClass is known by the name 'SAPbobsCOM.Fields.88.0'
class Fields(CoClassBaseClass): # A CoClass
	# Fields Class
	CLSID = IID('{9D3B180E-A24C-48C9-A742-093663FF1878}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFields,
	]
	default_interface = IFields

# This CoClass is known by the name 'SapBobsCom.FinancePeriod.88.0'
class FinancePeriod(CoClassBaseClass): # A CoClass
	# FinancePeriod Class
	CLSID = IID('{F1CD6BFD-F77D-4059-A4E7-016D298C5C4D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFinancePeriod,
	]
	default_interface = IFinancePeriod

# This CoClass is known by the name 'SapBobsCom.FinancePeriodParams.88.0'
class FinancePeriodParams(CoClassBaseClass): # A CoClass
	# FinancePeriodParams Class
	CLSID = IID('{6CC3E1D1-D934-46CD-9DAD-33C30A06CA1C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFinancePeriodParams,
	]
	default_interface = IFinancePeriodParams

# This CoClass is known by the name 'SapBobsCom.FinancePeriods.88.0'
class FinancePeriods(CoClassBaseClass): # A CoClass
	# FinancePeriods Class
	CLSID = IID('{E4546110-84BF-46DE-9E5B-CB9CA610296E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFinancePeriods,
	]
	default_interface = IFinancePeriods

# This CoClass is known by the name 'SAPbobsCOM.FinancialYear.88.0'
class FinancialYear(CoClassBaseClass): # A CoClass
	# FinancialYear Class
	CLSID = IID('{A44871DD-1C9F-4CCA-B9F9-CF688753D4B2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFinancialYear,
	]
	default_interface = IFinancialYear

# This CoClass is known by the name 'SAPbobsCOM.FinancialYearParams.88.0'
class FinancialYearParams(CoClassBaseClass): # A CoClass
	# FinancialYearParams Class
	CLSID = IID('{81305C7E-36A1-4336-A7D6-FEDB889A790B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFinancialYearParams,
	]
	default_interface = IFinancialYearParams

# This CoClass is known by the name 'SAPbobsCOM.FinancialYearsParams.88.0'
class FinancialYearsParams(CoClassBaseClass): # A CoClass
	# FinancialYearsParams Class
	CLSID = IID('{41CE0964-B3EC-45D0-AB38-D1D70788750E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFinancialYearsParams,
	]
	default_interface = IFinancialYearsParams

# This CoClass is known by the name 'SAPbobsCOM.FinancialYearsService.88.0'
class FinancialYearsService(CoClassBaseClass): # A CoClass
	# FinancialYearsService Class
	CLSID = IID('{1870838E-C4B4-4ACB-A0F8-FD98EE7673F6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFinancialYearsService,
	]
	default_interface = IFinancialYearsService

class FormPreferencesService(CoClassBaseClass): # A CoClass
	# FormPreferencesService Class
	CLSID = IID('{08F86A95-6E92-4287-AA3A-8B044183ED1F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFormPreferencesService,
	]
	default_interface = IFormPreferencesService

# This CoClass is known by the name 'SapBobsCom.FormattedSearches.88.0'
class FormattedSearches(CoClassBaseClass): # A CoClass
	# FormattedSearches Class
	CLSID = IID('{B4031DD0-97CA-4315-8ED6-211B8368E96F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IFormattedSearches,
	]
	default_interface = IFormattedSearches

# This CoClass is known by the name 'SapBobsCom.Forms1099.88.0'
class Forms1099(CoClassBaseClass): # A CoClass
	# Forms1099 Class
	CLSID = IID('{97B3DA37-698B-4ED4-84E8-B8A110AEC25E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IForms1099,
	]
	default_interface = IForms1099

# This CoClass is known by the name 'SapBobsCom.GLAccount.88.0'
class GLAccount(CoClassBaseClass): # A CoClass
	# GLAccount Class
	CLSID = IID('{9D04BDB8-F941-49C2-A9C1-E11A71681BAA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGLAccount,
	]
	default_interface = IGLAccount

# This CoClass is known by the name 'SapBobsCom.GLAccounts.88.0'
class GLAccounts(CoClassBaseClass): # A CoClass
	# GLAccounts Class
	CLSID = IID('{F7DE78D1-5738-4D41-8002-396D495E6483}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGLAccounts,
	]
	default_interface = IGLAccounts

# This CoClass is known by the name 'SAPbobsCOM.GTIParams.88.0'
class GTIParams(CoClassBaseClass): # A CoClass
	# GTIParams Class
	CLSID = IID('{9B1154A7-0B01-4FF6-89F3-9A601676D895}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGTIParams,
	]
	default_interface = IGTIParams

# This CoClass is known by the name 'SAPbobsCOM.GTIParamsCollection.88.0'
class GTIParamsCollection(CoClassBaseClass): # A CoClass
	# GTIParamsCollection Class
	CLSID = IID('{47C12E2F-E1CA-41E8-A9FA-F8415E2B6125}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGTIParamsCollection,
	]
	default_interface = IGTIParamsCollection

# This CoClass is known by the name 'SAPbobsCOM.GTIsService.88.0'
class GTIsService(CoClassBaseClass): # A CoClass
	# GTIsService Class
	CLSID = IID('{E90FD334-9FC7-4E35-8E2D-43D338D63C1F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGTIsService,
	]
	default_interface = IGTIsService

# This CoClass is known by the name 'SapBobsCom.GeneralCollectionParams.88.0'
class GeneralCollectionParams(CoClassBaseClass): # A CoClass
	# GeneralCollectionParams Class
	CLSID = IID('{BA6EBBED-CE1B-4EB3-9B32-FE16126BFFC2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGeneralCollectionParams,
	]
	default_interface = IGeneralCollectionParams

# This CoClass is known by the name 'SapBobsCom.GeneralData.88.0'
class GeneralData(CoClassBaseClass): # A CoClass
	# GeneralData Class
	CLSID = IID('{2240A153-81F1-4335-8702-1EB085CB1056}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGeneralData,
	]
	default_interface = IGeneralData

class GeneralDataCollection(CoClassBaseClass): # A CoClass
	# GeneralDataCollection Class
	CLSID = IID('{16BDDE57-AD9D-48FE-9E33-964239B3F414}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGeneralDataCollection,
	]
	default_interface = IGeneralDataCollection

# This CoClass is known by the name 'SapBobsCom.GeneralDataParams.88.0'
class GeneralDataParams(CoClassBaseClass): # A CoClass
	# GeneralDataParams Class
	CLSID = IID('{E56E576E-555C-4F31-8170-0EFA192411E2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGeneralDataParams,
	]
	default_interface = IGeneralDataParams

# This CoClass is known by the name 'SapBobsCom.GeneralService.88.0'
class GeneralService(CoClassBaseClass): # A CoClass
	# GeneralService Class
	CLSID = IID('{5433B477-761B-47F3-8F1B-12694ED7AE47}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGeneralService,
	]
	default_interface = IGeneralService

# This CoClass is known by the name 'SAPbobsCOM.GetChangeLogParams.88.0'
class GetChangeLogParams(CoClassBaseClass): # A CoClass
	# GetChangeLogParams Class
	CLSID = IID('{BCB7B6F8-6750-499E-B446-BC080CAD82D1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IGetChangeLogParams,
	]
	default_interface = IGetChangeLogParams

# This CoClass is known by the name 'SapBobsCom.HouseBankAccounts.88.0'
class HouseBankAccounts(CoClassBaseClass): # A CoClass
	# HouseBankAccounts Class
	CLSID = IID('{65307EF1-BD5A-4297-B9F0-7F957D7CC0FC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IHouseBankAccounts,
	]
	default_interface = IHouseBankAccounts

# This CoClass is known by the name 'SAPbobsCOM.ImportFileParam.88.0'
class ImportFileParam(CoClassBaseClass): # A CoClass
	# ImportFileParam Class
	CLSID = IID('{6A174FBA-0ED4-4619-BC5F-2DF68BB53C89}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IImportFileParam,
	]
	default_interface = IImportFileParam

# This CoClass is known by the name 'SAPbobsCOM.ImportProcesses.88.0'
class ImportProcesses(CoClassBaseClass): # A CoClass
	# ImportProcesses Class
	CLSID = IID('{0F2D8F44-9F7D-4290-8A2C-9B08EC782ECD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IImportProcesses,
	]
	default_interface = IImportProcesses

# This CoClass is known by the name 'SAPbobsCOM.Industries.88.0'
class Industries(CoClassBaseClass): # A CoClass
	# Industries Class
	CLSID = IID('{4E6D1836-16F8-4D8F-9BF8-0271F4856450}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IIndustries,
	]
	default_interface = IIndustries

# This CoClass is known by the name 'SapBobsCom.InventoryCycles.88.0'
class InventoryCycles(CoClassBaseClass): # A CoClass
	# InventoryCycles Class
	CLSID = IID('{A9FD63E5-C131-4554-975C-7D8C5C0A2A0A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IInventoryCycles,
	]
	default_interface = IInventoryCycles

# This CoClass is known by the name 'SapBobsCom.InvokeParams.88.0'
class InvokeParams(CoClassBaseClass): # A CoClass
	# InvokeParams Class
	CLSID = IID('{49353779-B77E-4F0C-B8DE-499566F0A89A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IInvokeParams,
	]
	default_interface = IInvokeParams

# This CoClass is known by the name 'SapBobsCom.ItemCycleCount.88.0'
class ItemCycleCount(CoClassBaseClass): # A CoClass
	# ItemCycleCount Class
	CLSID = IID('{17865049-85ED-47FE-8CCF-C481E3373439}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItemCycleCount,
	]
	default_interface = IItemCycleCount

class ItemGroups(CoClassBaseClass): # A CoClass
	# ItemGroups Class
	CLSID = IID('{5F2AE736-E6D3-4D3A-BCB5-F9EE3A45872A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItemGroups,
	]
	default_interface = IItemGroups

class ItemLocalizationInfos(CoClassBaseClass): # A CoClass
	# ItemLocalizationInfos Class
	CLSID = IID('{2254824E-D59D-4A5D-8817-2F49B620154E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItemLocalizationInfos,
	]
	default_interface = IItemLocalizationInfos

# This CoClass is known by the name 'SapBobsCom.ItemProperties.88.0'
class ItemProperties(CoClassBaseClass): # A CoClass
	# ItemProperties Class
	CLSID = IID('{91CC17DA-3F2C-464A-8060-8338ADD207DA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItemProperties,
	]
	default_interface = IItemProperties

# This CoClass is known by the name 'SAPbobsCOM.ItemWarehouseInfo.88.0'
class ItemWarehouseInfo(CoClassBaseClass): # A CoClass
	# ItemWarehouseInfo Class
	CLSID = IID('{494EAB50-0ED0-4773-8BCF-9F769A80B6BC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItemWarehouseInfo,
	]
	default_interface = IItemWarehouseInfo

# This CoClass is known by the name 'SAPbobsCOM.JournalEntries_Lines.88.0'
class Items(CoClassBaseClass): # A CoClass
	# Items Class
	CLSID = IID('{210393EC-DEF3-4E55-965C-C2891393A73C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItems,
	]
	default_interface = IItems

class Items_PreferredVendors(CoClassBaseClass): # A CoClass
	# Items_PreferredVendors Class
	CLSID = IID('{03826AF0-3BF7-4C97-B1F1-D5B2CCE19621}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItems_PreferredVendors,
	]
	default_interface = IItems_PreferredVendors

class Items_Prices(CoClassBaseClass): # A CoClass
	# Items_Prices Class
	CLSID = IID('{5C63DF2C-6C18-4447-A9BB-B6277EF0DAF2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IItems_Prices,
	]
	default_interface = IItems_Prices

class JournalEntries(CoClassBaseClass): # A CoClass
	# JournalEntries Class
	CLSID = IID('{6E3987D0-11D5-4A95-B5B7-E5BCFE88E060}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalEntries,
	]
	default_interface = IJournalEntries

# This CoClass is known by the name 'SAPbobsCOM.JournalEntries.88.0'
class JournalEntries_Lines(CoClassBaseClass): # A CoClass
	# JournalEntries_Lines Class
	CLSID = IID('{70BFE200-77E9-4D02-B0E6-49800F3E9AD2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalEntries_Lines,
	]
	default_interface = IJournalEntries_Lines

# This CoClass is known by the name 'SAPbobsCOM.JournalEntryDocumentType.88.0'
class JournalEntryDocumentType(CoClassBaseClass): # A CoClass
	# JournalEntryDocumentType Class
	CLSID = IID('{431269A1-6E83-4195-A446-19D355C7E6A0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalEntryDocumentType,
	]
	default_interface = IJournalEntryDocumentType

# This CoClass is known by the name 'SAPbobsCOM.JournalEntryDocumentTypeParams.88.0'
class JournalEntryDocumentTypeParams(CoClassBaseClass): # A CoClass
	# JournalEntryDocumentTypeParams Class
	CLSID = IID('{8490CA7E-FCC5-422B-8359-BC2B74FDCD44}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalEntryDocumentTypeParams,
	]
	default_interface = IJournalEntryDocumentTypeParams

# This CoClass is known by the name 'SAPbobsCOM.JournalEntryDocumentTypeParamsCollection.88.0'
class JournalEntryDocumentTypeParamsCollection(CoClassBaseClass): # A CoClass
	# JournalEntryDocumentTypeParamsCollection Class
	CLSID = IID('{84119864-5879-482E-ADE4-D1C839F40BCE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalEntryDocumentTypeParamsCollection,
	]
	default_interface = IJournalEntryDocumentTypeParamsCollection

# This CoClass is known by the name 'SAPbobsCOM.JournalEntryDocumentTypeService.88.0'
class JournalEntryDocumentTypeService(CoClassBaseClass): # A CoClass
	# JournalEntryDocumentTypeService Class
	CLSID = IID('{12BC616F-58C9-4281-8EF8-633FD300E827}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalEntryDocumentTypeService,
	]
	default_interface = IJournalEntryDocumentTypeService

# This CoClass is known by the name 'SAPbobsCOM.JournalVouchers.88.0'
class JournalVouchers(CoClassBaseClass): # A CoClass
	# JournalVouchers Class
	CLSID = IID('{FC75103E-6EAA-4246-A097-B6F81E9DD4A3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IJournalVouchers,
	]
	default_interface = IJournalVouchers

# This CoClass is known by the name 'SAPbobsCOM.KPI.88.0'
class KPI(CoClassBaseClass): # A CoClass
	# KPI Class
	CLSID = IID('{60A224F4-B8DA-4288-B9DC-1380D60DFD4C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IKPI,
	]
	default_interface = IKPI

# This CoClass is known by the name 'SAPbobsCOM.KPIParams.88.0'
class KPIParams(CoClassBaseClass): # A CoClass
	# KPIParams Class
	CLSID = IID('{828E364E-A21E-452E-9733-C49A96051736}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IKPIParams,
	]
	default_interface = IKPIParams

# This CoClass is known by the name 'SAPbobsCOM.KPI_ItemLine.88.0'
class KPI_ItemLine(CoClassBaseClass): # A CoClass
	# KPI_ItemLine Class
	CLSID = IID('{F56E791B-BAEE-49D5-9981-DB03FBFDFD47}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IKPI_ItemLine,
	]
	default_interface = IKPI_ItemLine

# This CoClass is known by the name 'SAPbobsCOM.KPI_ItemLines.88.0'
class KPI_ItemLines(CoClassBaseClass): # A CoClass
	# KPI_ItemLines Class
	CLSID = IID('{9A19D585-D582-4079-BDDB-CA9F28F76603}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IKPI_ItemLines,
	]
	default_interface = IKPI_ItemLines

# This CoClass is known by the name 'SAPbobsCOM.KPIsParams.88.0'
class KPIsParams(CoClassBaseClass): # A CoClass
	# KPIsParams Class
	CLSID = IID('{6F959012-2D32-4854-814C-4B0B89621EE0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IKPIsParams,
	]
	default_interface = IKPIsParams

# This CoClass is known by the name 'SAPbobsCOM.KPIsService.88.0'
class KPIsService(CoClassBaseClass): # A CoClass
	# KPIsService Class
	CLSID = IID('{871E4EA1-65DD-402C-AD85-7739F14D13F1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IKPIsService,
	]
	default_interface = IKPIsService

# This CoClass is known by the name 'SAPbobsCOM.KnowledgeBaseSolutions.88.0'
class KnowledgeBaseSolutions(CoClassBaseClass): # A CoClass
	# KnowledgeBaseSolutions Class
	CLSID = IID('{7A042067-2E94-48B5-A7CB-3534F6223B35}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IKnowledgeBaseSolutions,
	]
	default_interface = IKnowledgeBaseSolutions

# This CoClass is known by the name 'SAPbobsCOM.LandedCost.88.0'
class LandedCost(CoClassBaseClass): # A CoClass
	# LandedCost Class
	CLSID = IID('{00AC5F7B-92BD-4EB4-AF80-0673AB0B0B7D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILandedCost,
	]
	default_interface = ILandedCost

# This CoClass is known by the name 'SAPbobsCOM.LandedCostParams.88.0'
class LandedCostParams(CoClassBaseClass): # A CoClass
	# LandedCostParams Class
	CLSID = IID('{251C6447-671B-4ACB-9CB3-C8E072B5E60D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILandedCostParams,
	]
	default_interface = ILandedCostParams

# This CoClass is known by the name 'SAPbobsCOM.LandedCost_CostLine.88.0'
class LandedCost_CostLine(CoClassBaseClass): # A CoClass
	# LandedCost_CostLine Class
	CLSID = IID('{8EDBEEE5-B0AB-4400-889A-851F0F74FFEF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILandedCost_CostLine,
	]
	default_interface = ILandedCost_CostLine

# This CoClass is known by the name 'SAPbobsCOM.LandedCost_CostLines.88.0'
class LandedCost_CostLines(CoClassBaseClass): # A CoClass
	# LandedCost_CostLines Class
	CLSID = IID('{A2EC2F58-8237-41EC-94A1-89BA109C8EB9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILandedCost_CostLines,
	]
	default_interface = ILandedCost_CostLines

# This CoClass is known by the name 'SAPbobsCOM.LandedCost_ItemLine.88.0'
class LandedCost_ItemLine(CoClassBaseClass): # A CoClass
	# LandedCost_ItemLine Class
	CLSID = IID('{438F04FE-3A92-426F-BD6C-29807B132A19}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILandedCost_ItemLine,
	]
	default_interface = ILandedCost_ItemLine

# This CoClass is known by the name 'SAPbobsCOM.LandedCost_ItemLines.88.0'
class LandedCost_ItemLines(CoClassBaseClass): # A CoClass
	# LandedCost_ItemLines Class
	CLSID = IID('{0F314F27-D439-454B-9722-A1C1AE6A11A5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILandedCost_ItemLines,
	]
	default_interface = ILandedCost_ItemLines

# This CoClass is known by the name 'SapBobsCom.LandedCostsCodes.88.0'
class LandedCostsCodes(CoClassBaseClass): # A CoClass
	# LandedCostsCodes Class
	CLSID = IID('{52E836D1-B708-41C5-850C-624B33BB2BE3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILandedCostsCodes,
	]
	default_interface = ILandedCostsCodes

# This CoClass is known by the name 'SAPbobsCOM.LandedCostsParams.88.0'
class LandedCostsParams(CoClassBaseClass): # A CoClass
	# LandedCostsParams Class
	CLSID = IID('{1569ABCE-0AFF-4A64-9558-9B23DE1B0512}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILandedCostsParams,
	]
	default_interface = ILandedCostsParams

# This CoClass is known by the name 'SAPbobsCOM.LandedCostsService.88.0'
class LandedCostsService(CoClassBaseClass): # A CoClass
	# LandedCostsService Class
	CLSID = IID('{1DC7EF54-44B5-4B53-90E9-EA337660D8F2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILandedCostsService,
	]
	default_interface = ILandedCostsService

# This CoClass is known by the name 'SAPbobsCOM.Layer.88.0'
class Layer(CoClassBaseClass): # A CoClass
	# Layer Class
	CLSID = IID('{ABCF9B92-C676-4369-A84F-1A7B29838E4E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILayer,
	]
	default_interface = ILayer

# This CoClass is known by the name 'SAPbobsCOM.Layers.88.0'
class Layers(CoClassBaseClass): # A CoClass
	# Layers Class
	CLSID = IID('{43885104-EC53-4FF2-965B-BA783636A33E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILayers,
	]
	default_interface = ILayers

# This CoClass is known by the name 'SAPbobsCOM.LegalData.88.0'
class LegalData(CoClassBaseClass): # A CoClass
	# LegalData Class
	CLSID = IID('{65BDBFCE-903B-43E2-98FD-8B46471141BD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILegalData,
	]
	default_interface = ILegalData

# This CoClass is known by the name 'SAPbobsCOM.LegalDataDetail.88.0'
class LegalDataDetail(CoClassBaseClass): # A CoClass
	# LegalDataDetail Class
	CLSID = IID('{B3DEEBBD-3798-43CD-9A29-1432782507D3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILegalDataDetail,
	]
	default_interface = ILegalDataDetail

# This CoClass is known by the name 'SAPbobsCOM.LegalDataDetailCollection.88.0'
class LegalDataDetailCollection(CoClassBaseClass): # A CoClass
	# LegalDataDetailCollection Class
	CLSID = IID('{486F8D7E-FB6A-49BA-9333-ED25151631D8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILegalDataDetailCollection,
	]
	default_interface = ILegalDataDetailCollection

# This CoClass is known by the name 'SAPbobsCOM.LegalDataParams.88.0'
class LegalDataParams(CoClassBaseClass): # A CoClass
	# LegalDataParams Class
	CLSID = IID('{9A0BF629-D6FA-4CD8-A7E7-2C57E0677593}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILegalDataParams,
	]
	default_interface = ILegalDataParams

# This CoClass is known by the name 'SAPbobsCOM.LegalDataParamsCollection.88.0'
class LegalDataParamsCollection(CoClassBaseClass): # A CoClass
	# LegalDataParamsCollection Class
	CLSID = IID('{2B7E88E6-AA4B-48A5-A462-AD771C618A44}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILegalDataParamsCollection,
	]
	default_interface = ILegalDataParamsCollection

# This CoClass is known by the name 'SAPbobsCOM.LegalDataService.88.0'
class LegalDataService(CoClassBaseClass): # A CoClass
	# LegalDataService Class
	CLSID = IID('{E8289C17-9062-4232-A0B9-F82C67364B57}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILegalDataService,
	]
	default_interface = ILegalDataService

# This CoClass is known by the name 'SapBobsCom.LengthMeasures.88.0'
class LengthMeasures(CoClassBaseClass): # A CoClass
	# LengthMeasures Class
	CLSID = IID('{F1778F57-69E0-4FED-8EA1-D4921A239055}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILengthMeasures,
	]
	default_interface = ILengthMeasures

# This CoClass is known by the name 'SapBobsCom.LocalEra.88.0'
class LocalEra(CoClassBaseClass): # A CoClass
	# LocalEra Class
	CLSID = IID('{F0D891FD-5D68-466B-90C3-0EDE46E01241}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ILocalEra,
	]
	default_interface = ILocalEra

# This CoClass is known by the name 'SapBobsCom.Manufacturers.88.0'
class Manufacturers(CoClassBaseClass): # A CoClass
	# Manufacturers Class
	CLSID = IID('{04C582B6-340A-4E71-B18B-460A37A04A62}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IManufacturers,
	]
	default_interface = IManufacturers

# This CoClass is known by the name 'SAPbobsCOM.MaterialGroup.88.0'
class MaterialGroup(CoClassBaseClass): # A CoClass
	# MaterialGroup Class
	CLSID = IID('{BF695196-36EF-4BEE-AEA9-AB35D9B40D22}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialGroup,
	]
	default_interface = IMaterialGroup

# This CoClass is known by the name 'SAPbobsCOM.MaterialGroupParams.88.0'
class MaterialGroupParams(CoClassBaseClass): # A CoClass
	# MaterialGroupParams Class
	CLSID = IID('{E432B857-5835-4E67-A3E1-BF6ED7AED2D2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialGroupParams,
	]
	default_interface = IMaterialGroupParams

# This CoClass is known by the name 'SAPbobsCOM.MaterialGroupsParams.88.0'
class MaterialGroupsParams(CoClassBaseClass): # A CoClass
	# MaterialGroupsParams Class
	CLSID = IID('{3E16229E-BFD2-42F0-9044-85D8EB97865F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialGroupsParams,
	]
	default_interface = IMaterialGroupsParams

# This CoClass is known by the name 'SAPbobsCOM.MaterialGroupsService.88.0'
class MaterialGroupsService(CoClassBaseClass): # A CoClass
	# MaterialGroupsService Class
	CLSID = IID('{224BFAE2-6275-450B-B64A-D6D8521EE697}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialGroupsService,
	]
	default_interface = IMaterialGroupsService

# This CoClass is known by the name 'SAPbobsCOM.MaterialRevaluation.88.0'
class MaterialRevaluation(CoClassBaseClass): # A CoClass
	# MaterialRevaluation Class
	CLSID = IID('{B133843B-6DB2-4920-976F-1C7EB0AD60A2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialRevaluation,
	]
	default_interface = IMaterialRevaluation

# This CoClass is known by the name 'SAPbobsCOM.MaterialRevaluationFIFO.88.0'
class MaterialRevaluationFIFO(CoClassBaseClass): # A CoClass
	# MaterialRevaluationFIFO Class
	CLSID = IID('{53845C38-AC44-41AE-B21A-9A9EE1018A4D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialRevaluationFIFO,
	]
	default_interface = IMaterialRevaluationFIFO

# This CoClass is known by the name 'SAPbobsCOM.MaterialRevaluationFIFOParams.88.0'
class MaterialRevaluationFIFOParams(CoClassBaseClass): # A CoClass
	# MaterialRevaluationFIFOParams Class
	CLSID = IID('{6DE9F2ED-C121-43F2-B922-CE373DC2EC17}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialRevaluationFIFOParams,
	]
	default_interface = IMaterialRevaluationFIFOParams

# This CoClass is known by the name 'SAPbobsCOM.MaterialRevaluationFIFOService.88.0'
class MaterialRevaluationFIFOService(CoClassBaseClass): # A CoClass
	# MaterialRevaluationFIFOService Class
	CLSID = IID('{6AEEDCED-BA23-49D4-9853-D371A33AA311}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialRevaluationFIFOService,
	]
	default_interface = IMaterialRevaluationFIFOService

# This CoClass is known by the name 'SAPbobsCOM.MaterialRevaluation_lines.88.0'
class MaterialRevaluation_lines(CoClassBaseClass): # A CoClass
	# MaterialRevaluation_lines Class
	CLSID = IID('{64572B16-A58D-40D4-B869-10787D0A8EE2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMaterialRevaluation_lines,
	]
	default_interface = IMaterialRevaluation_lines

# This CoClass is known by the name 'SapBobsCom.Message.88.0'
class Message(CoClassBaseClass): # A CoClass
	# Message Class
	CLSID = IID('{5F05E0D7-EA2B-4FA6-B7DB-D436CB1AAD63}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessage,
	]
	default_interface = IMessage

# This CoClass is known by the name 'SapBobsCom.MessageDataColumn.88.0'
class MessageDataColumn(CoClassBaseClass): # A CoClass
	# MessageDataColumn Class
	CLSID = IID('{6D9B2EFB-F9A8-4AE9-9C92-6C0DDF80EA56}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessageDataColumn,
	]
	default_interface = IMessageDataColumn

# This CoClass is known by the name 'SapBobsCom.MessageDataColumns.88.0'
class MessageDataColumns(CoClassBaseClass): # A CoClass
	# MessageDataColumns Class
	CLSID = IID('{36FA3872-B465-409C-8F70-24AC72D4D5CE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessageDataColumns,
	]
	default_interface = IMessageDataColumns

# This CoClass is known by the name 'SapBobsCom.MessageDataLine.88.0'
class MessageDataLine(CoClassBaseClass): # A CoClass
	# MessageDataLine Class
	CLSID = IID('{DEA042B3-1E27-4546-9F43-D78BD356E060}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessageDataLine,
	]
	default_interface = IMessageDataLine

# This CoClass is known by the name 'SapBobsCom.MessageDataLines.88.0'
class MessageDataLines(CoClassBaseClass): # A CoClass
	# MessageDataLines Class
	CLSID = IID('{6956AD8B-4137-40EE-8614-DBC251938619}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessageDataLines,
	]
	default_interface = IMessageDataLines

class MessageHeader(CoClassBaseClass): # A CoClass
	# MessageHeader Class
	CLSID = IID('{FF4507B4-AF5E-4599-89D6-B24974CE248E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessageHeader,
	]
	default_interface = IMessageHeader

# This CoClass is known by the name 'SapBobsCom.MessageHeaders.88.0'
class MessageHeaders(CoClassBaseClass): # A CoClass
	# MessageHeaders Class
	CLSID = IID('{D03750AE-84B3-4539-A931-36AAA98C4EBB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessageHeaders,
	]
	default_interface = IMessageHeaders

# This CoClass is known by the name 'SAPbobsCOM.Messages.88.0'
class Messages(CoClassBaseClass): # A CoClass
	# Messages Class
	CLSID = IID('{C397C564-B506-4649-9C12-E4B63BBD7711}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessages,
	]
	default_interface = IMessages

# This CoClass is known by the name 'SapBobsCom.MessagesService.88.0'
class MessagesService(CoClassBaseClass): # A CoClass
	# MessagesService Class
	CLSID = IID('{4D2FFFD1-12AF-439B-9E32-049F24A661D8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMessagesService,
	]
	default_interface = IMessagesService

# This CoClass is known by the name 'SapBobsCom.MultiLanguageTranslations.88.0'
class MultiLanguageTranslations(CoClassBaseClass): # A CoClass
	# MultiLanguageTranslations Class
	CLSID = IID('{F041210F-6968-47CD-B441-40A059D76A1A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMultiLanguageTranslations,
	]
	default_interface = IMultiLanguageTranslations

# This CoClass is known by the name 'SapBobsCom.MultiplePayment.88.0'
class MultiplePayment(CoClassBaseClass): # A CoClass
	# MultiplePayment Class
	CLSID = IID('{FDC4607A-1635-40A8-8519-A756C180FCFB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMultiplePayment,
	]
	default_interface = IMultiplePayment

# This CoClass is known by the name 'SapBobsCom.MultiplePayments.88.0'
class MultiplePayments(CoClassBaseClass): # A CoClass
	# MultiplePayments Class
	CLSID = IID('{BF84F083-2917-4B14-80E4-3333A08C7073}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IMultiplePayments,
	]
	default_interface = IMultiplePayments

# This CoClass is known by the name 'SapBobsCom.NCMCodeSetup.88.0'
class NCMCodeSetup(CoClassBaseClass): # A CoClass
	# NCMCodeSetup Class
	CLSID = IID('{EAD60362-CE52-4064-BA2B-E76EA5297CB3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INCMCodeSetup,
	]
	default_interface = INCMCodeSetup

# This CoClass is known by the name 'SapBobsCom.NCMCodeSetupParams.88.0'
class NCMCodeSetupParams(CoClassBaseClass): # A CoClass
	# NCMCodeSetupParams Class
	CLSID = IID('{1B73D91C-F2B5-4BF3-A772-0A95FBBA1128}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INCMCodeSetupParams,
	]
	default_interface = INCMCodeSetupParams

# This CoClass is known by the name 'SapBobsCom.NCMCodeSetupParamsCollection.88.0'
class NCMCodeSetupParamsCollection(CoClassBaseClass): # A CoClass
	# NCMCodeSetupParamsCollection Class
	CLSID = IID('{F3C8C06A-7D48-4B85-9BD6-12344F1CC72E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INCMCodeSetupParamsCollection,
	]
	default_interface = INCMCodeSetupParamsCollection

# This CoClass is known by the name 'SapBobsCom.NCMCodesSetupService.88.0'
class NCMCodesSetupService(CoClassBaseClass): # A CoClass
	# NCMCodesSetupService Class
	CLSID = IID('{F25B1134-169D-4C7C-B46A-B90707621373}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INCMCodesSetupService,
	]
	default_interface = INCMCodesSetupService

# This CoClass is known by the name 'SAPbobsCOM.NFModel.88.0'
class NFModel(CoClassBaseClass): # A CoClass
	# NFModel Class
	CLSID = IID('{F0C0A764-0170-479E-BEA9-152989FB0E55}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INFModel,
	]
	default_interface = INFModel

# This CoClass is known by the name 'SAPbobsCOM.NFModelParams.88.0'
class NFModelParams(CoClassBaseClass): # A CoClass
	# NFModelParams Class
	CLSID = IID('{4211C5EE-D841-47F4-85CE-752D2DB519C2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INFModelParams,
	]
	default_interface = INFModelParams

# This CoClass is known by the name 'SAPbobsCOM.NFModelsParams.88.0'
class NFModelsParams(CoClassBaseClass): # A CoClass
	# NFModelsParams Class
	CLSID = IID('{989D909A-FA21-488B-B144-A7AA6B920308}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INFModelsParams,
	]
	default_interface = INFModelsParams

# This CoClass is known by the name 'SAPbobsCOM.NFModelsService.88.0'
class NFModelsService(CoClassBaseClass): # A CoClass
	# NFModelsService Class
	CLSID = IID('{6DFC79D0-66CD-483F-AF0E-DBEA40C86AAC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INFModelsService,
	]
	default_interface = INFModelsService

# This CoClass is known by the name 'SAPbobsCOM.NatureOfAssessee.88.0'
class NatureOfAssessee(CoClassBaseClass): # A CoClass
	# NatureOfAssessee Class
	CLSID = IID('{2E43D661-7B70-4889-95E8-63B49DF0CDFE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INatureOfAssessee,
	]
	default_interface = INatureOfAssessee

# This CoClass is known by the name 'SAPbobsCOM.NatureOfAssesseeParams.88.0'
class NatureOfAssesseeParams(CoClassBaseClass): # A CoClass
	# NatureOfAssesseeParams Class
	CLSID = IID('{31A74034-7CDC-4A30-AE5A-2F237201F390}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INatureOfAssesseeParams,
	]
	default_interface = INatureOfAssesseeParams

# This CoClass is known by the name 'SAPbobsCOM.NatureOfAssesseesParams.88.0'
class NatureOfAssesseesParams(CoClassBaseClass): # A CoClass
	# NatureOfAssesseesParams Class
	CLSID = IID('{1CDABF4D-2512-4C50-8387-3D5661526475}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INatureOfAssesseesParams,
	]
	default_interface = INatureOfAssesseesParams

# This CoClass is known by the name 'SAPbobsCOM.NatureOfAssesseesService.88.0'
class NatureOfAssesseesService(CoClassBaseClass): # A CoClass
	# NatureOfAssesseesService Class
	CLSID = IID('{F3801C93-51D8-48E9-9018-0CAB9A4FCBC2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INatureOfAssesseesService,
	]
	default_interface = INatureOfAssesseesService

# This CoClass is known by the name 'SAPbobsCOM.NotaFiscalCFOP.88.0'
class NotaFiscalCFOP(CoClassBaseClass): # A CoClass
	# NotaFiscalCFOP Class
	CLSID = IID('{9A38EECB-D61C-469C-9425-C66BAAA0623E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INotaFiscalCFOP,
	]
	default_interface = INotaFiscalCFOP

# This CoClass is known by the name 'SAPbobsCOM.NotaFiscalCST.88.0'
class NotaFiscalCST(CoClassBaseClass): # A CoClass
	# NotaFiscalCST Class
	CLSID = IID('{7CD6F364-32D1-4862-8470-E27D69A03F08}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INotaFiscalCST,
	]
	default_interface = INotaFiscalCST

# This CoClass is known by the name 'SAPbobsCOM.NotaFiscalUsage.88.0'
class NotaFiscalUsage(CoClassBaseClass): # A CoClass
	# NotaFiscalUsage Class
	CLSID = IID('{2C3D3B79-8BCD-4CF4-981D-1033A54CBF17}')
	coclass_sources = [
	]
	coclass_interfaces = [
		INotaFiscalUsage,
	]
	default_interface = INotaFiscalUsage

# This CoClass is known by the name 'SAPbobsCOM.OccurenceCode.88.0'
class OccurenceCode(CoClassBaseClass): # A CoClass
	# OccurenceCode Class
	CLSID = IID('{2A2351A9-3BB7-4FD0-807C-2D1FEAB7477D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IOccurenceCode,
	]
	default_interface = IOccurenceCode

# This CoClass is known by the name 'SAPbobsCOM.OccurenceCodeParams.88.0'
class OccurenceCodeParams(CoClassBaseClass): # A CoClass
	# OccurenceCodeParams Class
	CLSID = IID('{62CDCF16-DA97-4440-AED9-3C1FB8C60D4B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IOccurenceCodeParams,
	]
	default_interface = IOccurenceCodeParams

# This CoClass is known by the name 'SAPbobsCOM.OccurenceCodeParamsCollection.88.0'
class OccurenceCodeParamsCollection(CoClassBaseClass): # A CoClass
	# OccurenceCodeParamsCollection Class
	CLSID = IID('{D178B341-234B-4CEC-AB38-5D2227C64DF3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IOccurenceCodeParamsCollection,
	]
	default_interface = IOccurenceCodeParamsCollection

# This CoClass is known by the name 'SAPbobsCOM.OccurrenceCodesService.88.0'
class OccurrenceCodesService(CoClassBaseClass): # A CoClass
	# OccurrenceCodesService Class
	CLSID = IID('{9A0F5F4B-EE27-4C5D-8BC0-09F916CF962C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IOccurrenceCodesService,
	]
	default_interface = IOccurrenceCodesService

# This CoClass is known by the name 'SapBobsCom.OpenningBalanceAccount.88.0'
class OpenningBalanceAccount(CoClassBaseClass): # A CoClass
	# OpenningBalanceAccount Class
	CLSID = IID('{6749C3DD-5643-464C-82AB-CEE67CC78C9C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IOpenningBalanceAccount,
	]
	default_interface = IOpenningBalanceAccount

# This CoClass is known by the name 'SapBobsCom.OriginalItem.88.0'
class OriginalItem(CoClassBaseClass): # A CoClass
	# OriginalItem Class
	CLSID = IID('{3DAD979D-9F98-4BBA-8566-7789FD6C8615}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IOriginalItem,
	]
	default_interface = IOriginalItem

# This CoClass is known by the name 'SapBobsCom.OriginalItemParams.88.0'
class OriginalItemParams(CoClassBaseClass): # A CoClass
	# OriginalItemParams Class
	CLSID = IID('{5421B2C4-A3D9-4965-9ED8-1A0BEEECCD5C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IOriginalItemParams,
	]
	default_interface = IOriginalItemParams

# This CoClass is known by the name 'SAPbobsCOM.PackagesTypes.88.0'
class PackagesTypes(CoClassBaseClass): # A CoClass
	# PackagesTypes Class
	CLSID = IID('{84FAFD4C-5213-4CB8-9F2F-7FECB428F0ED}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPackagesTypes,
	]
	default_interface = IPackagesTypes

# This CoClass is known by the name 'SAPbobsCOM.PartnersSetup.88.0'
class PartnersSetup(CoClassBaseClass): # A CoClass
	# PartnersSetup Class
	CLSID = IID('{28C5094B-E595-4D16-BB84-07C23357EDA0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPartnersSetup,
	]
	default_interface = IPartnersSetup

# This CoClass is known by the name 'SAPbobsCOM.PartnersSetupParams.88.0'
class PartnersSetupParams(CoClassBaseClass): # A CoClass
	# PartnersSetupParams Class
	CLSID = IID('{00F3FE74-2DDE-4095-888D-A0E7D4BA83AC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPartnersSetupParams,
	]
	default_interface = IPartnersSetupParams

# This CoClass is known by the name 'SAPbobsCOM.PartnersSetupsParams.88.0'
class PartnersSetupsParams(CoClassBaseClass): # A CoClass
	# PartnersSetupsParams Class
	CLSID = IID('{A64105B1-0FB5-47EA-852E-A9975E5A5722}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPartnersSetupsParams,
	]
	default_interface = IPartnersSetupsParams

# This CoClass is known by the name 'SAPbobsCOM.PartnersSetupsService.88.0'
class PartnersSetupsService(CoClassBaseClass): # A CoClass
	# PartnersSetupsService Class
	CLSID = IID('{15DB95C7-BC17-4B52-94E3-E8D252DB6F03}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPartnersSetupsService,
	]
	default_interface = IPartnersSetupsService

# This CoClass is known by the name 'SAPbobsCOM.PathAdmin.88.0'
class PathAdmin(CoClassBaseClass): # A CoClass
	# PathAdmin Class
	CLSID = IID('{3FE3132C-CA33-4338-A4C7-140952E59D31}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPathAdmin,
	]
	default_interface = IPathAdmin

# This CoClass is known by the name 'SAPbobsCOM.PaymentBlock.88.0'
class PaymentBlock(CoClassBaseClass): # A CoClass
	# PaymentBlock Class
	CLSID = IID('{3D580E7A-74D7-48C1-854B-269EFC3B7F59}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentBlock,
	]
	default_interface = IPaymentBlock

# This CoClass is known by the name 'SAPbobsCOM.PaymentBlockParams.88.0'
class PaymentBlockParams(CoClassBaseClass): # A CoClass
	# PaymentBlockParams Class
	CLSID = IID('{07C983CC-2615-4105-A114-AB0094DBD192}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentBlockParams,
	]
	default_interface = IPaymentBlockParams

# This CoClass is known by the name 'SAPbobsCOM.PaymentBlocksParams.88.0'
class PaymentBlocksParams(CoClassBaseClass): # A CoClass
	# PaymentBlocksParams Class
	CLSID = IID('{9CE26B68-F839-4799-A385-D31DDAB92BEB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentBlocksParams,
	]
	default_interface = IPaymentBlocksParams

# This CoClass is known by the name 'SAPbobsCOM.PaymentBlocksService.88.0'
class PaymentBlocksService(CoClassBaseClass): # A CoClass
	# PaymentBlocksService Class
	CLSID = IID('{4DBA16CD-1221-4A1F-90C3-E2472532E820}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentBlocksService,
	]
	default_interface = IPaymentBlocksService

# This CoClass is known by the name 'SAPbobsCOM.BankPages.88.0'
class PaymentRunExport(CoClassBaseClass): # A CoClass
	# PaymentRunExport Class
	CLSID = IID('{856AB71E-0D54-4BA5-95CA-7135D77040EC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentRunExport,
	]
	default_interface = IPaymentRunExport

class PaymentRunExport_Lines(CoClassBaseClass): # A CoClass
	# PaymentRunExport_Lines Class
	CLSID = IID('{A2A9F005-92C0-4949-B2D7-92B7D8AAA784}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentRunExport_Lines,
	]
	default_interface = IPaymentRunExport_Lines

# This CoClass is known by the name 'SAPbobsCOM.PaymentTermsTypes.88.0'
class PaymentTermsTypes(CoClassBaseClass): # A CoClass
	# PaymentTermsTypes Class
	CLSID = IID('{403E32F9-EBDD-4528-89C2-FE8BE8F7F0A6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPaymentTermsTypes,
	]
	default_interface = IPaymentTermsTypes

# This CoClass is known by the name 'SAPbobsCOM.Payments.88.0'
class Payments(CoClassBaseClass): # A CoClass
	# Payments Class
	CLSID = IID('{A52ED4BA-1C19-4553-9A60-D69B653E8CB5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments,
	]
	default_interface = IPayments

# This CoClass is known by the name 'SAPbobsCOM.Payments_Accounts.88.0'
class Payments_Accounts(CoClassBaseClass): # A CoClass
	# Payments_Accounts Class
	CLSID = IID('{0E77E5DB-93A3-4FCF-BB4B-BE8323F27387}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments_Accounts,
	]
	default_interface = IPayments_Accounts

class Payments_ApprovalRequests(CoClassBaseClass): # A CoClass
	# Payments_ApprovalRequests Class
	CLSID = IID('{9BD8670D-B894-43A6-9CF7-F3C07E7DDCB6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments_ApprovalRequests,
	]
	default_interface = IPayments_ApprovalRequests

# This CoClass is known by the name 'SAPbobsCOM.Payments_Checks.88.0'
class Payments_Checks(CoClassBaseClass): # A CoClass
	# Payments_Checks Class
	CLSID = IID('{6155B8DA-5812-48F9-8955-67CE75857600}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments_Checks,
	]
	default_interface = IPayments_Checks

# This CoClass is known by the name 'SAPbobsCOM.Payments_CreditCards.88.0'
class Payments_CreditCards(CoClassBaseClass): # A CoClass
	# Payments_CreditCards Class
	CLSID = IID('{1C972937-3B53-45EE-9728-516996023C1A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments_CreditCards,
	]
	default_interface = IPayments_CreditCards

# This CoClass is known by the name 'SAPbobsCOM.Payments_Invoices.88.0'
class Payments_Invoices(CoClassBaseClass): # A CoClass
	# Payments_Invoices Class
	CLSID = IID('{ADCC23F1-37CE-4327-BE13-88D1E14F8877}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPayments_Invoices,
	]
	default_interface = IPayments_Invoices

# This CoClass is known by the name 'SapBobsCom.PeriodCategory.88.0'
class PeriodCategory(CoClassBaseClass): # A CoClass
	# PeriodCategory Class
	CLSID = IID('{6499CEB7-4CF2-48F6-93B7-93C949DBA246}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPeriodCategory,
	]
	default_interface = IPeriodCategory

# This CoClass is known by the name 'SapBobsCom.PeriodCategoryParams.88.0'
class PeriodCategoryParams(CoClassBaseClass): # A CoClass
	# PeriodCategoryParams Class
	CLSID = IID('{C473B788-84C8-4B04-B63F-AB4F7348BF1F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPeriodCategoryParams,
	]
	default_interface = IPeriodCategoryParams

# This CoClass is known by the name 'SapBobsCom.PeriodCategoryParamsCollection.88.0'
class PeriodCategoryParamsCollection(CoClassBaseClass): # A CoClass
	# PeriodCategoryParamsCollection Class
	CLSID = IID('{BBC9323D-F9D4-4087-A7E0-1768D5F64538}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPeriodCategoryParamsCollection,
	]
	default_interface = IPeriodCategoryParamsCollection

# This CoClass is known by the name 'SapBobsCom.PickLists.88.0'
class PickLists(CoClassBaseClass): # A CoClass
	# PickLists Class
	CLSID = IID('{23BACDC0-773E-4283-BE9C-BB2D0A216961}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPickLists,
	]
	default_interface = IPickLists

# This CoClass is known by the name 'SapBobsCom.PickLists_Lines.88.0'
class PickLists_Lines(CoClassBaseClass): # A CoClass
	# PickLists_Lines Class
	CLSID = IID('{9E2A9072-D759-4FEB-AD91-90CCC8BC7D64}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPickLists_Lines,
	]
	default_interface = IPickLists_Lines

# This CoClass is known by the name 'SapBobsCom.PredefinedText.88.0'
class PredefinedText(CoClassBaseClass): # A CoClass
	# PredefinedText Class
	CLSID = IID('{1B107C12-CCB2-4F12-A67B-E1700F36570B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPredefinedText,
	]
	default_interface = IPredefinedText

# This CoClass is known by the name 'SapBobsCom.PredefinedTextParams.88.0'
class PredefinedTextParams(CoClassBaseClass): # A CoClass
	# PredefinedTextParams Class
	CLSID = IID('{FEC77FB3-300B-4F11-9931-7BAA71C9EB9A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPredefinedTextParams,
	]
	default_interface = IPredefinedTextParams

# This CoClass is known by the name 'SapBobsCom.PredefinedTextsParams.88.0'
class PredefinedTextsParams(CoClassBaseClass): # A CoClass
	# PredefinedTextsParams Class
	CLSID = IID('{686C8BDD-2405-4A47-AE0B-4E2E0C7C27FF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPredefinedTextsParams,
	]
	default_interface = IPredefinedTextsParams

# This CoClass is known by the name 'SapBobsCom.PredefinedTextsService.88.0'
class PredefinedTextsService(CoClassBaseClass): # A CoClass
	# PredefinedTextsService Class
	CLSID = IID('{C5006530-1F40-4FD6-A525-6BCBF66DE58B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPredefinedTextsService,
	]
	default_interface = IPredefinedTextsService

# This CoClass is known by the name 'SAPbobsCOM.PriceLists.88.0'
class PriceLists(CoClassBaseClass): # A CoClass
	# PriceLists Class
	CLSID = IID('{C7E88977-022A-494D-BC9D-09FA85E7AC15}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IPriceLists,
	]
	default_interface = IPriceLists

# This CoClass is known by the name 'SAPbobsCOM.ProductTrees.88.0'
class ProductTrees(CoClassBaseClass): # A CoClass
	# ProductTrees Class
	CLSID = IID('{B2CC6793-FFCF-4389-980D-B5FF458B2EC8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProductTrees,
	]
	default_interface = IProductTrees

# This CoClass is known by the name 'SAPbobsCOM.ProductTrees_Lines.88.0'
class ProductTrees_Lines(CoClassBaseClass): # A CoClass
	# ProductTrees_Lines Class
	CLSID = IID('{D9F478E8-7891-4C69-A96D-39D5881CFE39}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProductTrees_Lines,
	]
	default_interface = IProductTrees_Lines

# This CoClass is known by the name 'SapBobsCom.ProductionOrders.88.0'
class ProductionOrders(CoClassBaseClass): # A CoClass
	# ProductionOrders Class
	CLSID = IID('{37C235F6-0465-4E85-80A0-776D4602B09B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProductionOrders,
	]
	default_interface = IProductionOrders

# This CoClass is known by the name 'SapBobsCom.ProductionOrders_Lines.88.0'
class ProductionOrders_Lines(CoClassBaseClass): # A CoClass
	# ProductionOrders_Lines Class
	CLSID = IID('{9AC69118-AA6E-44B4-ACDC-176426BCBA1C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProductionOrders_Lines,
	]
	default_interface = IProductionOrders_Lines

# This CoClass is known by the name 'SapBobsCom.ProductionOrders_SalesOrderLines.88.0'
class ProductionOrders_SalesOrderLines(CoClassBaseClass): # A CoClass
	# ProductionOrders_SalesOrderLines Class
	CLSID = IID('{AEA80754-8283-49E8-A4A5-2523BA860D5F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProductionOrders_SalesOrderLines,
	]
	default_interface = IProductionOrders_SalesOrderLines

# This CoClass is known by the name 'SapBobsCom.ProfitCenter.88.0'
class ProfitCenter(CoClassBaseClass): # A CoClass
	# ProfitCenter Class
	CLSID = IID('{8DBC2FA6-D028-4CF6-9987-EE7EDFC91F71}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProfitCenter,
	]
	default_interface = IProfitCenter

# This CoClass is known by the name 'SapBobsCom.ProfitCenterParams.88.0'
class ProfitCenterParams(CoClassBaseClass): # A CoClass
	# ProfitCenterParams Class
	CLSID = IID('{7FDEAE23-7D23-4F12-BA4A-02E65FD9C534}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProfitCenterParams,
	]
	default_interface = IProfitCenterParams

# This CoClass is known by the name 'SapBobsCom.ProfitCentersParams.88.0'
class ProfitCentersParams(CoClassBaseClass): # A CoClass
	# ProfitCentersParams Class
	CLSID = IID('{5EE7C7ED-EEC8-48E4-A394-BBAECC769C43}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProfitCentersParams,
	]
	default_interface = IProfitCentersParams

# This CoClass is known by the name 'SapBobsCom.ProfitCentersService.88.0'
class ProfitCentersService(CoClassBaseClass): # A CoClass
	# ProfitCentersService Class
	CLSID = IID('{F4F504EC-6960-4064-BC79-BD395CB495B7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProfitCentersService,
	]
	default_interface = IProfitCentersService

# This CoClass is known by the name 'SapBobsCom.Project.88.0'
class Project(CoClassBaseClass): # A CoClass
	# Project Class
	CLSID = IID('{1322FD3F-D88B-4321-9AC1-D9423CFBF06A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProject,
	]
	default_interface = IProject

# This CoClass is known by the name 'SapBobsCom.ProjectParams.88.0'
class ProjectParams(CoClassBaseClass): # A CoClass
	# ProjectParams Class
	CLSID = IID('{88134489-A686-4E22-811B-40E0728F4497}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProjectParams,
	]
	default_interface = IProjectParams

# This CoClass is known by the name 'SapBobsCom.ProjectsParams.88.0'
class ProjectsParams(CoClassBaseClass): # A CoClass
	# ProjectsParams Class
	CLSID = IID('{5764FA3D-17B0-4CDC-80CD-6D6BB2ED446F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProjectsParams,
	]
	default_interface = IProjectsParams

# This CoClass is known by the name 'SapBobsCom.ProjectsService.88.0'
class ProjectsService(CoClassBaseClass): # A CoClass
	# ProjectsService Class
	CLSID = IID('{74598C2A-7868-4A07-83CE-229328FD3A11}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IProjectsService,
	]
	default_interface = IProjectsService

# This CoClass is known by the name 'SAPbobsCOM.QueryCategories.1'
class QueryCategories(CoClassBaseClass): # A CoClass
	# QueryCategories Class
	CLSID = IID('{D89C1B1F-B7A1-4669-B80D-E3A041767ABE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IQueryCategories,
	]
	default_interface = IQueryCategories

# This CoClass is known by the name 'SAPbobsCOM.Queue.88.0'
class Queue(CoClassBaseClass): # A CoClass
	# Queue Class
	CLSID = IID('{EA2133A7-F8D4-4444-834F-1129CE2081EB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IQueue,
	]
	default_interface = IQueue

# This CoClass is known by the name 'SAPbobsCOM.QueueMembers.88.0'
class QueueMembers(CoClassBaseClass): # A CoClass
	# QueueMembers Class
	CLSID = IID('{79148B90-9790-418A-B904-DA8C72CCCDDF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IQueueMembers,
	]
	default_interface = IQueueMembers

# This CoClass is known by the name 'SapBobsCom.Recipient.88.0'
class Recipient(CoClassBaseClass): # A CoClass
	# Recipient Class
	CLSID = IID('{5C9EBDA2-D0B1-487D-BEA0-DCDB44D6A56B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRecipient,
	]
	default_interface = IRecipient

# This CoClass is known by the name 'SapBobsCom.RecipientCollection.88.0'
class RecipientCollection(CoClassBaseClass): # A CoClass
	# RecipientCollection Class
	CLSID = IID('{CE2AC3A6-339A-4F3B-9C70-600FC4A6F2DE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRecipientCollection,
	]
	default_interface = IRecipientCollection

# This CoClass is known by the name 'SAPbobsCOM.Recipients.88.0'
class Recipients(CoClassBaseClass): # A CoClass
	# Recipients Class
	CLSID = IID('{921DBA91-7B93-4AEB-859C-C4452CA0F739}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRecipients,
	]
	default_interface = IRecipients

# This CoClass is known by the name 'SAPbobsCOM.Recordset.88.0'
class Recordset(CoClassBaseClass): # A CoClass
	# Recordset Class
	CLSID = IID('{11FA87EF-9F44-4528-AE1D-DAF92AEA3545}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRecordset,
	]
	default_interface = IRecordset

# This CoClass is known by the name 'SAPbobsCOM.Relationships.88.0'
class Relationships(CoClassBaseClass): # A CoClass
	# Relationships Class
	CLSID = IID('{097DDC08-E989-4426-87DB-9EFAD0FF64C3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRelationships,
	]
	default_interface = IRelationships

class ReportFilterService(CoClassBaseClass): # A CoClass
	# ReportFilterService Class
	CLSID = IID('{A2E1CAAE-481E-4DD3-A6D7-EEF4CC1A96E7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportFilterService,
	]
	default_interface = IReportFilterService

# This CoClass is known by the name 'SapBobsCom.ReportLayout.88.0'
class ReportLayout(CoClassBaseClass): # A CoClass
	# ReportLayout Class
	CLSID = IID('{17432CFA-F59A-4F5E-B58D-A2948523C77F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportLayout,
	]
	default_interface = IReportLayout

# This CoClass is known by the name 'SapBobsCom.ReportLayoutItem.88.0'
class ReportLayoutItem(CoClassBaseClass): # A CoClass
	# ReportLayoutItem Class
	CLSID = IID('{94A52D5C-D174-4B52-9A5B-2E9E936226DF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportLayoutItem,
	]
	default_interface = IReportLayoutItem

# This CoClass is known by the name 'SapBobsCom.ReportLayoutItems.88.0'
class ReportLayoutItems(CoClassBaseClass): # A CoClass
	# ReportLayoutItems Class
	CLSID = IID('{28729C80-FAA2-449D-8847-926D8A225E6A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportLayoutItems,
	]
	default_interface = IReportLayoutItems

# This CoClass is known by the name 'SapBobsCom.ReportLayoutParams.88.0'
class ReportLayoutParams(CoClassBaseClass): # A CoClass
	# ReportLayoutParams Class
	CLSID = IID('{AC6E5992-362B-4007-8C90-1AA8DF3B3BA2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportLayoutParams,
	]
	default_interface = IReportLayoutParams

# This CoClass is known by the name 'SapBobsCom.ReportLayoutPrintParams.88.0'
class ReportLayoutPrintParams(CoClassBaseClass): # A CoClass
	# ReportLayoutPrintParams Class
	CLSID = IID('{6162B662-5834-44EC-9A3A-6E36B4EB227F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportLayoutPrintParams,
	]
	default_interface = IReportLayoutPrintParams

class ReportLayout_TranslationLine(CoClassBaseClass): # A CoClass
	# ReportLayout_TranslationLine Class
	CLSID = IID('{E8F14B2A-6381-4A84-8BF2-A4DA70A9F684}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportLayout_TranslationLine,
	]
	default_interface = IReportLayout_TranslationLine

class ReportLayout_TranslationLines(CoClassBaseClass): # A CoClass
	# ReportLayout_TranslationLines Class
	CLSID = IID('{49ABC0B0-082C-4F04-913B-199D08444440}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportLayout_TranslationLines,
	]
	default_interface = IReportLayout_TranslationLines

class ReportLayoutsParams(CoClassBaseClass): # A CoClass
	# ReportLayoutsParams Class
	CLSID = IID('{B9580913-6CE6-48EC-84CF-E22544326D60}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportLayoutsParams,
	]
	default_interface = IReportLayoutsParams

# This CoClass is known by the name 'SapBobsCom.ReportsService.88.0'
class ReportLayoutsService(CoClassBaseClass): # A CoClass
	# ReportLayoutsService Class
	CLSID = IID('{B11BE4C5-0512-4150-A932-336EBF71547F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportLayoutsService,
	]
	default_interface = IReportLayoutsService

# This CoClass is known by the name 'SapBobsCom.ReportParams.88.0'
class ReportParams(CoClassBaseClass): # A CoClass
	# ReportParams Class
	CLSID = IID('{5B9ECA1D-2E75-42EC-BCF2-FBD84756B8B1}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportParams,
	]
	default_interface = IReportParams

# This CoClass is known by the name 'SAPbobsCOM.ReportType.88.0'
class ReportType(CoClassBaseClass): # A CoClass
	# ReportType Class
	CLSID = IID('{8FA3D085-7415-4301-8262-C977EB250400}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportType,
	]
	default_interface = IReportType

# This CoClass is known by the name 'SAPbobsCOM.ReportTypeParams.88.0'
class ReportTypeParams(CoClassBaseClass): # A CoClass
	# ReportTypeParams Class
	CLSID = IID('{6A5583E4-CC36-4360-982B-135BAD6BBFD2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportTypeParams,
	]
	default_interface = IReportTypeParams

# This CoClass is known by the name 'SAPbobsCOM.ReportTypesParams.88.0'
class ReportTypesParams(CoClassBaseClass): # A CoClass
	# ReportTypesParams Class
	CLSID = IID('{0AE67F4C-4636-4B39-AB14-B5C669FB2DF0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportTypesParams,
	]
	default_interface = IReportTypesParams

# This CoClass is known by the name 'SAPbobsCOM.ReportTypesService.88.0'
class ReportTypesService(CoClassBaseClass): # A CoClass
	# ReportTypesService Class
	CLSID = IID('{EEDDBCFE-7934-4DE6-9B67-F43B454D3336}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IReportTypesService,
	]
	default_interface = IReportTypesService

# This CoClass is known by the name 'SAPbobsCOM.RetornoCode.88.0'
class RetornoCode(CoClassBaseClass): # A CoClass
	# RetornoCode Class
	CLSID = IID('{E57AA648-0ADC-4146-A01E-19E0AB5C0A2D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRetornoCode,
	]
	default_interface = IRetornoCode

# This CoClass is known by the name 'SAPbobsCOM.RetornoCodeParams.88.0'
class RetornoCodeParams(CoClassBaseClass): # A CoClass
	# RetornoCodeParams Class
	CLSID = IID('{3932D717-09BF-4109-BDBB-CBF31DEF5E34}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRetornoCodeParams,
	]
	default_interface = IRetornoCodeParams

# This CoClass is known by the name 'SAPbobsCOM.RetornoCodeParamsCollection.88.0'
class RetornoCodeParamsCollection(CoClassBaseClass): # A CoClass
	# RetornoCodeParamsCollection Class
	CLSID = IID('{E25C76F1-5CE3-4001-AAD4-525D50E4C294}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRetornoCodeParamsCollection,
	]
	default_interface = IRetornoCodeParamsCollection

# This CoClass is known by the name 'SAPbobsCOM.RetornoCodesService.88.0'
class RetornoCodesService(CoClassBaseClass): # A CoClass
	# RetornoCodesService Class
	CLSID = IID('{AFC4F081-3100-4940-88E0-E614C717E8A7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRetornoCodesService,
	]
	default_interface = IRetornoCodesService

# This CoClass is known by the name 'SapBobsCom.RoundedData.88.0'
class RoundedData(CoClassBaseClass): # A CoClass
	# RoundedData Class
	CLSID = IID('{142EBC48-A651-4AA5-831C-8A4DA3172194}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IRoundedData,
	]
	default_interface = IRoundedData

# This CoClass is known by the name 'SAPbobsCOM.SBObob.88.0'
class SBObob(CoClassBaseClass): # A CoClass
	# SBObob Class
	CLSID = IID('{A740D0B2-649F-40A6-AF5E-77FF340AEEFD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISBObob,
	]
	default_interface = ISBObob

# This CoClass is known by the name 'SAPbobsCOM.SalesForecast.88.0'
class SalesForecast(CoClassBaseClass): # A CoClass
	# SalesForecast Class
	CLSID = IID('{3E6CC39D-A5A5-43E7-856E-4A1D4D97A77D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesForecast,
	]
	default_interface = ISalesForecast

# This CoClass is known by the name 'SAPbobsCOM.SalesForecast_Lines.88.0'
class SalesForecast_Lines(CoClassBaseClass): # A CoClass
	# SalesForecast_Lines Class
	CLSID = IID('{8B560D21-5616-4D85-ACA9-BC8145B30A73}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesForecast_Lines,
	]
	default_interface = ISalesForecast_Lines

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunities.88.0'
class SalesOpportunities(CoClassBaseClass): # A CoClass
	# SalesOpportunities Class
	CLSID = IID('{E7843EA1-A67D-4C9A-B61D-EABDE49D4692}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunities,
	]
	default_interface = ISalesOpportunities

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesCompetition.88.0'
class SalesOpportunitiesCompetition(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesCompetition Class
	CLSID = IID('{C27CB0AA-2304-4D4E-B292-8ED9651F34A3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesCompetition,
	]
	default_interface = ISalesOpportunitiesCompetition

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesInterests.88.0'
class SalesOpportunitiesInterests(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesInterests Class
	CLSID = IID('{D48A6D0F-F063-4ED4-B1E1-59B6998EE91A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesInterests,
	]
	default_interface = ISalesOpportunitiesInterests

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesLines.88.0'
class SalesOpportunitiesLines(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesLines Class
	CLSID = IID('{B9FED360-AD27-45E1-AB8A-714FB217B022}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesLines,
	]
	default_interface = ISalesOpportunitiesLines

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesPartners.88.0'
class SalesOpportunitiesPartners(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesPartners Class
	CLSID = IID('{0DA4D491-BDE7-4126-81E1-BCDA814B5332}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesPartners,
	]
	default_interface = ISalesOpportunitiesPartners

# This CoClass is known by the name 'SAPbobsCOM.SalesOpportunitiesReasons.88.0'
class SalesOpportunitiesReasons(CoClassBaseClass): # A CoClass
	# SalesOpportunitiesReasons Class
	CLSID = IID('{C3B4DABB-A057-4D70-AE0C-7ABD7A4254B0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitiesReasons,
	]
	default_interface = ISalesOpportunitiesReasons

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityCompetitorSetup.88.0'
class SalesOpportunityCompetitorSetup(CoClassBaseClass): # A CoClass
	# SalesOpportunityCompetitorSetup Class
	CLSID = IID('{5CCE45B6-F63F-4CEE-9FF8-F05F0943C696}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityCompetitorSetup,
	]
	default_interface = ISalesOpportunityCompetitorSetup

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityCompetitorSetupParams.88.0'
class SalesOpportunityCompetitorSetupParams(CoClassBaseClass): # A CoClass
	# SalesOpportunityCompetitorSetupParams Class
	CLSID = IID('{BB7C303A-1C58-4718-98BA-318FBCDB3502}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityCompetitorSetupParams,
	]
	default_interface = ISalesOpportunityCompetitorSetupParams

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityCompetitorSetupParamsCollection.88.0'
class SalesOpportunityCompetitorSetupParamsCollection(CoClassBaseClass): # A CoClass
	# SalesOpportunityCompetitorSetupParamsCollection Class
	CLSID = IID('{2A1B975B-3697-472C-A9AA-57B400510C93}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityCompetitorSetupParamsCollection,
	]
	default_interface = ISalesOpportunityCompetitorSetupParamsCollection

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityCompetitorsSetupService.88.0'
class SalesOpportunityCompetitorsSetupService(CoClassBaseClass): # A CoClass
	# SalesOpportunityCompetitorsSetupService Class
	CLSID = IID('{64D39F13-2594-4AE9-A4C1-E32EA143C3C7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityCompetitorsSetupService,
	]
	default_interface = ISalesOpportunityCompetitorsSetupService

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityInterestSetup.88.0'
class SalesOpportunityInterestSetup(CoClassBaseClass): # A CoClass
	# SalesOpportunityInterestSetup Class
	CLSID = IID('{99D4BEE7-9E10-4C05-885B-4BEA6BFB1983}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityInterestSetup,
	]
	default_interface = ISalesOpportunityInterestSetup

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityInterestSetupParams.88.0'
class SalesOpportunityInterestSetupParams(CoClassBaseClass): # A CoClass
	# SalesOpportunityInterestSetupParams Class
	CLSID = IID('{B6ED00E3-ECCF-40C1-A0EE-5B3C5C22BE8B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityInterestSetupParams,
	]
	default_interface = ISalesOpportunityInterestSetupParams

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityInterestSetupParamsCollection.88.0'
class SalesOpportunityInterestSetupParamsCollection(CoClassBaseClass): # A CoClass
	# SalesOpportunityInterestSetupParamsCollection Class
	CLSID = IID('{DE04D890-B86A-47EF-AEFD-562E6187C25F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityInterestSetupParamsCollection,
	]
	default_interface = ISalesOpportunityInterestSetupParamsCollection

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityInterestsSetupService.88.0'
class SalesOpportunityInterestsSetupService(CoClassBaseClass): # A CoClass
	# SalesOpportunityInterestsSetupService Class
	CLSID = IID('{108C5978-B8B4-452F-9C4E-67ECDE1AA94E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityInterestsSetupService,
	]
	default_interface = ISalesOpportunityInterestsSetupService

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityReasonSetup.88.0'
class SalesOpportunityReasonSetup(CoClassBaseClass): # A CoClass
	# SalesOpportunityReasonSetup Class
	CLSID = IID('{5E789D08-DD00-438D-A3B0-91CAB1CEA247}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityReasonSetup,
	]
	default_interface = ISalesOpportunityReasonSetup

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityReasonSetupParams.88.0'
class SalesOpportunityReasonSetupParams(CoClassBaseClass): # A CoClass
	# SalesOpportunityReasonSetupParams Class
	CLSID = IID('{969F9241-8C84-4966-B0D9-EC89E15E43B8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityReasonSetupParams,
	]
	default_interface = ISalesOpportunityReasonSetupParams

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityReasonSetupParamsCollection.88.0'
class SalesOpportunityReasonSetupParamsCollection(CoClassBaseClass): # A CoClass
	# SalesOpportunityReasonSetupParamsCollection Class
	CLSID = IID('{F9FF31EB-6912-401D-91E5-ADDC459EBECA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityReasonSetupParamsCollection,
	]
	default_interface = ISalesOpportunityReasonSetupParamsCollection

# This CoClass is known by the name 'SapBobsCom.SalesOpportunityReasonsSetupService.88.0'
class SalesOpportunityReasonsSetupService(CoClassBaseClass): # A CoClass
	# SalesOpportunityReasonsSetupService Class
	CLSID = IID('{6AFDF201-9B72-4E70-B1B0-BECC5508D8FD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunityReasonsSetupService,
	]
	default_interface = ISalesOpportunityReasonsSetupService

# This CoClass is known by the name 'SapBobsCom.SalesOpportunitySourceSetup.88.0'
class SalesOpportunitySourceSetup(CoClassBaseClass): # A CoClass
	# SalesOpportunitySourceSetup Class
	CLSID = IID('{F12BD69F-83F6-46F0-A602-3E374B2400FB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitySourceSetup,
	]
	default_interface = ISalesOpportunitySourceSetup

# This CoClass is known by the name 'SapBobsCom.SalesOpportunitySourceSetupParams.88.0'
class SalesOpportunitySourceSetupParams(CoClassBaseClass): # A CoClass
	# SalesOpportunitySourceSetupParams Class
	CLSID = IID('{B8FFD2FD-01A8-404E-995F-B7C004675ADB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitySourceSetupParams,
	]
	default_interface = ISalesOpportunitySourceSetupParams

# This CoClass is known by the name 'SapBobsCom.SalesOpportunitySourceSetupParamsCollection.88.0'
class SalesOpportunitySourceSetupParamsCollection(CoClassBaseClass): # A CoClass
	# SalesOpportunitySourceSetupParamsCollection Class
	CLSID = IID('{35CD3214-7F63-4C98-8969-E1D83791B7BA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitySourceSetupParamsCollection,
	]
	default_interface = ISalesOpportunitySourceSetupParamsCollection

# This CoClass is known by the name 'SapBobsCom.SalesOpportunitySourcesSetupService.88.0'
class SalesOpportunitySourcesSetupService(CoClassBaseClass): # A CoClass
	# SalesOpportunitySourcesSetupService Class
	CLSID = IID('{918EBBE1-6DBB-4B20-AF74-34A5CA1B5E21}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesOpportunitySourcesSetupService,
	]
	default_interface = ISalesOpportunitySourcesSetupService

# This CoClass is known by the name 'SapBobsCom.SalesPersons.88.0'
class SalesPersons(CoClassBaseClass): # A CoClass
	# SalesPersons Class
	CLSID = IID('{A3DFD03F-4F42-44A0-9EBD-ECA4370209DD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesPersons,
	]
	default_interface = ISalesPersons

# This CoClass is known by the name 'SapBobsCom.SalesStages.88.0'
class SalesStages(CoClassBaseClass): # A CoClass
	# SalesStages Class
	CLSID = IID('{180937C4-1314-4A9D-BFF2-27C3969681DC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesStages,
	]
	default_interface = ISalesStages

# This CoClass is known by the name 'SAPbobsCOM.SalesTaxAuthorities.88.0'
class SalesTaxAuthorities(CoClassBaseClass): # A CoClass
	# SalesTaxAuthorities Class
	CLSID = IID('{7F146AF0-3304-4133-BC4F-48797C66B12F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesTaxAuthorities,
	]
	default_interface = ISalesTaxAuthorities

# This CoClass is known by the name 'SAPbobsCOM.SalesTaxAuthoritiesTypes.88.0'
class SalesTaxAuthoritiesTypes(CoClassBaseClass): # A CoClass
	# SalesTaxAuthoritiesTypes Class
	CLSID = IID('{717F1B41-306E-4695-8F4E-7DACA54EA87B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesTaxAuthoritiesTypes,
	]
	default_interface = ISalesTaxAuthoritiesTypes

# This CoClass is known by the name 'SAPbobsCOM.SalesTaxCodes.88.0'
class SalesTaxCodes(CoClassBaseClass): # A CoClass
	# SalesTaxCodes Class
	CLSID = IID('{97C9DB0B-4DBF-4EEA-98A9-04EE1F5B031E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesTaxCodes,
	]
	default_interface = ISalesTaxCodes

# This CoClass is known by the name 'SAPbobsCOM.SalesTaxCodes_Lines.88.0'
class SalesTaxCodes_Lines(CoClassBaseClass): # A CoClass
	# SalesTaxCodes_Lines Class
	CLSID = IID('{4385C84B-AE8C-424F-9071-546FF9E1D503}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISalesTaxCodes_Lines,
	]
	default_interface = ISalesTaxCodes_Lines

# This CoClass is known by the name 'SAPbobsCOM.Section.88.0'
class Section(CoClassBaseClass): # A CoClass
	# Section Class
	CLSID = IID('{978E2893-F916-456D-B318-0BDE27B4246E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISection,
	]
	default_interface = ISection

# This CoClass is known by the name 'SAPbobsCOM.SectionParams.88.0'
class SectionParams(CoClassBaseClass): # A CoClass
	# SectionParams Class
	CLSID = IID('{2468326B-CAE1-42CA-8139-3D674F3E4875}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISectionParams,
	]
	default_interface = ISectionParams

# This CoClass is known by the name 'SAPbobsCOM.SectionsParams.88.0'
class SectionsParams(CoClassBaseClass): # A CoClass
	# SectionsParams Class
	CLSID = IID('{FE490117-D92F-4CFD-A046-641F27A4FD94}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISectionsParams,
	]
	default_interface = ISectionsParams

# This CoClass is known by the name 'SAPbobsCOM.SectionsService.88.0'
class SectionsService(CoClassBaseClass): # A CoClass
	# SectionsService Class
	CLSID = IID('{09BAC4F7-AA34-4417-8C7F-7451098A4D5D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISectionsService,
	]
	default_interface = ISectionsService

# This CoClass is known by the name 'SAPbobsCOM.SerialNumberDetail.88.0'
class SerialNumberDetail(CoClassBaseClass): # A CoClass
	# SerialNumberDetail Class
	CLSID = IID('{8018B387-2D98-40E1-9983-365221335839}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISerialNumberDetail,
	]
	default_interface = ISerialNumberDetail

# This CoClass is known by the name 'SAPbobsCOM.SerialNumberDetailParams.88.0'
class SerialNumberDetailParams(CoClassBaseClass): # A CoClass
	# SerialNumberDetailParams Class
	CLSID = IID('{DF752E29-B42C-4FB2-8634-AC2F74DC9DEE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISerialNumberDetailParams,
	]
	default_interface = ISerialNumberDetailParams

# This CoClass is known by the name 'SAPbobsCOM.SerialNumberDetailsService.88.0'
class SerialNumberDetailsService(CoClassBaseClass): # A CoClass
	# SerialNumberDetailsService Class
	CLSID = IID('{91C11377-CA6F-484B-9761-E7341517FD59}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISerialNumberDetailsService,
	]
	default_interface = ISerialNumberDetailsService

# This CoClass is known by the name 'SAPbobsCOM.SerialNumbers.88.0'
class SerialNumbers(CoClassBaseClass): # A CoClass
	# SerialNumbers Class
	CLSID = IID('{6BA3F221-1146-4650-AE35-03C139F04C02}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISerialNumbers,
	]
	default_interface = ISerialNumbers

# This CoClass is known by the name 'SapBobsCom.Series.88.0'
class Series(CoClassBaseClass): # A CoClass
	# Series Class
	CLSID = IID('{9B92292E-B9FD-4317-B7FA-5E1BD04C8697}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISeries,
	]
	default_interface = ISeries

# This CoClass is known by the name 'SapBobsCom.SeriesCollection.88.0'
class SeriesCollection(CoClassBaseClass): # A CoClass
	# SeriesCollection Class
	CLSID = IID('{7D2E0C15-AC4A-4833-9567-F7167B71CA53}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISeriesCollection,
	]
	default_interface = ISeriesCollection

# This CoClass is known by the name 'SAPbobsCOM.SeriesLine.88.0'
class SeriesLine(CoClassBaseClass): # A CoClass
	# SeriesLine Class
	CLSID = IID('{793B4DFE-8628-4E29-BE9F-2C81E26FE82C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISeriesLine,
	]
	default_interface = ISeriesLine

# This CoClass is known by the name 'SAPbobsCOM.SeriesLines.88.0'
class SeriesLines(CoClassBaseClass): # A CoClass
	# SeriesLines Class
	CLSID = IID('{D9811035-C659-4D43-B92F-56378C1CC50C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISeriesLines,
	]
	default_interface = ISeriesLines

# This CoClass is known by the name 'SapBobsCom.SeriesParams.88.0'
class SeriesParams(CoClassBaseClass): # A CoClass
	# SeriesParams Class
	CLSID = IID('{BFFCB767-876B-4A47-BB72-7B8ECAD30228}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISeriesParams,
	]
	default_interface = ISeriesParams

# This CoClass is known by the name 'SAPbobsCOM.SeriesService.88.0'
class SeriesService(CoClassBaseClass): # A CoClass
	# SeriesService Class
	CLSID = IID('{6140412B-302D-4CC8-9B65-4D554892B2FF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISeriesService,
	]
	default_interface = ISeriesService

# This CoClass is known by the name 'SAPbobsCOM.ServiceCallActivities.88.0'
class ServiceCallActivities(CoClassBaseClass): # A CoClass
	# ServiceCallActivities Class
	CLSID = IID('{0ED9BFD6-A5ED-40D2-8645-BE4ED8AC9CE5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallActivities,
	]
	default_interface = IServiceCallActivities

# This CoClass is known by the name 'SAPbobsCOM.ServiceCallInventoryExpenses.88.0'
class ServiceCallInventoryExpenses(CoClassBaseClass): # A CoClass
	# ServiceCallInventoryExpenses Class
	CLSID = IID('{692B8669-26B5-4D4F-A768-F92576E3EF85}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallInventoryExpenses,
	]
	default_interface = IServiceCallInventoryExpenses

# This CoClass is known by the name 'SapBobsCom.ServiceCallOrigin.88.0'
class ServiceCallOrigin(CoClassBaseClass): # A CoClass
	# ServiceCallOrigin Class
	CLSID = IID('{AC388829-78AF-4297-973E-CC26057B737D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallOrigin,
	]
	default_interface = IServiceCallOrigin

# This CoClass is known by the name 'SapBobsCom.ServiceCallOriginParams.88.0'
class ServiceCallOriginParams(CoClassBaseClass): # A CoClass
	# ServiceCallOriginParams Class
	CLSID = IID('{0A65D039-CEA5-4AA4-8F48-F5D6DA35737A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallOriginParams,
	]
	default_interface = IServiceCallOriginParams

# This CoClass is known by the name 'SapBobsCom.ServiceCallOriginParamsCollection.88.0'
class ServiceCallOriginParamsCollection(CoClassBaseClass): # A CoClass
	# ServiceCallOriginParamsCollection Class
	CLSID = IID('{6815F02A-AC31-4264-93DF-A403569495AC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallOriginParamsCollection,
	]
	default_interface = IServiceCallOriginParamsCollection

# This CoClass is known by the name 'SapBobsCom.ServiceCallOriginsService.88.0'
class ServiceCallOriginsService(CoClassBaseClass): # A CoClass
	# ServiceCallOriginsService Class
	CLSID = IID('{D6B048C3-D52A-4627-B4CF-81D0B203C076}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallOriginsService,
	]
	default_interface = IServiceCallOriginsService

# This CoClass is known by the name 'SapBobsCom.ServiceCallProblemType.88.0'
class ServiceCallProblemType(CoClassBaseClass): # A CoClass
	# ServiceCallProblemType Class
	CLSID = IID('{F3F8DF1B-8D02-467D-AFFB-CCF42B3C168E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallProblemType,
	]
	default_interface = IServiceCallProblemType

# This CoClass is known by the name 'SapBobsCom.ServiceCallProblemTypeParams.88.0'
class ServiceCallProblemTypeParams(CoClassBaseClass): # A CoClass
	# ServiceCallProblemTypeParams Class
	CLSID = IID('{ECE6964D-9F54-4552-9727-F31126FDE3F8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallProblemTypeParams,
	]
	default_interface = IServiceCallProblemTypeParams

# This CoClass is known by the name 'SapBobsCom.ServiceCallProblemTypeParamsCollection.88.0'
class ServiceCallProblemTypeParamsCollection(CoClassBaseClass): # A CoClass
	# ServiceCallProblemTypeParamsCollection Class
	CLSID = IID('{B7DDAC79-1287-429E-B0C6-8D09A8F6A043}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallProblemTypeParamsCollection,
	]
	default_interface = IServiceCallProblemTypeParamsCollection

# This CoClass is known by the name 'SapBobsCom.ServiceCallProblemTypesService.88.0'
class ServiceCallProblemTypesService(CoClassBaseClass): # A CoClass
	# ServiceCallProblemTypesService Class
	CLSID = IID('{50CED8F8-E378-4B24-80C5-FFF89AE44EC7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallProblemTypesService,
	]
	default_interface = IServiceCallProblemTypesService

# This CoClass is known by the name 'SapBobsCom.ServiceCallSolutionStatus.88.0'
class ServiceCallSolutionStatus(CoClassBaseClass): # A CoClass
	# ServiceCallSolutionStatus Class
	CLSID = IID('{F0380309-A375-4E72-BEF1-D983C80D0F8C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallSolutionStatus,
	]
	default_interface = IServiceCallSolutionStatus

# This CoClass is known by the name 'SapBobsCom.ServiceCallSolutionStatusParams.88.0'
class ServiceCallSolutionStatusParams(CoClassBaseClass): # A CoClass
	# ServiceCallSolutionStatusParams Class
	CLSID = IID('{08186613-A26E-4BC9-9832-3422FC4621D5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallSolutionStatusParams,
	]
	default_interface = IServiceCallSolutionStatusParams

# This CoClass is known by the name 'SapBobsCom.ServiceCallSolutionStatusParamsCollection.88.0'
class ServiceCallSolutionStatusParamsCollection(CoClassBaseClass): # A CoClass
	# ServiceCallSolutionStatusParamsCollection Class
	CLSID = IID('{4E0DC009-5AF1-4931-92D5-B5C051C11800}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallSolutionStatusParamsCollection,
	]
	default_interface = IServiceCallSolutionStatusParamsCollection

# This CoClass is known by the name 'SapBobsCom.ServiceCallSolutionStatusService.88.0'
class ServiceCallSolutionStatusService(CoClassBaseClass): # A CoClass
	# ServiceCallSolutionStatusService Class
	CLSID = IID('{BCCBA528-E381-4559-90D2-A242DE43AD60}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallSolutionStatusService,
	]
	default_interface = IServiceCallSolutionStatusService

# This CoClass is known by the name 'SAPbobsCOM.ServiceCallSolutions.88.0'
class ServiceCallSolutions(CoClassBaseClass): # A CoClass
	# ServiceCallSolutions Class
	CLSID = IID('{71ECA915-CB27-41B1-9E9F-DF819F1C52D6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallSolutions,
	]
	default_interface = IServiceCallSolutions

# This CoClass is known by the name 'SapBobsCom.ServiceCallStatus.88.0'
class ServiceCallStatus(CoClassBaseClass): # A CoClass
	# ServiceCallStatus Class
	CLSID = IID('{AB36A971-B92E-4C38-BA4B-2BE928C8C652}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallStatus,
	]
	default_interface = IServiceCallStatus

# This CoClass is known by the name 'SapBobsCom.ServiceCallStatusParams.88.0'
class ServiceCallStatusParams(CoClassBaseClass): # A CoClass
	# ServiceCallStatusParams Class
	CLSID = IID('{33A595E0-A668-490E-8D9F-5BBD94927FDA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallStatusParams,
	]
	default_interface = IServiceCallStatusParams

# This CoClass is known by the name 'SapBobsCom.ServiceCallStatusParamsCollection.88.0'
class ServiceCallStatusParamsCollection(CoClassBaseClass): # A CoClass
	# ServiceCallStatusParamsCollection Class
	CLSID = IID('{9D2F3E85-AF82-4AF9-AB62-9B210FA52B46}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallStatusParamsCollection,
	]
	default_interface = IServiceCallStatusParamsCollection

# This CoClass is known by the name 'SapBobsCom.ServiceCallStatusService.88.0'
class ServiceCallStatusService(CoClassBaseClass): # A CoClass
	# ServiceCallStatusService Class
	CLSID = IID('{7F9581D3-34A6-4B9A-88E3-E518307C6FF6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallStatusService,
	]
	default_interface = IServiceCallStatusService

# This CoClass is known by the name 'SapBobsCom.ServiceCallType.88.0'
class ServiceCallType(CoClassBaseClass): # A CoClass
	# ServiceCallType Class
	CLSID = IID('{A59ECD2A-FD2C-47A5-8D59-BD3410E5E408}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallType,
	]
	default_interface = IServiceCallType

# This CoClass is known by the name 'SapBobsCom.ServiceCallTypeParams.88.0'
class ServiceCallTypeParams(CoClassBaseClass): # A CoClass
	# ServiceCallTypeParams Class
	CLSID = IID('{9883D635-027D-472C-AAA6-AC346F3DF308}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallTypeParams,
	]
	default_interface = IServiceCallTypeParams

# This CoClass is known by the name 'SapBobsCom.ServiceCallTypeParamsCollection.88.0'
class ServiceCallTypeParamsCollection(CoClassBaseClass): # A CoClass
	# ServiceCallTypeParamsCollection Class
	CLSID = IID('{62F0798F-B9DB-43CB-B3BA-5C499E271143}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallTypeParamsCollection,
	]
	default_interface = IServiceCallTypeParamsCollection

# This CoClass is known by the name 'SapBobsCom.ServiceCallTypesService.88.0'
class ServiceCallTypesService(CoClassBaseClass): # A CoClass
	# ServiceCallTypesService Class
	CLSID = IID('{D9DD7A40-DA9C-4ED0-A5B9-103650442A61}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCallTypesService,
	]
	default_interface = IServiceCallTypesService

# This CoClass is known by the name 'SAPbobsCOM.ServiceCalls.88.0'
class ServiceCalls(CoClassBaseClass): # A CoClass
	# ServiceCalls Class
	CLSID = IID('{41501B90-66B9-49BC-920E-EAEF90F119B2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceCalls,
	]
	default_interface = IServiceCalls

# This CoClass is known by the name 'SAPbobsCOM.ServiceContract_Lines.88.0'
class ServiceContract_Lines(CoClassBaseClass): # A CoClass
	# ServiceContract_Lines Class
	CLSID = IID('{8F1131E9-C31E-4F6D-BC3A-1F94AE2CEACF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceContract_Lines,
	]
	default_interface = IServiceContract_Lines

# This CoClass is known by the name 'SAPbobsCOM.ServiceContracts.88.0'
class ServiceContracts(CoClassBaseClass): # A CoClass
	# ServiceContracts Class
	CLSID = IID('{3267FC28-5E07-4BA5-B072-C8F160D7C1C4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceContracts,
	]
	default_interface = IServiceContracts

# This CoClass is known by the name 'SAPbobsCOM.ServiceGroup.88.0'
class ServiceGroup(CoClassBaseClass): # A CoClass
	# ServiceGroup Class
	CLSID = IID('{036CFBA9-9D90-46D7-BCA2-5C1B028E56A4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceGroup,
	]
	default_interface = IServiceGroup

# This CoClass is known by the name 'SAPbobsCOM.ServiceGroupParams.88.0'
class ServiceGroupParams(CoClassBaseClass): # A CoClass
	# ServiceGroupParams Class
	CLSID = IID('{871BC4E7-9FB2-4847-8031-FF03A682F0D5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceGroupParams,
	]
	default_interface = IServiceGroupParams

# This CoClass is known by the name 'SAPbobsCOM.ServiceGroupsParams.88.0'
class ServiceGroupsParams(CoClassBaseClass): # A CoClass
	# ServiceGroupsParams Class
	CLSID = IID('{1F27E785-8D39-4E94-9022-6EAF45962D86}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceGroupsParams,
	]
	default_interface = IServiceGroupsParams

# This CoClass is known by the name 'SAPbobsCOM.ServiceGroupsService.88.0'
class ServiceGroupsService(CoClassBaseClass): # A CoClass
	# ServiceGroupsService Class
	CLSID = IID('{F2637576-718A-48FF-9B0E-355645D088E3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceGroupsService,
	]
	default_interface = IServiceGroupsService

# This CoClass is known by the name 'SAPbobsCOM.ServiceTaxPostingParams.88.0'
class ServiceTaxPostingParams(CoClassBaseClass): # A CoClass
	# ServiceTaxPostingParams Class
	CLSID = IID('{001A7E87-FD95-421B-8F59-DBA53D45745B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceTaxPostingParams,
	]
	default_interface = IServiceTaxPostingParams

# This CoClass is known by the name 'SAPbobsCOM.ServiceTaxPostingParamsCollection.88.0'
class ServiceTaxPostingParamsCollection(CoClassBaseClass): # A CoClass
	# ServiceTaxPostingParamsCollection Class
	CLSID = IID('{B10E527A-7667-46CC-AA30-461F5D93FA99}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceTaxPostingParamsCollection,
	]
	default_interface = IServiceTaxPostingParamsCollection

# This CoClass is known by the name 'SAPbobsCOM.ServiceTaxPostingService.88.0'
class ServiceTaxPostingService(CoClassBaseClass): # A CoClass
	# ServiceTaxPostingService Class
	CLSID = IID('{2FA94E31-95AE-4F97-BD68-90E1DCC414F5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IServiceTaxPostingService,
	]
	default_interface = IServiceTaxPostingService

# This CoClass is known by the name 'SapBobsCom.ShippingTypes.88.0'
class ShippingTypes(CoClassBaseClass): # A CoClass
	# ShippingTypes Class
	CLSID = IID('{AFB12D1C-F0C3-4FA6-BF53-CA858C1BE796}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IShippingTypes,
	]
	default_interface = IShippingTypes

# This CoClass is known by the name 'SAPbobsCOM.ShowDifferenceParams.88.0'
class ShowDifferenceParams(CoClassBaseClass): # A CoClass
	# ShowDifferenceParams Class
	CLSID = IID('{EBCC9023-5BC9-4CA8-B28F-24E4E60F0965}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IShowDifferenceParams,
	]
	default_interface = IShowDifferenceParams

# This CoClass is known by the name 'SAPbobsCOM.SpecialPrices.88.0'
class SpecialPrices(CoClassBaseClass): # A CoClass
	# SpecialPrices Class
	CLSID = IID('{4F6D3681-33BD-41F5-BFEA-DE2059E4ADF4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISpecialPrices,
	]
	default_interface = ISpecialPrices

# This CoClass is known by the name 'SAPbobsCOM.SpecialPricesDataAreas.88.0'
class SpecialPricesDataAreas(CoClassBaseClass): # A CoClass
	# SpecialPricesDataAreas Class
	CLSID = IID('{7A1326F7-9545-4AAC-B875-C317CF7D76B4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISpecialPricesDataAreas,
	]
	default_interface = ISpecialPricesDataAreas

# This CoClass is known by the name 'SAPbobsCOM.SpecialPricesQuantityAreas.88.0'
class SpecialPricesQuantityAreas(CoClassBaseClass): # A CoClass
	# SpecialPricesQuantityAreas Class
	CLSID = IID('{36E908CF-6A46-413F-8BD6-C027651A58EA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ISpecialPricesQuantityAreas,
	]
	default_interface = ISpecialPricesQuantityAreas

# This CoClass is known by the name 'SAPbobsCOM.State.88.0'
class State(CoClassBaseClass): # A CoClass
	# State Class
	CLSID = IID('{06ACC334-F4CD-4259-B2A8-149807E97E6C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IState,
	]
	default_interface = IState

# This CoClass is known by the name 'SAPbobsCOM.StateParams.88.0'
class StateParams(CoClassBaseClass): # A CoClass
	# StateParams Class
	CLSID = IID('{9A92B21A-A70D-489C-86EC-47E379581650}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStateParams,
	]
	default_interface = IStateParams

# This CoClass is known by the name 'SAPbobsCOM.StatesParams.88.0'
class StatesParams(CoClassBaseClass): # A CoClass
	# StatesParams Class
	CLSID = IID('{80DB1499-68B7-473B-B0A7-CE7F0F1FCECF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStatesParams,
	]
	default_interface = IStatesParams

# This CoClass is known by the name 'SAPbobsCOM.StatesService.88.0'
class StatesService(CoClassBaseClass): # A CoClass
	# StatesService Class
	CLSID = IID('{EA05A4CC-F1C8-41C4-8F84-64A9D9CA9883}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStatesService,
	]
	default_interface = IStatesService

# This CoClass is known by the name 'SAPbobsCOM.StockTaking.88.0'
class StockTaking(CoClassBaseClass): # A CoClass
	# StockTaking Class
	CLSID = IID('{CBC0A7DF-E458-45B8-B640-955215643708}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStockTaking,
	]
	default_interface = IStockTaking

# This CoClass is known by the name 'SAPbobsCOM.StockTransfer.88.0'
class StockTransfer(CoClassBaseClass): # A CoClass
	# StockTransfer Class
	CLSID = IID('{E2174012-44BF-4A47-B117-283D13C66C5E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStockTransfer,
	]
	default_interface = IStockTransfer

class StockTransfer_ApprovalRequests(CoClassBaseClass): # A CoClass
	# StockTransfer_ApprovalRequests Class
	CLSID = IID('{89BD7B04-5C1F-41DC-8B8C-4F8CFFA716CD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStockTransfer_ApprovalRequests,
	]
	default_interface = IStockTransfer_ApprovalRequests

# This CoClass is known by the name 'SAPbobsCOM.StockTransfer_Lines.88.0'
class StockTransfer_Lines(CoClassBaseClass): # A CoClass
	# StockTransfer_Lines Class
	CLSID = IID('{9C11E37D-538D-4819-85D1-00048E759E11}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStockTransfer_Lines,
	]
	default_interface = IStockTransfer_Lines

class StockTransfer_TaxExtension(CoClassBaseClass): # A CoClass
	# StockTransfer_TaxExtension Class
	CLSID = IID('{455B78FC-1F3F-4178-A67B-026130220693}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IStockTransfer_TaxExtension,
	]
	default_interface = IStockTransfer_TaxExtension

# This CoClass is known by the name 'SAPbobsCOM.TargetGroup.88.0'
class TargetGroup(CoClassBaseClass): # A CoClass
	# TargetGroup Class
	CLSID = IID('{979EB99E-C8C7-4558-ADF5-DCB1BED01451}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITargetGroup,
	]
	default_interface = ITargetGroup

# This CoClass is known by the name 'SAPbobsCOM.TargetGroupParams.88.0'
class TargetGroupParams(CoClassBaseClass): # A CoClass
	# TargetGroupParams Class
	CLSID = IID('{E1CFA100-9492-4B13-9AB1-4980DEC2DEB5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITargetGroupParams,
	]
	default_interface = ITargetGroupParams

# This CoClass is known by the name 'SAPbobsCOM.TargetGroupsDetail.88.0'
class TargetGroupsDetail(CoClassBaseClass): # A CoClass
	# TargetGroupsDetail Class
	CLSID = IID('{82F30FF0-185D-4F73-8ECD-7CE2E4E77FEE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITargetGroupsDetail,
	]
	default_interface = ITargetGroupsDetail

# This CoClass is known by the name 'SAPbobsCOM.TargetGroupsDetails.88.0'
class TargetGroupsDetails(CoClassBaseClass): # A CoClass
	# TargetGroupsDetails Class
	CLSID = IID('{400500D2-38E8-4EB9-9C7F-1843B8D2ED20}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITargetGroupsDetails,
	]
	default_interface = ITargetGroupsDetails

# This CoClass is known by the name 'SAPbobsCOM.TargetGroupsParams.88.0'
class TargetGroupsParams(CoClassBaseClass): # A CoClass
	# TargetGroupsParams Class
	CLSID = IID('{6745AAF0-21A4-4999-B90F-0C5B8595DF18}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITargetGroupsParams,
	]
	default_interface = ITargetGroupsParams

# This CoClass is known by the name 'SAPbobsCOM.TargetGroupsService.88.0'
class TargetGroupsService(CoClassBaseClass): # A CoClass
	# TargetGroupsService Class
	CLSID = IID('{84A6DF78-FF80-4131-9A1E-742801212279}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITargetGroupsService,
	]
	default_interface = ITargetGroupsService

# This CoClass is known by the name 'SAPbobsCOM.TaxCodeDetermination.88.0'
class TaxCodeDetermination(CoClassBaseClass): # A CoClass
	# TaxCodeDetermination Class
	CLSID = IID('{163BF46A-64A8-4757-A11B-B7958797CC85}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxCodeDetermination,
	]
	default_interface = ITaxCodeDetermination

# This CoClass is known by the name 'SAPbobsCOM.TaxCodeDeterminationParams.88.0'
class TaxCodeDeterminationParams(CoClassBaseClass): # A CoClass
	# TaxCodeDeterminationParams Class
	CLSID = IID('{BD9CCFD9-ABF6-4596-AD04-363D8046FAA2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxCodeDeterminationParams,
	]
	default_interface = ITaxCodeDeterminationParams

# This CoClass is known by the name 'SAPbobsCOM.TaxCodeDeterminationsParams.88.0'
class TaxCodeDeterminationsParams(CoClassBaseClass): # A CoClass
	# TaxCodeDeterminationsParams Class
	CLSID = IID('{FC78A30F-5B21-4311-B9C3-7C684E870590}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxCodeDeterminationsParams,
	]
	default_interface = ITaxCodeDeterminationsParams

# This CoClass is known by the name 'SAPbobsCOM.TaxCodeDeterminationsService.88.0'
class TaxCodeDeterminationsService(CoClassBaseClass): # A CoClass
	# TaxCodeDeterminationsService Class
	CLSID = IID('{4F0A05FF-FCE7-48C8-9F39-8768444639BF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxCodeDeterminationsService,
	]
	default_interface = ITaxCodeDeterminationsService

# This CoClass is known by the name 'SAPbobsCOM.TaxDefinitions.88.0'
class TaxDefinitions(CoClassBaseClass): # A CoClass
	# TaxDefinitions Class
	CLSID = IID('{63F814CA-BC06-4069-9B83-5A73B7BE911D}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxDefinitions,
	]
	default_interface = ITaxDefinitions

class TaxExtension(CoClassBaseClass): # A CoClass
	# TaxExtension Class
	CLSID = IID('{94BACBC3-E916-4D1F-9469-F7F44F8E39F0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxExtension,
	]
	default_interface = ITaxExtension

# This CoClass is known by the name 'SAPbobsCOM.TaxInvoice_Lines.88.0'
class TaxInvoice_Lines(CoClassBaseClass): # A CoClass
	# TaxInvoice_Lines Class
	CLSID = IID('{411526CA-B3C4-489C-B4FB-6539B5BF09C2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxInvoice_Lines,
	]
	default_interface = ITaxInvoice_Lines

# This CoClass is known by the name 'SAPbobsCOM.TaxInvoice_OperationCodes.88.0'
class TaxInvoice_OperationCodes(CoClassBaseClass): # A CoClass
	# TaxInvoice_OperationCodes Class
	CLSID = IID('{A1A07E2A-270F-4C69-8D1A-68D5CEF00CD2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxInvoice_OperationCodes,
	]
	default_interface = ITaxInvoice_OperationCodes

# This CoClass is known by the name 'SAPbobsCOM.TaxInvoices.88.0'
class TaxInvoices(CoClassBaseClass): # A CoClass
	# TaxInvoices Class
	CLSID = IID('{2393BA89-A02B-4E4E-8703-0412A8B757C4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxInvoices,
	]
	default_interface = ITaxInvoices

# This CoClass is known by the name 'SAPbobsCOM.TaxJurisdictions.88.0'
class TaxJurisdictions(CoClassBaseClass): # A CoClass
	# TaxJurisdictions Class
	CLSID = IID('{576DD096-1276-42C3-9BCA-25FBCEE2E3CD}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxJurisdictions,
	]
	default_interface = ITaxJurisdictions

class TaxReportAccount(CoClassBaseClass): # A CoClass
	# TaxReportAccount Class
	CLSID = IID('{73B70E17-5D4B-4AD8-BF03-DBD596A6C4CC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportAccount,
	]
	default_interface = ITaxReportAccount

class TaxReportAccounts(CoClassBaseClass): # A CoClass
	# TaxReportAccounts Class
	CLSID = IID('{B7BB4C0A-4CE3-494B-B928-AA94004B0866}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportAccounts,
	]
	default_interface = ITaxReportAccounts

class TaxReportBusinessPartner(CoClassBaseClass): # A CoClass
	# TaxReportBusinessPartner Class
	CLSID = IID('{7BFDBDE4-A073-448A-B89B-6300C5B8B8E5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportBusinessPartner,
	]
	default_interface = ITaxReportBusinessPartner

class TaxReportBusinessPartners(CoClassBaseClass): # A CoClass
	# TaxReportBusinessPartners Class
	CLSID = IID('{48528290-6FDA-4F13-ABDE-8B3DE992ACCA}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportBusinessPartners,
	]
	default_interface = ITaxReportBusinessPartners

class TaxReportDocument(CoClassBaseClass): # A CoClass
	# TaxReportDocument Class
	CLSID = IID('{E6BBD705-997C-468F-924D-ABE0D1B96E8B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportDocument,
	]
	default_interface = ITaxReportDocument

class TaxReportDocuments(CoClassBaseClass): # A CoClass
	# TaxReportDocuments Class
	CLSID = IID('{62EC03F0-1AC2-40AA-B3B4-CB7D3964E0BF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportDocuments,
	]
	default_interface = ITaxReportDocuments

class TaxReportFilter(CoClassBaseClass): # A CoClass
	# TaxReportFilter Class
	CLSID = IID('{120471FC-3B19-4A4B-89DB-8999A7439A3C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportFilter,
	]
	default_interface = ITaxReportFilter

class TaxReportFilterParams(CoClassBaseClass): # A CoClass
	# TaxReportFilterParams Class
	CLSID = IID('{44E44FE4-3855-4EEF-9854-D8FF22F4801E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportFilterParams,
	]
	default_interface = ITaxReportFilterParams

class TaxReportFiltersParams(CoClassBaseClass): # A CoClass
	# TaxReportFiltersParams Class
	CLSID = IID('{F060E5FE-31B3-4480-8A4F-EB5BB0964C4B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportFiltersParams,
	]
	default_interface = ITaxReportFiltersParams

class TaxReportGroup(CoClassBaseClass): # A CoClass
	# TaxReportGroup Class
	CLSID = IID('{360A35E4-0B22-4324-AA42-9DF442E64379}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportGroup,
	]
	default_interface = ITaxReportGroup

class TaxReportGroups(CoClassBaseClass): # A CoClass
	# TaxReportGroups Class
	CLSID = IID('{7FD8CD14-6E6B-4B4F-801A-0155E5389896}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportGroups,
	]
	default_interface = ITaxReportGroups

class TaxReportSeries(CoClassBaseClass): # A CoClass
	# TaxReportSeries Class
	CLSID = IID('{9B4D2E09-CE62-49C7-BF5D-0D9BC6BD9F81}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportSeries,
	]
	default_interface = ITaxReportSeries

class TaxReportSeriesCollection(CoClassBaseClass): # A CoClass
	# TaxReportSeriesCollection Class
	CLSID = IID('{B69F1DD8-E760-42A1-8E55-C7078C936DB5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxReportSeriesCollection,
	]
	default_interface = ITaxReportSeriesCollection

# This CoClass is known by the name 'SAPbobsCOM.TaxWebSite.88.0'
class TaxWebSite(CoClassBaseClass): # A CoClass
	# TaxWebSite Class
	CLSID = IID('{051656EB-47C7-4435-B61D-D4135C235EA5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxWebSite,
	]
	default_interface = ITaxWebSite

# This CoClass is known by the name 'SAPbobsCOM.TaxWebSiteParams.88.0'
class TaxWebSiteParams(CoClassBaseClass): # A CoClass
	# TaxWebSiteParams Class
	CLSID = IID('{6684E784-5C62-4636-B20E-8AAA5B20BBF2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxWebSiteParams,
	]
	default_interface = ITaxWebSiteParams

# This CoClass is known by the name 'SAPbobsCOM.TaxWebSitesParams.88.0'
class TaxWebSitesParams(CoClassBaseClass): # A CoClass
	# TaxWebSitesParams Class
	CLSID = IID('{93780531-1F63-4CD5-9F32-2A232E2679C5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxWebSitesParams,
	]
	default_interface = ITaxWebSitesParams

# This CoClass is known by the name 'SAPbobsCOM.TaxWebSitesService.88.0'
class TaxWebSitesService(CoClassBaseClass): # A CoClass
	# TaxWebSitesService Class
	CLSID = IID('{1AF6323B-193A-4A12-A001-67993DA9310E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITaxWebSitesService,
	]
	default_interface = ITaxWebSitesService

class TeamMembers(CoClassBaseClass): # A CoClass
	# TeamMembers Class
	CLSID = IID('{D562FBDC-788B-4D80-B9EB-9238CC4EF91C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITeamMembers,
	]
	default_interface = ITeamMembers

class Teams(CoClassBaseClass): # A CoClass
	# Teams Class
	CLSID = IID('{65ABB505-DD62-4C94-8E7B-BF63BC35E51E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITeams,
	]
	default_interface = ITeams

# This CoClass is known by the name 'SAPbobsCOM.Territories.88.0'
class Territories(CoClassBaseClass): # A CoClass
	# Territories Class
	CLSID = IID('{B03EE5C0-48D5-4E20-A33A-FF2DBE5AF478}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITerritories,
	]
	default_interface = ITerritories

class TransactionCode(CoClassBaseClass): # A CoClass
	# TransactionCode Class
	CLSID = IID('{EACF6445-6CE2-41DA-AB6E-681B6BB6BA11}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITransactionCode,
	]
	default_interface = ITransactionCode

class TransactionCodeParams(CoClassBaseClass): # A CoClass
	# TransactionCodeParams Class
	CLSID = IID('{3FF0DED0-0DD1-4D92-85A8-6120FD8E3040}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITransactionCodeParams,
	]
	default_interface = ITransactionCodeParams

class TransactionCodeParamsCollection(CoClassBaseClass): # A CoClass
	# TransactionCodeParamsCollection Class
	CLSID = IID('{DE0B0369-F5A1-4BCC-AD4A-47AE8F410EF4}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITransactionCodeParamsCollection,
	]
	default_interface = ITransactionCodeParamsCollection

class TransactionCodesService(CoClassBaseClass): # A CoClass
	# TransactionCodesService Class
	CLSID = IID('{C5649BC6-2AF9-4C88-B065-1D14E80A6B1E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITransactionCodesService,
	]
	default_interface = ITransactionCodesService

# This CoClass is known by the name 'SapBobsCom.TranslationsInUserLanguages.88.0'
class TranslationsInUserLanguages(CoClassBaseClass): # A CoClass
	# TranslationsInUserLanguages Class
	CLSID = IID('{5BD31F83-42C4-4D73-95D3-53AA2E45A16B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		ITranslationsInUserLanguages,
	]
	default_interface = ITranslationsInUserLanguages

# This CoClass is known by the name 'SAPbobsCOM.UserActionRecord.88.0'
class UserActionRecord(CoClassBaseClass): # A CoClass
	# UserActionRecord Class
	CLSID = IID('{29A38C16-BE81-444A-B50B-6BAA2931CFC8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserActionRecord,
	]
	default_interface = IUserActionRecord

class UserBranchAssignment(CoClassBaseClass): # A CoClass
	# UserBranchAssignment Class
	CLSID = IID('{0119B251-4EBE-410F-AD86-1F2D401D28F3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserBranchAssignment,
	]
	default_interface = IUserBranchAssignment

# This CoClass is known by the name 'SapBobsCom.UserDefaultGroups.88.0'
class UserDefaultGroups(CoClassBaseClass): # A CoClass
	# UserDefaultGroups Class
	CLSID = IID('{DF69751C-704D-47C1-87DC-0F7D074BC516}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserDefaultGroups,
	]
	default_interface = IUserDefaultGroups

# This CoClass is known by the name 'SAPbobsCOM.UserFields.88.0'
class UserFields(CoClassBaseClass): # A CoClass
	# UserFields Class
	CLSID = IID('{A994F7F0-BF16-4C8E-B03C-74CE9EF2ECF5}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserFields,
	]
	default_interface = IUserFields

# This CoClass is known by the name 'SAPbobsCOM.UserFieldsMD.88.0'
class UserFieldsMD(CoClassBaseClass): # A CoClass
	# UserFieldsMD Class
	CLSID = IID('{E944AF70-E7E5-4414-833E-A62BFCF9EA65}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserFieldsMD,
	]
	default_interface = IUserFieldsMD

# This CoClass is known by the name 'SAPbobsCOM.UserKeysMD.88.0'
class UserKeysMD(CoClassBaseClass): # A CoClass
	# UserKeysMD Class
	CLSID = IID('{208C7E76-4919-4468-AE9E-13976C9BE255}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserKeysMD,
	]
	default_interface = IUserKeysMD

# This CoClass is known by the name 'SAPbobsCOM.UserKeysMD_Elements.88.0'
class UserKeysMD_Elements(CoClassBaseClass): # A CoClass
	# UserKeysMD_Elements Class
	CLSID = IID('{A2120F6A-992A-4AAE-A98B-F573035921E8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserKeysMD_Elements,
	]
	default_interface = IUserKeysMD_Elements

# This CoClass is known by the name 'SapBobsCom.UserLanguages.88.0'
class UserLanguages(CoClassBaseClass): # A CoClass
	# UserLanguages Class
	CLSID = IID('{5004E453-F544-4559-BE4D-76D7C6E1278C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserLanguages,
	]
	default_interface = IUserLanguages

# This CoClass is known by the name 'SapBobsCom.UserLicenseParams.88.0'
class UserLicenseParams(CoClassBaseClass): # A CoClass
	# UserLicenseParams Class
	CLSID = IID('{EE5CC625-8EC4-42A3-B9A2-53B254F222DB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserLicenseParams,
	]
	default_interface = IUserLicenseParams

# This CoClass is known by the name 'SapBobsCom.UserMenuItem.88.0'
class UserMenuItem(CoClassBaseClass): # A CoClass
	# UserMenuItem Class
	CLSID = IID('{E53F69BA-CA7A-4D3D-86BF-B36CC42A3646}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserMenuItem,
	]
	default_interface = IUserMenuItem

# This CoClass is known by the name 'SapBobsCom.UserMenuItems.88.0'
class UserMenuItems(CoClassBaseClass): # A CoClass
	# UserMenuItems Class
	CLSID = IID('{43AFB8C0-18E3-4452-B1F0-CDA85C1F463F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserMenuItems,
	]
	default_interface = IUserMenuItems

# This CoClass is known by the name 'SapBobsCom.UserMenuParams.88.0'
class UserMenuParams(CoClassBaseClass): # A CoClass
	# UserMenuParams Class
	CLSID = IID('{722D7EF1-D469-4168-B435-F4434F1502A0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserMenuParams,
	]
	default_interface = IUserMenuParams

# This CoClass is known by the name 'SapBobsCom.UserMenuService.88.0'
class UserMenuService(CoClassBaseClass): # A CoClass
	# UserMenuService Class
	CLSID = IID('{B0C0628F-DBC1-48C8-9E88-ADB8D7E8758C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserMenuService,
	]
	default_interface = IUserMenuService

# This CoClass is known by the name 'SAPbobsCOM.UserObjectMD_ChildTables.88.0'
class UserObjectMD_ChildTables(CoClassBaseClass): # A CoClass
	# UserObjectMD_ChildTables Class
	CLSID = IID('{28F2FDF3-FCEC-4D90-983B-D4C805891EC0}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserObjectMD_ChildTables,
	]
	default_interface = IUserObjectMD_ChildTables

# This CoClass is known by the name 'SAPbobsCOM.UserObjectMD_EnhancedFormColumns.88.0'
class UserObjectMD_EnhancedFormColumns(CoClassBaseClass): # A CoClass
	# UserObjectMD_EnhancedFormColumns Class
	CLSID = IID('{128C44F7-92DA-4BCB-B864-107D02E1ECFB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserObjectMD_EnhancedFormColumns,
	]
	default_interface = IUserObjectMD_EnhancedFormColumns

# This CoClass is known by the name 'SAPbobsCOM.UserObjectMD_FindColumns.88.0'
class UserObjectMD_FindColumns(CoClassBaseClass): # A CoClass
	# UserObjectMD_FindColumns Class
	CLSID = IID('{1C59C249-B65E-472F-80BB-EE0A05F75666}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserObjectMD_FindColumns,
	]
	default_interface = IUserObjectMD_FindColumns

# This CoClass is known by the name 'SAPbobsCOM.UserObjectMD_FormColumns.88.0'
class UserObjectMD_FormColumns(CoClassBaseClass): # A CoClass
	# UserObjectMD_FormColumns Class
	CLSID = IID('{C1A276C6-FD68-4693-8D70-D9A7A3E69712}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserObjectMD_FormColumns,
	]
	default_interface = IUserObjectMD_FormColumns

# This CoClass is known by the name 'SAPbobsCOM.UserObjectsMD.88.0'
class UserObjectsMD(CoClassBaseClass): # A CoClass
	# UserDefinedObjects Class
	CLSID = IID('{8AEF84A8-9762-4736-A6BC-778EA10CA4C2}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserObjectsMD,
	]
	default_interface = IUserObjectsMD

# This CoClass is known by the name 'SAPbobsCOM.UserPermission.88.0'
class UserPermission(CoClassBaseClass): # A CoClass
	# UserPermission Class
	CLSID = IID('{F9779E16-EDDF-4C59-B80D-A24F34EA1ECE}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserPermission,
	]
	default_interface = IUserPermission

class UserPermissionForms(CoClassBaseClass): # A CoClass
	# ExtendUserPermTree Class
	CLSID = IID('{6D4864DD-75DF-4305-A8CB-C7E2381DD7B3}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserPermissionForms,
	]
	default_interface = IUserPermissionForms

# This CoClass is known by the name 'SAPbobsCOM.UserPermissionTree.88.0'
class UserPermissionTree(CoClassBaseClass): # A CoClass
	# UserPermissionTree Class
	CLSID = IID('{950BE47C-4B36-49F3-A313-57146222DC3C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserPermissionTree,
	]
	default_interface = IUserPermissionTree

# This CoClass is known by the name 'SapBobsCom.UserQueries.88.0'
class UserQueries(CoClassBaseClass): # A CoClass
	# UserQueries Class
	CLSID = IID('{5881CB86-9E3A-403D-A3C8-D1B888F3C4F7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserQueries,
	]
	default_interface = IUserQueries

# This CoClass is known by the name 'SAPbobsCOM.UserTable.88.0'
class UserTable(CoClassBaseClass): # A CoClass
	# UserTable Class
	CLSID = IID('{EBB0F6A6-D704-41FF-8D22-CC3B76407F5B}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserTable,
	]
	default_interface = IUserTable

# This CoClass is known by the name 'SAPbobsCOM.UserTables.88.0'
class UserTables(CoClassBaseClass): # A CoClass
	# UserTables Class
	CLSID = IID('{CD793E21-582C-4408-8AF7-1B256D29BF5A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserTables,
	]
	default_interface = IUserTables

# This CoClass is known by the name 'SAPbobsCOM.UserTablesMD.88.0'
class UserTablesMD(CoClassBaseClass): # A CoClass
	# UserTablesMD Class
	CLSID = IID('{04A02F02-1211-4507-87DB-DBE6A4807718}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserTablesMD,
	]
	default_interface = IUserTablesMD

# This CoClass is known by the name 'SapBobsCom.UserValidValues.88.0'
class UserValidValues(CoClassBaseClass): # A CoClass
	# UserValidValues Class
	CLSID = IID('{A912A61F-CCFA-450D-9B6C-CA22F88D1FE8}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUserValidValues,
	]
	default_interface = IUserValidValues

# This CoClass is known by the name 'SAPbobsCOM.Users.88.0'
class Users(CoClassBaseClass): # A CoClass
	# Users Class
	CLSID = IID('{1B0F044E-5955-4426-8CEE-885A8388A8F9}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IUsers,
	]
	default_interface = IUsers

# This CoClass is known by the name 'SAPbobsCOM.ValidValue.88.0'
class ValidValue(CoClassBaseClass): # A CoClass
	# ValidValue Class
	CLSID = IID('{4838BBDC-5B48-44EF-A7F7-A705BB07B24F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IValidValue,
	]
	default_interface = IValidValue

# This CoClass is known by the name 'SAPbobsCOM.ValidValues.88.0'
class ValidValues(CoClassBaseClass): # A CoClass
	# ValidValues Class
	CLSID = IID('{C54F7212-C3DC-4E35-B61C-73E6297F1AD6}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IValidValues,
	]
	default_interface = IValidValues

# This CoClass is known by the name 'SAPbobsCOM.ValidValuesMD.88.0'
class ValidValuesMD(CoClassBaseClass): # A CoClass
	# ValidValuesMD Class
	CLSID = IID('{C868B9F4-6EC8-4A28-81AF-546DD81B1083}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IValidValuesMD,
	]
	default_interface = IValidValuesMD

# This CoClass is known by the name 'SapBobsCom.VatGroups.88.0'
class VatGroups(CoClassBaseClass): # A CoClass
	# VatGroups Class
	CLSID = IID('{C8D20CC8-E622-4D4A-8EE8-AE014B6271DF}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IVatGroups,
	]
	default_interface = IVatGroups

# This CoClass is known by the name 'SapBobsCom.VatGroups_Lines.88.0'
class VatGroups_Lines(CoClassBaseClass): # A CoClass
	# VatGroups_Lines Class
	CLSID = IID('{68D4BD48-09E9-4F7E-B8FC-43E3FA23F86F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IVatGroups_Lines,
	]
	default_interface = IVatGroups_Lines

# This CoClass is known by the name 'SapBobsCom.WarehouseLocations.88.0'
class WarehouseLocations(CoClassBaseClass): # A CoClass
	# WarehouseLocations Class
	CLSID = IID('{000DE7D3-9F70-4BA6-BDE0-F4FFFDD7813E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWarehouseLocations,
	]
	default_interface = IWarehouseLocations

# This CoClass is known by the name 'SAPbobsCOM.Warehouses.88.0'
class Warehouses(CoClassBaseClass): # A CoClass
	# Warehouses Class
	CLSID = IID('{57544A70-71BC-4A35-B018-BB43DD24941A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWarehouses,
	]
	default_interface = IWarehouses

# This CoClass is known by the name 'SapBobsCom.WeightMeasures.88.0'
class WeightMeasures(CoClassBaseClass): # A CoClass
	# WeightMeasures Class
	CLSID = IID('{701AB128-130F-4ECA-B477-EDAC4B7C875A}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWeightMeasures,
	]
	default_interface = IWeightMeasures

# This CoClass is known by the name 'SapBobsCom.WithholdingTaxCodes.88.0'
class WithholdingTaxCodes(CoClassBaseClass): # A CoClass
	# WithholdingTaxCodes Class
	CLSID = IID('{DB78F75E-A7AB-4DEC-A2CF-62ACE2A3E27F}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWithholdingTaxCodes,
	]
	default_interface = IWithholdingTaxCodes

# This CoClass is known by the name 'SapBobsCom.WithholdingTaxCodes_Lines.88.0'
class WithholdingTaxCodes_Lines(CoClassBaseClass): # A CoClass
	# WithholdingTaxCodes_Lines Class
	CLSID = IID('{68C30771-F870-4567-8F0A-D7E21756D2BB}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWithholdingTaxCodes_Lines,
	]
	default_interface = IWithholdingTaxCodes_Lines

# This CoClass is known by the name 'SAPbobsCOM.WithholdingTaxData.88.0'
class WithholdingTaxData(CoClassBaseClass): # A CoClass
	# WithholdingTaxData Class
	CLSID = IID('{F00B2064-7046-4E6A-9286-1284170CFA80}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWithholdingTaxData,
	]
	default_interface = IWithholdingTaxData

# This CoClass is known by the name 'SapBobsCom.WithholdingTaxLines.88.0'
class WithholdingTaxLines(CoClassBaseClass): # A CoClass
	# WithholdingTaxLines Class
	CLSID = IID('{95AF3307-477A-4189-A934-CC32F18264F7}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWithholdingTaxLines,
	]
	default_interface = IWithholdingTaxLines

# This CoClass is known by the name 'SapBobsCom.WizardPaymentMethods.88.0'
class WizardPaymentMethods(CoClassBaseClass): # A CoClass
	# WizardPaymentMethods Class
	CLSID = IID('{B5BF5462-BCF6-49F4-925B-510460F45EFC}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWizardPaymentMethods,
	]
	default_interface = IWizardPaymentMethods

# This CoClass is known by the name 'SAPbobsCOM.WorkOrder_Lines.88.0'
class WorkOrder_Lines(CoClassBaseClass): # A CoClass
	# WorkOrder_Lines Class
	CLSID = IID('{457F56A9-7F85-4ABF-91A4-5384A0CED40C}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWorkOrder_Lines,
	]
	default_interface = IWorkOrder_Lines

# This CoClass is known by the name 'SAPbobsCOM.WorkOrders.88.0'
class WorkOrders(CoClassBaseClass): # A CoClass
	# WorkOrders Class
	CLSID = IID('{0C610415-1BAF-4B92-B485-23D9F3E5AA9E}')
	coclass_sources = [
	]
	coclass_interfaces = [
		IWorkOrders,
	]
	default_interface = IWorkOrders

# This CoClass is known by the name 'SAPbobsCOM._GenArrObj.88.0'
class _GenArrObj(CoClassBaseClass): # A CoClass
	# _GenArrObj Class
	CLSID = IID('{D3259ECE-289F-4B9B-9C81-AD71D8EACE67}')
	coclass_sources = [
	]
	coclass_interfaces = [
		I_GenArrObj,
	]
	default_interface = I_GenArrObj

IAccountCategoriesParams_vtables_dispatch_ = 1
IAccountCategoriesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{797B09FC-E40A-42FA-9045-30B351D937F1}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{797B09FC-E40A-42FA-9045-30B351D937F1}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IAccountCategory_vtables_dispatch_ = 1
IAccountCategory_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CategoryCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CategoryName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CategoryName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CategorySource' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CategorySource' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IAccountCategoryParams_vtables_dispatch_ = 1
IAccountCategoryParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CategoryCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CategoryCode' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CategoryName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IAccountCategoryService_vtables_dispatch_ = 1
IAccountCategoryService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddCategory' , u'pIAccountCategory' , u'ppIAccountCategoryParams' , ), 10, (10, (), [ (9, 1, None, "IID('{F656351C-32B3-4FE5-9054-221B5988B7E7}')") , 
			(16393, 10, None, "IID('{797B09FC-E40A-42FA-9045-30B351D937F1}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCategory' , u'pIAccountCategory' , ), 11, (11, (), [ (9, 1, None, "IID('{F656351C-32B3-4FE5-9054-221B5988B7E7}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteCategory' , u'pIAccountCategoryParams' , ), 12, (12, (), [ (9, 1, None, "IID('{797B09FC-E40A-42FA-9045-30B351D937F1}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetCategory' , u'pIAccountCategoryParams' , u'ppIAccountCategory' , ), 13, (13, (), [ (9, 1, None, "IID('{797B09FC-E40A-42FA-9045-30B351D937F1}')") , 
			(16393, 10, None, "IID('{F656351C-32B3-4FE5-9054-221B5988B7E7}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetCategoryList' , u'ppIAccountCategoriesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{AABB98FA-CCB5-4F0D-A6B6-5684708886C9}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IAccountSegmentationCategories_vtables_dispatch_ = 1
IAccountSegmentationCategories_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lSegmentId' , u'bstrCode' , u'pbRsltFound' , ), 6, (6, (), [ 
			(3, 1, None, None) , (8, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SegmentID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SegmentID' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IAccountSegmentations_vtables_dispatch_ = 1
IAccountSegmentations_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsID' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Size' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Size' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Categories' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{414D11BE-00FC-4AF1-BEDF-C0B3308E1A40}')") , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IAccountsService_vtables_dispatch_ = 1
IAccountsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'CreateOpenBalance' , u'pIOpenningBalanceAccount' , u'pGLAccounts' , ), 10, (10, (), [ (9, 1, None, "IID('{31BF39D4-A4A4-4FF6-A946-D7DFB4B37D5D}')") , 
			(9, 1, None, "IID('{DFFEC465-C3AA-45DD-ABBC-9D025A328335}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
]

IAccrualType_vtables_dispatch_ = 1
IAccrualType_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PostingAccount' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PostingAccount' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CalculationAccount' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CalculationAccount' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'InterimAccount' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'InterimAccount' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IAccrualTypeParams_vtables_dispatch_ = 1
IAccrualTypeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IAccrualTypes_vtables_dispatch_ = 1
IAccrualTypes_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{439BEC35-EDAA-4F54-8FEF-647658D06148}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{439BEC35-EDAA-4F54-8FEF-647658D06148}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IAccrualTypesParams_vtables_dispatch_ = 1
IAccrualTypesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{70DC39C1-4019-4618-9D1F-7D227A68491F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{70DC39C1-4019-4618-9D1F-7D227A68491F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IAccrualTypesService_vtables_dispatch_ = 1
IAccrualTypesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddAccrualType' , u'pIAccrualType' , u'ppIAccrualTypeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{439BEC35-EDAA-4F54-8FEF-647658D06148}')") , 
			(16393, 10, None, "IID('{70DC39C1-4019-4618-9D1F-7D227A68491F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateAccrualType' , u'pIAccrualType' , ), 11, (11, (), [ (9, 1, None, "IID('{439BEC35-EDAA-4F54-8FEF-647658D06148}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteAccrualType' , u'pIAccrualTypeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{70DC39C1-4019-4618-9D1F-7D227A68491F}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetAccrualType' , u'pIAccrualTypeParams' , u'ppIAccrualType' , ), 13, (13, (), [ (9, 1, None, "IID('{70DC39C1-4019-4618-9D1F-7D227A68491F}')") , 
			(16393, 10, None, "IID('{439BEC35-EDAA-4F54-8FEF-647658D06148}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetAccrualTypeList' , u'ppIAccrualTypesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{046161D0-6736-48A3-A619-805A9C68F5C1}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IAcctSegmnt_Categories_vtables_dispatch_ = 1
IAcctSegmnt_Categories_vtables_ = [
	(( u'SegmentID' , u'plRsltVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SegmentID' , u'plRsltVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IActivitiesParams_vtables_dispatch_ = 1
IActivitiesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IActivitiesService_vtables_dispatch_ = 1
IActivitiesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddActivity' , u'pIActivity' , u'ppIActivityParams' , ), 10, (10, (), [ (9, 1, None, "IID('{EE825513-A21F-467A-AAC5-931A7939C954}')") , 
			(16393, 10, None, "IID('{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateActivity' , u'pIActivity' , ), 11, (11, (), [ (9, 1, None, "IID('{EE825513-A21F-467A-AAC5-931A7939C954}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteActivity' , u'pIActivityParams' , ), 12, (12, (), [ (9, 1, None, "IID('{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetActivity' , u'pIActivityParams' , u'ppIActivity' , ), 13, (13, (), [ (9, 1, None, "IID('{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')") , 
			(16393, 10, None, "IID('{EE825513-A21F-467A-AAC5-931A7939C954}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetActivityList' , u'ppIActivitiesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{8289DE12-A145-459F-90F2-69A907294981}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GetSingleInstanceFromSeries' , u'pIActivityInstanceParams' , u'ppIActivity' , ), 15, (15, (), [ (9, 1, None, "IID('{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}')") , 
			(16393, 10, None, "IID('{EE825513-A21F-467A-AAC5-931A7939C954}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UpdateSingleInstanceInSeries' , u'pIActivity' , u'ppIActivityParams' , ), 16, (16, (), [ (9, 1, None, "IID('{EE825513-A21F-467A-AAC5-931A7939C954}')") , 
			(16393, 10, None, "IID('{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}')") , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DeleteSingleInstanceFromSeries' , u'pIActivityInstanceParams' , ), 17, (17, (), [ (9, 1, None, "IID('{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}')") , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetTopNActivityInstances' , u'pActivityInstancesListParams' , u'ppActivityInstancesParams' , ), 18, (18, (), [ (9, 1, None, "IID('{14BE1C8C-20CA-4E53-A55C-097AB57740B8}')") , 
			(16393, 10, None, "IID('{681D8515-EF90-42C7-9463-3CE0B14E72C5}')") , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IActivity_vtables_dispatch_ = 1
IActivity_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ActivityCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ActivityDate' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ActivityDate' , u'pdateRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ActivityTime' , u'ptimeRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ActivityTime' , u'ptimeRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Closed' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Closed' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CloseDate' , u'pdateRsltVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'CloseDate' , u'pdateRsltVal' , ), 17, (17, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'plRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'plRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'penumRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'penumRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Activity' , u'penumRsltVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Activity' , u'penumRsltVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'ActivityType' , u'plRsltVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'ActivityType' , u'plRsltVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'plRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'plRsltVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'StartTime' , u'ptimeRsltVal' , ), 29, (29, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'StartTime' , u'ptimeRsltVal' , ), 29, (29, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'EndTime' , u'ptimeRsltVal' , ), 30, (30, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'EndTime' , u'ptimeRsltVal' , ), 30, (30, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Duration' , u'ppRsltVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Duration' , u'ppRsltVal' , ), 31, (31, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'DurationType' , u'penumRsltVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'DurationType' , u'penumRsltVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployee' , u'plRsltVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployee' , u'plRsltVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'plRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'plRsltVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'HandledBy' , u'plRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'HandledBy' , u'plRsltVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'Reminder' , u'penumRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Reminder' , u'penumRsltVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'ReminderPeriod' , u'ppRsltVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'ReminderPeriod' , u'ppRsltVal' , ), 37, (37, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ReminderType' , u'penumRsltVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'ReminderType' , u'penumRsltVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'Personalflag' , u'penumRsltVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'Personalflag' , u'penumRsltVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'ParentobjectId' , u'plRsltVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Parentobjecttype' , u'pbstrRsltVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'Room' , u'pbstrRsltVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'Room' , u'pbstrRsltVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Inactiveflag' , u'penumRsltVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Inactiveflag' , u'penumRsltVal' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'PreviousActivity' , u'plRsltVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'PreviousActivity' , u'plRsltVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'plRsltVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'plRsltVal' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'Tentativeflag' , u'penumRsltVal' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'Tentativeflag' , u'penumRsltVal' , ), 50, (50, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'EndDuedate' , u'pdateRsltVal' , ), 51, (51, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'EndDuedate' , u'pdateRsltVal' , ), 51, (51, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'DocTypeEx' , u'pbstrRsltVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'DocTypeEx' , u'pbstrRsltVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 53, (53, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 53, (53, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'RecurrencePattern' , u'penumRsltVal' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'RecurrencePattern' , u'penumRsltVal' , ), 54, (54, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'endType' , u'penumRsltVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'endType' , u'penumRsltVal' , ), 55, (55, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'SeriesStartDate' , u'pdateRsltVal' , ), 56, (56, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'SeriesEndDate' , u'pdateRsltVal' , ), 57, (57, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'SeriesEndDate' , u'pdateRsltVal' , ), 57, (57, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'MaxOccurrence' , u'plRsltVal' , ), 58, (58, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'MaxOccurrence' , u'plRsltVal' , ), 58, (58, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'Interval' , u'plRsltVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'Interval' , u'plRsltVal' , ), 59, (59, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'Sunday' , u'penumRsltVal' , ), 60, (60, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'Sunday' , u'penumRsltVal' , ), 60, (60, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'Monday' , u'penumRsltVal' , ), 61, (61, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'Monday' , u'penumRsltVal' , ), 61, (61, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'Tuesday' , u'penumRsltVal' , ), 62, (62, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'Tuesday' , u'penumRsltVal' , ), 62, (62, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'Wednesday' , u'penumRsltVal' , ), 63, (63, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'Wednesday' , u'penumRsltVal' , ), 63, (63, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'Thursday' , u'penumRsltVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'Thursday' , u'penumRsltVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'Friday' , u'penumRsltVal' , ), 65, (65, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'Friday' , u'penumRsltVal' , ), 65, (65, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'Saturday' , u'penumRsltVal' , ), 66, (66, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'Saturday' , u'penumRsltVal' , ), 66, (66, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'RepeatOption' , u'penumRsltVal' , ), 67, (67, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'RepeatOption' , u'penumRsltVal' , ), 67, (67, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'BelongedSeriesNum' , u'plRsltVal' , ), 68, (68, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'IsRemoved' , u'penumRsltVal' , ), 69, (69, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 70, (70, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 70, (70, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pbstrRsltVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pbstrRsltVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'HandledByEmployee' , u'plRsltVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'HandledByEmployee' , u'plRsltVal' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'RecurrenceSequenceSpecifier' , u'penumRssVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'RecurrenceSequenceSpecifier' , u'penumRssVal' , ), 73, (73, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'RecurrenceDayInMonth' , u'plDayInMonth' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'RecurrenceDayInMonth' , u'plDayInMonth' , ), 74, (74, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'RecurrenceMonth' , u'plMonth' , ), 75, (75, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'RecurrenceMonth' , u'plMonth' , ), 75, (75, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'RecurrenceDayOfWeek' , u'penumDayOfWeekVal' , ), 76, (76, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'RecurrenceDayOfWeek' , u'penumDayOfWeekVal' , ), 76, (76, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 77, (77, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
]

IActivityInstanceParams_vtables_dispatch_ = 1
IActivityInstanceParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ActivityCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ActivityCode' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InstanceDate' , u'pdateRsltVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'InstanceDate' , u'pdateRsltVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IActivityInstancesListParams_vtables_dispatch_ = 1
IActivityInstancesListParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InstanceCount' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'InstanceCount' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IActivityInstancesParams_vtables_dispatch_ = 1
IActivityInstancesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IActivityLocations_vtables_dispatch_ = 1
IActivityLocations_vtables_ = [
	(( u'Code' , u'plVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IActivityParams_vtables_dispatch_ = 1
IActivityParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ActivityCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ActivityCode' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IActivityStatus_vtables_dispatch_ = 1
IActivityStatus_vtables_ = [
	(( u'StatusDescription' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'StatusDescription' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'StatusId' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'StatusName' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'StatusName' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ActivityID' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 6, (6, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IActivityTypes_vtables_dispatch_ = 1
IActivityTypes_vtables_ = [
	(( u'Code' , u'plVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IAdditionalExpenses_vtables_dispatch_ = 1
IAdditionalExpenses_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ExpnsCode' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccount' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccount' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'FixedAmountRevenues' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'FixedAmountRevenues' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'FixedAmountExpenses' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'FixedAmountExpenses' , u'pVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'OutputVATGroup' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'OutputVATGroup' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'InputVATGroup' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'InputVATGroup' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DistributionMethod' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DistributionMethod' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Includein1099' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Includein1099' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'FreightOffsetAccount' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'FreightOffsetAccount' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ExpensCode' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseExemptedAccount' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseExemptedAccount' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesExemptedAccount' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesExemptedAccount' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DrawingMethod' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'DrawingMethod' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'FreightType' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'FreightType' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Stock' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Stock' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'LastPurchasePrice' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'LastPurchasePrice' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
]

IAddressExtension_vtables_dispatch_ = 1
IAddressExtension_vtables_ = [
	(( u'ShipToStreet' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ShipToStreet' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ShipToStreetNo' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ShipToStreetNo' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ShipToBlock' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ShipToBlock' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ShipToBuilding' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ShipToBuilding' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCity' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCity' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ShipToZipCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ShipToZipCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCounty' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCounty' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ShipToState' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ShipToState' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCountry' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCountry' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ShipToAddressType' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ShipToAddressType' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BillToStreet' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BillToStreet' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BillToStreetNo' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'BillToStreetNo' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BillToBlock' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'BillToBlock' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'BillToBuilding' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'BillToBuilding' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BillToCity' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BillToCity' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BillToZipCode' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BillToZipCode' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BillToCounty' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'BillToCounty' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'BillToState' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'BillToState' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'BillToCountry' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'BillToCountry' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'BillToAddressType' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BillToAddressType' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
]

IAdminInfo_vtables_dispatch_ = 1
IAdminInfo_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CompanyName' , u'pbstrRsltVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CompanyName' , u'pbstrRsltVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PrintingHeader' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PrintingHeader' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber1' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber1' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber2' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber2' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ManagingDirector' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ManagingDirector' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ChartofAccountsTemplate' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ChartofAccountsTemplate' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'LocalCurrency' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'LocalCurrency' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'SystemCurrency' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'SystemCurrency' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CreditBalancewithMinusSign' , u'penumRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CreditBalancewithMinusSign' , u'penumRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'StandardUnitofLength' , u'plRsltVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'StandardUnitofLength' , u'plRsltVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'WeightUnitDefault' , u'plRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'WeightUnitDefault' , u'plRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'DirectIndirectRate' , u'penumRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DirectIndirectRate' , u'penumRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'MinimumAmountfor347Report' , u'pdblRsltVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'MinimumAmountfor347Report' , u'pdblRsltVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SetItemsWarehouses' , u'penumRsltVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'SetItemsWarehouses' , u'penumRsltVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'TaxOffice' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'TaxOffice' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'DeductionFileNo' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'DeductionFileNo' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'TaxCollection' , u'penumRsltVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'TaxCollection' , u'penumRsltVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinition' , u'penumRsltVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinition' , u'penumRsltVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercentage' , u'pdblRsltVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercentage' , u'pdblRsltVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'AdvancesonCorpIncomeTax' , u'pdblRsltVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'AdvancesonCorpIncomeTax' , u'pdblRsltVal' , ), 34, (34, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'WithTax' , u'plRsltVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'WithTax' , u'plRsltVal' , ), 35, (35, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxVendorDdct' , u'penumRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxVendorDdct' , u'penumRsltVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'CustomersDeductionatSource' , u'penumRsltVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'CustomersDeductionatSource' , u'penumRsltVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxTdctPercnt' , u'pdblRsltVal' , ), 38, (38, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxTdctPercnt' , u'pdblRsltVal' , ), 38, (38, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxDdctExpired' , u'pdtRsltVal' , ), 39, (39, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxDdctExpired' , u'pdtRsltVal' , ), 39, (39, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxDdctOffice' , u'pbstrRsltVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxDdctOffice' , u'pbstrRsltVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'CommitmentRestriction' , u'penumRsltVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'CommitmentRestriction' , u'penumRsltVal' , ), 41, (41, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'CreditRestriction' , u'penumRsltVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'CreditRestriction' , u'penumRsltVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'RestrictSales' , u'penumRsltVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'RestrictSales' , u'penumRsltVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'RestrictDelNotesPO' , u'penumRsltVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'RestrictDelNotesPO' , u'penumRsltVal' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'RestrictOrders' , u'penumRsltVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'RestrictOrders' , u'penumRsltVal' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'ConsiderDelNotesinSalesR' , u'penumRsltVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'ConsiderDelNotesinSalesR' , u'penumRsltVal' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'CreditDepositType' , u'penumRsltVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'CreditDepositType' , u'penumRsltVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'UseTax' , u'penumRsltVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'UseTax' , u'penumRsltVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'SplitPO' , u'penumRsltVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'SplitPO' , u'penumRsltVal' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'AltNameForApInvoice' , u'pbstrRsltVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'AltNameForApInvoice' , u'pbstrRsltVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'AltNameforCreditMemo' , u'pbstrRsltVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'AltNameforCreditMemo' , u'pbstrRsltVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'AltNameForGoodsReceipt' , u'pbstrRsltVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'AltNameForGoodsReceipt' , u'pbstrRsltVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'AltNameForGoodsReturn' , u'pbstrRsltVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'AltNameForGoodsReturn' , u'pbstrRsltVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'AltNameForPurchase' , u'pbstrRsltVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'AltNameForPurchase' , u'pbstrRsltVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'AlertTypeforWHStock' , u'penumRsltVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'AlertTypeforWHStock' , u'penumRsltVal' , ), 55, (55, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'SetCommissionbyCustomer' , u'penumRsltVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'SetCommissionbyCustomer' , u'penumRsltVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'SetCommissionbyItem' , u'penumRsltVal' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'SetCommissionbyItem' , u'penumRsltVal' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'SetCommissionbySE' , u'penumRsltVal' , ), 58, (58, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'SetCommissionbySE' , u'penumRsltVal' , ), 58, (58, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'DefaultCustomerPaymentTerms' , u'plRsltVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'DefaultCustomerPaymentTerms' , u'plRsltVal' , ), 59, (59, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'DefaultVendorPaymentTerms' , u'plRsltVal' , ), 60, (60, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'DefaultVendorPaymentTerms' , u'plRsltVal' , ), 60, (60, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'CalculateGrossProfitperTra' , u'penumRsltVal' , ), 61, (61, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'CalculateGrossProfitperTra' , u'penumRsltVal' , ), 61, (61, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'PriceListforCostPrice' , u'plRsltVal' , ), 62, (62, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'PriceListforCostPrice' , u'plRsltVal' , ), 62, (62, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitAfterSale' , u'penumRsltVal' , ), 63, (63, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitAfterSale' , u'penumRsltVal' , ), 63, (63, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'DisplayPriceforPriceOnly' , u'penumRsltVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'DisplayPriceforPriceOnly' , u'penumRsltVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'CalculateTaxinSalesQuotati' , u'penumRsltVal' , ), 65, (65, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'CalculateTaxinSalesQuotati' , u'penumRsltVal' , ), 65, (65, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'BaseField' , u'penumRsltVal' , ), 66, (66, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'BaseField' , u'penumRsltVal' , ), 66, (66, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'AllowClosedSalesQuotations' , u'penumRsltVal' , ), 67, (67, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'AllowClosedSalesQuotations' , u'penumRsltVal' , ), 67, (67, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'UserConversionCode' , u'penumRsltVal' , ), 68, (68, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'UserConversionCode' , u'penumRsltVal' , ), 68, (68, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'CompanyColor' , u'plRsltVal' , ), 69, (69, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'CompanyColor' , u'plRsltVal' , ), 69, (69, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'TotalsAccuracy' , u'plRsltVal' , ), 70, (70, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'TotalsAccuracy' , u'plRsltVal' , ), 70, (70, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'AccuracyofQuantities' , u'plRsltVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'AccuracyofQuantities' , u'plRsltVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'PriceAccuracy' , u'plRsltVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'PriceAccuracy' , u'plRsltVal' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'RateAccuracy' , u'plRsltVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'RateAccuracy' , u'plRsltVal' , ), 73, (73, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'PercentageAccuracy' , u'plRsltVal' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'PercentageAccuracy' , u'plRsltVal' , ), 74, (74, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'MeasuringAccuracy' , u'plRsltVal' , ), 75, (75, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'MeasuringAccuracy' , u'plRsltVal' , ), 75, (75, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'AddressinForeignLanguage' , u'pbstrRsltVal' , ), 76, (76, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'AddressinForeignLanguage' , u'pbstrRsltVal' , ), 76, (76, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTaxCode' , u'pbstrRsltVal' , ), 77, (77, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTaxCode' , u'pbstrRsltVal' , ), 77, (77, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'LetterHeaderinForeignLangu' , u'pbstrRsltVal' , ), 78, (78, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'LetterHeaderinForeignLangu' , u'pbstrRsltVal' , ), 78, (78, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber1ForeignLang' , u'pbstrRsltVal' , ), 79, (79, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber1ForeignLang' , u'pbstrRsltVal' , ), 79, (79, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber2ForeignLang' , u'pbstrRsltVal' , ), 80, (80, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber2ForeignLang' , u'pbstrRsltVal' , ), 80, (80, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumberForeignLang' , u'pbstrRsltVal' , ), 81, (81, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumberForeignLang' , u'pbstrRsltVal' , ), 81, (81, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'ManagingDirectorForeignLan' , u'pbstrRsltVal' , ), 82, (82, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'ManagingDirectorForeignLan' , u'pbstrRsltVal' , ), 82, (82, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'TimeTemplate' , u'penumRsltVal' , ), 83, (83, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'TimeTemplate' , u'penumRsltVal' , ), 83, (83, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'DateTemplate' , u'penumRsltVal' , ), 84, (84, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'DateTemplate' , u'penumRsltVal' , ), 84, (84, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'DateSeparator' , u'pbstrRsltVal' , ), 85, (85, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'DateSeparator' , u'pbstrRsltVal' , ), 85, (85, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'FCCheckAccount' , u'penumRsltVal' , ), 86, (86, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'FCCheckAccount' , u'penumRsltVal' , ), 86, (86, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'ChangedExistingOrders' , u'penumRsltVal' , ), 87, (87, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'ChangedExistingOrders' , u'penumRsltVal' , ), 87, (87, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'MultiCurrencyCheck' , u'penumRsltVal' , ), 88, (88, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'MultiCurrencyCheck' , u'penumRsltVal' , ), 88, (88, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'ISRType' , u'plRsltVal' , ), 89, (89, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'ISRType' , u'plRsltVal' , ), 89, (89, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'DisplayRoundingRemark' , u'penumRsltVal' , ), 90, (90, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'DisplayRoundingRemark' , u'penumRsltVal' , ), 90, (90, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pbstrRsltVal' , ), 91, (91, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pbstrRsltVal' , ), 91, (91, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'BlockSystemCurrencyEditing' , u'penumRsltVal' , ), 92, (92, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'BlockSystemCurrencyEditing' , u'penumRsltVal' , ), 92, (92, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'BlockPostingDateEditing' , u'penumRsltVal' , ), 93, (93, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'BlockPostingDateEditing' , u'penumRsltVal' , ), 93, (93, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'DefaultWarehouse' , u'pbstrRsltVal' , ), 94, (94, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'DefaultWarehouse' , u'pbstrRsltVal' , ), 94, (94, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'BlockTaxDate' , u'penumRsltVal' , ), 95, (95, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'BlockTaxDate' , u'penumRsltVal' , ), 95, (95, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinitionforVatitem' , u'pbstrRsltVal' , ), 96, (96, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinitionforVatitem' , u'pbstrRsltVal' , ), 96, (96, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinitionforVatservice' , u'pbstrRsltVal' , ), 97, (97, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinitionforVatservice' , u'pbstrRsltVal' , ), 97, (97, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroupforPurchaseItem' , u'pbstrRsltVal' , ), 98, (98, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroupforPurchaseItem' , u'pbstrRsltVal' , ), 98, (98, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroupforServicePurchase' , u'pbstrRsltVal' , ), 99, (99, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroupforServicePurchase' , u'pbstrRsltVal' , ), 99, (99, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'CalculateBudget' , u'penumRsltVal' , ), 100, (100, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'CalculateBudget' , u'penumRsltVal' , ), 100, (100, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'CustomerIdNumber' , u'pbstrRsltVal' , ), 101, (101, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'CustomerIdNumber' , u'pbstrRsltVal' , ), 101, (101, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'BlockBudget' , u'penumRsltVal' , ), 102, (102, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'BlockBudget' , u'penumRsltVal' , ), 102, (102, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAlert' , u'penumRsltVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAlert' , u'penumRsltVal' , ), 103, (103, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'BlockPurchaseOrders' , u'penumRsltVal' , ), 104, (104, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'BlockPurchaseOrders' , u'penumRsltVal' , ), 104, (104, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'BlockBookkeeping' , u'penumRsltVal' , ), 105, (105, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'BlockBookkeeping' , u'penumRsltVal' , ), 105, (105, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBudgetCostAssessMt' , u'plRsltVal' , ), 106, (106, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBudgetCostAssessMt' , u'plRsltVal' , ), 106, (106, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'ContinuousStockManagement' , u'penumRsltVal' , ), 107, (107, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'ContinuousStockManagement' , u'penumRsltVal' , ), 107, (107, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'ContinuousStockSystem' , u'penumRsltVal' , ), 108, (108, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'ContinuousStockSystem' , u'penumRsltVal' , ), 108, (108, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'RoundTaxAmounts' , u'penumRsltVal' , ), 109, (109, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'RoundTaxAmounts' , u'penumRsltVal' , ), 109, (109, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'BlockDelNotesforPurchase' , u'penumRsltVal' , ), 110, (110, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'BlockDelNotesforPurchase' , u'penumRsltVal' , ), 110, (110, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'FileNumberinIncomeTax' , u'pbstrRsltVal' , ), 111, (111, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'FileNumberinIncomeTax' , u'pbstrRsltVal' , ), 111, (111, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'penumRsltVal' , ), 112, (112, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'penumRsltVal' , ), 112, (112, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankNo' , u'pbstrRsltVal' , ), 113, (113, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankNo' , u'pbstrRsltVal' , ), 113, (113, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankAccount' , u'pbstrRsltVal' , ), 114, (114, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankAccount' , u'pbstrRsltVal' , ), 114, (114, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBranch' , u'pbstrRsltVal' , ), 115, (115, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'UsePASystem' , u'penumRsltVal' , ), 116, (116, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'UsePASystem' , u'penumRsltVal' , ), 116, (116, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'ServiceCode' , u'pbstrRsltVal' , ), 117, (117, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'ServiceCode' , u'pbstrRsltVal' , ), 117, (117, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'ServicePassword' , u'pbstrRsltVal' , ), 118, (118, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
	(( u'ServicePassword' , u'pbstrRsltVal' , ), 118, (118, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 916 , (3, 0, None, None) , 0 , )),
	(( u'ParamFolderPath' , u'pbstrRsltVal' , ), 119, (119, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 920 , (3, 0, None, None) , 0 , )),
	(( u'ParamFolderPath' , u'pbstrRsltVal' , ), 119, (119, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 924 , (3, 0, None, None) , 0 , )),
	(( u'ExcelFolderPath' , u'pbstrRsltVal' , ), 120, (120, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 928 , (3, 0, None, None) , 0 , )),
	(( u'ExcelFolderPath' , u'pbstrRsltVal' , ), 120, (120, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 932 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID2' , u'pbstrRsltVal' , ), 121, (121, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 936 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID2' , u'pbstrRsltVal' , ), 121, (121, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 940 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID3' , u'pbstrRsltVal' , ), 122, (122, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 944 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID3' , u'pbstrRsltVal' , ), 122, (122, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 948 , (3, 0, None, None) , 0 , )),
	(( u'DecimalSeparator' , u'pbstrRsltVal' , ), 123, (123, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 952 , (3, 0, None, None) , 0 , )),
	(( u'DecimalSeparator' , u'pbstrRsltVal' , ), 123, (123, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 956 , (3, 0, None, None) , 0 , )),
	(( u'ThousandsSeparator' , u'pbstrRsltVal' , ), 124, (124, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 960 , (3, 0, None, None) , 0 , )),
	(( u'ThousandsSeparator' , u'pbstrRsltVal' , ), 124, (124, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 964 , (3, 0, None, None) , 0 , )),
	(( u'DisplayCurrencyontheRight' , u'penumRsltVal' , ), 125, (125, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 968 , (3, 0, None, None) , 0 , )),
	(( u'DisplayCurrencyontheRight' , u'penumRsltVal' , ), 125, (125, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 972 , (3, 0, None, None) , 0 , )),
	(( u'AlertbyWarehouse' , u'penumRsltVal' , ), 126, (126, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 976 , (3, 0, None, None) , 0 , )),
	(( u'AlertbyWarehouse' , u'penumRsltVal' , ), 126, (126, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 980 , (3, 0, None, None) , 0 , )),
	(( u'PriceSystem' , u'penumRsltVal' , ), 127, (127, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 984 , (3, 0, None, None) , 0 , )),
	(( u'PriceSystem' , u'penumRsltVal' , ), 127, (127, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 988 , (3, 0, None, None) , 0 , )),
	(( u'WholdingTaxDedHierarchy' , u'penumRsltVal' , ), 128, (128, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 992 , (3, 0, None, None) , 0 , )),
	(( u'WholdingTaxDedHierarchy' , u'penumRsltVal' , ), 128, (128, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 996 , (3, 0, None, None) , 0 , )),
	(( u'DocConfirmation' , u'penumRsltVal' , ), 129, (129, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1000 , (3, 0, None, None) , 0 , )),
	(( u'DocConfirmation' , u'penumRsltVal' , ), 129, (129, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1004 , (3, 0, None, None) , 0 , )),
	(( u'DefaultforBatchStatus' , u'penumRsltVal' , ), 130, (130, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1008 , (3, 0, None, None) , 0 , )),
	(( u'DefaultforBatchStatus' , u'penumRsltVal' , ), 130, (130, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1012 , (3, 0, None, None) , 0 , )),
	(( u'GLMethod' , u'penumRsltVal' , ), 131, (131, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1016 , (3, 0, None, None) , 0 , )),
	(( u'GLMethod' , u'penumRsltVal' , ), 131, (131, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1020 , (3, 0, None, None) , 0 , )),
	(( u'UniqueSerialNo' , u'penumRsltVal' , ), 132, (132, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1024 , (3, 0, None, None) , 0 , )),
	(( u'UniqueSerialNo' , u'penumRsltVal' , ), 132, (132, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1028 , (3, 0, None, None) , 0 , )),
	(( u'MaxHistory' , u'plRsltVal' , ), 133, (133, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1032 , (3, 0, None, None) , 0 , )),
	(( u'MaxHistory' , u'plRsltVal' , ), 133, (133, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1036 , (3, 0, None, None) , 0 , )),
	(( u'ChangeDefReconAPAccounts' , u'penumRsltVal' , ), 134, (134, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1040 , (3, 0, None, None) , 0 , )),
	(( u'ChangeDefReconAPAccounts' , u'penumRsltVal' , ), 134, (134, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1044 , (3, 0, None, None) , 0 , )),
	(( u'ChangeDefReconARAccounts' , u'penumRsltVal' , ), 135, (135, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1048 , (3, 0, None, None) , 0 , )),
	(( u'ChangeDefReconARAccounts' , u'penumRsltVal' , ), 135, (135, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1052 , (3, 0, None, None) , 0 , )),
	(( u'BPTypeCode' , u'pbstrRsltVal' , ), 136, (136, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1056 , (3, 0, None, None) , 0 , )),
	(( u'BPTypeCode' , u'pbstrRsltVal' , ), 136, (136, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1060 , (3, 0, None, None) , 0 , )),
	(( u'PBSNumber' , u'pbstrRsltVal' , ), 137, (137, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1064 , (3, 0, None, None) , 0 , )),
	(( u'PBSNumber' , u'pbstrRsltVal' , ), 137, (137, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1068 , (3, 0, None, None) , 0 , )),
	(( u'PBSGroupNumber' , u'pbstrRsltVal' , ), 138, (138, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1072 , (3, 0, None, None) , 0 , )),
	(( u'PBSGroupNumber' , u'pbstrRsltVal' , ), 138, (138, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1076 , (3, 0, None, None) , 0 , )),
	(( u'OrganizationNumber' , u'pbstrRsltVal' , ), 139, (139, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1080 , (3, 0, None, None) , 0 , )),
	(( u'OrganizationNumber' , u'pbstrRsltVal' , ), 139, (139, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1084 , (3, 0, None, None) , 0 , )),
	(( u'AccountSegmentsSeparator' , u'pbstrRsltVal' , ), 140, (140, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1088 , (3, 0, None, None) , 0 , )),
	(( u'AccountSegmentsSeparator' , u'pbstrRsltVal' , ), 140, (140, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1092 , (3, 0, None, None) , 0 , )),
	(( u'DisplayBookkeepingWindow' , u'penumRsltVal' , ), 141, (141, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1096 , (3, 0, None, None) , 0 , )),
	(( u'DisplayBookkeepingWindow' , u'penumRsltVal' , ), 141, (141, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1100 , (3, 0, None, None) , 0 , )),
	(( u'SHandleWT' , u'penumRsltVal' , ), 142, (142, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1104 , (3, 0, None, None) , 0 , )),
	(( u'SHandleWT' , u'penumRsltVal' , ), 142, (142, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1108 , (3, 0, None, None) , 0 , )),
	(( u'SDefaultWTCode' , u'pbstrRsltVal' , ), 143, (143, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1112 , (3, 0, None, None) , 0 , )),
	(( u'SDefaultWTCode' , u'pbstrRsltVal' , ), 143, (143, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1116 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxPHandle' , u'pbstrRsltVal' , ), 144, (144, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1120 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxPHandle' , u'pbstrRsltVal' , ), 144, (144, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1124 , (3, 0, None, None) , 0 , )),
	(( u'PDefaultWTCode' , u'pbstrRsltVal' , ), 145, (145, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1128 , (3, 0, None, None) , 0 , )),
	(( u'PDefaultWTCode' , u'pbstrRsltVal' , ), 145, (145, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1132 , (3, 0, None, None) , 0 , )),
	(( u'WTLiableExpense' , u'penumRsltVal' , ), 146, (146, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1136 , (3, 0, None, None) , 0 , )),
	(( u'WTLiableExpense' , u'penumRsltVal' , ), 146, (146, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1140 , (3, 0, None, None) , 0 , )),
	(( u'UseNegativeAmounts' , u'penumRsltVal' , ), 147, (147, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1144 , (3, 0, None, None) , 0 , )),
	(( u'UseNegativeAmounts' , u'penumRsltVal' , ), 147, (147, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1148 , (3, 0, None, None) , 0 , )),
	(( u'HolidaysName' , u'pbstrRsltVal' , ), 148, (148, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1152 , (3, 0, None, None) , 0 , )),
	(( u'HolidaysName' , u'pbstrRsltVal' , ), 148, (148, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1156 , (3, 0, None, None) , 0 , )),
	(( u'OrderBlock' , u'pbstrRsltVal' , ), 149, (149, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1160 , (3, 0, None, None) , 0 , )),
	(( u'OrderBlock' , u'pbstrRsltVal' , ), 149, (149, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1164 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'penumRsltVal' , ), 150, (150, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1168 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'penumRsltVal' , ), 150, (150, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1172 , (3, 0, None, None) , 0 , )),
	(( u'AdressFromWH' , u'penumRsltVal' , ), 151, (151, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1176 , (3, 0, None, None) , 0 , )),
	(( u'AdressFromWH' , u'penumRsltVal' , ), 151, (151, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1180 , (3, 0, None, None) , 0 , )),
	(( u'OrderingParty' , u'pbstrRsltVal' , ), 152, (152, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1184 , (3, 0, None, None) , 0 , )),
	(( u'OrderingParty' , u'pbstrRsltVal' , ), 152, (152, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1188 , (3, 0, None, None) , 0 , )),
	(( u'CertificateNo' , u'pbstrRsltVal' , ), 153, (153, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1192 , (3, 0, None, None) , 0 , )),
	(( u'CertificateNo' , u'pbstrRsltVal' , ), 153, (153, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1196 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pdtRsltVal' , ), 154, (154, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 1200 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pdtRsltVal' , ), 154, (154, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 1204 , (3, 0, None, None) , 0 , )),
	(( u'NationalInsuranceNo' , u'pbstrRsltVal' , ), 155, (155, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1208 , (3, 0, None, None) , 0 , )),
	(( u'NationalInsuranceNo' , u'pbstrRsltVal' , ), 155, (155, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1212 , (3, 0, None, None) , 0 , )),
	(( u'SalesOrderConfirmed' , u'penumRsltVal' , ), 156, (156, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1216 , (3, 0, None, None) , 0 , )),
	(( u'SalesOrderConfirmed' , u'penumRsltVal' , ), 156, (156, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1220 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOrderConfirmed' , u'penumRsltVal' , ), 157, (157, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1224 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOrderConfirmed' , u'penumRsltVal' , ), 157, (157, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1228 , (3, 0, None, None) , 0 , )),
	(( u'SDfltITWT' , u'pbstrRsltVal' , ), 158, (158, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1232 , (3, 0, None, None) , 0 , )),
	(( u'SDfltITWT' , u'pbstrRsltVal' , ), 158, (158, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1236 , (3, 0, None, None) , 0 , )),
	(( u'PDfltITWT' , u'pbstrRsltVal' , ), 159, (159, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1240 , (3, 0, None, None) , 0 , )),
	(( u'PDfltITWT' , u'pbstrRsltVal' , ), 159, (159, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1244 , (3, 0, None, None) , 0 , )),
	(( u'DefaultAccountCurrency' , u'penumRsltVal' , ), 160, (160, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1248 , (3, 0, None, None) , 0 , )),
	(( u'DefaultAccountCurrency' , u'penumRsltVal' , ), 160, (160, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1252 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTaxforVendors' , u'penumRsltVal' , ), 161, (161, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1256 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTaxforVendors' , u'penumRsltVal' , ), 161, (161, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1260 , (3, 0, None, None) , 0 , )),
	(( u'CreateAutoVATLineinJDT' , u'penumRsltVal' , ), 162, (162, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1264 , (3, 0, None, None) , 0 , )),
	(( u'CreateAutoVATLineinJDT' , u'penumRsltVal' , ), 162, (162, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1268 , (3, 0, None, None) , 0 , )),
	(( u'ConsumeForecast' , u'penumRsltVal' , ), 163, (163, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1272 , (3, 0, None, None) , 0 , )),
	(( u'ConsumeForecast' , u'penumRsltVal' , ), 163, (163, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1276 , (3, 0, None, None) , 0 , )),
	(( u'ConsumptionMethod' , u'penumRsltVal' , ), 164, (164, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1280 , (3, 0, None, None) , 0 , )),
	(( u'ConsumptionMethod' , u'penumRsltVal' , ), 164, (164, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1284 , (3, 0, None, None) , 0 , )),
	(( u'DaysBackward' , u'plRsltVal' , ), 165, (165, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1288 , (3, 0, None, None) , 0 , )),
	(( u'DaysBackward' , u'plRsltVal' , ), 165, (165, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1292 , (3, 0, None, None) , 0 , )),
	(( u'DaysForward' , u'plRsltVal' , ), 166, (166, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1296 , (3, 0, None, None) , 0 , )),
	(( u'DaysForward' , u'plRsltVal' , ), 166, (166, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1300 , (3, 0, None, None) , 0 , )),
	(( u'DefaultDunningTerm' , u'pbstrRsltVal' , ), 167, (167, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1304 , (3, 0, None, None) , 0 , )),
	(( u'DefaultDunningTerm' , u'pbstrRsltVal' , ), 167, (167, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1308 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankAccountKey' , u'pVal' , ), 168, (168, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1312 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankAccountKey' , u'pVal' , ), 168, (168, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1316 , (3, 0, None, None) , 0 , )),
	(( u'MultiLanguageSupportEnable' , u'penumRsltVal' , ), 169, (169, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1320 , (3, 0, None, None) , 0 , )),
	(( u'MultiLanguageSupportEnable' , u'penumRsltVal' , ), 169, (169, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1324 , (3, 0, None, None) , 0 , )),
	(( u'AllowFuturePostingDate' , u'penumRsltVal' , ), 170, (170, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1328 , (3, 0, None, None) , 0 , )),
	(( u'AllowFuturePostingDate' , u'penumRsltVal' , ), 170, (170, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1332 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalIdNumber' , u'pbstrRsltVal' , ), 171, (171, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1336 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalIdNumber' , u'pbstrRsltVal' , ), 171, (171, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1340 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 172, (172, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1344 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 172, (172, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1348 , (3, 0, None, None) , 0 , )),
	(( u'CalculateRowDiscount' , u'penumRsltVal' , ), 173, (173, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1352 , (3, 0, None, None) , 0 , )),
	(( u'CalculateRowDiscount' , u'penumRsltVal' , ), 173, (173, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1356 , (3, 0, None, None) , 0 , )),
	(( u'BankStatementInstalled' , u'pVal' , ), 174, (174, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1360 , (3, 0, None, None) , 0 , )),
	(( u'UniqueTaxPayerReference' , u'pbstrRsltVal' , ), 175, (175, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1364 , (3, 0, None, None) , 0 , )),
	(( u'UniqueTaxPayerReference' , u'pbstrRsltVal' , ), 175, (175, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1368 , (3, 0, None, None) , 0 , )),
	(( u'EmployerReference' , u'pbstrRsltVal' , ), 176, (176, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1372 , (3, 0, None, None) , 0 , )),
	(( u'EmployerReference' , u'pbstrRsltVal' , ), 176, (176, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1376 , (3, 0, None, None) , 0 , )),
	(( u'PeriodStatusAutoChange' , u'penumRsltVal' , ), 177, (177, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1380 , (3, 0, None, None) , 0 , )),
	(( u'PeriodStatusAutoChange' , u'penumRsltVal' , ), 177, (177, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1384 , (3, 0, None, None) , 0 , )),
	(( u'PeriodStatusChangeDelay' , u'pVal' , ), 178, (178, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1388 , (3, 0, None, None) , 0 , )),
	(( u'PeriodStatusChangeDelay' , u'pVal' , ), 178, (178, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1392 , (3, 0, None, None) , 0 , )),
	(( u'ExtendedAdminInfo' , u'pVal' , ), 179, (179, (), [ (16393, 10, None, "IID('{6AAAB602-C1E1-4988-BF5D-ECE369936FC0}')") , ], 1 , 2 , 4 , 0 , 1396 , (3, 0, None, None) , 0 , )),
	(( u'XMLFileFolderPath' , u'pbstrRsltVal' , ), 180, (180, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1400 , (3, 0, None, None) , 0 , )),
	(( u'XMLFileFolderPath' , u'pbstrRsltVal' , ), 180, (180, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1404 , (3, 0, None, None) , 0 , )),
	(( u'QueryAccuracy' , u'pVal' , ), 181, (181, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1408 , (3, 0, None, None) , 0 , )),
	(( u'QueryAccuracy' , u'pVal' , ), 181, (181, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1412 , (3, 0, None, None) , 0 , )),
	(( u'GeneralManager' , u'pbstrRsltVal' , ), 182, (182, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1416 , (3, 0, None, None) , 0 , )),
	(( u'GeneralManager' , u'pbstrRsltVal' , ), 182, (182, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1420 , (3, 0, None, None) , 0 , )),
	(( u'GeneralManagerForeignLanguage' , u'pbstrRsltVal' , ), 183, (183, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1424 , (3, 0, None, None) , 0 , )),
	(( u'GeneralManagerForeignLanguage' , u'pbstrRsltVal' , ), 183, (183, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1428 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitPercentForServiceDocuments' , u'ppRsltVal' , ), 200, (200, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1432 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitPercentForServiceDocuments' , u'ppRsltVal' , ), 200, (200, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1436 , (3, 0, None, None) , 0 , )),
	(( u'PickList' , u'penumRsltVal' , ), 201, (201, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1440 , (3, 0, None, None) , 0 , )),
	(( u'PickList' , u'penumRsltVal' , ), 201, (201, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1444 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 202, (202, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1448 , (3, 0, None, None) , 0 , )),
	(( u'CopyExchangeRateInCopyTo' , u'penumRsltVal' , ), 203, (203, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1452 , (3, 0, None, None) , 0 , )),
	(( u'CopyExchangeRateInCopyTo' , u'penumRsltVal' , ), 203, (203, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1456 , (3, 0, None, None) , 0 , )),
	(( u'GTSOutboundFolder' , u'ppRsltVal' , ), 204, (204, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1460 , (3, 0, None, None) , 0 , )),
	(( u'GTSOutboundFolder' , u'ppRsltVal' , ), 204, (204, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1464 , (3, 0, None, None) , 0 , )),
	(( u'GTSInboundFolder' , u'ppRsltVal' , ), 205, (205, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1468 , (3, 0, None, None) , 0 , )),
	(( u'GTSInboundFolder' , u'ppRsltVal' , ), 205, (205, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1472 , (3, 0, None, None) , 0 , )),
	(( u'GTSSeparateCode' , u'ppRsltVal' , ), 206, (206, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1476 , (3, 0, None, None) , 0 , )),
	(( u'GTSSeparateCode' , u'ppRsltVal' , ), 206, (206, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1480 , (3, 0, None, None) , 0 , )),
	(( u'GTSDefaultChecker' , u'ppRsltVal' , ), 207, (207, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1484 , (3, 0, None, None) , 0 , )),
	(( u'GTSDefaultChecker' , u'ppRsltVal' , ), 207, (207, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1488 , (3, 0, None, None) , 0 , )),
	(( u'GTSDefaultPayee' , u'ppRsltVal' , ), 208, (208, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1492 , (3, 0, None, None) , 0 , )),
	(( u'GTSDefaultPayee' , u'ppRsltVal' , ), 208, (208, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1496 , (3, 0, None, None) , 0 , )),
	(( u'GTSMaxAmount' , u'ppRsltVal' , ), 209, (209, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1500 , (3, 0, None, None) , 0 , )),
	(( u'GTSMaxAmount' , u'ppRsltVal' , ), 209, (209, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1504 , (3, 0, None, None) , 0 , )),
	(( u'GTSResponseToExceeding' , u'penumRsltVal' , ), 210, (210, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1508 , (3, 0, None, None) , 0 , )),
	(( u'GTSResponseToExceeding' , u'penumRsltVal' , ), 210, (210, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1512 , (3, 0, None, None) , 0 , )),
	(( u'UseProductionProfitAndLossAccount' , u'penumRsltVal' , ), 211, (211, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1516 , (3, 0, None, None) , 0 , )),
	(( u'UseProductionProfitAndLossAccount' , u'penumRsltVal' , ), 211, (211, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1520 , (3, 0, None, None) , 0 , )),
	(( u'WTAccumAmountAP' , u'pRsltVal' , ), 212, (212, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1524 , (3, 0, None, None) , 0 , )),
	(( u'WTAccumAmountAP' , u'pRsltVal' , ), 212, (212, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1528 , (3, 0, None, None) , 0 , )),
	(( u'WTAccumAmountAR' , u'pRsltVal' , ), 213, (213, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1532 , (3, 0, None, None) , 0 , )),
	(( u'WTAccumAmountAR' , u'pRsltVal' , ), 213, (213, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1536 , (3, 0, None, None) , 0 , )),
	(( u'ApplicationOfIFRS' , u'penumRsltVal' , ), 214, (214, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1540 , (3, 0, None, None) , 0 , )),
	(( u'ApplicationOfIFRS' , u'penumRsltVal' , ), 214, (214, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1544 , (3, 0, None, None) , 0 , )),
	(( u'StartingInFiscalYear' , u'pRsltVal' , ), 215, (215, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1548 , (3, 0, None, None) , 0 , )),
	(( u'StartingInFiscalYear' , u'pRsltVal' , ), 215, (215, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1552 , (3, 0, None, None) , 0 , )),
	(( u'ReportAccordingTo' , u'pRsltVal' , ), 216, (216, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1556 , (3, 0, None, None) , 0 , )),
	(( u'ReportAccordingTo' , u'pRsltVal' , ), 216, (216, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1560 , (3, 0, None, None) , 0 , )),
	(( u'CreateOnlineQuotation' , u'penumRsltVal' , ), 217, (217, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1564 , (3, 0, None, None) , 0 , )),
	(( u'CreateOnlineQuotation' , u'penumRsltVal' , ), 217, (217, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1568 , (3, 0, None, None) , 0 , )),
	(( u'CopyOpenRowsToDelivery' , u'penumRsltVal' , ), 218, (218, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1572 , (3, 0, None, None) , 0 , )),
	(( u'CopyOpenRowsToDelivery' , u'penumRsltVal' , ), 218, (218, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1576 , (3, 0, None, None) , 0 , )),
	(( u'EnableApprovalProcedureInDI' , u'penumRsltVal' , ), 219, (219, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1580 , (3, 0, None, None) , 0 , )),
	(( u'EnableApprovalProcedureInDI' , u'penumRsltVal' , ), 219, (219, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1584 , (3, 0, None, None) , 0 , )),
	(( u'IsPrinterConnected' , u'penumRsltVal' , ), 220, (220, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1588 , (3, 0, None, None) , 0 , )),
	(( u'IsPrinterConnected' , u'penumRsltVal' , ), 220, (220, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1592 , (3, 0, None, None) , 0 , )),
	(( u'EnableBranches' , u'penumRsltVal' , ), 230, (230, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1596 , (3, 0, None, None) , 0 , )),
	(( u'EnableBranches' , u'penumRsltVal' , ), 230, (230, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1600 , (3, 0, None, None) , 0 , )),
	(( u'IEMandatoryValidation' , u'penumRsltVal' , ), 231, (231, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1604 , (3, 0, None, None) , 0 , )),
	(( u'IEMandatoryValidation' , u'penumRsltVal' , ), 231, (231, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1608 , (3, 0, None, None) , 0 , )),
	(( u'EnablePaymentDueDates' , u'penumResultValue' , ), 232, (232, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1612 , (3, 0, None, None) , 0 , )),
	(( u'EnablePaymentDueDates' , u'penumResultValue' , ), 232, (232, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1616 , (3, 0, None, None) , 0 , )),
	(( u'MaximumNumberOfDaysForDueDate' , u'plResultValue' , ), 233, (233, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1620 , (3, 0, None, None) , 0 , )),
	(( u'MaximumNumberOfDaysForDueDate' , u'plResultValue' , ), 233, (233, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1624 , (3, 0, None, None) , 0 , )),
	(( u'AliasName' , u'pbstrRsltValue' , ), 234, (234, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1628 , (3, 0, None, None) , 0 , )),
	(( u'AliasName' , u'pbstrRsltValue' , ), 234, (234, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1632 , (3, 0, None, None) , 0 , )),
	(( u'EnableCentralizedIncomingPayments' , u'penumResultValue' , ), 235, (235, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1636 , (3, 0, None, None) , 0 , )),
	(( u'EnableCentralizedIncomingPayments' , u'penumResultValue' , ), 235, (235, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1640 , (3, 0, None, None) , 0 , )),
	(( u'EnableCentralizedOutgoingPayments' , u'penumResultValue' , ), 236, (236, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1644 , (3, 0, None, None) , 0 , )),
	(( u'EnableCentralizedOutgoingPayments' , u'penumResultValue' , ), 236, (236, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1648 , (3, 0, None, None) , 0 , )),
	(( u'TaxRateDetermination' , u'penumRsltVal' , ), 237, (237, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1652 , (3, 0, None, None) , 0 , )),
	(( u'TaxRateDetermination' , u'penumRsltVal' , ), 237, (237, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1656 , (3, 0, None, None) , 0 , )),
	(( u'AllowMultipleBAOnSamePeriod' , u'penumResultValue' , ), 238, (238, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1660 , (3, 0, None, None) , 0 , )),
	(( u'AllowMultipleBAOnSamePeriod' , u'penumResultValue' , ), 238, (238, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1664 , (3, 0, None, None) , 0 , )),
	(( u'BlockMultipleBAOnSameAPDocument' , u'penumResultValue' , ), 239, (239, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1668 , (3, 0, None, None) , 0 , )),
	(( u'BlockMultipleBAOnSameAPDocument' , u'penumResultValue' , ), 239, (239, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1672 , (3, 0, None, None) , 0 , )),
	(( u'BlockMultipleBAOnSameARDocument' , u'penumResultValue' , ), 240, (240, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1676 , (3, 0, None, None) , 0 , )),
	(( u'BlockMultipleBAOnSameARDocument' , u'penumResultValue' , ), 240, (240, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1680 , (3, 0, None, None) , 0 , )),
	(( u'BoletoFolderPath' , u'pbstrRsltVal' , ), 241, (241, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1684 , (3, 0, None, None) , 0 , )),
	(( u'BoletoFolderPath' , u'pbstrRsltVal' , ), 241, (241, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1688 , (3, 0, None, None) , 0 , )),
]

IAlertManagement_vtables_dispatch_ = 1
IAlertManagement_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Param' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Param' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'QueryID' , u'plRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'QueryID' , u'plRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'FrequencyType' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'FrequencyType' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DayOfExecution' , u'plRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DayOfExecution' , u'plRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ExecutionTime' , u'pdtRsltVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ExecutionTime' , u'pdtRsltVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'LastExecutionDate' , u'pdtRsltVal' , ), 21, (21, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'LastExecutionTime' , u'plRsltVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'NextExecutionDate' , u'pdtRsltVal' , ), 23, (23, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'NextExecutionTime' , u'pdtRsltVal' , ), 24, (24, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'SaveHistory' , u'penumRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'SaveHistory' , u'penumRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'AlertManagementRecipients' , u'ppRsltVal' , ), 26, (26, (), [ (16393, 10, None, "IID('{F675D408-2207-4E44-AE93-3BFDA7DE7CA3}')") , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'AlertManagementDocuments' , u'ppRsltVal' , ), 27, (27, (), [ (16393, 10, None, "IID('{A6E70E75-647C-48BF-A642-84841BD85B2C}')") , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'FrequencyInterval' , u'plRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'FrequencyInterval' , u'plRsltVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
]

IAlertManagementDocument_vtables_dispatch_ = 1
IAlertManagementDocument_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IAlertManagementDocuments_vtables_dispatch_ = 1
IAlertManagementDocuments_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IAlertManagementParams_vtables_dispatch_ = 1
IAlertManagementParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IAlertManagementParamsCollection_vtables_dispatch_ = 1
IAlertManagementParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{CC51470B-7859-4DC8-B636-E3856A52C02D}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CC51470B-7859-4DC8-B636-E3856A52C02D}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IAlertManagementRecipient_vtables_dispatch_ = 1
IAlertManagementRecipient_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SendEmail' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SendEmail' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SendSMS' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SendSMS' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SendFax' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SendFax' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SendInternal' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SendInternal' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IAlertManagementRecipients_vtables_dispatch_ = 1
IAlertManagementRecipients_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{B93946BC-D44E-4D81-8071-B56EF0830B51}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{B93946BC-D44E-4D81-8071-B56EF0830B51}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IAlertManagementService_vtables_dispatch_ = 1
IAlertManagementService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetAlertManagement' , u'pAlertManagementParams' , u'ppRsltIAlertManagement' , ), 10, (10, (), [ (9, 1, None, "IID('{CC51470B-7859-4DC8-B636-E3856A52C02D}')") , 
			(16393, 10, None, "IID('{9E52D02D-16FC-4E2C-87FC-CD070F5D646A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateAlertManagement' , u'pIAlertManagement' , ), 11, (11, (), [ (9, 1, None, "IID('{9E52D02D-16FC-4E2C-87FC-CD070F5D646A}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AddAlertManagement' , u'pAlertManagement' , u'ppRsltIAlertManagementParams' , ), 12, (12, (), [ (9, 1, None, "IID('{9E52D02D-16FC-4E2C-87FC-CD070F5D646A}')") , 
			(16393, 10, None, "IID('{CC51470B-7859-4DC8-B636-E3856A52C02D}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetAlertManagementList' , u'pAlertManagementParams' , u'ppRsltIAlertManagementParamsCollection' , ), 13, (13, (), [ (9, 1, None, "IID('{CC51470B-7859-4DC8-B636-E3856A52C02D}')") , 
			(16393, 10, None, "IID('{341FC52D-5088-4DE4-8308-7085F8D950A1}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IAlternateCatNum_vtables_dispatch_ = 1
IAlternateCatNum_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Substitute' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Substitute' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ItemCode' , u'CardCode' , u'Substitute' , u'Found' , 
			), 11, (11, (), [ (8, 1, None, None) , (8, 1, None, None) , (8, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DisplayBPCatalogNumber' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DisplayBPCatalogNumber' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IAlternativeItem_vtables_dispatch_ = 1
IAlternativeItem_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AlternativeItemCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AlternativeItemCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'MatchFactor' , u'ppRsltVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MatchFactor' , u'ppRsltVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IAlternativeItems_vtables_dispatch_ = 1
IAlternativeItems_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IAlternativeItemsService_vtables_dispatch_ = 1
IAlternativeItemsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddItem' , u'pIOriginalItem' , u'ppIOriginalItemParams' , ), 10, (10, (), [ (9, 1, None, "IID('{4631570A-DAE1-43BB-9E4A-BA9957E593E1}')") , 
			(16393, 10, None, "IID('{BC7EF5B4-EEA5-4C83-8478-FBC484133A79}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateItem' , u'pIOriginalItem' , ), 11, (11, (), [ (9, 1, None, "IID('{4631570A-DAE1-43BB-9E4A-BA9957E593E1}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteItem' , u'pIOriginalItemParams' , ), 12, (12, (), [ (9, 1, None, "IID('{BC7EF5B4-EEA5-4C83-8478-FBC484133A79}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetItem' , u'pIOriginalItemParams' , u'ppIOriginalItem' , ), 13, (13, (), [ (9, 1, None, "IID('{BC7EF5B4-EEA5-4C83-8478-FBC484133A79}')") , 
			(16393, 10, None, "IID('{4631570A-DAE1-43BB-9E4A-BA9957E593E1}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalRequest_vtables_dispatch_ = 1
IApprovalRequest_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ObjectType' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'IsDraft' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ObjectEntry' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CurrentStage' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'OriginatorID' , u'plRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalRequestLines' , u'ppRsltVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{100612B7-46C2-4489-A406-504575577467}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalRequestDecisions' , u'ppRsltVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{B148F7EE-7416-4B22-B266-55321DF794D8}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IApprovalRequestDecision_vtables_dispatch_ = 1
IApprovalRequestDecision_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ApproverUserName' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ApproverUserName' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ApproverPassword' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ApproverPassword' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IApprovalRequestDecisions_vtables_dispatch_ = 1
IApprovalRequestDecisions_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{FB002972-8E0A-4819-AC30-B955B37C4772}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{FB002972-8E0A-4819-AC30-B955B37C4772}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalRequestLine_vtables_dispatch_ = 1
IApprovalRequestLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StageCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IApprovalRequestLines_vtables_dispatch_ = 1
IApprovalRequestLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{6228C442-C4B7-4841-9275-54B459F42BCB}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{6228C442-C4B7-4841-9275-54B459F42BCB}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalRequestParams_vtables_dispatch_ = 1
IApprovalRequestParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IApprovalRequestsParams_vtables_dispatch_ = 1
IApprovalRequestsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalRequestsService_vtables_dispatch_ = 1
IApprovalRequestsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UpdateRequest' , u'pIApprovalRequest' , ), 10, (10, (), [ (9, 1, None, "IID('{92196C1E-B89A-4F4E-8E37-A1F2FAC71C5C}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetApprovalRequest' , u'pIApprovalRequestParams' , u'ppIApprovalRequest' , ), 11, (11, (), [ (9, 1, None, "IID('{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}')") , 
			(16393, 10, None, "IID('{92196C1E-B89A-4F4E-8E37-A1F2FAC71C5C}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetApprovalRequestList' , u'ppIApprovalRequestsParams' , ), 12, (12, (), [ (16393, 10, None, "IID('{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetOpenApprovalRequestList' , u'ppIApprovalRequestsParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetAllApprovalRequestsList' , u'ppIApprovalRequestsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IApprovalStage_vtables_dispatch_ = 1
IApprovalStage_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'NoOfApproversRequired' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'NoOfApproversRequired' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalStageApprovers' , u'ppRslt' , ), 15, (15, (), [ (16393, 10, None, "IID('{D154A6C0-19F8-46CE-B66D-FFC856FC0310}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IApprovalStageApprover_vtables_dispatch_ = 1
IApprovalStageApprover_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalStageApprovers_vtables_dispatch_ = 1
IApprovalStageApprovers_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalStageParams_vtables_dispatch_ = 1
IApprovalStageParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IApprovalStages_vtables_dispatch_ = 1
IApprovalStages_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalStagesParams_vtables_dispatch_ = 1
IApprovalStagesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalStagesService_vtables_dispatch_ = 1
IApprovalStagesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddApprovalStage' , u'pApprovalStage' , u'ppRsltIApprovalStageParams' , ), 11, (11, (), [ (9, 1, None, "IID('{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')") , 
			(16393, 10, None, "IID('{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetApprovalStage' , u'pIApprovalStageParams' , u'ppRsltIApprovalStage' , ), 12, (12, (), [ (9, 1, None, "IID('{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')") , 
			(16393, 10, None, "IID('{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UpdateApprovalStage' , u'pIApprovalStage' , ), 13, (13, (), [ (9, 1, None, "IID('{67D827C6-26FA-43AD-84B9-38F2C233BEB8}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RemoveApprovalStage' , u'pIApprovalStageParams' , ), 14, (14, (), [ (9, 1, None, "IID('{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetApprovalStageList' , u'ppRsltIApprovalStagesParams' , ), 15, (15, (), [ (16393, 10, None, "IID('{03664F1A-4FCF-401A-84E1-934D1F101EA4}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplate_vtables_dispatch_ = 1
IApprovalTemplate_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UseTerms' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UseTerms' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'IsActive' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'IsActive' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalTemplateUsers' , u'ppRslt' , ), 16, (16, (), [ (16393, 10, None, "IID('{948C7B32-1518-45ED-99A3-94AA328CD7FF}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalTemplateStages' , u'ppRslt' , ), 17, (17, (), [ (16393, 10, None, "IID('{02B05079-F380-48A7-A573-0BB7307A52C0}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalTemplateDocuments' , u'ppRslt' , ), 18, (18, (), [ (16393, 10, None, "IID('{216D15B1-8639-435F-8C85-4967488AD161}')") , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalTemplateTerms' , u'ppRslt' , ), 19, (19, (), [ (16393, 10, None, "IID('{EFFD365E-5096-4B19-9187-986F83D337E0}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalTemplateQueries' , u'ppRslt' , ), 20, (20, (), [ (16393, 10, None, "IID('{5C730C88-3D5F-4C01-911A-56813AD89504}')") , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateDocument_vtables_dispatch_ = 1
IApprovalTemplateDocument_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateDocuments_vtables_dispatch_ = 1
IApprovalTemplateDocuments_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{81BEC420-E567-4353-95BA-71F26FD54BCD}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{81BEC420-E567-4353-95BA-71F26FD54BCD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateParams_vtables_dispatch_ = 1
IApprovalTemplateParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateQueries_vtables_dispatch_ = 1
IApprovalTemplateQueries_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateQuery_vtables_dispatch_ = 1
IApprovalTemplateQuery_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'QueryID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'QueryID' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateStage_vtables_dispatch_ = 1
IApprovalTemplateStage_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SortID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SortID' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalStageCode' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalStageCode' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateStages_vtables_dispatch_ = 1
IApprovalTemplateStages_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateTerm_vtables_dispatch_ = 1
IApprovalTemplateTerm_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ConditionType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ConditionType' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'OperationType' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'OperationType' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateTerms_vtables_dispatch_ = 1
IApprovalTemplateTerms_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{5691EAF4-B571-4BDA-B908-F7596767830E}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{5691EAF4-B571-4BDA-B908-F7596767830E}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateUser_vtables_dispatch_ = 1
IApprovalTemplateUser_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplateUsers_vtables_dispatch_ = 1
IApprovalTemplateUsers_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplates_vtables_dispatch_ = 1
IApprovalTemplates_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplatesParams_vtables_dispatch_ = 1
IApprovalTemplatesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IApprovalTemplatesService_vtables_dispatch_ = 1
IApprovalTemplatesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddApprovalTemplate' , u'pApprovalTemplate' , u'ppRsltIApprovalTemplateParams' , ), 11, (11, (), [ (9, 1, None, "IID('{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')") , 
			(16393, 10, None, "IID('{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetApprovalTemplate' , u'pIApprovalTemplateParams' , u'ppRsltIApprovalTemplate' , ), 12, (12, (), [ (9, 1, None, "IID('{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')") , 
			(16393, 10, None, "IID('{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UpdateApprovalTemplate' , u'pIApprovalTemplate' , ), 13, (13, (), [ (9, 1, None, "IID('{82C83910-6247-4BFB-AAE2-C9AD27B1947D}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RemoveApprovalTemplate' , u'pIApprovalTemplateParams' , ), 14, (14, (), [ (9, 1, None, "IID('{1445B394-DD5B-4542-9E3B-2B6E9CA92621}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetApprovalTemplateList' , u'ppRsltIApprovalTemplatesParams' , ), 15, (15, (), [ (16393, 10, None, "IID('{14E8A7AE-CC48-4793-B4C6-4942E83F92BD}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IAttachment_vtables_dispatch_ = 1
IAttachment_vtables_ = [
	(( u'FileName' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'FileName' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
]

IAttachments_vtables_dispatch_ = 1
IAttachments_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{18B4A57B-206A-4CF7-B94B-7325AED96137}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Refresh' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 1 , )),
]

IAttachments2_vtables_dispatch_ = 1
IAttachments2_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsoluteEntry' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{F9D49CC8-76E7-4387-AA71-ED03A361F510}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IAttachments2_Lines_vtables_dispatch_ = 1
IAttachments2_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SourcePath' , u'pbstrRsltVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SourcePath' , u'pbstrRsltVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FileName' , u'pbstrRsltVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FileName' , u'pbstrRsltVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FileExtension' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FileExtension' , u'pbstrRsltVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentDate' , u'pdtRsltVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Override' , u'penumRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Override' , u'penumRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IBOEDocumentType_vtables_dispatch_ = 1
IBOEDocumentType_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocDescription' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocDescription' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IBOEDocumentTypeParams_vtables_dispatch_ = 1
IBOEDocumentTypeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBOEDocumentTypes_vtables_dispatch_ = 1
IBOEDocumentTypes_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{746B0E89-0625-4B20-BD67-029DB26D074D}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{746B0E89-0625-4B20-BD67-029DB26D074D}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBOEDocumentTypesParams_vtables_dispatch_ = 1
IBOEDocumentTypesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{7B45A310-CED5-4D41-9A54-BED0F11B6950}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{7B45A310-CED5-4D41-9A54-BED0F11B6950}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBOEDocumentTypesService_vtables_dispatch_ = 1
IBOEDocumentTypesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddBOEDocumentType' , u'pIBOEDocumentType' , u'ppIBOEDocumentTypeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{746B0E89-0625-4B20-BD67-029DB26D074D}')") , 
			(16393, 10, None, "IID('{7B45A310-CED5-4D41-9A54-BED0F11B6950}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateBOEDocumentType' , u'pIBOEDocumentType' , ), 11, (11, (), [ (9, 1, None, "IID('{746B0E89-0625-4B20-BD67-029DB26D074D}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteBOEDocumentType' , u'pIBOEDocumentTypeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{7B45A310-CED5-4D41-9A54-BED0F11B6950}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetBOEDocumentType' , u'pIBOEDocumentTypeParams' , u'ppIBOEDocumentType' , ), 13, (13, (), [ (9, 1, None, "IID('{7B45A310-CED5-4D41-9A54-BED0F11B6950}')") , 
			(16393, 10, None, "IID('{746B0E89-0625-4B20-BD67-029DB26D074D}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetBOEDocumentTypeList' , u'ppIBOEDocumentTypesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{B25EF557-1E57-4CA8-BDD3-B2AF96815278}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBOEInstruction_vtables_dispatch_ = 1
IBOEInstruction_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'InstructionEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'InstructionCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InstructionCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'InstructionDesc' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'InstructionDesc' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'IsCancelInstruction' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'IsCancelInstruction' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IBOEInstructionParams_vtables_dispatch_ = 1
IBOEInstructionParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'InstructionEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'InstructionEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InstructionCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBOEInstructions_vtables_dispatch_ = 1
IBOEInstructions_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{70443238-FECE-4E0B-8900-9C5D06C4E71C}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{70443238-FECE-4E0B-8900-9C5D06C4E71C}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBOEInstructionsParams_vtables_dispatch_ = 1
IBOEInstructionsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBOEInstructionsService_vtables_dispatch_ = 1
IBOEInstructionsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddBOEInstruction' , u'pIBOEInstruction' , u'ppIBOEInstructionParams' , ), 10, (10, (), [ (9, 1, None, "IID('{70443238-FECE-4E0B-8900-9C5D06C4E71C}')") , 
			(16393, 10, None, "IID('{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateBOEInstruction' , u'pIBOEInstruction' , ), 11, (11, (), [ (9, 1, None, "IID('{70443238-FECE-4E0B-8900-9C5D06C4E71C}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteBOEInstruction' , u'pIBOEInstructionParams' , ), 12, (12, (), [ (9, 1, None, "IID('{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetBOEInstruction' , u'pIBOEInstructionParams' , u'ppIBOEInstruction' , ), 13, (13, (), [ (9, 1, None, "IID('{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}')") , 
			(16393, 10, None, "IID('{70443238-FECE-4E0B-8900-9C5D06C4E71C}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetBOEInstructionList' , u'ppIBOEInstructionsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{910426DC-C7C4-4EBC-8FB3-97BC2805C81D}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBOELine_vtables_dispatch_ = 1
IBOELine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BOEKey' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BOENumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdateRsltVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Bank' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AccountNumber' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'amount' , u'ppRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BOEStatus' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Transferred' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IBOELineParams_vtables_dispatch_ = 1
IBOELineParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BOEKey' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BOEKey' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBOELines_vtables_dispatch_ = 1
IBOELines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBOELinesParams_vtables_dispatch_ = 1
IBOELinesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{225FB23A-8178-4A0B-A9F4-88D1F33278DC}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{225FB23A-8178-4A0B-A9F4-88D1F33278DC}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBOELinesService_vtables_dispatch_ = 1
IBOELinesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetBOELine' , u'pIBOELineParams' , u'ppIBOELine' , ), 10, (10, (), [ (9, 1, None, "IID('{225FB23A-8178-4A0B-A9F4-88D1F33278DC}')") , 
			(16393, 10, None, "IID('{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
]

IBOEPortfolio_vtables_dispatch_ = 1
IBOEPortfolio_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioID' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioID' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioNum' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioNum' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioDescription' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioDescription' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IBOEPortfolioParams_vtables_dispatch_ = 1
IBOEPortfolioParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioID' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IBOEPortfolios_vtables_dispatch_ = 1
IBOEPortfolios_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBOEPortfoliosParams_vtables_dispatch_ = 1
IBOEPortfoliosParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBOEPortfoliosService_vtables_dispatch_ = 1
IBOEPortfoliosService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddBOEPortfolio' , u'pIBOEPortfolio' , u'ppIBOEPortfolioParams' , ), 10, (10, (), [ (9, 1, None, "IID('{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')") , 
			(16393, 10, None, "IID('{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateBOEPortfolio' , u'pIBOEPortfolio' , ), 11, (11, (), [ (9, 1, None, "IID('{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteBOEPortfolio' , u'pIBOEPortfolioParams' , ), 12, (12, (), [ (9, 1, None, "IID('{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetBOEPortfolio' , u'pIBOEPortfolioParams' , u'ppIBOEPortfolio' , ), 13, (13, (), [ (9, 1, None, "IID('{7E0EA2EC-9661-427C-B8EB-0C818F908F67}')") , 
			(16393, 10, None, "IID('{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetBOEPortfolioList' , u'ppIBOEPortfoliosParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{C44BDF5B-E877-4183-AC97-76D9E4921BB3}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBPAccountReceivablePayble_vtables_dispatch_ = 1
IBPAccountReceivablePayble_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AccountType' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AccountType' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBPAddresses_vtables_dispatch_ = 1
IBPAddresses_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'AddressName2' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'AddressName2' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'AddressName3' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'AddressName3' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'TypeOfAddress' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'TypeOfAddress' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 23, (23, (), [ ], 1 , 1 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'RowNum' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
]

IBPBankAccounts_vtables_dispatch_ = 1
IBPBankAccounts_vtables_ = [
	(( u'LogInstance' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LogInstance' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserNo4' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserNo4' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UserNo2' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserNo2' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ControlKey' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ControlKey' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'UserNo3' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'UserNo3' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'AccountNo' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'AccountNo' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'UserNo1' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'UserNo1' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'InternalKey' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'InternalKey' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 22, (22, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 23, (23, (), [ ], 1 , 1 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 24, (24, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'BIK' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'BIK' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'CorrespondentAccount' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'CorrespondentAccount' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CustomerIdNumber' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'CustomerIdNumber' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'ISRType' , u'plRsltVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ISRType' , u'plRsltVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 33, (33, (), [ ], 1 , 1 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'BICSwiftCode' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'BICSwiftCode' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'ABARoutingNumber' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ABARoutingNumber' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'MandateID' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'MandateID' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'SignatureDate' , u'pVal' , ), 37, (37, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'SignatureDate' , u'pVal' , ), 37, (37, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
]

IBPBranchAssignment_vtables_dispatch_ = 1
IBPBranchAssignment_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBPCode_vtables_dispatch_ = 1
IBPCode_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdtRsltVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdtRsltVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Debit' , u'pdblRsltVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Debit' , u'pdblRsltVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Credit' , u'pdblRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Credit' , u'pdblRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SystemDebit' , u'pdblRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SystemDebit' , u'pdblRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SystemCredit' , u'pdblRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'SystemCredit' , u'pdblRsltVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ForeignDebit' , u'pdblRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ForeignDebit' , u'pdblRsltVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ForeignCredit' , u'pdblRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ForeignCredit' , u'pdblRsltVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ForeignCurrency' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ForeignCurrency' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IBPCodes_vtables_dispatch_ = 1
IBPCodes_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{259FA540-F962-4A5D-9BF5-E9772AF43A31}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{259FA540-F962-4A5D-9BF5-E9772AF43A31}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBPFiscalRegistryID_vtables_dispatch_ = 1
IBPFiscalRegistryID_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lGroupCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CNAECode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CNAECode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IBPFiscalTaxID_vtables_dispatch_ = 1
IBPFiscalTaxID_vtables_ = [
	(( u'UserFields' , u'ppRsltVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TaxId0' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TaxId0' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TaxId1' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TaxId1' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TaxId2' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxId2' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxId3' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxId3' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxId4' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxId4' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxId5' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxId5' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TaxId6' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxId6' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TaxId7' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TaxId7' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'TaxId8' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'TaxId8' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'TaxId9' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'TaxId9' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TaxId10' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TaxId10' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TaxId11' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TaxId11' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'CNAECode' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'CNAECode' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'AddrType' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
]

IBPPaymentDates_vtables_dispatch_ = 1
IBPPaymentDates_vtables_ = [
	(( u'PaymentDate' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDate' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 4, (4, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 6, (6, (), [ ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBPPaymentMethods_vtables_dispatch_ = 1
IBPPaymentMethods_vtables_ = [
	(( u'PaymentMethodCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 4, (4, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBPPriorities_vtables_dispatch_ = 1
IBPPriorities_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PriorityDescription' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PriorityDescription' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IBPWithholdingTax_vtables_dispatch_ = 1
IBPWithholdingTax_vtables_ = [
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 4, (4, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBankChargesAllocationCode_vtables_dispatch_ = 1
IBankChargesAllocationCode_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IBankChargesAllocationCodeParams_vtables_dispatch_ = 1
IBankChargesAllocationCodeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBankChargesAllocationCodesParams_vtables_dispatch_ = 1
IBankChargesAllocationCodesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{53062C45-E05A-4717-909C-3C3073E10DDD}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{53062C45-E05A-4717-909C-3C3073E10DDD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBankChargesAllocationCodesService_vtables_dispatch_ = 1
IBankChargesAllocationCodesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddBankChargesAllocationCode' , u'pIBankChargesAllocationCode' , u'ppIBankChargesAllocationCodeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{95968C8C-6866-4B59-BB03-E08A96684591}')") , 
			(16393, 10, None, "IID('{53062C45-E05A-4717-909C-3C3073E10DDD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateBankChargesAllocationCode' , u'pIBankChargesAllocationCode' , ), 11, (11, (), [ (9, 1, None, "IID('{95968C8C-6866-4B59-BB03-E08A96684591}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteBankChargesAllocationCode' , u'pIBankChargesAllocationCodeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{53062C45-E05A-4717-909C-3C3073E10DDD}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetBankChargesAllocationCode' , u'pIBankChargesAllocationCodeParams' , u'ppIBankChargesAllocationCode' , ), 13, (13, (), [ (9, 1, None, "IID('{53062C45-E05A-4717-909C-3C3073E10DDD}')") , 
			(16393, 10, None, "IID('{95968C8C-6866-4B59-BB03-E08A96684591}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetBankChargesAllocationCodeList' , u'ppIBankChargesAllocationCodesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{46BCE59C-FCA9-4AC3-8A3D-07090C41E5F2}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetDefaultBankChargesAllocationCode' , u'pIBankChargesAllocationCodeParams' , ), 15, (15, (), [ (9, 1, None, "IID('{53062C45-E05A-4717-909C-3C3073E10DDD}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IBankPages_vtables_dispatch_ = 1
IBankPages_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AccountCode' , u'Sequence' , u'Found' , ), 5, (5, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Sequence' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DebitAmount' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DebitAmount' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CreditAmount' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CreditAmount' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BankMatch' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DataSource' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'StatementNumber' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'StatementNumber' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumber' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumber' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'PaymentCreated' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'PaymentCreated' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DocNumberType' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DocNumberType' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReference' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReference' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumberEx' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumberEx' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 29, (29, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 30, (30, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'BICSwiftCode' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'BICSwiftCode' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
]

IBankStatement_vtables_dispatch_ = 1
IBankStatement_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'InternalNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BankAccountKey' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BankAccountKey' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'StatementNumber' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'StatementNumber' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'StatementDate' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'StatementDate' , u'pdateRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Imported' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'StartingBalanceF' , u'ppRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'StartingBalanceF' , u'ppRsltVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'EndingBalanceF' , u'ppRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'EndingBalanceF' , u'ppRsltVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'StartingBalanceL' , u'ppRsltVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'StartingBalanceL' , u'ppRsltVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'EndingBalanceL' , u'ppRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'EndingBalanceL' , u'ppRsltVal' , ), 20, (20, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BankStatementRows' , u'ppRsltVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{7E9C6F20-F9A1-470C-B50D-D1EA112B030A}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'BankStatementFileHash' , u'ppRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'BankStatementFileHash' , u'ppRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'BankStatementGUID' , u'ppRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BankStatementGUID' , u'ppRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
]

IBankStatementParams_vtables_dispatch_ = 1
IBankStatementParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'InternalNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'InternalNumber' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BankAccountKey' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'StatementNumber' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'StatementDate' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Imported' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'StartingBalanceF' , u'ppRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'EndingBalanceF' , u'ppRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'StartingBalanceL' , u'ppRsltVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'EndingBalanceL' , u'ppRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IBankStatementRow_vtables_dispatch_ = 1
IBankStatementRow_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ExternalBankStatementNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AccountNumber' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdateRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DebitAmountFC' , u'ppRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DebitAmountFC' , u'ppRsltVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CreditAmountFC' , u'ppRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'CreditAmountFC' , u'ppRsltVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CreditCurrency' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CreditCurrency' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Balance' , u'ppRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Balance' , u'ppRsltVal' , ), 20, (20, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ReconciliationNo' , u'plRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BPName' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BPName' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'StatementNumber' , u'plRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'RowStatus' , u'pbstrRsltVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'plRsltVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'plRsltVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DocNumType' , u'penumRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DocNumType' , u'penumRsltVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Details2' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Details2' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReferenceNo' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReferenceNo' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'CreateMethod' , u'penumRsltVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'BankStmtLineDate' , u'pdateRsltVal' , ), 32, (32, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'BankStmtLineDate' , u'pdateRsltVal' , ), 32, (32, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'BankStmtDueDate' , u'pdateRsltVal' , ), 33, (33, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'BankStmtDueDate' , u'pdateRsltVal' , ), 33, (33, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'InternalBankOpCode' , u'plRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'BPBankAccount' , u'pbstrRsltVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'BPBankAccount' , u'pbstrRsltVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'DebitAmountLC' , u'ppRsltVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'DebitAmountLC' , u'ppRsltVal' , ), 36, (36, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'CreditAmountLC' , u'ppRsltVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'CreditAmountLC' , u'ppRsltVal' , ), 37, (37, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRate' , u'ppRsltVal' , ), 38, (38, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRate' , u'ppRsltVal' , ), 38, (38, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'IBANofBPBankAccount' , u'pbstrRsltVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'IBANofBPBankAccount' , u'pbstrRsltVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'FeeOnTheLine' , u'ppRsltVal' , ), 40, (40, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'FeeOnTheLine' , u'ppRsltVal' , ), 40, (40, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'VATAmountLC' , u'ppRsltVal' , ), 41, (41, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'VATAmountLC' , u'ppRsltVal' , ), 41, (41, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'VATAmountFC' , u'ppRsltVal' , ), 42, (42, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'VATAmountFC' , u'ppRsltVal' , ), 42, (42, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntryID' , u'plRsltVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'PaymentID' , u'plRsltVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'PostingMethod' , u'penumRsltVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'GLAccountforFee' , u'pbstrRsltVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'FeeProfitCenter' , u'pbstrRsltVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'FeeProject' , u'pbstrRsltVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'MultiplePayments' , u'ppRsltVal' , ), 50, (50, (), [ (16393, 10, None, "IID('{4207538F-AAC0-4EDD-9002-6F710410D5C6}')") , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCode' , u'pbstrRsltVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCode' , u'pbstrRsltVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule' , u'pVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule' , u'pVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule2' , u'pVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule2' , u'pVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule3' , u'pVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule3' , u'pVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule4' , u'pVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule4' , u'pVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule5' , u'pVal' , ), 56, (56, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'FeeDistributionRule5' , u'pVal' , ), 56, (56, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'BPBICSwiftCode' , u'pVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'BPBICSwiftCode' , u'pVal' , ), 57, (57, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'Source' , u'penumRsltVal' , ), 58, (58, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 59, (59, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
]

IBankStatementRows_vtables_dispatch_ = 1
IBankStatementRows_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{2647D070-305A-43E8-89AE-B4D2C41E5168}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{2647D070-305A-43E8-89AE-B4D2C41E5168}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBankStatements_vtables_dispatch_ = 1
IBankStatements_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBankStatementsFilter_vtables_dispatch_ = 1
IBankStatementsFilter_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Bank' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Bank' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Account' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Account' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IBankStatementsImportFile_vtables_dispatch_ = 1
IBankStatementsImportFile_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FileName' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FileName' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Bank' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Bank' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Account' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Account' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IBankStatementsParams_vtables_dispatch_ = 1
IBankStatementsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBankStatementsService_vtables_dispatch_ = 1
IBankStatementsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddBankStatement' , u'pIBankStatement' , u'ppIBankStatementParams' , ), 10, (10, (), [ (9, 1, None, "IID('{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')") , 
			(16393, 10, None, "IID('{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateBankStatement' , u'pIBankStatement' , ), 11, (11, (), [ (9, 1, None, "IID('{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteBankStatement' , u'pIBankStatementParams' , ), 12, (12, (), [ (9, 1, None, "IID('{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetBankStatement' , u'pIBankStatementParams' , u'ppIBankStatement' , ), 13, (13, (), [ (9, 1, None, "IID('{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}')") , 
			(16393, 10, None, "IID('{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetBankStatementList' , u'pIBankStatementsFilter' , u'ppIBankStatementsParams' , ), 14, (14, (), [ (9, 1, None, "IID('{9A4EDA67-F390-4901-80F3-0D85F73994B7}')") , 
			(16393, 10, None, "IID('{2C841DE4-014D-44C4-9D48-6A9B7BCD789A}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBanks_vtables_dispatch_ = 1
IBanks_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsEntry' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BankName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BankName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AccountforOutgoingChecks' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BranchforOutgoingChecks' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'NextCheckNumber' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'SwiftNo' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'SwiftNo' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PostOffice' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PostOffice' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankAccountKey' , u'plRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankAccountKey' , u'plRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
]

IBatchNumberDetail_vtables_dispatch_ = 1
IBatchNumberDetail_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Batch' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BatchAttribute1' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BatchAttribute1' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BatchAttribute2' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BatchAttribute2' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'AdmissionDate' , u'pdateRsltVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'AdmissionDate' , u'pdateRsltVal' , ), 17, (17, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturingDate' , u'pdateRsltVal' , ), 18, (18, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturingDate' , u'pdateRsltVal' , ), 18, (18, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pdateRsltVal' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pdateRsltVal' , ), 19, (19, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SystemNumber' , u'plRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
]

IBatchNumberDetailParams_vtables_dispatch_ = 1
IBatchNumberDetailParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBatchNumberDetailsService_vtables_dispatch_ = 1
IBatchNumberDetailsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pIBatchNumberDetail' , ), 10, (10, (), [ (9, 1, None, "IID('{A302DDF1-F725-46B9-8CC4-19E5766CEAC0}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIBatchNumberDetailParams' , u'ppIBatchNumberDetail' , ), 11, (11, (), [ (9, 1, None, "IID('{CF02E105-3575-467B-9AD6-5BF719C9BC8B}')") , 
			(16393, 10, None, "IID('{A302DDF1-F725-46B9-8CC4-19E5766CEAC0}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IBatchNumbers_vtables_dispatch_ = 1
IBatchNumbers_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BatchNumber' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BatchNumber' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNumber' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNumber' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNumber' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNumber' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ExpiryDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ExpiryDate' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturingDate' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturingDate' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AddmisionDate' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AddmisionDate' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BaseLineNumber' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BaseLineNumber' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
]

IBillOfExchange_vtables_dispatch_ = 1
IBillOfExchange_vtables_ = [
	(( u'BillOfExchangeNo' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeNo' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeDueDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeDueDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceNo' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceNo' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCode' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCode' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BPBankAct' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BPBankAct' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCountry' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BPBankCountry' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ControlKey' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus1' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus1' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus2' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus2' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus3' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PaymentEngineStatus3' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 28, (28, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'StampTaxCode' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'StampTaxCode' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'StampTaxAmount' , u'pdblRsltVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'StampTaxAmount' , u'pdblRsltVal' , ), 30, (30, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'FolioNumber' , u'pbstrRsltVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'FolioNumber' , u'pbstrRsltVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'FolioPrefixString' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'FolioPrefixString' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'InterestAmount' , u'pVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'InterestAmount' , u'pVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DiscountAmount' , u'pVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DiscountAmount' , u'pVal' , ), 34, (34, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'FineAmount' , u'pVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'FineAmount' , u'pVal' , ), 35, (35, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'InterestDate' , u'pVal' , ), 36, (36, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'InterestDate' , u'pVal' , ), 36, (36, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'DiscountDate' , u'pVal' , ), 37, (37, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DiscountDate' , u'pVal' , ), 37, (37, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'FineDate' , u'pVal' , ), 38, (38, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'FineDate' , u'pVal' , ), 38, (38, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'IOFAmount' , u'pVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'IOFAmount' , u'pVal' , ), 39, (39, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ServiceFeeAmount' , u'pVal' , ), 40, (40, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ServiceFeeAmount' , u'pVal' , ), 40, (40, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'OtherExpensesAmount' , u'pVal' , ), 41, (41, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'OtherExpensesAmount' , u'pVal' , ), 41, (41, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'OtherIncomesAmount' , u'pVal' , ), 42, (42, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'OtherIncomesAmount' , u'pVal' , ), 42, (42, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
]

IBillOfExchangeTrans_BankPages_vtables_dispatch_ = 1
IBillOfExchangeTrans_BankPages_vtables_ = [
	(( u'AccountCode' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Sequence' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Sequence' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IBillOfExchangeTrans_Deposits_vtables_dispatch_ = 1
IBillOfExchangeTrans_Deposits_vtables_ = [
	(( u'DepositNorm' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'DepositNorm' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'PostingType' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'PostingType' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BankDepositAccount' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BankDepositAccount' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IBillOfExchangeTransaction_vtables_dispatch_ = 1
IBillOfExchangeTransaction_vtables_ = [
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'InternalKey' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'StatusFrom' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'StatusFrom' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StatusTo' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'StatusTo' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TransactionDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TransactionTime' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'IsBoeReconciled' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'IsBoeReconciled' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TransactionNumber' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{2DBFED56-4DB4-455A-9C22-E2C01C052D39}')") , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Deposits' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BankPages' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}')") , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 17, (17, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BOETransactionkey' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
]

IBillOfExchangeTransaction_Lines_vtables_dispatch_ = 1
IBillOfExchangeTransaction_Lines_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeNo' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeNo' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeType' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeType' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeDueDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreement_vtables_dispatch_ = 1
IBlanketAgreement_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AgreementNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BPName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pdateRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TerminateDate' , u'pdateRsltVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TerminateDate' , u'pdateRsltVal' , ), 16, (16, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'AgreementType' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'AgreementType' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'plRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'plRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'IgnorePricesInAgreement' , u'penumRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Renewal' , u'penumRsltVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Renewal' , u'penumRsltVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'penumRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'penumRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'RemindTime' , u'plRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'RemindTime' , u'plRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'BlanketAgreements_ItemsLines' , u'ppRsltVal' , ), 27, (27, (), [ (16393, 10, None, "IID('{FECE5DF5-E254-43C1-BDD9-5C82097B9B9D}')") , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'SettlementProbability' , u'plRsltVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SettlementProbability' , u'plRsltVal' , ), 28, (28, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 29, (29, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'AgreementMethod' , u'penumRsltVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'AgreementMethod' , u'penumRsltVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTerms' , u'plResult' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTerms' , u'plResult' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'plResult' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'plResult' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'SigningDate' , u'pdateResult' , ), 33, (33, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'SigningDate' , u'pdateResult' , ), 33, (33, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'AmendmentTo' , u'plResult' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'AmendmentTo' , u'plResult' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreementParams_vtables_dispatch_ = 1
IBlanketAgreementParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AgreementNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AgreementNo' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreementsDocument_vtables_dispatch_ = 1
IBlanketAgreementsDocument_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AgreementRowNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNo' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocumentRowNumber' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocumentDate' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UnitPrice' , u'ppRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'ppRsltVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UoM' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'RowStatus' , u'pbstrRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Discount' , u'ppRsltVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreementsDocuments_vtables_dispatch_ = 1
IBlanketAgreementsDocuments_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{14AF3328-811A-4FE5-A55A-C17BECE10062}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{14AF3328-811A-4FE5-A55A-C17BECE10062}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreementsParams_vtables_dispatch_ = 1
IBlanketAgreementsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreementsService_vtables_dispatch_ = 1
IBlanketAgreementsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddBlanketAgreement' , u'pIBlanketAgreement' , u'ppIBlanketAgreementParams' , ), 10, (10, (), [ (9, 1, None, "IID('{14F49B88-4722-45AC-993A-AD7680142769}')") , 
			(16393, 10, None, "IID('{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateBlanketAgreement' , u'pIBlanketAgreement' , ), 11, (11, (), [ (9, 1, None, "IID('{14F49B88-4722-45AC-993A-AD7680142769}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetBlanketAgreement' , u'pIBlanketAgreementParams' , u'ppIBlanketAgreement' , ), 12, (12, (), [ (9, 1, None, "IID('{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')") , 
			(16393, 10, None, "IID('{14F49B88-4722-45AC-993A-AD7680142769}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetBlanketAgreementList' , u'ppIBlanketAgreementsParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{C1751C9B-F39D-4401-87D9-2C0C6B2DD2D2}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CancelBlanketAgreement' , u'pIBlanketAgreementParams' , ), 14, (14, (), [ (9, 1, None, "IID('{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GetRelatedDocuments' , u'pIBlanketAgreementParams' , u'ppIBlanketAgreementsDocuments' , ), 15, (15, (), [ (9, 1, None, "IID('{A3C28485-77EA-4396-9D1F-FAD7279A74A1}')") , 
			(16393, 10, None, "IID('{EFA05C0F-B878-48E4-AA66-4E266FA5CC1A}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreements_DetailsLine_vtables_dispatch_ = 1
IBlanketAgreements_DetailsLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AgreementNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AgreementRowNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'AgreementEffectiveRowNumber' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Frequency' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Frequency' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'From' , u'pdateRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'From' , u'pdateRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'To' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'To' , u'pdateRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ReleaseInformation' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ReleaseInformation' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'ppRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'ppRsltVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ConsumeSalesForecast' , u'penumRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ConsumeSalesForecast' , u'penumRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PlannedAmountLC' , u'ppRsltVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PlannedAmountLC' , u'ppRsltVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PlannedAmountFC' , u'ppRsltVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'PlannedAmountFC' , u'ppRsltVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreements_DetailsLines_vtables_dispatch_ = 1
IBlanketAgreements_DetailsLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{E21D5CB9-5B51-4598-8989-75A702DFC29E}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{E21D5CB9-5B51-4598-8989-75A702DFC29E}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreements_ItemsLine_vtables_dispatch_ = 1
IBlanketAgreements_ItemsLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AgreementNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AgreementRowNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroup' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PlannedQuantity' , u'ppRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PlannedQuantity' , u'ppRsltVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UnitPrice' , u'ppRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'UnitPrice' , u'ppRsltVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CumulativeQuantity' , u'ppRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'CumulativeAmountLC' , u'ppRsltVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CumulativeAmountFC' , u'ppRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BlanketAgreements_DetailsLines' , u'ppRsltVal' , ), 23, (23, (), [ (16393, 10, None, "IID('{EB66D894-270C-4DF1-B76A-AB91ABE88D03}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PortionOfReturns' , u'ppRsltVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PortionOfReturns' , u'ppRsltVal' , ), 24, (24, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'EndOfWarranty' , u'pdateRsltVal' , ), 25, (25, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'EndOfWarranty' , u'pdateRsltVal' , ), 25, (25, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 26, (26, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PlannedAmountLC' , u'ppRsltVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'PlannedAmountLC' , u'ppRsltVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'PlannedAmountFC' , u'ppRsltVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'PlannedAmountFC' , u'ppRsltVal' , ), 28, (28, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'LineDiscount' , u'ppRsltVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'LineDiscount' , u'ppRsltVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
]

IBlanketAgreements_ItemsLines_vtables_dispatch_ = 1
IBlanketAgreements_ItemsLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{C083AAA6-1496-4E5F-82B0-201194FD8651}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{C083AAA6-1496-4E5F-82B0-201194FD8651}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBlob_vtables_dispatch_ = 1
IBlob_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Content' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Content' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBlobParams_vtables_dispatch_ = 1
IBlobParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BlobTableKeySegments' , u'ppRsltVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{86FB8743-E265-47A1-BE6C-7A5E9FEEAAAB}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Table' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Table' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Field' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Field' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'FileName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'FileName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IBlobTableKeySegment_vtables_dispatch_ = 1
IBlobTableKeySegment_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IBlobTableKeySegments_vtables_dispatch_ = 1
IBlobTableKeySegments_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBoxes1099_vtables_dispatch_ = 1
IBoxes1099_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FormCode' , u'plRsltVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pbstrRsltVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pbstrRsltVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BoxDescription' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BoxDescription' , u'pbstrRsltVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Minimum1099Amount' , u'pdblRsltVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Minimum1099Amount' , u'pdblRsltVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IBranch_vtables_dispatch_ = 1
IBranch_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IBranchParams_vtables_dispatch_ = 1
IBranchParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBranchesParams_vtables_dispatch_ = 1
IBranchesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBranchesService_vtables_dispatch_ = 1
IBranchesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddBranch' , u'pIBranch' , u'ppIBranchParams' , ), 10, (10, (), [ (9, 1, None, "IID('{DC24341F-4CD3-4608-9ED4-745882053E6A}')") , 
			(16393, 10, None, "IID('{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateBranch' , u'pIBranch' , ), 11, (11, (), [ (9, 1, None, "IID('{DC24341F-4CD3-4608-9ED4-745882053E6A}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteBranch' , u'pIBranchParams' , ), 12, (12, (), [ (9, 1, None, "IID('{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetBranch' , u'pIBranchParams' , u'ppIBranch' , ), 13, (13, (), [ (9, 1, None, "IID('{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}')") , 
			(16393, 10, None, "IID('{DC24341F-4CD3-4608-9ED4-745882053E6A}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetBranchList' , u'ppIBranchesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{3CA31A48-0CEE-436B-9447-E14D8D27C546}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBrazilBeverageIndexer_vtables_dispatch_ = 1
IBrazilBeverageIndexer_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BeverageGroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BeverageGroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BeverageTableCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BeverageTableCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BeverageCommercialBrandCode' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BeverageCommercialBrandCode' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BeverageID' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IBrazilBeverageIndexerParams_vtables_dispatch_ = 1
IBrazilBeverageIndexerParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BeverageGroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BeverageGroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BeverageTableCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BeverageTableCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BeverageCommercialBrandCode' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BeverageCommercialBrandCode' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IBrazilBeverageIndexersParams_vtables_dispatch_ = 1
IBrazilBeverageIndexersParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBrazilBeverageIndexersService_vtables_dispatch_ = 1
IBrazilBeverageIndexersService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIBrazilBeverageIndexer' , u'ppIBrazilBeverageIndexerParams' , ), 10, (10, (), [ (9, 1, None, "IID('{F17A759E-0E4E-448D-BA57-E6EF3760A591}')") , 
			(16393, 10, None, "IID('{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIBrazilBeverageIndexerParams' , ), 11, (11, (), [ (9, 1, None, "IID('{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIBrazilBeverageIndexerParams' , u'ppIBrazilBeverageIndexer' , ), 12, (12, (), [ (9, 1, None, "IID('{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}')") , 
			(16393, 10, None, "IID('{F17A759E-0E4E-448D-BA57-E6EF3760A591}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppIBrazilBeverageIndexersParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{C9C4DE1F-9409-446D-AC6A-0FAD12624939}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBrazilFuelIndexer_vtables_dispatch_ = 1
IBrazilFuelIndexer_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FuelID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FuelGroupCode' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FuelGroupCode' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FuelCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FuelCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IBrazilFuelIndexerParams_vtables_dispatch_ = 1
IBrazilFuelIndexerParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FuelID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FuelID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FuelGroupCode' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FuelCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IBrazilFuelIndexersParams_vtables_dispatch_ = 1
IBrazilFuelIndexersParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBrazilFuelIndexersService_vtables_dispatch_ = 1
IBrazilFuelIndexersService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIBrazilFuelIndexer' , u'ppIBrazilFuelIndexerParams' , ), 10, (10, (), [ (9, 1, None, "IID('{45CD0988-1275-4D2C-BF2C-5D04CB984489}')") , 
			(16393, 10, None, "IID('{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIBrazilFuelIndexerParams' , ), 11, (11, (), [ (9, 1, None, "IID('{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIBrazilFuelIndexerParams' , u'ppIBrazilFuelIndexer' , ), 12, (12, (), [ (9, 1, None, "IID('{24D0CDB0-8592-4CD3-A247-9A51C55D060F}')") , 
			(16393, 10, None, "IID('{45CD0988-1275-4D2C-BF2C-5D04CB984489}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppIBrazilFuelIndexersParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{C7037B05-9DF8-47CA-8819-4D9460F03794}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBrazilMultiIndexer_vtables_dispatch_ = 1
IBrazilMultiIndexer_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'plRsltValue' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltValue' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltValue' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltValue' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltValue' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltValue' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltValue' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FirstRefIndexerCode' , u'pbstrRsltValue' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'FirstRefIndexerCode' , u'pbstrRsltValue' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SecondRefIndexerCode' , u'pbstrRsltValue' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SecondRefIndexerCode' , u'pbstrRsltValue' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ThirdRefIndexerCode' , u'pbstrRsltValue' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ThirdRefIndexerCode' , u'pbstrRsltValue' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'GetReferencedIndexerType' , u'referenceIndex' , u'penumRsltType' , u'plRsltValue' , u'pvbSuccess' , 
			), 17, (17, (), [ (3, 1, None, None) , (16387, 2, None, None) , (16387, 2, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

IBrazilMultiIndexerParams_vtables_dispatch_ = 1
IBrazilMultiIndexerParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltValue' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltValue' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltValue' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltValue' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltValue' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'FirstRefIndexerCode' , u'pbstrRsltValue' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SecondRefIndexerCode' , u'pbstrRsltValue' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ThirdRefIndexerCode' , u'pbstrRsltValue' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IBrazilMultiIndexersParams_vtables_dispatch_ = 1
IBrazilMultiIndexersParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBrazilMultiIndexersService_vtables_dispatch_ = 1
IBrazilMultiIndexersService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIBrazilMultiIndexer' , u'ppIBrazilMultiIndexerParams' , ), 10, (10, (), [ (9, 1, None, "IID('{EB892090-5B7A-48F1-849C-5F4A0048B2DA}')") , 
			(16393, 10, None, "IID('{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIBrazilMultiIndexerParams' , ), 11, (11, (), [ (9, 1, None, "IID('{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIBrazilMultiIndexerParams' , u'ppIBrazilMultiIndexer' , ), 12, (12, (), [ (9, 1, None, "IID('{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')") , 
			(16393, 10, None, "IID('{EB892090-5B7A-48F1-849C-5F4A0048B2DA}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetIndexerTypeList' , u'pIBrazilMultiIndexerParams' , u'ppIBrazilMultiIndexersParams' , ), 13, (13, (), [ (9, 1, None, "IID('{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}')") , 
			(16393, 10, None, "IID('{292717A3-9E69-4C34-BE56-A61A52CA8AA2}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBrazilNumericIndexer_vtables_dispatch_ = 1
IBrazilNumericIndexer_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IBrazilNumericIndexerParams_vtables_dispatch_ = 1
IBrazilNumericIndexerParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IBrazilNumericIndexersParams_vtables_dispatch_ = 1
IBrazilNumericIndexersParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBrazilNumericIndexersService_vtables_dispatch_ = 1
IBrazilNumericIndexersService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIBrazilNumericIndexer' , u'ppIBrazilNumericIndexerParams' , ), 10, (10, (), [ (9, 1, None, "IID('{69B00574-A904-4416-AC73-94E84B7882CA}')") , 
			(16393, 10, None, "IID('{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIBrazilNumericIndexerParams' , ), 11, (11, (), [ (9, 1, None, "IID('{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIBrazilNumericIndexerParams' , u'ppIBrazilNumericIndexer' , ), 12, (12, (), [ (9, 1, None, "IID('{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')") , 
			(16393, 10, None, "IID('{69B00574-A904-4416-AC73-94E84B7882CA}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetIndexerTypeList' , u'pIBrazilNumericIndexerParams' , u'ppIBrazilNumericIndexersParams' , ), 13, (13, (), [ (9, 1, None, "IID('{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}')") , 
			(16393, 10, None, "IID('{12696EFB-62EF-4BD0-9B7B-456F3999DAEF}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBrazilStringIndexer_vtables_dispatch_ = 1
IBrazilStringIndexer_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IBrazilStringIndexerParams_vtables_dispatch_ = 1
IBrazilStringIndexerParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'IndexerType' , u'penumRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IBrazilStringIndexersParams_vtables_dispatch_ = 1
IBrazilStringIndexersParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBrazilStringIndexersService_vtables_dispatch_ = 1
IBrazilStringIndexersService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIBrazilStringIndexer' , u'ppIBrazilStringIndexerParams' , ), 10, (10, (), [ (9, 1, None, "IID('{BCE76DC7-889C-4A7A-B77F-842FC7D0684E}')") , 
			(16393, 10, None, "IID('{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIBrazilStringIndexerParams' , ), 11, (11, (), [ (9, 1, None, "IID('{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIBrazilStringIndexerParams' , u'ppIBrazilStringIndexer' , ), 12, (12, (), [ (9, 1, None, "IID('{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')") , 
			(16393, 10, None, "IID('{BCE76DC7-889C-4A7A-B77F-842FC7D0684E}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetIndexerTypeList' , u'pIBrazilStringIndexerParams' , u'ppIBrazilStringIndexersParams' , ), 13, (13, (), [ (9, 1, None, "IID('{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}')") , 
			(16393, 10, None, "IID('{F2A7926C-BDB1-4151-8FEC-5A58C2BCC600}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBudget_vtables_dispatch_ = 1
IBudget_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 4, (4, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualExpensesCreditSys' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualExpensesCreditLoc' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualExpensesDebitSys' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualExpensesDebitLoc' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualRevenuesCredit' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'FutureAnnualRevenuesDebit' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'FutureRevenuesDebitSys' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FutureRevenuesDebitLoc' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ParentAccPercent' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ParentAccPercent' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'StartofFiscalYear' , u'pVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ParentAccountKey' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ParentAccountKey' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetDebitSys' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetDebitSys' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BudgetBalanceDebitSys' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BudgetBalanceDebitLoc' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetDebitLoc' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetDebitLoc' , u'pVal' , ), 21, (21, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetCreditSys' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetCreditSys' , u'pVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetCreditLoc' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TotalAnnualBudgetCreditLoc' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BudgetBalanceCreditSys' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BudgetBalanceCreditLoc' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DivisionCode' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DivisionCode' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 29, (29, (), [ (16393, 10, None, "IID('{D2BAB599-C7C6-4301-B925-B6BB51092A79}')") , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 30, (30, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 31, (31, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'BudgetScenario' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BudgetScenario' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'CostAccountingLines' , u'pVal' , ), 35, (35, (), [ (16393, 10, None, "IID('{F1E88ED4-1F91-4FE5-B4EB-13B48CB46F52}')") , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
]

IBudgetCostAccounting_Lines_vtables_dispatch_ = 1
IBudgetCostAccounting_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Dimension' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Dimension' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleDebitLC' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleDebitLC' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleDebitSC' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleDebitSC' , u'pVal' , ), 9, (9, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleCreditLC' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleCreditLC' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleCreditSC' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DistrRuleCreditSC' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IBudgetDistribution_vtables_dispatch_ = 1
IBudgetDistribution_vtables_ = [
	(( u'September' , u'pVal' , ), 1, (1, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'September' , u'pVal' , ), 1, (1, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'August' , u'pVal' , ), 2, (2, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'August' , u'pVal' , ), 2, (2, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'July' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'July' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'June' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'June' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'May' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'May' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'April' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'April' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'March' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'March' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'February' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'February' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'December' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'December' , u'pVal' , ), 9, (9, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'November' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'November' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'October' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'October' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'January' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'January' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAmount' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAmount' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DivisionCode' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lBgdCode' , u'Found' , ), 19, (19, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 20, (20, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
]

IBudgetScenarios_vtables_dispatch_ = 1
IBudgetScenarios_vtables_ = [
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'InitialRatioPercentage' , u'pVal' , ), 2, (2, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'InitialRatioPercentage' , u'pVal' , ), 2, (2, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'StartofFiscalYear' , u'pVal' , ), 3, (3, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StartofFiscalYear' , u'pVal' , ), 3, (3, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BasicBudget' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BasicBudget' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsID' , u'Found' , ), 9, (9, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 10, (10, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
]

IBudget_Lines_vtables_dispatch_ = 1
IBudget_Lines_vtables_ = [
	(( u'PrecentOfAnnualBudgetAmount' , u'pVal' , ), 1, (1, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'RowDetails' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'RowDetails' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FutExpenSysDebit' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FutExpenDebit' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FutExpenSysCredit' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FutExpenCredit' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FutIncomesSysCredit' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FutIncomesSysDebit' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'FutIncomesCredit' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BudgetSysTotDebit' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BudgetSysTotDebit' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BalSysTotDebit' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BalTotDebit' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BudgetTotCredit' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BudgetTotCredit' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BudgetSysTotCredit' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BudgetSysTotCredit' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BudgetTotDebit' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BudgetTotDebit' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BalSysTotCredit' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BalTotCredit' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'BudgetKey' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 24, (24, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 25, (25, (), [ ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'FutureIncomeDeb' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
]

IBusinessPartnerGroups_vtables_dispatch_ = 1
IBusinessPartnerGroups_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lGroupCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IBusinessPartnerPropertiesParams_vtables_dispatch_ = 1
IBusinessPartnerPropertiesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{B7546EA2-0DE7-4F28-8596-ACCD323F584E}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{B7546EA2-0DE7-4F28-8596-ACCD323F584E}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IBusinessPartnerPropertiesService_vtables_dispatch_ = 1
IBusinessPartnerPropertiesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UpdateBusinessPartnerProperty' , u'pIBusinessPartnerProperty' , ), 10, (10, (), [ (9, 1, None, "IID('{38DA089C-BF1E-457E-B486-F1E35293F5F1}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetBusinessPartnerProperty' , u'pIBusinessPartnerPropertyParams' , u'ppIBusinessPartnerProperty' , ), 11, (11, (), [ (9, 1, None, "IID('{B7546EA2-0DE7-4F28-8596-ACCD323F584E}')") , 
			(16393, 10, None, "IID('{38DA089C-BF1E-457E-B486-F1E35293F5F1}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetBusinessPartnerPropertyList' , u'ppIBusinessPartnerPropertiesParams' , ), 12, (12, (), [ (16393, 10, None, "IID('{00C7246F-BD54-4E8B-8CE0-39F9C6568F68}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IBusinessPartnerProperty_vtables_dispatch_ = 1
IBusinessPartnerProperty_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PropertyCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PropertyName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PropertyName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBusinessPartnerPropertyParams_vtables_dispatch_ = 1
IBusinessPartnerPropertyParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PropertyCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PropertyCode' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PropertyName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IBusinessPartners_vtables_dispatch_ = 1
IBusinessPartners_vtables_ = [
	(( u'CardCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'CardType' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'CardType' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'MailAddress' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'MailAddress' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MailZipCode' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MailZipCode' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Phone1' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Phone1' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Phone2' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Phone2' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PayTermsGrpCode' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PayTermsGrpCode' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CreditLimit' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CreditLimit' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'MaxCommitment' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'MaxCommitment' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'VatLiable' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'VatLiable' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleAtSource' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleAtSource' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'DeductionValidUntil' , u'pVal' , ), 24, (24, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DeductionValidUntil' , u'pVal' , ), 24, (24, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'IntrestRatePercent' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'IntrestRatePercent' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercent' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercent' , u'pVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroupCode' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroupCode' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'RateDiffAccount' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'RateDiffAccount' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Cellular' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'Cellular' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'AvarageLate' , u'pVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'AvarageLate' , u'pVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'MailCity' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'MailCity' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'MailCounty' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'MailCounty' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'MailCountry' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'MailCountry' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'DefaultAccount' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'DefaultAccount' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBranch' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBranch' , u'pVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankCode' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBankCode' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalID' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalID' , u'pVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'FatherCard' , u'pVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'FatherCard' , u'pVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'CardForeignName' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'CardForeignName' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'FatherType' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'FatherType' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'Properties' , u'GroupNum' , u'pVal' , ), 52, (52, (), [ (3, 0, None, None) , 
			(16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'Properties' , u'GroupNum' , u'pVal' , ), 52, (52, (), [ (3, 0, None, None) , 
			(3, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'DeductionOffice' , u'pVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'DeductionOffice' , u'pVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'ExportCode' , u'pVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'ExportCode' , u'pVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'MinIntrest' , u'pVal' , ), 55, (55, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'MinIntrest' , u'pVal' , ), 55, (55, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'CardCode' , u'Found' , ), 57, (57, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 58, (58, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 59, (59, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 60, (60, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'CurrentAccountBalance' , u'pVal' , ), 61, (61, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'OpenDeliveryNotesBalance' , u'pVal' , ), 62, (62, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'OpenOrdersBalance' , u'pVal' , ), 63, (63, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'ContactEmployees' , u'pVal' , ), 64, (64, (), [ (16393, 10, None, "IID('{52C8673B-CA79-4476-9F2E-28109AE17545}')") , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'ShippingType' , u'pVal' , ), 66, (66, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'ShippingType' , u'pVal' , ), 66, (66, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pVal' , ), 69, (69, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pVal' , ), 69, (69, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardCode' , u'pVal' , ), 70, (70, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardCode' , u'pVal' , ), 70, (70, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardNum' , u'pVal' , ), 71, (71, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardNum' , u'pVal' , ), 71, (71, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardExpiration' , u'pVal' , ), 72, (72, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardExpiration' , u'pVal' , ), 72, (72, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'DebitorAccount' , u'pVal' , ), 73, (73, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'DebitorAccount' , u'pVal' , ), 73, (73, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 75, (75, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 76, (76, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'OpenOpportunities' , u'pVal' , ), 77, (77, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'Valid' , u'pVal' , ), 78, (78, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'Valid' , u'pVal' , ), 78, (78, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pVal' , ), 79, (79, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pVal' , ), 79, (79, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pVal' , ), 80, (80, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pVal' , ), 80, (80, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'ValidRemarks' , u'pVal' , ), 81, (81, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'ValidRemarks' , u'pVal' , ), 81, (81, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'Frozen' , u'pVal' , ), 82, (82, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'Frozen' , u'pVal' , ), 82, (82, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'FrozenFrom' , u'pVal' , ), 83, (83, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'FrozenFrom' , u'pVal' , ), 83, (83, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'FrozenTo' , u'pVal' , ), 84, (84, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'FrozenTo' , u'pVal' , ), 84, (84, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'FrozenRemarks' , u'pVal' , ), 85, (85, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'FrozenRemarks' , u'pVal' , ), 85, (85, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 86, (86, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'Addresses' , u'pVal' , ), 87, (87, (), [ (16393, 10, None, "IID('{02F225DD-827F-4065-BC4A-14D5F4136D28}')") , ], 1 , 2 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 88, (88, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 88, (88, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'BillToState' , u'pVal' , ), 89, (89, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'BillToState' , u'pVal' , ), 89, (89, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'ExemptNum' , u'pVal' , ), 90, (90, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'ExemptNum' , u'pVal' , ), 90, (90, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 91, (91, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 91, (91, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'FormCode1099' , u'pVal' , ), 92, (92, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'FormCode1099' , u'pVal' , ), 92, (92, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pVal' , ), 93, (93, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pVal' , ), 93, (93, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'PeymentMethodCode' , u'pVal' , ), 94, (94, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'PeymentMethodCode' , u'pVal' , ), 94, (94, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'BackOrder' , u'pVal' , ), 95, (95, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'BackOrder' , u'pVal' , ), 95, (95, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'PartialDelivery' , u'pVal' , ), 96, (96, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'PartialDelivery' , u'pVal' , ), 96, (96, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunning' , u'pVal' , ), 97, (97, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunning' , u'pVal' , ), 97, (97, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 98, (98, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 98, (98, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'HouseBank' , u'pVal' , ), 99, (99, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankCountry' , u'pVal' , ), 100, (100, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankAccount' , u'pVal' , ), 101, (101, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'ShipToDefault' , u'pVal' , ), 102, (102, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'ShipToDefault' , u'pVal' , ), 102, (102, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'DunningLevel' , u'pVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'DunningDate' , u'pVal' , ), 104, (104, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'CollectionAuthorization' , u'pVal' , ), 105, (105, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'CollectionAuthorization' , u'pVal' , ), 105, (105, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'DME' , u'pVal' , ), 106, (106, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'DME' , u'pVal' , ), 106, (106, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'InstructionKey' , u'pVal' , ), 107, (107, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'InstructionKey' , u'pVal' , ), 107, (107, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'SinglePayment' , u'pVal' , ), 108, (108, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'SinglePayment' , u'pVal' , ), 108, (108, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pVal' , ), 109, (109, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pVal' , ), 109, (109, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 110, (110, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 110, (110, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDetails' , u'pVal' , ), 111, (111, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDetails' , u'pVal' , ), 111, (111, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankBranch' , u'pVal' , ), 112, (112, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'OwnerIDNumber' , u'pVal' , ), 113, (113, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'OwnerIDNumber' , u'pVal' , ), 113, (113, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockDescription' , u'pVal' , ), 114, (114, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockDescription' , u'pVal' , ), 114, (114, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptionLetterNum' , u'pVal' , ), 115, (115, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'MaxAmountOfExemption' , u'pVal' , ), 116, (116, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'MaxAmountOfExemption' , u'pVal' , ), 116, (116, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateFrom' , u'pVal' , ), 117, (117, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateTo' , u'pVal' , ), 118, (118, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'AccountRecivablePayables' , u'pVal' , ), 119, (119, (), [ (16393, 10, None, "IID('{4162242D-4217-47FA-BDFF-5070B6D03F30}')") , ], 1 , 2 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'LinkedBusinessPartner' , u'pVal' , ), 120, (120, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'LinkedBusinessPartner' , u'pVal' , ), 120, (120, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'LastMultiReconciliationNum' , u'pVal' , ), 121, (121, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'LastMultiReconciliationNum' , u'pVal' , ), 121, (121, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'Equalization' , u'pVal' , ), 122, (122, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'Equalization' , u'pVal' , ), 122, (122, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'SubjectToWithholdingTax' , u'pVal' , ), 123, (123, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'SubjectToWithholdingTax' , u'pVal' , ), 123, (123, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'CertificateNumber' , u'pVal' , ), 124, (124, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'CertificateNumber' , u'pVal' , ), 124, (124, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pVal' , ), 125, (125, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pVal' , ), 125, (125, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'NationalInsuranceNum' , u'pVal' , ), 126, (126, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'NationalInsuranceNum' , u'pVal' , ), 126, (126, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'AccrualCriteria' , u'pVal' , ), 127, (127, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
	(( u'AccrualCriteria' , u'pVal' , ), 127, (127, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 916 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 128, (128, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 920 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 128, (128, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 924 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 129, (129, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 928 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 129, (129, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 932 , (3, 0, None, None) , 0 , )),
	(( u'BillToBuildingFloorRoom' , u'pVal' , ), 130, (130, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 936 , (3, 0, None, None) , 0 , )),
	(( u'BillToBuildingFloorRoom' , u'pVal' , ), 130, (130, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 940 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentClearAct' , u'pVal' , ), 131, (131, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 944 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentClearAct' , u'pVal' , ), 131, (131, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 948 , (3, 0, None, None) , 0 , )),
	(( u'ChannelBP' , u'pVal' , ), 132, (132, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 952 , (3, 0, None, None) , 0 , )),
	(( u'ChannelBP' , u'pVal' , ), 132, (132, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 956 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTechnician' , u'pVal' , ), 133, (133, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 960 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTechnician' , u'pVal' , ), 133, (133, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 964 , (3, 0, None, None) , 0 , )),
	(( u'BilltoDefault' , u'pVal' , ), 134, (134, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 968 , (3, 0, None, None) , 0 , )),
	(( u'BilltoDefault' , u'pVal' , ), 134, (134, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 972 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangDisc' , u'pVal' , ), 135, (135, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 976 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangDisc' , u'pVal' , ), 135, (135, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 980 , (3, 0, None, None) , 0 , )),
	(( u'Territory' , u'pVal' , ), 136, (136, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 984 , (3, 0, None, None) , 0 , )),
	(( u'Territory' , u'pVal' , ), 136, (136, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 988 , (3, 0, None, None) , 0 , )),
	(( u'ShipToBuildingFloorRoom' , u'pVal' , ), 137, (137, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 992 , (3, 0, None, None) , 0 , )),
	(( u'ShipToBuildingFloorRoom' , u'pVal' , ), 137, (137, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 996 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangPres' , u'pVal' , ), 138, (138, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1000 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangPres' , u'pVal' , ), 138, (138, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1004 , (3, 0, None, None) , 0 , )),
	(( u'BPPaymentMethods' , u'pVal' , ), 139, (139, (), [ (16393, 10, None, "IID('{7D947F60-6017-44AA-AEAC-9721FF263D5E}')") , ], 1 , 2 , 4 , 0 , 1008 , (3, 0, None, None) , 0 , )),
	(( u'BPWithholdingTax' , u'pVal' , ), 140, (140, (), [ (16393, 10, None, "IID('{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}')") , ], 1 , 2 , 4 , 0 , 1012 , (3, 0, None, None) , 0 , )),
	(( u'BPPaymentDates' , u'pVal' , ), 141, (141, (), [ (16393, 10, None, "IID('{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}')") , ], 1 , 2 , 4 , 0 , 1016 , (3, 0, None, None) , 0 , )),
	(( u'BPBankAccounts' , u'pVal' , ), 142, (142, (), [ (16393, 10, None, "IID('{472B7A32-EB83-4D3A-9908-699D5C8DC33B}')") , ], 1 , 2 , 4 , 0 , 1020 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 143, (143, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1024 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 143, (143, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1028 , (3, 0, None, None) , 0 , )),
	(( u'VatGroupLatinAmerica' , u'pVal' , ), 144, (144, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1032 , (3, 0, None, None) , 0 , )),
	(( u'VatGroupLatinAmerica' , u'pVal' , ), 144, (144, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1036 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 145, (145, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 1040 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 146, (146, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 1044 , (3, 0, None, None) , 0 , )),
	(( u'DunningTerm' , u'pVal' , ), 147, (147, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1048 , (3, 0, None, None) , 0 , )),
	(( u'DunningTerm' , u'pVal' , ), 147, (147, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1052 , (3, 0, None, None) , 0 , )),
	(( u'HouseBank' , u'pVal' , ), 99, (99, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1056 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankCountry' , u'pVal' , ), 100, (100, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1060 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankAccount' , u'pVal' , ), 101, (101, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1064 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankBranch' , u'pVal' , ), 112, (112, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1068 , (3, 0, None, None) , 0 , )),
	(( u'Website' , u'pVal' , ), 148, (148, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1072 , (3, 0, None, None) , 0 , )),
	(( u'Website' , u'pVal' , ), 148, (148, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1076 , (3, 0, None, None) , 0 , )),
	(( u'OtherReceivablePayable' , u'pVal' , ), 149, (149, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1080 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDateProcedureNumber' , u'pVal' , ), 150, (150, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1084 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDateProcedureNumber' , u'pVal' , ), 150, (150, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1088 , (3, 0, None, None) , 0 , )),
	(( u'Profession' , u'pVal' , ), 151, (151, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1092 , (3, 0, None, None) , 0 , )),
	(( u'Profession' , u'pVal' , ), 151, (151, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1096 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeonCollection' , u'pbstrRsltVal' , ), 152, (152, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1100 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeonCollection' , u'pbstrRsltVal' , ), 152, (152, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1104 , (3, 0, None, None) , 0 , )),
	(( u'CompanyPrivate' , u'penumRsltVal' , ), 153, (153, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1108 , (3, 0, None, None) , 0 , )),
	(( u'CompanyPrivate' , u'penumRsltVal' , ), 153, (153, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1112 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 154, (154, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1116 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 154, (154, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1120 , (3, 0, None, None) , 0 , )),
	(( u'UnpaidBillofExchange' , u'pbstrRsltVal' , ), 155, (155, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1124 , (3, 0, None, None) , 0 , )),
	(( u'UnpaidBillofExchange' , u'pbstrRsltVal' , ), 155, (155, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1128 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxDeductionGroup' , u'pVal' , ), 156, (156, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1132 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxDeductionGroup' , u'pVal' , ), 156, (156, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1136 , (3, 0, None, None) , 0 , )),
	(( u'BankChargesAllocationCode' , u'pbstrRsltVal' , ), 157, (157, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1140 , (3, 0, None, None) , 0 , )),
	(( u'BankChargesAllocationCode' , u'pbstrRsltVal' , ), 157, (157, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1144 , (3, 0, None, None) , 0 , )),
	(( u'FiscalTaxID' , u'pVal' , ), 158, (158, (), [ (16393, 10, None, "IID('{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}')") , ], 1 , 2 , 4 , 0 , 1148 , (3, 0, None, None) , 0 , )),
	(( u'TaxRoundingRule' , u'pVal' , ), 159, (159, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1152 , (3, 0, None, None) , 0 , )),
	(( u'TaxRoundingRule' , u'pVal' , ), 159, (159, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1156 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptionLetterNum' , u'pVal' , ), 115, (115, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1160 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateFrom' , u'pVal' , ), 117, (117, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 1164 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateTo' , u'pVal' , ), 118, (118, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 1168 , (3, 0, None, None) , 0 , )),
	(( u'CompanyRegistrationNumber' , u'pbstrRsltVal' , ), 160, (160, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1172 , (3, 0, None, None) , 0 , )),
	(( u'CompanyRegistrationNumber' , u'pbstrRsltVal' , ), 160, (160, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1176 , (3, 0, None, None) , 0 , )),
	(( u'VerificationNumber' , u'pbstrRsltVal' , ), 161, (161, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1180 , (3, 0, None, None) , 0 , )),
	(( u'VerificationNumber' , u'pbstrRsltVal' , ), 161, (161, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1184 , (3, 0, None, None) , 0 , )),
	(( u'OtherReceivablePayable' , u'pVal' , ), 149, (149, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1188 , (3, 0, None, None) , 0 , )),
	(( u'OperationCode347' , u'pVal' , ), 162, (162, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1192 , (3, 0, None, None) , 0 , )),
	(( u'OperationCode347' , u'pVal' , ), 162, (162, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1196 , (3, 0, None, None) , 0 , )),
	(( u'InsuranceOperation347' , u'pVal' , ), 163, (163, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1200 , (3, 0, None, None) , 0 , )),
	(( u'InsuranceOperation347' , u'pVal' , ), 163, (163, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1204 , (3, 0, None, None) , 0 , )),
	(( u'DiscountBaseObject' , u'pVal' , ), 164, (164, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1208 , (3, 0, None, None) , 0 , )),
	(( u'DiscountBaseObject' , u'pVal' , ), 164, (164, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1212 , (3, 0, None, None) , 0 , )),
	(( u'DiscountRelations' , u'pVal' , ), 165, (165, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1216 , (3, 0, None, None) , 0 , )),
	(( u'DiscountRelations' , u'pVal' , ), 165, (165, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1220 , (3, 0, None, None) , 0 , )),
	(( u'DiscountGroups' , u'pVal' , ), 166, (166, (), [ (16393, 10, None, "IID('{7B78B94A-9F54-4A05-9A64-0A1E89484ECB}')") , ], 1 , 2 , 4 , 0 , 1224 , (3, 0, None, None) , 0 , )),
	(( u'TypeReport' , u'penumRsltVal' , ), 167, (167, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1228 , (3, 0, None, None) , 0 , )),
	(( u'TypeReport' , u'penumRsltVal' , ), 167, (167, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1232 , (3, 0, None, None) , 0 , )),
	(( u'ThresholdOverlook' , u'pVal' , ), 168, (168, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1236 , (3, 0, None, None) , 0 , )),
	(( u'ThresholdOverlook' , u'pVal' , ), 168, (168, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1240 , (3, 0, None, None) , 0 , )),
	(( u'SurchargeOverlook' , u'pVal' , ), 169, (169, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1244 , (3, 0, None, None) , 0 , )),
	(( u'SurchargeOverlook' , u'pVal' , ), 169, (169, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1248 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentInterimAccount' , u'pbstrRsltVal' , ), 170, (170, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1252 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentInterimAccount' , u'pbstrRsltVal' , ), 170, (170, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1256 , (3, 0, None, None) , 0 , )),
	(( u'HierarchicalDeduction' , u'pVal' , ), 171, (171, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1260 , (3, 0, None, None) , 0 , )),
	(( u'HierarchicalDeduction' , u'pVal' , ), 171, (171, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1264 , (3, 0, None, None) , 0 , )),
	(( u'ShaamGroup' , u'pVal' , ), 172, (172, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1268 , (3, 0, None, None) , 0 , )),
	(( u'ShaamGroup' , u'pVal' , ), 172, (172, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1272 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxCertified' , u'pVal' , ), 173, (173, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1276 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxCertified' , u'pVal' , ), 173, (173, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1280 , (3, 0, None, None) , 0 , )),
	(( u'BookkeepingCertified' , u'pVal' , ), 174, (174, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1284 , (3, 0, None, None) , 0 , )),
	(( u'BookkeepingCertified' , u'pVal' , ), 174, (174, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1288 , (3, 0, None, None) , 0 , )),
	(( u'PlanningGroup' , u'pbstrRsltVal' , ), 175, (175, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1292 , (3, 0, None, None) , 0 , )),
	(( u'PlanningGroup' , u'pbstrRsltVal' , ), 175, (175, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1296 , (3, 0, None, None) , 0 , )),
	(( u'Affiliate' , u'pVal' , ), 176, (176, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1300 , (3, 0, None, None) , 0 , )),
	(( u'Affiliate' , u'pVal' , ), 176, (176, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1304 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pVal' , ), 177, (177, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1308 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pVal' , ), 177, (177, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1312 , (3, 0, None, None) , 0 , )),
	(( u'VatIDNum' , u'pbstrRsltVal' , ), 178, (178, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1316 , (3, 0, None, None) , 0 , )),
	(( u'VatIDNum' , u'pbstrRsltVal' , ), 178, (178, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1320 , (3, 0, None, None) , 0 , )),
	(( u'DatevAccount' , u'plRsltVal' , ), 179, (179, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1324 , (3, 0, None, None) , 0 , )),
	(( u'DatevAccount' , u'plRsltVal' , ), 179, (179, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1328 , (3, 0, None, None) , 0 , )),
	(( u'DatevFirstDataEntry' , u'pVal' , ), 180, (180, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1332 , (3, 0, None, None) , 0 , )),
	(( u'DatevFirstDataEntry' , u'pVal' , ), 180, (180, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1336 , (3, 0, None, None) , 0 , )),
	(( u'GTSRegNo' , u'pbstrRsltVal' , ), 181, (181, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1340 , (3, 0, None, None) , 0 , )),
	(( u'GTSRegNo' , u'pbstrRsltVal' , ), 181, (181, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1344 , (3, 0, None, None) , 0 , )),
	(( u'GTSBankAccountNo' , u'pbstrRsltVal' , ), 182, (182, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1348 , (3, 0, None, None) , 0 , )),
	(( u'GTSBankAccountNo' , u'pbstrRsltVal' , ), 182, (182, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1352 , (3, 0, None, None) , 0 , )),
	(( u'GTSBillingAddrTel' , u'pbstrRsltVal' , ), 183, (183, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1356 , (3, 0, None, None) , 0 , )),
	(( u'GTSBillingAddrTel' , u'pbstrRsltVal' , ), 183, (183, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1360 , (3, 0, None, None) , 0 , )),
	(( u'ETaxWebSite' , u'pVal' , ), 184, (184, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1364 , (3, 0, None, None) , 0 , )),
	(( u'ETaxWebSite' , u'pVal' , ), 184, (184, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1368 , (3, 0, None, None) , 0 , )),
	(( u'HouseBankIBAN' , u'pVal' , ), 185, (185, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1372 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 186, (186, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1376 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 186, (186, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1380 , (3, 0, None, None) , 0 , )),
	(( u'AutomaticPosting' , u'penumRsltVal' , ), 187, (187, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1384 , (3, 0, None, None) , 0 , )),
	(( u'AutomaticPosting' , u'penumRsltVal' , ), 187, (187, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1388 , (3, 0, None, None) , 0 , )),
	(( u'InterestAccount' , u'pVal' , ), 188, (188, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1392 , (3, 0, None, None) , 0 , )),
	(( u'InterestAccount' , u'pVal' , ), 188, (188, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1396 , (3, 0, None, None) , 0 , )),
	(( u'FeeAccount' , u'pVal' , ), 189, (189, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1400 , (3, 0, None, None) , 0 , )),
	(( u'FeeAccount' , u'pVal' , ), 189, (189, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1404 , (3, 0, None, None) , 0 , )),
	(( u'CampaignNumber' , u'pVal' , ), 190, (190, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1408 , (3, 0, None, None) , 0 , )),
	(( u'CampaignNumber' , u'pVal' , ), 190, (190, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1412 , (3, 0, None, None) , 0 , )),
	(( u'UpdateFromXML' , u'FileName' , u'ooErr' , ), 191, (191, (), [ (8, 1, None, None) , 
			(16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 1416 , (3, 0, None, None) , 0 , )),
	(( u'VATRegistrationNumber' , u'pVal' , ), 192, (192, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1420 , (3, 0, None, None) , 0 , )),
	(( u'VATRegistrationNumber' , u'pVal' , ), 192, (192, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1424 , (3, 0, None, None) , 0 , )),
	(( u'RepresentativeName' , u'pVal' , ), 193, (193, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1428 , (3, 0, None, None) , 0 , )),
	(( u'RepresentativeName' , u'pVal' , ), 193, (193, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1432 , (3, 0, None, None) , 0 , )),
	(( u'IndustryType' , u'pVal' , ), 194, (194, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1436 , (3, 0, None, None) , 0 , )),
	(( u'IndustryType' , u'pVal' , ), 194, (194, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1440 , (3, 0, None, None) , 0 , )),
	(( u'BusinessType' , u'pVal' , ), 195, (195, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1444 , (3, 0, None, None) , 0 , )),
	(( u'BusinessType' , u'pVal' , ), 195, (195, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1448 , (3, 0, None, None) , 0 , )),
	(( u'BPBranchAssignment' , u'pVal' , ), 201, (201, (), [ (16393, 10, None, "IID('{C65DEE24-288A-43E4-9F93-93F384B157BB}')") , ], 1 , 2 , 4 , 0 , 1452 , (3, 0, None, None) , 0 , )),
	(( u'AliasName' , u'pbstrRsltValue' , ), 202, (202, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1456 , (3, 0, None, None) , 0 , )),
	(( u'AliasName' , u'pbstrRsltValue' , ), 202, (202, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1460 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBlanketAgreementNumber' , u'pVal' , ), 203, (203, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1464 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBlanketAgreementNumber' , u'pVal' , ), 203, (203, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1468 , (3, 0, None, None) , 0 , )),
]

IBusinessPartnersService_vtables_dispatch_ = 1
IBusinessPartnersService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'CreateOpenBalance' , u'pIOpenningBalanceAccount' , u'pBPCodes' , ), 10, (10, (), [ (9, 1, None, "IID('{31BF39D4-A4A4-4FF6-A946-D7DFB4B37D5D}')") , 
			(9, 1, None, "IID('{9B7AB6DE-2A25-4329-9423-6B175EB8BCD3}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
]

IBusinessPlaceIENumbers_vtables_dispatch_ = 1
IBusinessPlaceIENumbers_vtables_ = [
	(( u'Add' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'plRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'plRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'IENumber' , u'plRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'IENumber' , u'plRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IBusinessPlaceTributaryInfos_vtables_dispatch_ = 1
IBusinessPlaceTributaryInfos_vtables_ = [
	(( u'Add' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNumber' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltValue' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'plRsltValue' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TributaryID' , u'plRsltValue' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TributaryType' , u'plRsltValue' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TributaryType' , u'plRsltValue' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TTStartDate' , u'pdtRsltValue' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TTStartDate' , u'pdtRsltValue' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TTEndDate' , u'pdtRsltValue' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TTEndDate' , u'pdtRsltValue' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TributaryRegimeCode' , u'plRsltValue' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TributaryRegimeCode' , u'plRsltValue' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TRCStartDate' , u'pdtRsltValue' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TRCStartDate' , u'pdtRsltValue' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TRCEndDate' , u'pdtRsltValue' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TRCEndDate' , u'pdtRsltValue' , ), 16, (16, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

IBusinessPlaces_vtables_dispatch_ = 1
IBusinessPlaces_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lBplId' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BPLName' , u'pbstrRsltVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BPLNameForeign' , u'pbstrRsltVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'VATRegNum' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RepName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Business' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Addressforeign' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MainBPL' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxOfficeNo' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Disabled' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'IENumbers' , u'pVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{EC280F9D-83C0-4324-9B19-18CB128A7021}')") , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BPLName' , u'pbstrRsltVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BPLNameForeign' , u'pbstrRsltVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'VATRegNum' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'RepName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Business' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Addressforeign' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'MainBPL' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TaxOfficeNo' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Disabled' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DefaultCustomerID' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DefaultCustomerID' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DefaultVendorID' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'DefaultVendorID' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DefaultWarehouseID' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DefaultWarehouseID' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTaxCode' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTaxCode' , u'pbstrRsltVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'TaxOffice' , u'pbstrRsltVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'TaxOffice' , u'pbstrRsltVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pbstrRsltVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pbstrRsltVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID2' , u'pbstrRsltVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID2' , u'pbstrRsltVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID3' , u'pbstrRsltVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID3' , u'pbstrRsltVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalIdNumber' , u'pbstrRsltVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalIdNumber' , u'pbstrRsltVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'NatureOfCompanyCode' , u'plRsltVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'NatureOfCompanyCode' , u'plRsltVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'EconomicActivityTypeCode' , u'plRsltVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'EconomicActivityTypeCode' , u'plRsltVal' , ), 41, (41, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CreditContributionOriginCode' , u'pbstrRsltVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CreditContributionOriginCode' , u'pbstrRsltVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'IPIPeriodCode' , u'pbstrRsltVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'IPIPeriodCode' , u'pbstrRsltVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'CooperativeAssociationTypeCode' , u'plRsltVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'CooperativeAssociationTypeCode' , u'plRsltVal' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'ProfitTaxationCode' , u'plRsltVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'ProfitTaxationCode' , u'plRsltVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'CompanyQualificationCode' , u'plRsltVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'CompanyQualificationCode' , u'plRsltVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'DeclarerTypeCode' , u'plRsltVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'DeclarerTypeCode' , u'plRsltVal' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'PreferredStateCode' , u'pbstrRsltVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'PreferredStateCode' , u'pbstrRsltVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pbstrRsltVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pbstrRsltVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pbstrRsltVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pbstrRsltVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'Building' , u'pbstrRsltVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'Building' , u'pbstrRsltVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 56, (56, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 56, (56, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 57, (57, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 59, (59, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'AliasName' , u'pbstrRsltValue' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'AliasName' , u'pbstrRsltValue' , ), 61, (61, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'CommercialRegister' , u'pbstrRsltValue' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'CommercialRegister' , u'pbstrRsltValue' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'DateOfIncorporation' , u'pdtRsltValue' , ), 63, (63, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'DateOfIncorporation' , u'pdtRsltValue' , ), 63, (63, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'SPEDProfile' , u'pbstrRsltValue' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'SPEDProfile' , u'pbstrRsltValue' , ), 64, (64, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'EnvironmentType' , u'plRsltValue' , ), 65, (65, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'EnvironmentType' , u'plRsltValue' , ), 65, (65, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'Opting4ICMS' , u'penumRsltValue' , ), 66, (66, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'Opting4ICMS' , u'penumRsltValue' , ), 66, (66, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'TributaryInfos' , u'pValue' , ), 67, (67, (), [ (16393, 10, None, "IID('{C1BF990C-0774-48F2-901C-84E414D881C6}')") , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'PaymentClearingAccount' , u'pbstrRsltVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'PaymentClearingAccount' , u'pbstrRsltVal' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
]

ICallArgument_vtables_dispatch_ = 1
ICallArgument_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ICallArguments_vtables_dispatch_ = 1
ICallArguments_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{CB6D5BD6-878B-4966-9E6B-8599949B657F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CB6D5BD6-878B-4966-9E6B-8599949B657F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICallMessage_vtables_dispatch_ = 1
ICallMessage_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ErrorCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ErrorCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'MessageBody' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'MessageBody' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pdateRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CreationTime' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CreationTime' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CallMessageArguments' , u'ppRsltVal' , ), 17, (17, (), [ (16393, 10, None, "IID('{7DE64B38-CB91-46C2-B1F2-B016D3CBD61D}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

ICallMessageArgument_vtables_dispatch_ = 1
ICallMessageArgument_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ICallMessageArguments_vtables_dispatch_ = 1
ICallMessageArguments_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICallMessages_vtables_dispatch_ = 1
ICallMessages_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{297DB996-8B05-4D4A-BD2D-333A643F7303}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{297DB996-8B05-4D4A-BD2D-333A643F7303}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICampaign_vtables_dispatch_ = 1
ICampaign_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CampaignNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CampaignName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CampaignName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CampaignType' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CampaignType' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroup' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroup' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 16, (16, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'FinishDate' , u'pdateRsltVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'FinishDate' , u'pdateRsltVal' , ), 17, (17, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'GeneratedByWizard' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'GeneratedByWizard' , u'penumRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'AttachementsEntry' , u'plRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'AttachementsEntry' , u'plRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CampaignBusinessPartners' , u'ppRsltVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{05167588-6D3A-4C0E-AEFA-284CFDA23B7E}')") , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CampaignItems' , u'ppRsltVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{317E97C8-89A1-45FB-BDD3-8AB420DDF340}')") , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CampaignPartners' , u'ppRsltVal' , ), 23, (23, (), [ (16393, 10, None, "IID('{40BEDE06-EB4F-4914-BCDF-71018C6FE98C}')") , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
]

ICampaignBusinessPartner_vtables_dispatch_ = 1
ICampaignBusinessPartner_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CampaignNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CampaignLineNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BPName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BPName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BPGroupName' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BPIndustryName' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BPStatus' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ContactTitle' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ContactPosition' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ContactEmail' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ContactTelephone' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ContactMobile' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ContactFax' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ContactAddress' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Response' , u'penumRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Response' , u'penumRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'RelatedSalesOpportunity' , u'plRsltVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'RelatedSalesOpportunity' , u'plRsltVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Building' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Building' , u'pbstrRsltVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'penumRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'penumRsltVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'IsShowLinkedDoc' , u'penumRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'IsShowLinkedDoc' , u'penumRsltVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'DocNumber' , u'plRsltVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ContactTitle' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ContactPosition' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ContactEmail' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ContactTelephone' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ContactMobile' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'ContactFax' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'ContactAddress' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
]

ICampaignBusinessPartners_vtables_dispatch_ = 1
ICampaignBusinessPartners_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICampaignItem_vtables_dispatch_ = 1
ICampaignItem_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CampaignNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CampaignLineNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ItemType' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroup' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

ICampaignItems_vtables_dispatch_ = 1
ICampaignItems_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{F68C8591-8115-4DC6-B1EF-5071C5CEB367}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{F68C8591-8115-4DC6-B1EF-5071C5CEB367}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICampaignParams_vtables_dispatch_ = 1
ICampaignParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CampaignNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CampaignNumber' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CampaignName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CampaignName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ICampaignPartner_vtables_dispatch_ = 1
ICampaignPartner_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CampaignNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CampaignLineNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PartnerID' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PartnerID' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipCode' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipCode' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'RelatedBP' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'RelatedBP' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ICampaignPartners_vtables_dispatch_ = 1
ICampaignPartners_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{A93138D1-7360-49C9-8F1C-EC5239C494B0}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{A93138D1-7360-49C9-8F1C-EC5239C494B0}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICampaignsParams_vtables_dispatch_ = 1
ICampaignsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{E47E4050-E7A6-4FD5-8F38-A8066213559A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{E47E4050-E7A6-4FD5-8F38-A8066213559A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICampaignsService_vtables_dispatch_ = 1
ICampaignsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pICampaign' , u'ppICampaignParams' , ), 10, (10, (), [ (9, 1, None, "IID('{87B9E57D-866B-4AE6-9C1D-571888134690}')") , 
			(16393, 10, None, "IID('{E47E4050-E7A6-4FD5-8F38-A8066213559A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pICampaign' , ), 11, (11, (), [ (9, 1, None, "IID('{87B9E57D-866B-4AE6-9C1D-571888134690}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pICampaignParams' , ), 12, (12, (), [ (9, 1, None, "IID('{E47E4050-E7A6-4FD5-8F38-A8066213559A}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pICampaignParams' , u'ppICampaign' , ), 13, (13, (), [ (9, 1, None, "IID('{E47E4050-E7A6-4FD5-8F38-A8066213559A}')") , 
			(16393, 10, None, "IID('{87B9E57D-866B-4AE6-9C1D-571888134690}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppICampaignsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{EF865450-BA41-490B-B580-3D566BA3681A}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'pICampaignParams' , ), 15, (15, (), [ (9, 1, None, "IID('{E47E4050-E7A6-4FD5-8F38-A8066213559A}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ICashDiscount_vtables_dispatch_ = 1
ICashDiscount_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ByDate' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ByDate' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Freight' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Freight' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Tax' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Tax' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DiscountLines' , u'ppRsltVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{E14BAC45-1772-407F-B255-178FF23F91E3}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

ICashDiscountParams_vtables_dispatch_ = 1
ICashDiscountParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICashDiscountsParams_vtables_dispatch_ = 1
ICashDiscountsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{60288E22-2FC1-402B-80FE-04D66413E1A0}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{60288E22-2FC1-402B-80FE-04D66413E1A0}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICashDiscountsService_vtables_dispatch_ = 1
ICashDiscountsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddCashDiscount' , u'pICashDiscount' , u'ppICashDiscountParams' , ), 10, (10, (), [ (9, 1, None, "IID('{A46D71C0-8C65-4B7E-BBA7-F6228CA0FE76}')") , 
			(16393, 10, None, "IID('{60288E22-2FC1-402B-80FE-04D66413E1A0}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCashDiscount' , u'pICashDiscount' , ), 11, (11, (), [ (9, 1, None, "IID('{A46D71C0-8C65-4B7E-BBA7-F6228CA0FE76}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteCashDiscount' , u'pICashDiscountParams' , ), 12, (12, (), [ (9, 1, None, "IID('{60288E22-2FC1-402B-80FE-04D66413E1A0}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetCashDiscount' , u'pICashDiscountParams' , u'ppICashDiscount' , ), 13, (13, (), [ (9, 1, None, "IID('{60288E22-2FC1-402B-80FE-04D66413E1A0}')") , 
			(16393, 10, None, "IID('{A46D71C0-8C65-4B7E-BBA7-F6228CA0FE76}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetCashDiscountList' , u'ppICashDiscountsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{38B3A4C7-93BE-4A6C-A060-C54D34979E1C}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICashFlowAssignments_vtables_dispatch_ = 1
ICashFlowAssignments_vtables_ = [
	(( u'Count' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 4, (4, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CashFlowAssignmentsID' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CashFlowLineItemID' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CashFlowLineItemID' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMeans' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMeans' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AmountLC' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AmountLC' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AmountFC' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AmountFC' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ICashFlowLineItem_vtables_dispatch_ = 1
ICashFlowLineItem_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LineItemID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineItemName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ActiveLineItem' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ParentArticle' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Level' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Drawer' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

ICashFlowLineItemParams_vtables_dispatch_ = 1
ICashFlowLineItemParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LineItemID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineItemID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LineItemName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICashFlowLineItemsParams_vtables_dispatch_ = 1
ICashFlowLineItemsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{A6EE3F95-9556-4409-9BCB-9DC06E009E22}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{A6EE3F95-9556-4409-9BCB-9DC06E009E22}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICashFlowLineItemsService_vtables_dispatch_ = 1
ICashFlowLineItemsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetCashFlowLineItem' , u'pICashFlowLineItemParams' , u'ppICashFlowLineItem' , ), 10, (10, (), [ (9, 1, None, "IID('{A6EE3F95-9556-4409-9BCB-9DC06E009E22}')") , 
			(16393, 10, None, "IID('{D2EDF723-F433-4A0A-A4A9-5D8E628CC3E3}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetCashFlowLineItemList' , u'ppICashFlowLineItemsParams' , ), 11, (11, (), [ (16393, 10, None, "IID('{7B677F06-BB36-462B-BABF-99676A90BC70}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

ICertificateSeries_vtables_dispatch_ = 1
ICertificateSeries_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Section' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Section' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DefaultSeries' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DefaultSeries' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SeriesLines' , u'ppRsltVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{D5B65908-18C4-493A-B1F3-BC7987AF01DD}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ICertificateSeriesParams_vtables_dispatch_ = 1
ICertificateSeriesParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Section' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ICertificateSeriesParamsCollection_vtables_dispatch_ = 1
ICertificateSeriesParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICertificateSeriesService_vtables_dispatch_ = 1
ICertificateSeriesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddCertificateSeries' , u'pICertificateSeries' , u'ppICertificateSeriesParams' , ), 10, (10, (), [ (9, 1, None, "IID('{56F2B212-48C0-453C-9298-380C6F7350F2}')") , 
			(16393, 10, None, "IID('{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCertificateSeries' , u'pICertificateSeries' , ), 11, (11, (), [ (9, 1, None, "IID('{56F2B212-48C0-453C-9298-380C6F7350F2}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteCertificateSeries' , u'pICertificateSeriesParams' , ), 12, (12, (), [ (9, 1, None, "IID('{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetCertificateSeries' , u'pICertificateSeriesParams' , u'ppICertificateSeries' , ), 13, (13, (), [ (9, 1, None, "IID('{A0B604D4-3D7B-427D-9EA1-15456A2329BD}')") , 
			(16393, 10, None, "IID('{56F2B212-48C0-453C-9298-380C6F7350F2}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetCertificateSeriesList' , u'ppICertificateSeriesParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{731625D2-901C-40C1-A06C-C6A72FC00D8C}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IChangeLogDifferenceParams_vtables_dispatch_ = 1
IChangeLogDifferenceParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pdateRsltVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ChangedField' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'OldValue' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'NewValue' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ArrayOffset' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'plRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IChangeLogDifferencesParams_vtables_dispatch_ = 1
IChangeLogDifferencesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IChangeLogParams_vtables_dispatch_ = 1
IChangeLogParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LogInstance' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UpdatedDate' , u'pdateRsltVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ObjectCode' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IChangeLogsParams_vtables_dispatch_ = 1
IChangeLogsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IChangeLogsService_vtables_dispatch_ = 1
IChangeLogsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetChangeLog' , u'pIGetChangeLogParams' , u'ppIChangeLogsParams' , ), 10, (10, (), [ (9, 1, None, "IID('{E8632E10-873F-4EBF-8339-E57C985D4472}')") , 
			(16393, 10, None, "IID('{D2FE59A3-5DA7-403C-9EAB-EF2C8CD8EFEA}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetChangeLogDifferences' , u'pIShowDifferenceParams' , u'ppIChangeLogDifferencesParams' , ), 11, (11, (), [ (9, 1, None, "IID('{87447CCD-DE87-4992-A2FD-2B0E26460BCB}')") , 
			(16393, 10, None, "IID('{FA06709C-FEAA-4E4B-85F1-063578C32965}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IChartOfAccounts_vtables_dispatch_ = 1
IChartOfAccounts_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AccountCode' , u'Found' , ), 2, (2, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Balance' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAccount' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BudgetAccount' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccount' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccount' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryAccount' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'AccountLevel' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DataExportCode' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DataExportCode' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'FatherAccountKey' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FatherAccountKey' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCode' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'RateConversion' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'RateConversion' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiableAccount' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiableAccount' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptAccount' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptAccount' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ExternalReconNo' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'InternalReconNo' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'AccountType' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'AccountType' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'AcctCurrency' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'AcctCurrency' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Balance_syscurr' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Balance_FrgnCurr' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Protected' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Protected' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ReconciledAccount' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'ReconciledAccount' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'LiableForAdvances' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'LiableForAdvances' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'ForeignName' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'ForeignName' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationCoordinated' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationCoordinated' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'LockManualTransaction' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'LockManualTransaction' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'FormatCode' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'FormatCode' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 40, (40, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'AllowChangeVatGroup' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'AllowChangeVatGroup' , u'pVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'DefaultVatGroup' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'DefaultVatGroup' , u'pVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'plRsltVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'plRsltVal' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pbstrRsltVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pbstrRsltVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'LoadingType' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'LoadingType' , u'pVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode' , u'pVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode' , u'pVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode2' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode2' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode3' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode3' , u'pVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode4' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode4' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode5' , u'pVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'LoadingFactorCode5' , u'pVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'PlanningLevel' , u'pVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'PlanningLevel' , u'pVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'DatevAccount' , u'pVal' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'DatevAccount' , u'pVal' , ), 54, (54, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'DatevAutoAccount' , u'pVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'DatevAutoAccount' , u'pVal' , ), 55, (55, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'DatevFirstDataEntry' , u'pVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'DatevFirstDataEntry' , u'pVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'AllowMultipleLinking' , u'pVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'AllowMultipleLinking' , u'pVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'ProjectRelevant' , u'pVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'ProjectRelevant' , u'pVal' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRuleRelevant' , u'pVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRuleRelevant' , u'pVal' , ), 73, (73, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2Relevant' , u'pVal' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2Relevant' , u'pVal' , ), 74, (74, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3Relevant' , u'pVal' , ), 75, (75, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3Relevant' , u'pVal' , ), 75, (75, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4Relevant' , u'pVal' , ), 76, (76, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4Relevant' , u'pVal' , ), 76, (76, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5Relevant' , u'pVal' , ), 77, (77, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5Relevant' , u'pVal' , ), 77, (77, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 91, (91, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 91, (91, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'BPLName' , u'pVal' , ), 92, (92, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'VATRegNum' , u'pVal' , ), 93, (93, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
]

ICheckLine_vtables_dispatch_ = 1
ICheckLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CheckKey' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CheckKey' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Bank' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CashCheck' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CheckDate' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Customer' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CheckAmount' , u'ppRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Deposited' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Transferred' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'AccountNumber' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CheckCurrency' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

ICheckLineParams_vtables_dispatch_ = 1
ICheckLineParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CheckKey' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CheckKey' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICheckLines_vtables_dispatch_ = 1
ICheckLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{900A8956-ACED-4E66-B254-78EB55F7089F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{900A8956-ACED-4E66-B254-78EB55F7089F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICheckLinesParams_vtables_dispatch_ = 1
ICheckLinesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICheckLinesService_vtables_dispatch_ = 1
ICheckLinesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetCheckLine' , u'pICheckLineParams' , u'ppICheckLine' , ), 10, (10, (), [ (9, 1, None, "IID('{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}')") , 
			(16393, 10, None, "IID('{900A8956-ACED-4E66-B254-78EB55F7089F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetValidCheckLineList' , u'ppICheckLinesParams' , ), 11, (11, (), [ (16393, 10, None, "IID('{FFA181B4-6482-45B5-901D-525B13F491EA}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IChecksforPayment_vtables_dispatch_ = 1
IChecksforPayment_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'CheckKey' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CheckKey' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BankName' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CheckDate' , u'pVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CheckDate' , u'pVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'AccountNumber' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'AccountNumber' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntryReference' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntryReference' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDate' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDate' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PaymentNo' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CheckAmount' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Transferable' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Transferable' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'VendorCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'VendorCode' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'CheckCurrency' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Canceled' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'CardOrAccount' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'CardOrAccount' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'VendorName' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Signature' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Signature' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'CustomerAccountCode' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'CustomerAccountCode' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'TransactionNumber' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'CreateJournalEntry' , u'pVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'CreateJournalEntry' , u'pVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 36, (36, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotal' , u'pVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 38, (38, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'DeductionRefundAmount' , u'pVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'DeductionRefundAmount' , u'pVal' , ), 39, (39, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'PrintedBy' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'TotalinWords' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'TotalinWords' , u'pVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 43, (43, (), [ (16393, 10, None, "IID('{A6DB2CDA-3A42-4A70-918C-53595D6091C9}')") , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ManualCheck' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'ManualCheck' , u'pVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
]

IChecksforPaymentLines_vtables_dispatch_ = 1
IChecksforPaymentLines_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'RowDetails' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RowDetails' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'RowTotal' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'RowTotal' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'RowCurrency' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RowCurrency' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinition' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinition' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercent' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CreditedAccount' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CreditedAccount' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IChooseFromList_vtables_dispatch_ = 1
IChooseFromList_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrObjectName' , u'pbRsltFound' , ), 6, (6, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ObjectName' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ObjectName' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ChooseFromList_Lines' , u'ppRsltVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{2E9D54CC-66FD-4688-9DA0-6AEE9C263D7E}')") , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IChooseFromList_Lines_vtables_dispatch_ = 1
IChooseFromList_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FieldNo' , u'pbstrRsltVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FieldNo' , u'pbstrRsltVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DisplayedName' , u'pbstrRsltVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DisplayedName' , u'pbstrRsltVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GroupBy' , u'penumRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GroupBy' , u'penumRsltVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Visible' , u'penumRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Visible' , u'penumRsltVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ShowType' , u'penumRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ShowType' , u'penumRsltVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SortOrder' , u'penumRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SortOrder' , u'penumRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'VisualIndex' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'VisualIndex' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

IClosingDateProcedure_vtables_dispatch_ = 1
IClosingDateProcedure_vtables_ = [
	(( u'UserFields' , u'ppRsltIUserFields' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDateNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDateCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BaselineDate' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'DueMonth' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ExtraMonth' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ExtraDay' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ClosingDateNum' , u'pbRsltFound' , ), 9, (9, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 11, (11, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ICockpit_vtables_dispatch_ = 1
ICockpit_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Time' , u'pdateRsltVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Manufacturer' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Manufacturer' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Publisher' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CockpitType' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

ICockpitParams_vtables_dispatch_ = 1
ICockpitParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CockpitType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICockpitsParams_vtables_dispatch_ = 1
ICockpitsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICockpitsService_vtables_dispatch_ = 1
ICockpitsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetCockpit' , u'pICockpitParams' , u'ppICockpit' , ), 10, (10, (), [ (9, 1, None, "IID('{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')") , 
			(16393, 10, None, "IID('{30EB7C61-BD42-4AAF-877E-DB6253066688}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AddCockpit' , u'pICockpit' , u'ppICockpitParams' , ), 11, (11, (), [ (9, 1, None, "IID('{30EB7C61-BD42-4AAF-877E-DB6253066688}')") , 
			(16393, 10, None, "IID('{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCockpit' , u'pICockpit' , ), 12, (12, (), [ (9, 1, None, "IID('{30EB7C61-BD42-4AAF-877E-DB6253066688}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DeleteCockpit' , u'pICockpitParams' , ), 13, (13, (), [ (9, 1, None, "IID('{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetCockpitList' , u'ppICockpitsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PublishCockpit' , u'pICockpit' , ), 15, (15, (), [ (9, 1, None, "IID('{30EB7C61-BD42-4AAF-877E-DB6253066688}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetUserCockpitList' , u'ppICockpitsParams' , ), 16, (16, (), [ (16393, 10, None, "IID('{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}')") , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetTemplateCockpitList' , u'ppICockpitsParams' , ), 17, (17, (), [ (16393, 10, None, "IID('{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}')") , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IColumnPreferences_vtables_dispatch_ = 1
IColumnPreferences_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FormID' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FormID' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemNumber' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ItemNumber' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Column' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Column' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Width' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Width' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'VisibleInForm' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'VisibleInForm' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TabsLayout' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TabsLayout' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'EditableInForm' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'EditableInForm' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'VisibleInExpanded' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'VisibleInExpanded' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ExpandedIndex' , u'plRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ExpandedIndex' , u'plRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'EditableInExpanded' , u'penumRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'EditableInExpanded' , u'penumRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'User' , u'plRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'User' , u'plRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
]

IColumnsPreferences_vtables_dispatch_ = 1
IColumnsPreferences_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{E498C4B2-E919-48EA-B512-79DE65B1F5CE}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{E498C4B2-E919-48EA-B512-79DE65B1F5CE}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IColumnsPreferencesParams_vtables_dispatch_ = 1
IColumnsPreferencesParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'User' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'User' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FormID' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FormID' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ICommand_vtables_dispatch_ = 1
ICommand_vtables_ = [
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Parameters' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{93CF87D1-95CB-459C-A906-729819461CA1}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Execute' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
]

ICommandParam_vtables_dispatch_ = 1
ICommandParam_vtables_ = [
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 2, (2, (), [ (16396, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 2, (2, (), [ (12, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Direction' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

ICommandParams_vtables_dispatch_ = 1
ICommandParams_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{8CA91808-D098-4416-8368-E426484BA8DB}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 1 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
]

ICommissionGroups_vtables_dispatch_ = 1
ICommissionGroups_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lGroupCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroupCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroupName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroupName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercentage' , u'pdblRsltVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercentage' , u'pdblRsltVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

ICompany_vtables_dispatch_ = 1
ICompany_vtables_ = [
	(( u'Connect' , u'RetVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Server' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Server' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'CompanyDB' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CompanyDB' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CompanyName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'WordDocsPath' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BitMapPath' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ExcelDocsPath' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Connected' , u'pVal' , ), 12, (12, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'AttachMentPath' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetBusinessObject' , u'Object' , u'pVal' , ), 14, (14, (), [ (3, 0, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetBusinessObjectFromXML' , u'FileName' , u'Index' , u'pVal' , ), 15, (15, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Disconnect' , ), 17, (17, (), [ ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'language' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'language' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GetLastError' , u'errCode' , u'errMsg' , ), 19, (19, (), [ (16387, 2, None, None) , 
			(16392, 2, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'StartTransaction' , ), 20, (20, (), [ ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'EndTransaction' , u'endType' , ), 21, (21, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'GetNewObjectCode' , u'ObjectCode' , ), 22, (22, (), [ (16392, 2, None, None) , ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'UseTrusted' , u'pVal' , ), 23, (23, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'UseTrusted' , u'pVal' , ), 23, (23, (), [ (11, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'GetCompanyList' , u'pVal' , ), 24, (24, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLobjectType' , u'FileName' , u'Index' , u'Object' , ), 25, (25, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLelementCount' , u'FileName' , u'Count' , ), 26, (26, (), [ (8, 1, None, None) , 
			(16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'UserTables' , u'pVal' , ), 27, (27, (), [ (16393, 10, None, "IID('{625162C1-3894-460F-94EC-72D6AFEA34D2}')") , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'XMLAsString' , u'pVal' , ), 28, (28, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'XMLAsString' , u'pVal' , ), 28, (28, (), [ (11, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'GetBusinessObjectXmlSchema' , u'Object' , u'SchemaStr' , ), 29, (29, (), [ (3, 1, None, None) , 
			(16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'XmlExportType' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'XmlExportType' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'InTransaction' , u'pVal' , ), 31, (31, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DbUserName' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DbUserName' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DbPassword' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DbPassword' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'GetContextCookie' , u'CookieStr' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'SetSboLoginContext' , u'conStr' , u'RetVal' , ), 35, (35, (), [ (8, 1, None, None) , 
			(16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DbServerType' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'DbServerType' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'AddonIdentifier' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'AddonIdentifier' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'LicenseServer' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'LicenseServer' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'GetLastErrorDescription' , u'errMsg' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'GetLastErrorCode' , u'errCode' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'GetNewObjectKey' , u'ObjectCode' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Version' , u'plRsltVersion' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'MinimalSupportedVersion' , u'plRsltMinimalSupVersion' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'DTCTransactionObject' , u'ppRsltIUnknown' , ), 44, (44, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'DTCTransactionObject' , u'ppRsltIUnknown' , ), 44, (44, (), [ (13, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'IsDTCTransactionObjectSet' , u'pbRslt' , ), 45, (45, (), [ (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'GetCompanyService' , u'ppRsltVal' , ), 46, (46, (), [ (16393, 10, None, "IID('{9D202A0D-3D49-47E0-AC0D-90333C553E85}')") , ], 1 , 1 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'ChangePassword' , u'NewPassword' , u'errCode' , ), 47, (47, (), [ (8, 1, None, None) , 
			(16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'InvalidateCache' , u'TableName' , u'errCode' , ), 48, (48, (), [ (8, 1, None, None) , 
			(16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Application' , ), 49, (49, (), [ (9, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'GetRegisteredServersList' , u'pVal' , ), 50, (50, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'AuthenticateUser' , u'bstrUserName' , u'bstrPassword' , u'penumRsltVal' , ), 51, (51, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'GetNewObjectType' , u'ObjectType' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'GetCompanyTime' , u'pTime' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'GetCompanyDate' , u'pDate' , ), 54, (54, (), [ (16391, 10, None, None) , ], 1 , 1 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
]

ICompanyInfo_vtables_dispatch_ = 1
ICompanyInfo_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'EnableExpensesManagement' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'EnableExpensesManagement' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'EnableAccountSegmentation' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'EnableAccountSegmentation' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'EnableBillOfExchange' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'EnableBillOfExchange' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BaseDateForExchangeRate' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BaseDateForExchangeRate' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BISRBankActKey' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BISRBankActKey' , u'plRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BISRBankCountry' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BISRBankNo' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BISRBankAccount' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BISRBranch' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'MaxRecordsInChooseFromList' , u'plRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'MaxRecordsInChooseFromList' , u'plRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'EnableCheckQuantityInRDR' , u'penumRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'EnableCheckQuantityInRDR' , u'penumRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SRIManagementSystem' , u'penumRsltVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'SRIManagementSystem' , u'penumRsltVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'AutoSRICreationOnReceipt' , u'penumRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'AutoSRICreationOnReceipt' , u'penumRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'IEPSPayer' , u'penumRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'IEPSPayer' , u'penumRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DefaultDaysForOrdCanc' , u'plRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DefaultDaysForOrdCanc' , u'plRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'PercentOfTotalAcquisition' , u'pdblRsltVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'PercentOfTotalAcquisition' , u'pdblRsltVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBaseAmountPerDoc' , u'pdblRsltVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBaseAmountPerDoc' , u'pdblRsltVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipIndication' , u'penumRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipIndication' , u'penumRsltVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'MinimumAmountForAppndixOP' , u'pdblRsltVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'MinimumAmountForAppndixOP' , u'pdblRsltVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DisplayTransactionsByDflt' , u'penumRsltVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DisplayTransactionsByDflt' , u'penumRsltVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'DefaultStampTax' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'DefaultStampTax' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'MinimumAmountForAnnualList' , u'pdblRsltVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'MinimumAmountForAnnualList' , u'pdblRsltVal' , ), 32, (32, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'BlockStockNegativeQuantity' , u'penumNewVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'BlockStockNegativeQuantity' , u'penumNewVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'AutoCreateCustomerEqCard' , u'penumRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'AutoCreateCustomerEqCard' , u'penumRsltVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'MaxNumberOfDocumentsInPmt' , u'plRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'MaxNumberOfDocumentsInPmt' , u'plRsltVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'EnableStockRelNoCostPrice' , u'penumRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'EnableStockRelNoCostPrice' , u'penumRsltVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Version' , u'plRsltVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CompanyName' , u'pbstrRsltVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'GroupLinesInVATCalculation' , u'penumRsltVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'TaxCalculationSystem' , u'penumRsltVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'EnableTransactionNotification' , u'penumRsltVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'EnableTransactionNotification' , u'penumRsltVal' , ), 41, (41, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
]

ICompanyService_vtables_dispatch_ = 1
ICompanyService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetBusinessService' , u'enumServiceType' , u'pRsltIDispatch' , ), 10, (10, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetCompanyInfo' , u'ppICompanyInfo' , ), 11, (11, (), [ (16393, 10, None, "IID('{97F84FDF-0E1F-4C2A-9FC2-B779411EC1EB}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCompanyInfo' , u'pICompanyInfo' , ), 12, (12, (), [ (9, 1, None, "IID('{97F84FDF-0E1F-4C2A-9FC2-B779411EC1EB}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetAdminInfo' , u'ppIAdminInfo' , ), 13, (13, (), [ (16393, 10, None, "IID('{4583DECC-E80D-46AE-B3C0-308FC33C58E9}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UpdateAdminInfo' , u'pIAdminInfo' , ), 14, (14, (), [ (9, 1, None, "IID('{4583DECC-E80D-46AE-B3C0-308FC33C58E9}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CreatePeriod' , u'pIPeriodCategory' , u'ppIPeriodCategoryParams' , ), 15, (15, (), [ (9, 1, None, "IID('{1C764D4F-63DA-46FE-BD81-56548EEDB2F6}')") , 
			(16393, 10, None, "IID('{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetPeriods' , u'pIPeriodCategoryParamsCollection' , ), 16, (16, (), [ (16393, 10, None, "IID('{A31EC6FB-9B3A-439E-828D-C95CB0646555}')") , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetPeriod' , u'pIPeriodCategoryParams' , u'ppIPeriodCategory' , ), 17, (17, (), [ (9, 1, None, "IID('{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')") , 
			(16393, 10, None, "IID('{1C764D4F-63DA-46FE-BD81-56548EEDB2F6}')") , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UpdatePeriod' , u'pIPeriodCategory' , ), 18, (18, (), [ (9, 1, None, "IID('{1C764D4F-63DA-46FE-BD81-56548EEDB2F6}')") , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetFinancePeriods' , u'pIPeriodCategoryParams' , u'ppIFinancePeriods' , ), 19, (19, (), [ (9, 1, None, "IID('{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')") , 
			(16393, 10, None, "IID('{4CA3F302-7EC4-4514-9F07-CB688C56A2ED}')") , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'GetFinancePeriod' , u'pIFinancePeriodParams' , u'ppIFinancePeriod' , ), 20, (20, (), [ (9, 1, None, "IID('{DA6203BB-DE30-4AC7-9567-5822C3463335}')") , 
			(16393, 10, None, "IID('{39DAE3AB-708D-4123-BC50-CC57F05D734E}')") , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UpdateFinancePeriod' , u'pIFinancePeriod' , ), 21, (21, (), [ (9, 1, None, "IID('{39DAE3AB-708D-4123-BC50-CC57F05D734E}')") , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CreatePeriodWithFinanceParams' , u'pIPeriodCategory' , u'pIFinancePeriodParams' , u'ppIPeriodCategoryParams' , ), 22, (22, (), [ 
			(9, 1, None, "IID('{1C764D4F-63DA-46FE-BD81-56548EEDB2F6}')") , (9, 1, None, "IID('{DA6203BB-DE30-4AC7-9567-5822C3463335}')") , (16393, 10, None, "IID('{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')") , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetFeaturesStatus' , u'ppIFeatureStatusCollection' , ), 23, (23, (), [ (16393, 10, None, "IID('{CB4596BC-49AF-40FF-AF45-DC92A9C75C97}')") , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetBlob' , u'pIBlobParams' , u'ppIBlob' , ), 24, (24, (), [ (9, 1, None, "IID('{6625CFCF-AADC-4D47-A83E-C1C786666117}')") , 
			(16393, 10, None, "IID('{E7838784-BDDC-4EC2-A812-C96B19D169C5}')") , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SetBlob' , u'pIBlobParams' , u'pIBlob' , ), 25, (25, (), [ (9, 1, None, "IID('{6625CFCF-AADC-4D47-A83E-C1C786666117}')") , 
			(9, 1, None, "IID('{E7838784-BDDC-4EC2-A812-C96B19D169C5}')") , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GetPathAdmin' , u'ppIPathAdmin' , ), 26, (26, (), [ (16393, 10, None, "IID('{029D7691-D339-4790-9D8A-652C86A30458}')") , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'UpdatePathAdmin' , u'pIPathAdmin' , ), 27, (27, (), [ (9, 1, None, "IID('{029D7691-D339-4790-9D8A-652C86A30458}')") , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GetGeneralService' , u'sServiceCode' , u'pRsltIDispatch' , ), 28, (28, (), [ (8, 1, None, None) , 
			(16393, 10, None, "IID('{31DE5655-438F-420E-83D0-016C88203706}')") , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'UpdateUserLicense' , u'pIUserLicenseParams' , ), 29, (29, (), [ (9, 1, None, "IID('{91B68A10-74AD-4FAC-98F5-746FDD45D957}')") , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'LoadBlobFromFile' , u'pIBlobParams' , ), 30, (30, (), [ (9, 1, None, "IID('{6625CFCF-AADC-4D47-A83E-C1C786666117}')") , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'SaveBlobToFile' , u'pIBlobParams' , ), 31, (31, (), [ (9, 1, None, "IID('{6625CFCF-AADC-4D47-A83E-C1C786666117}')") , ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'IsUserLicensed' , u'bstrUserName' , u'bstrLicType' , u'pBoolRslt' , ), 32, (32, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceMetaData' , u'ServiceCode' , u'bstrServiceMD' , ), 33, (33, (), [ (3, 1, None, None) , 
			(16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'RoundDecimal' , u'pIDecimalData' , u'ppIRoundedData' , ), 34, (34, (), [ (9, 1, None, "IID('{FF79D2D4-A79B-4DCF-A3BB-14A8B01A5FDC}')") , 
			(16393, 10, None, "IID('{EF86275D-924A-4AC9-9461-E9AAF80894B6}')") , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
]

IContactEmployees_vtables_dispatch_ = 1
IContactEmployees_vtables_ = [
	(( u'Position' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Phone1' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Phone1' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Phone2' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Phone2' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'E_Mail' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'E_Mail' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Remarks1' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Remarks1' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Remarks2' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Remarks2' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Password' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 14, (14, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 15, (15, (), [ ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 17, (17, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'InternalCode' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'PlaceOfBirth' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PlaceOfBirth' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DateOfBirth' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DateOfBirth' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Gender' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Gender' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Profession' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Profession' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Title' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Title' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'CityOfBirth' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'CityOfBirth' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 26, (26, (), [ ], 1 , 1 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'FirstName' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'FirstName' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'MiddleName' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'MiddleName' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'LastName' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'LastName' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
]

IContacts_vtables_dispatch_ = 1
IContacts_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ContactCode' , u'Found' , ), 3, (3, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 4, (4, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ContactDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ContactDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ContactTime' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ContactTime' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Recontact' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Recontact' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Closed' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Closed' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CloseDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CloseDate' , u'pVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Phone' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 20, (20, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Activity' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Activity' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'ActivityType' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'ActivityType' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'StartTime' , u'pVal' , ), 27, (27, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'StartTime' , u'pVal' , ), 27, (27, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'EndTime' , u'pVal' , ), 28, (28, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'EndTime' , u'pVal' , ), 28, (28, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Duration' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Duration' , u'pVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'DurationType' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'DurationType' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployee' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployee' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'HandledBy' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'HandledBy' , u'pVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 34, (34, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Reminder' , u'pVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'Reminder' , u'pVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ReminderPeriod' , u'pVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'ReminderPeriod' , u'pVal' , ), 36, (36, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'ReminderType' , u'pVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'ReminderType' , u'pVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'Personalflag' , u'pVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Personalflag' , u'pVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'ParentobjectId' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'Parentobjecttype' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Room' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Room' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Inactiveflag' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'Inactiveflag' , u'pVal' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'PreviousActivity' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'PreviousActivity' , u'pVal' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'Tentativeflag' , u'pVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'Tentativeflag' , u'pVal' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'EndDuedate' , u'pVal' , ), 50, (50, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'EndDuedate' , u'pVal' , ), 50, (50, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'DocTypeEx' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'DocTypeEx' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 55, (55, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 56, (56, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 56, (56, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
]

IContractTemplates_vtables_dispatch_ = 1
IContractTemplates_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'TemplateName' , u'Found' , ), 5, (5, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TemplateName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TemplateName' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TemplateIsDeleted' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TemplateIsDeleted' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TemplateIsRenewal' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TemplateIsRenewal' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'RemindBeforeRenewal' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'RemindBeforeRenewal' , u'pVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DurationOfCoverage' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DurationOfCoverage' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ResponseValue' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ResponseValue' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionUnit' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionUnit' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ContractType' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ContractType' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnabled' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnabled' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnabled' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnabled' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnabled' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnabled' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnabled' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnabled' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnabled' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnabled' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnabled' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnabled' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnabled' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnabled' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'MondayStart' , u'pVal' , ), 24, (24, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'MondayStart' , u'pVal' , ), 24, (24, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnd' , u'pVal' , ), 25, (25, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnd' , u'pVal' , ), 25, (25, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayStart' , u'pVal' , ), 26, (26, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayStart' , u'pVal' , ), 26, (26, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnd' , u'pVal' , ), 27, (27, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnd' , u'pVal' , ), 27, (27, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayStart' , u'pVal' , ), 28, (28, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayStart' , u'pVal' , ), 28, (28, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnd' , u'pVal' , ), 29, (29, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnd' , u'pVal' , ), 29, (29, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayStart' , u'pVal' , ), 30, (30, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayStart' , u'pVal' , ), 30, (30, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnd' , u'pVal' , ), 31, (31, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnd' , u'pVal' , ), 31, (31, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'FridayStart' , u'pVal' , ), 32, (32, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'FridayStart' , u'pVal' , ), 32, (32, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnd' , u'pVal' , ), 33, (33, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnd' , u'pVal' , ), 33, (33, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayStart' , u'pVal' , ), 34, (34, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayStart' , u'pVal' , ), 34, (34, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnd' , u'pVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnd' , u'pVal' , ), 35, (35, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'SundayStart' , u'pVal' , ), 36, (36, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'SundayStart' , u'pVal' , ), 36, (36, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnd' , u'pVal' , ), 37, (37, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnd' , u'pVal' , ), 37, (37, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'IncludeParts' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'IncludeParts' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'IncludeLabor' , u'pVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'IncludeLabor' , u'pVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'IncludeTravel' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'IncludeTravel' , u'pVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 41, (41, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 44, (44, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 45, (45, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'IncludeHolidays' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'IncludeHolidays' , u'pVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'ResponseUnit' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'ResponseUnit' , u'pVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 52, (52, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
]

ICostCenterType_vtables_dispatch_ = 1
ICostCenterType_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterTypeCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterTypeCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterTypeName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterTypeName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ICostCenterTypeParams_vtables_dispatch_ = 1
ICostCenterTypeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterTypeCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterTypeCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICostCenterTypes_vtables_dispatch_ = 1
ICostCenterTypes_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{B7334829-8658-48D1-9FF6-056E90AEB07D}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{B7334829-8658-48D1-9FF6-056E90AEB07D}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICostCenterTypesParams_vtables_dispatch_ = 1
ICostCenterTypesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{C8D6687E-6A96-4458-AF54-B052F20C26B3}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{C8D6687E-6A96-4458-AF54-B052F20C26B3}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICostCenterTypesService_vtables_dispatch_ = 1
ICostCenterTypesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddCostCenterType' , u'pICostCenterType' , u'ppICostCenterTypeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{B7334829-8658-48D1-9FF6-056E90AEB07D}')") , 
			(16393, 10, None, "IID('{C8D6687E-6A96-4458-AF54-B052F20C26B3}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCostCenterType' , u'pICostCenterType' , ), 11, (11, (), [ (9, 1, None, "IID('{B7334829-8658-48D1-9FF6-056E90AEB07D}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteCostCenterType' , u'pICostCenterTypeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{C8D6687E-6A96-4458-AF54-B052F20C26B3}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetCostCenterType' , u'pICostCenterTypeParams' , u'ppICostCenterType' , ), 13, (13, (), [ (9, 1, None, "IID('{C8D6687E-6A96-4458-AF54-B052F20C26B3}')") , 
			(16393, 10, None, "IID('{B7334829-8658-48D1-9FF6-056E90AEB07D}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetCostCenterTypeList' , u'ppICostCenterTypesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{C09C1DAE-49E3-43CF-AA54-D2EDDCAAE9DB}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICountriesParams_vtables_dispatch_ = 1
ICountriesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICountriesService_vtables_dispatch_ = 1
ICountriesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddCountry' , u'pICountry' , u'ppICountryParams' , ), 10, (10, (), [ (9, 1, None, "IID('{8A1D0D45-C379-4714-87A6-F81EA6284EEB}')") , 
			(16393, 10, None, "IID('{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCountry' , u'pICountry' , ), 11, (11, (), [ (9, 1, None, "IID('{8A1D0D45-C379-4714-87A6-F81EA6284EEB}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteCountry' , u'pICountryParams' , ), 12, (12, (), [ (9, 1, None, "IID('{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetCountryList' , u'ppICountriesParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{420B8379-83B3-4AE9-B7B8-4DDF73D3085D}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetCountry' , u'pICountryParams' , u'ppICountry' , ), 14, (14, (), [ (9, 1, None, "IID('{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}')") , 
			(16393, 10, None, "IID('{8A1D0D45-C379-4714-87A6-F81EA6284EEB}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICountry_vtables_dispatch_ = 1
ICountry_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CodeForReports' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CodeForReports' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AddressFormat' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AddressFormat' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'EU' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'EU' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfDigitsForTaxID' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfDigitsForTaxID' , u'plRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BankCodeDigits' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BankCodeDigits' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BankBranchDigits' , u'plRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BankBranchDigits' , u'plRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BankAccountDigits' , u'plRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BankAccountDigits' , u'plRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'BankControlKeyDigits' , u'plRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BankControlKeyDigits' , u'plRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DomesticAccountValidation' , u'penumRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DomesticAccountValidation' , u'penumRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'IbanValidation' , u'penumRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'IbanValidation' , u'penumRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Blacklisted' , u'penumRsltVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Blacklisted' , u'penumRsltVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'UICCountryCode' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'UICCountryCode' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
]

ICountryParams_vtables_dispatch_ = 1
ICountryParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ICreditCardPayments_vtables_dispatch_ = 1
ICreditCardPayments_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrCode' , u'pbRsltFound' , ), 6, (6, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DueDateCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DueDateCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DueDateName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DueDateName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DueDatesType' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'DueDatesType' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PaymentAfterDays' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PaymentAfterDays' , u'plRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PaymentAfterMonths' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'PaymentAfterMonths' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'FromDay1' , u'plRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'FromDay1' , u'plRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ToDay1' , u'plRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ToDay1' , u'plRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDay1' , u'plRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDay1' , u'plRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'NoOfMonths1' , u'plRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'NoOfMonths1' , u'plRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'FromDay2' , u'plRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'FromDay2' , u'plRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ToDay2' , u'plRsltVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ToDay2' , u'plRsltVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDay2' , u'plRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDay2' , u'plRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'NoOfMonths2' , u'plRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'NoOfMonths2' , u'plRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'FromDay3' , u'plRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'FromDay3' , u'plRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'ToDay3' , u'plRsltVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'ToDay3' , u'plRsltVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDay3' , u'plRsltVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDay3' , u'plRsltVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'NoOfMonths3' , u'plRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'NoOfMonths3' , u'plRsltVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'FromDay4' , u'plRsltVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'FromDay4' , u'plRsltVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'ToDay4' , u'plRsltVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'ToDay4' , u'plRsltVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDay4' , u'plRsltVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDay4' , u'plRsltVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'NoOfMonths4' , u'plRsltVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'NoOfMonths4' , u'plRsltVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
]

ICreditCards_vtables_dispatch_ = 1
ICreditCards_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCardCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardCode' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardName' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardName' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Telephone' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Telephone' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CompanyID' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CompanyID' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

ICreditLine_vtables_dispatch_ = 1
ICreditLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsId' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsId' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CreditCard' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'VoucherNumber' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PayDate' , u'pdateRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Deposited' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'NumOfPayments' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Customer' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Transferred' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Total' , u'ppRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CreditCurrency' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

ICreditLineParams_vtables_dispatch_ = 1
ICreditLineParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsId' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsId' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICreditLines_vtables_dispatch_ = 1
ICreditLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICreditLinesParams_vtables_dispatch_ = 1
ICreditLinesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{B0338FF7-542D-4AEA-A097-A51DECA7E671}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{B0338FF7-542D-4AEA-A097-A51DECA7E671}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICreditLinesService_vtables_dispatch_ = 1
ICreditLinesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetCreditLine' , u'pICreditLineParams' , u'ppICreditLine' , ), 10, (10, (), [ (9, 1, None, "IID('{B0338FF7-542D-4AEA-A097-A51DECA7E671}')") , 
			(16393, 10, None, "IID('{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetValidCreditLineList' , u'ppICreditLinesParams' , ), 11, (11, (), [ (16393, 10, None, "IID('{60836D85-E0A0-435F-B237-4A1E79D7D670}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

ICreditPaymentMethods_vtables_dispatch_ = 1
ICreditPaymentMethods_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AssignedtoCreditCard' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AssignedtoCreditCard' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PaymentCode' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PaymentCode' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'MinimumCreditAmount' , u'pdblRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'MinimumCreditAmount' , u'pdblRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'MinimumPaymentAmount' , u'pdblRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'MinimumPaymentAmount' , u'pdblRsltVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'MaxQtyWithoutApproval' , u'pdblRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'MaxQtyWithoutApproval' , u'pdblRsltVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'InstallmentPaymentsPossible' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'InstallmentPaymentsPossible' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
]

ICurrencies_vtables_dispatch_ = 1
ICurrencies_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Currency' , u'Found' , ), 2, (2, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocumentsCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DocumentsCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'InternationalDescription' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'InternationalDescription' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'HundredthName' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'HundredthName' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'EnglishName' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'EnglishName' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'EnglishHundredthName' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'EnglishHundredthName' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PluralInternationalDescription' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PluralInternationalDescription' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PluralHundredthName' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PluralHundredthName' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PluralEnglishName' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'PluralEnglishName' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'PluralEnglishHundredthName' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PluralEnglishHundredthName' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Decimals' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Decimals' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Rounding' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Rounding' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'RoundingInPayment' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'RoundingInPayment' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'MaxIncomingAmtDiff' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'MaxIncomingAmtDiff' , u'pVal' , ), 24, (24, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'MaxOutgoingAmtDiff' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'MaxOutgoingAmtDiff' , u'pVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'MaxIncomingAmtDiffPercent' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'MaxIncomingAmtDiffPercent' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'MaxOutgoingAmtDiffPercent' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'MaxOutgoingAmtDiffPercent' , u'pVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
]

ICurrencyRestrictions_vtables_dispatch_ = 1
ICurrencyRestrictions_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pbstrRsltVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CurrencyCode' , u'pbstrRsltVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CurrencyCode' , u'pbstrRsltVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CurrencyName' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Choose' , u'penumRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Choose' , u'penumRsltVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ICustomerEquipmentCards_vtables_dispatch_ = 1
ICustomerEquipmentCards_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'EquipmentCardNum' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'EquipmentCardNum' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ContactEmployeeCode' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ContactEmployeeCode' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DirectCustomerCode' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DirectCustomerCode' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DirectCustomerName' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DirectCustomerName' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceCode' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceCode' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceNumber' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DeliveryDate' , u'pVal' , ), 26, (26, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ContactPhone' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'StateCode' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'StateCode' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'InstallLocation' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'InstallLocation' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 39, (39, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'DeliveryCode' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'DeliveryCode' , u'pVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'DeliveryNumber' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'StatusOfSerialNumber' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'StatusOfSerialNumber' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ReplaceSN' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'ReplaceSN' , u'pVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTechnician' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTechnician' , u'pVal' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'ReplacedBySN' , u'pVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ReplacedBySN' , u'pVal' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Defaultterritory' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'Defaultterritory' , u'pVal' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 50, (50, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
]

ICustomsDeclaration_vtables_dispatch_ = 1
ICustomsDeclaration_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CCDNum' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CCDNum' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pdateRsltVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pdateRsltVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CustomsBroker' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CustomsBroker' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pdateRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pdateRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SupplyNum' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'SupplyNum' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'SupplyDate' , u'pdateRsltVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SupplyDate' , u'pdateRsltVal' , ), 16, (16, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'CustomsTerminal' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CustomsTerminal' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'PaymentKey' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PaymentKey' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
]

ICustomsDeclarationParams_vtables_dispatch_ = 1
ICustomsDeclarationParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CCDNum' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CCDNum' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICustomsDeclarationService_vtables_dispatch_ = 1
ICustomsDeclarationService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddCustomsDeclaration' , u'pICustomsDeclaration' , u'ppICustomsDeclarationParams' , ), 10, (10, (), [ (9, 1, None, "IID('{812BAA6F-715C-42E4-811F-287EF23E05A2}')") , 
			(16393, 10, None, "IID('{3D7A2391-5E52-45DE-80DB-A09ECADBD5A3}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCustomsDeclaration' , u'pICustomsDeclaration' , ), 11, (11, (), [ (9, 1, None, "IID('{812BAA6F-715C-42E4-811F-287EF23E05A2}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteCustomsDeclaration' , u'pICustomsDeclarationParams' , ), 12, (12, (), [ (9, 1, None, "IID('{3D7A2391-5E52-45DE-80DB-A09ECADBD5A3}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetCustomsDeclaration' , u'pICustomsDeclarationParams' , u'ppICustomsDeclaration' , ), 13, (13, (), [ (9, 1, None, "IID('{3D7A2391-5E52-45DE-80DB-A09ECADBD5A3}')") , 
			(16393, 10, None, "IID('{812BAA6F-715C-42E4-811F-287EF23E05A2}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ICustomsGroups_vtables_dispatch_ = 1
ICustomsGroups_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lGroupCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Customs' , u'pdblRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Customs' , u'pdblRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Purchase' , u'pdblRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Purchase' , u'pdblRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Other' , u'pdblRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Other' , u'pdblRsltVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Total' , u'pdblRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Total' , u'pdblRsltVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'CustomsAllocationAccount' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CustomsAllocationAccount' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'CustomsExpenseAccount' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CustomsExpenseAccount' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PortAddress' , u'pbstrValue' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'PortAddress' , u'pbstrValue' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'PortState' , u'pbstrValue' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PortState' , u'pbstrValue' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
]

IDNFCodeSetup_vtables_dispatch_ = 1
IDNFCodeSetup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DNFCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DNFCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UoM' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UoM' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'ppRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'ppRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IDNFCodeSetupParams_vtables_dispatch_ = 1
IDNFCodeSetupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DNFCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IDNFCodeSetupParamsCollection_vtables_dispatch_ = 1
IDNFCodeSetupParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDNFCodeSetupService_vtables_dispatch_ = 1
IDNFCodeSetupService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddDNFCodeSetup' , u'pIDNFCodeSetup' , u'ppIDNFCodeSetupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{F8E64A61-69DC-439B-82C9-0D7B1BD5E4B1}')") , 
			(16393, 10, None, "IID('{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDNFCodeSetup' , u'pIDNFCodeSetup' , ), 11, (11, (), [ (9, 1, None, "IID('{F8E64A61-69DC-439B-82C9-0D7B1BD5E4B1}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteDNFCodeSetup' , u'pIDNFCodeSetupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetDNFCodeSetup' , u'pIDNFCodeSetupParams' , u'ppIDNFCodeSetup' , ), 13, (13, (), [ (9, 1, None, "IID('{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}')") , 
			(16393, 10, None, "IID('{F8E64A61-69DC-439B-82C9-0D7B1BD5E4B1}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetDNFCodeSetupList' , u'ppIDNFCodeSetupParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{80B626C7-6F5E-4C42-BBD0-36A311400BAE}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDashboardPackageImportParams_vtables_dispatch_ = 1
IDashboardPackageImportParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PackageFilePath' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PackageFilePath' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ForceOverwritePackage' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ForceOverwritePackage' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ImportQueries' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ImportQueries' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ForceOverwriteQuery' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ForceOverwriteQuery' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IDashboardPackageParams_vtables_dispatch_ = 1
IDashboardPackageParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDashboardPackagesParams_vtables_dispatch_ = 1
IDashboardPackagesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{006B6314-B29C-407F-A8F8-11717E779A2A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{006B6314-B29C-407F-A8F8-11717E779A2A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDashboardPackagesService_vtables_dispatch_ = 1
IDashboardPackagesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ImportDashboardPackage' , u'pIDashboardPackageImportParams' , u'ppIDashboardPackageParams' , ), 10, (10, (), [ (9, 1, None, "IID('{D0D6E022-B36B-44E9-BD9A-24E3169AD532}')") , 
			(16393, 10, None, "IID('{006B6314-B29C-407F-A8F8-11717E779A2A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
]

IDataBrowser_vtables_dispatch_ = 1
IDataBrowser_vtables_ = [
	(( u'Recordset' , ), 1, (1, (), [ (9, 1, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 4 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'RecordCount' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'MoveFirst' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'MovePrevious' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'MoveNext' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'MoveLast' , ), 6, (6, (), [ ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BoF' , u'pVal' , ), 7, (7, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'EoF' , u'pVal' , ), 8, (8, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Refresh' , ), 9, (9, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ReadXml' , u'XmlFileStr' , u'Index' , ), 10, (10, (), [ (8, 1, None, None) , 
			(3, 1, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetByKeys' , u'keysStr' , u'pbRsltFound' , ), 11, (11, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IDecimalData_vtables_dispatch_ = 1
IDecimalData_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'ppRsltVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'ppRsltVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Context' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Context' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IDeductionTaxGroups_vtables_dispatch_ = 1
IDeductionTaxGroups_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lGroupKey' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GroupKey' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GroupName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GroupName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'MaxRedin' , u'pdblRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MaxRedin' , u'pdblRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'GroupExtendedCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GroupExtendedCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IDeductionTaxHierarchies_vtables_dispatch_ = 1
IDeductionTaxHierarchies_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsEntry' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'HierarchyCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'HierarchyCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'HierarchyName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'HierarchyName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pdtRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pdtRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ValidUntil' , u'pdtRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ValidUntil' , u'pdtRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{27A32FF4-4CC4-4D4A-860F-83E81EC52F3A}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'plRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'plRsltVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'MaximumTotal' , u'pdblRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'MaximumTotal' , u'pdblRsltVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdated' , u'pdtRsltVal' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
]

IDeductionTaxHierarchies_Lines_vtables_dispatch_ = 1
IDeductionTaxHierarchies_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'plRsltVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'plRsltVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'MaximumTotal' , u'pdblRsltVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MaximumTotal' , u'pdblRsltVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IDeductionTaxSubGroup_vtables_dispatch_ = 1
IDeductionTaxSubGroup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GroupName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GroupName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IDeductionTaxSubGroupParams_vtables_dispatch_ = 1
IDeductionTaxSubGroupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GroupName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDeductionTaxSubGroupsParams_vtables_dispatch_ = 1
IDeductionTaxSubGroupsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{2165070A-0BA0-4409-AC85-52A47508F236}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{2165070A-0BA0-4409-AC85-52A47508F236}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDeductionTaxSubGroupsService_vtables_dispatch_ = 1
IDeductionTaxSubGroupsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddDeductionTaxSubGroup' , u'pIDeductionTaxSubGroup' , u'ppIDeductionTaxSubGroupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{16403B63-EB90-4781-9C89-05EF77769731}')") , 
			(16393, 10, None, "IID('{2165070A-0BA0-4409-AC85-52A47508F236}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDeductionTaxSubGroup' , u'pIDeductionTaxSubGroup' , ), 11, (11, (), [ (9, 1, None, "IID('{16403B63-EB90-4781-9C89-05EF77769731}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetDeductionTaxSubGroup' , u'pIDeductionTaxSubGroupParams' , u'ppIDeductionTaxSubGroup' , ), 12, (12, (), [ (9, 1, None, "IID('{2165070A-0BA0-4409-AC85-52A47508F236}')") , 
			(16393, 10, None, "IID('{16403B63-EB90-4781-9C89-05EF77769731}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetDeductionTaxSubGroupList' , u'ppIDeductionTaxSubGroupsParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{9766B024-E4F6-4116-98AC-DE54D618BFFA}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDefaultCreditCards_vtables_dispatch_ = 1
IDefaultCreditCards_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardCode' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardCode' , u'plRsltVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CreditAccountCode' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CreditAccountCode' , u'pbstrRsltVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IDefaultDocuments_vtables_dispatch_ = 1
IDefaultDocuments_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ObjectType' , u'pbstrRsltVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ObjectType' , u'pbstrRsltVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NoofCopies' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'NoofCopies' , u'plRsltVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AddPrint' , u'penumRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AddPrint' , u'penumRsltVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AddExport' , u'penumRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AddExport' , u'penumRsltVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TotalsRounding' , u'penumRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TotalsRounding' , u'penumRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PermanentRemark' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PermanentRemark' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PrintTotals' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'PrintTotals' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PrintVendorCatalogNo' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PrintVendorCatalogNo' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'PrintDiscountData' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PrintDiscountData' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'NoofCopiesforManualDoc' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'NoofCopiesforManualDoc' , u'plRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'EnglishKeyboardEnteringItem' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'EnglishKeyboardEnteringItem' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'EnglishKeyboardEnteringBPC' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'EnglishKeyboardEnteringBPC' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
]

IDefaultElectronicSeriesParams_vtables_dispatch_ = 1
IDefaultElectronicSeriesParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ElectronicSeries' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ElectronicSeries' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IDefaultReportParams_vtables_dispatch_ = 1
IDefaultReportParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ReportCode' , u'Value' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ReportCode' , u'Value' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LayoutCode' , u'Value' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LayoutCode' , u'Value' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'Value' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'Value' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'Value' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'Value' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IDepartment_vtables_dispatch_ = 1
IDepartment_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IDepartmentParams_vtables_dispatch_ = 1
IDepartmentParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDepartmentsParams_vtables_dispatch_ = 1
IDepartmentsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{99E84704-3E04-40DD-BE1D-854068378E3A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{99E84704-3E04-40DD-BE1D-854068378E3A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDepartmentsService_vtables_dispatch_ = 1
IDepartmentsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddDepartment' , u'pIDepartment' , u'ppIDepartmentParams' , ), 10, (10, (), [ (9, 1, None, "IID('{B4CCEAAF-2511-4E3A-916F-8F0F7B6479C5}')") , 
			(16393, 10, None, "IID('{99E84704-3E04-40DD-BE1D-854068378E3A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDepartment' , u'pIDepartment' , ), 11, (11, (), [ (9, 1, None, "IID('{B4CCEAAF-2511-4E3A-916F-8F0F7B6479C5}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteDepartment' , u'pIDepartmentParams' , ), 12, (12, (), [ (9, 1, None, "IID('{99E84704-3E04-40DD-BE1D-854068378E3A}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetDepartment' , u'pIDepartmentParams' , u'ppIDepartment' , ), 13, (13, (), [ (9, 1, None, "IID('{99E84704-3E04-40DD-BE1D-854068378E3A}')") , 
			(16393, 10, None, "IID('{B4CCEAAF-2511-4E3A-916F-8F0F7B6479C5}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetDepartmentList' , u'ppIDepartmentsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{A7A2DCAC-BFE4-4CAA-B5D0-A337C4783C60}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDeposit_vtables_dispatch_ = 1
IDeposit_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DepositNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DepositType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DepositType' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DepositDate' , u'pdateRsltVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DepositDate' , u'pdateRsltVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DepositCurrency' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DepositCurrency' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DepositAccount' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DepositAccount' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'DepositorName' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DepositorName' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Bank' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Bank' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BankAccountNum' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BankAccountNum' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BankReference' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'BankReference' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TotalLC' , u'ppRsltVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TotalLC' , u'ppRsltVal' , ), 21, (21, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TotalFC' , u'ppRsltVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TotalSC' , u'ppRsltVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'AllocationAccount' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'AllocationAccount' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'ppRsltVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'ppRsltVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TaxAccount' , u'pbstrRsltVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'TaxAccount' , u'pbstrRsltVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmount' , u'ppRsltVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmount' , u'ppRsltVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'CommissionAccount' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'CommissionAccount' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Commission' , u'ppRsltVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Commission' , u'ppRsltVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'CommissionDate' , u'pdateRsltVal' , ), 30, (30, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'CommissionDate' , u'pdateRsltVal' , ), 30, (30, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'DepositAccountType' , u'penumRsltVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'DepositAccountType' , u'penumRsltVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Checks' , u'pVal' , ), 33, (33, (), [ (16393, 10, None, "IID('{4DA92EEC-3781-4B5B-B466-4001E7B6F439}')") , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Credits' , u'pVal' , ), 34, (34, (), [ (16393, 10, None, "IID('{0219BFB4-6A47-47F5-942F-8B05389A05FB}')") , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'BOEs' , u'pVal' , ), 35, (35, (), [ (16393, 10, None, "IID('{87ED882F-80FA-487D-8DA1-058E42B6BFA8}')") , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ReconcileAfterDeposit' , u'penumRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ReconcileAfterDeposit' , u'penumRsltVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'VoucherAccount' , u'pbstrRsltVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'VoucherAccount' , u'pbstrRsltVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'CommissionCurrency' , u'pbstrRsltVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'CommissionCurrency' , u'pbstrRsltVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'CommissionSC' , u'pRsltVal' , ), 47, (47, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'CommissionFC' , u'pRsltVal' , ), 48, (48, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmountSC' , u'pRsltVal' , ), 49, (49, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmountFC' , u'pRsltVal' , ), 50, (50, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
]

IDepositParams_vtables_dispatch_ = 1
IDepositParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DepositNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DepositNumber' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IDepositsParams_vtables_dispatch_ = 1
IDepositsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDepositsService_vtables_dispatch_ = 1
IDepositsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetDeposit' , u'pIDepositParams' , u'ppIDeposit' , ), 10, (10, (), [ (9, 1, None, "IID('{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')") , 
			(16393, 10, None, "IID('{29A116DF-AE12-4A45-A5F0-3436E170B26B}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AddDeposit' , u'pIDeposit' , u'ppIDepositParams' , ), 11, (11, (), [ (9, 1, None, "IID('{29A116DF-AE12-4A45-A5F0-3436E170B26B}')") , 
			(16393, 10, None, "IID('{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDeposit' , u'pIDeposit' , ), 12, (12, (), [ (9, 1, None, "IID('{29A116DF-AE12-4A45-A5F0-3436E170B26B}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CancelDeposit' , u'pIDepositParams' , ), 13, (13, (), [ (9, 1, None, "IID('{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetDepositList' , u'ppIDepositsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{3FFD991B-9010-4832-89C6-903CBB33AD7D}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDimension_vtables_dispatch_ = 1
IDimension_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DimensionCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DimensionName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'IsActive' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'IsActive' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DimensionDescription' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DimensionDescription' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IDimensionParams_vtables_dispatch_ = 1
IDimensionParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DimensionCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DimensionCode' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DimensionName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDimensionsParams_vtables_dispatch_ = 1
IDimensionsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{D50B349A-0226-4D72-9FEC-B38D21C65FE0}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{D50B349A-0226-4D72-9FEC-B38D21C65FE0}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDimensionsService_vtables_dispatch_ = 1
IDimensionsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDimension' , u'pIDimension' , ), 10, (10, (), [ (9, 1, None, "IID('{0C349981-9E5F-4814-910B-8995D5E9D32E}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetDimension' , u'pIDimensionParams' , u'ppIDimension' , ), 11, (11, (), [ (9, 1, None, "IID('{D50B349A-0226-4D72-9FEC-B38D21C65FE0}')") , 
			(16393, 10, None, "IID('{0C349981-9E5F-4814-910B-8995D5E9D32E}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetDimensionList' , u'ppIDimensionsParams' , ), 12, (12, (), [ (16393, 10, None, "IID('{7055A28F-3019-4826-A4CC-FC4E5D5E42C7}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IDiscountGroups_vtables_dispatch_ = 1
IDiscountGroups_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ObjectEntry' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ObjectEntry' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercentage' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercentage' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BaseObjectType' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IDiscountLine_vtables_dispatch_ = 1
IDiscountLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DiscountCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineId' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NumOfDays' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'NumOfDays' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Discount' , u'ppRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Discount' , u'ppRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Day' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Day' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Month' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Month' , u'plRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IDiscountLines_vtables_dispatch_ = 1
IDiscountLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{73042DE8-A510-4C53-B256-FD249BA13723}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{73042DE8-A510-4C53-B256-FD249BA13723}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDistributionRule_vtables_dispatch_ = 1
IDistributionRule_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FactorCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FactorCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FactorDescription' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FactorDescription' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TotalFactor' , u'ppRsltVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TotalFactor' , u'ppRsltVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Direct' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Direct' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'InWhichDimension' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'InWhichDimension' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRuleLines' , u'ppRsltVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{0B5DE094-FB49-4B4C-AA7C-F87F5E3A932F}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'pbstrRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'pbstrRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

IDistributionRuleLine_vtables_dispatch_ = 1
IDistributionRuleLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CenterCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CenterCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TotalInCenter' , u'ppRsltVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TotalInCenter' , u'ppRsltVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pdateRsltVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pdateRsltVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'EffectiveTo' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'EffectiveTo' , u'pdateRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IDistributionRuleLines_vtables_dispatch_ = 1
IDistributionRuleLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDistributionRuleParams_vtables_dispatch_ = 1
IDistributionRuleParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FactorCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FactorCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FactorDescription' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDistributionRulesParams_vtables_dispatch_ = 1
IDistributionRulesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{A91769F5-16B5-49A6-8305-A2DC6054206F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{A91769F5-16B5-49A6-8305-A2DC6054206F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDistributionRulesService_vtables_dispatch_ = 1
IDistributionRulesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddDistributionRule' , u'pIDistributionRule' , u'ppIDistributionRuleParams' , ), 10, (10, (), [ (9, 1, None, "IID('{FC2AB5F1-3242-42D2-985E-D23052C9834A}')") , 
			(16393, 10, None, "IID('{A91769F5-16B5-49A6-8305-A2DC6054206F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDistributionRule' , u'pIDistributionRule' , ), 11, (11, (), [ (9, 1, None, "IID('{FC2AB5F1-3242-42D2-985E-D23052C9834A}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteDistributionRule' , u'pIDistributionRuleParams' , ), 12, (12, (), [ (9, 1, None, "IID('{A91769F5-16B5-49A6-8305-A2DC6054206F}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetDistributionRule' , u'pIDistributionRuleParams' , u'ppIDistributionRule' , ), 13, (13, (), [ (9, 1, None, "IID('{A91769F5-16B5-49A6-8305-A2DC6054206F}')") , 
			(16393, 10, None, "IID('{FC2AB5F1-3242-42D2-985E-D23052C9834A}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetDistributionRuleList' , u'ppIDistributionRulesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{E5EB0192-6BCF-43FF-94E7-8A17C7F6B566}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDocumentChangeMenuName_vtables_dispatch_ = 1
IDocumentChangeMenuName_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ChangedMenuName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ChangedMenuName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IDocumentPackageItems_vtables_dispatch_ = 1
IDocumentPackageItems_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IDocumentPackages_vtables_dispatch_ = 1
IDocumentPackages_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Items' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{8E861D67-6E55-4201-9AE5-F193127E6F67}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TotalWeight' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Units' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Units' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IDocumentSeriesParams_vtables_dispatch_ = 1
IDocumentSeriesParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IDocumentSeriesUserParams_vtables_dispatch_ = 1
IDocumentSeriesUserParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'User' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'User' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IDocumentTypeParams_vtables_dispatch_ = 1
IDocumentTypeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IDocument_ApprovalRequests_vtables_dispatch_ = 1
IDocument_ApprovalRequests_vtables_ = [
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalTemplatesID' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IDocument_Installments_vtables_dispatch_ = 1
IDocument_Installments_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Percentage' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Percentage' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Total' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Total' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LastDunningDate' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DunningLevel' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DunningLevel' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TotalFC' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TotalFC' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'InstallmentId' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PaymentOrdered' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

IDocument_Lines_vtables_dispatch_ = 1
IDocument_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ShipDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ShipDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PriceAfterVAT' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PriceAfterVAT' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SerialNum' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SerialNum' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CommisionPercent' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CommisionPercent' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'TreeType' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'UseBaseUnits' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'UseBaseUnits' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'SupplierCatNum' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'SupplierCatNum' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'BarCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'BarCode' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Height1' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Height1' , u'pVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Hight1Unit' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Hight1Unit' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Height2' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Height2' , u'pVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Height2Unit' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Height2Unit' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Lengh1' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'Lengh1' , u'pVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'Lengh1Unit' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Lengh1Unit' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Lengh2' , u'pVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'Lengh2' , u'pVal' , ), 31, (31, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Lengh2Unit' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Lengh2Unit' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'Weight1' , u'pVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'Weight1' , u'pVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'Weight1Unit' , u'pVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'Weight1Unit' , u'pVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'Weight2' , u'pVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Weight2' , u'pVal' , ), 35, (35, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'Weight2Unit' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Weight2Unit' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'Factor1' , u'pVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'Factor1' , u'pVal' , ), 37, (37, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Factor2' , u'pVal' , ), 38, (38, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Factor2' , u'pVal' , ), 38, (38, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Factor3' , u'pVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'Factor3' , u'pVal' , ), 39, (39, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'Factor4' , u'pVal' , ), 40, (40, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'Factor4' , u'pVal' , ), 40, (40, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 41, (41, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'BaseEntry' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'BaseEntry' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'BaseLine' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'BaseLine' , u'pVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'Volume' , u'pVal' , ), 45, (45, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'Volume' , u'pVal' , ), 45, (45, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'VolumeUnit' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'VolumeUnit' , u'pVal' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 48, (48, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 49, (49, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'Width1' , u'pVal' , ), 50, (50, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'Width1' , u'pVal' , ), 50, (50, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'Width1Unit' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'Width1Unit' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'Width2' , u'pVal' , ), 52, (52, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'Width2' , u'pVal' , ), 52, (52, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'Width2Unit' , u'pVal' , ), 53, (53, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'Width2Unit' , u'pVal' , ), 53, (53, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'PickStatus' , u'pVal' , ), 58, (58, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'PickQuantity' , u'pVal' , ), 59, (59, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'PickListIdNumber' , u'pVal' , ), 60, (60, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'OriginalItem' , u'pVal' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'BackOrder' , u'pVal' , ), 62, (62, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'BackOrder' , u'pVal' , ), 62, (62, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'FreeText' , u'pVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'ShippingMethod' , u'pVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'ShippingMethod' , u'pVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'POTargetNum' , u'pVal' , ), 65, (65, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'POTargetEntry' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'POTargetRowNum' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumbers' , u'pVal' , ), 68, (68, (), [ (16393, 10, None, "IID('{93E5E52B-181E-46B8-96CB-1C066AC04DCA}')") , ], 1 , 2 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'BatchNumbers' , u'pVal' , ), 69, (69, (), [ (16393, 10, None, "IID('{1FEF5698-93E1-4167-AEA0-4BB151792623}')") , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'Expenses' , u'pVal' , ), 70, (70, (), [ (16393, 10, None, "IID('{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}')") , ], 1 , 2 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'CorrectionInvoiceItem' , u'pVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'CorrectionInvoiceItem' , u'pVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'CorrInvAmountToStock' , u'pVal' , ), 72, (72, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'CorrInvAmountToStock' , u'pVal' , ), 72, (72, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'CorrInvAmountToDiffAcct' , u'pVal' , ), 73, (73, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'CorrInvAmountToDiffAcct' , u'pVal' , ), 73, (73, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'AppliedTax' , u'pVal' , ), 74, (74, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'AppliedTaxFC' , u'pVal' , ), 75, (75, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'AppliedTaxSC' , u'pVal' , ), 76, (76, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 77, (77, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxPercent' , u'pVal' , ), 78, (78, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTaxFC' , u'pVal' , ), 79, (79, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTaxSC' , u'pVal' , ), 80, (80, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'NetTaxAmount' , u'pVal' , ), 81, (81, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'NetTaxAmountFC' , u'pVal' , ), 82, (82, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'NetTaxAmountSC' , u'pVal' , ), 83, (83, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 84, (84, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 84, (84, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercentagePerRow' , u'pVal' , ), 86, (86, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercentagePerRow' , u'pVal' , ), 86, (86, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotal' , u'pVal' , ), 87, (87, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 88, (88, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 88, (88, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTax' , u'pVal' , ), 89, (89, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'MeasureUnit' , u'pVal' , ), 90, (90, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'UnitsOfMeasurment' , u'pVal' , ), 91, (91, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'ExciseAmount' , u'pVal' , ), 92, (92, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'ExciseAmount' , u'pVal' , ), 92, (92, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'TaxPerUnit' , u'pVal' , ), 93, (93, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'TotalInclTax' , u'pVal' , ), 94, (94, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'CountryOrg' , u'pVal' , ), 95, (95, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'CountryOrg' , u'pVal' , ), 95, (95, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'SWW' , u'pVal' , ), 96, (96, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'SWW' , u'pVal' , ), 96, (96, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'ConsumerSalesForecast' , u'pVal' , ), 97, (97, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'ConsumerSalesForecast' , u'pVal' , ), 97, (97, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxLines' , u'ppRsltVal' , ), 98, (98, (), [ (16393, 10, None, "IID('{458A15A5-B980-4543-A289-F6477A36EB24}')") , ], 1 , 2 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'CFOPCode' , u'pbstrRsltVal' , ), 99, (99, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'CFOPCode' , u'pbstrRsltVal' , ), 99, (99, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'CSTCode' , u'pVal' , ), 100, (100, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'CSTCode' , u'pVal' , ), 100, (100, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'Usage' , u'pVal' , ), 101, (101, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'Usage' , u'pVal' , ), 101, (101, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'TaxOnly' , u'penumRsltVal' , ), 102, (102, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'TaxOnly' , u'penumRsltVal' , ), 102, (102, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'TaxBeforeDPM' , u'pVal' , ), 103, (103, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'TaxBeforeDPMFC' , u'pVal' , ), 104, (104, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'TaxBeforeDPMSC' , u'pVal' , ), 105, (105, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'TransactionType' , u'ppRsltVal' , ), 106, (106, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'TransactionType' , u'ppRsltVal' , ), 106, (106, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'DistributeExpense' , u'penumRsltVal' , ), 107, (107, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'DistributeExpense' , u'penumRsltVal' , ), 107, (107, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pbstrRsltVal' , ), 108, (108, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pbstrRsltVal' , ), 108, (108, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'RowTotalFC' , u'pdblRsltVal' , ), 109, (109, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'RowTotalFC' , u'pdblRsltVal' , ), 109, (109, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'RowTotalSC' , u'pdblRsltVal' , ), 110, (110, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'LastBuyInmPrice' , u'pdblRsltVal' , ), 111, (111, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'LastBuyDistributeSumFc' , u'pdblRsltVal' , ), 112, (112, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'LastBuyDistributeSumSc' , u'pdblRsltVal' , ), 113, (113, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'LastBuyDistributeSum' , u'pdblRsltVal' , ), 114, (114, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'StockDistributesumForeign' , u'pdblRsltVal' , ), 115, (115, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'StockDistributesumSystem' , u'pdblRsltVal' , ), 116, (116, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'StockDistributesum' , u'pdblRsltVal' , ), 117, (117, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'StockInmPrice' , u'pdblRsltVal' , ), 118, (118, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'PickStatusEx' , u'pVal' , ), 119, (119, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 120, (120, (), [ ], 1 , 1 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'pVal' , ), 121, (121, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'BaseOpenQuantity' , u'pVal' , ), 122, (122, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'UnitPrice' , u'pVal' , ), 123, (123, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'UnitPrice' , u'pVal' , ), 123, (123, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'LineStatus' , u'penumRsltVal' , ), 124, (124, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'LineStatus' , u'penumRsltVal' , ), 124, (124, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'PackageQuantity' , u'pVal' , ), 125, (125, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'Text' , u'pVal' , ), 126, (126, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 77, (77, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'LineType' , u'penumRsltVal' , ), 127, (127, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'LineType' , u'penumRsltVal' , ), 127, (127, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode' , u'pVal' , ), 128, (128, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode' , u'pVal' , ), 128, (128, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'COGSAccountCode' , u'pVal' , ), 129, (129, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'COGSAccountCode' , u'pVal' , ), 129, (129, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'ChangeAssemlyBoMWarehouse' , u'pVal' , ), 130, (130, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'ChangeAssemlyBoMWarehouse' , u'pVal' , ), 130, (130, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'NetTaxAmount' , u'pVal' , ), 81, (81, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'NetTaxAmountFC' , u'pVal' , ), 82, (82, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'ItemDetails' , u'pVal' , ), 131, (131, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'ItemDetails' , u'pVal' , ), 131, (131, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'ActualDeliveryDate' , u'pVal' , ), 132, (132, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'ActualDeliveryDate' , u'pVal' , ), 132, (132, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 133, (133, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 133, (133, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode2' , u'pVal' , ), 134, (134, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode2' , u'pVal' , ), 134, (134, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode3' , u'pVal' , ), 135, (135, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode3' , u'pVal' , ), 135, (135, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode4' , u'pVal' , ), 136, (136, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode4' , u'pVal' , ), 136, (136, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode5' , u'pVal' , ), 137, (137, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode5' , u'pVal' , ), 137, (137, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
	(( u'RemainingOpenQuantity' , u'pVal' , ), 138, (138, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 916 , (3, 0, None, None) , 0 , )),
	(( u'OpenAmount' , u'pVal' , ), 139, (139, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 920 , (3, 0, None, None) , 0 , )),
	(( u'OpenAmountFC' , u'pVal' , ), 140, (140, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 924 , (3, 0, None, None) , 0 , )),
	(( u'OpenAmountSC' , u'pVal' , ), 141, (141, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 928 , (3, 0, None, None) , 0 , )),
	(( u'MeasureUnit' , u'pVal' , ), 90, (90, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 932 , (3, 0, None, None) , 0 , )),
	(( u'UnitsOfMeasurment' , u'pVal' , ), 91, (91, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 936 , (3, 0, None, None) , 0 , )),
	(( u'GrossBuyPrice' , u'ppRsltVal' , ), 170, (170, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 940 , (3, 0, None, None) , 0 , )),
	(( u'GrossBuyPrice' , u'ppRsltVal' , ), 170, (170, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 944 , (3, 0, None, None) , 0 , )),
	(( u'GrossBase' , u'ppRsltVal' , ), 171, (171, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 948 , (3, 0, None, None) , 0 , )),
	(( u'GrossBase' , u'ppRsltVal' , ), 171, (171, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 952 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitTotalBasePrice' , u'ppRsltVal' , ), 172, (172, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 956 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitTotalBasePrice' , u'ppRsltVal' , ), 172, (172, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 960 , (3, 0, None, None) , 0 , )),
	(( u'ExLineNo' , u'pbstrRsltVal' , ), 173, (173, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 964 , (3, 0, None, None) , 0 , )),
	(( u'ExLineNo' , u'pbstrRsltVal' , ), 173, (173, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 968 , (3, 0, None, None) , 0 , )),
	(( u'TaxJurisdictions' , u'pVal' , ), 181, (181, (), [ (16393, 10, None, "IID('{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}')") , ], 1 , 2 , 4 , 0 , 972 , (3, 0, None, None) , 0 , )),
	(( u'RequiredDate' , u'pVal' , ), 182, (182, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 976 , (3, 0, None, None) , 0 , )),
	(( u'RequiredDate' , u'pVal' , ), 182, (182, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 980 , (3, 0, None, None) , 0 , )),
	(( u'RequiredQuantity' , u'pVal' , ), 183, (183, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 984 , (3, 0, None, None) , 0 , )),
	(( u'RequiredQuantity' , u'pVal' , ), 183, (183, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 988 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode2' , u'pVal' , ), 184, (184, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 992 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode2' , u'pVal' , ), 184, (184, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 996 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode3' , u'pVal' , ), 185, (185, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1000 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode3' , u'pVal' , ), 185, (185, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1004 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode4' , u'pVal' , ), 186, (186, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1008 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode4' , u'pVal' , ), 186, (186, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1012 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode5' , u'pVal' , ), 187, (187, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1016 , (3, 0, None, None) , 0 , )),
	(( u'COGSCostingCode5' , u'pVal' , ), 187, (187, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1020 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotal' , u'pVal' , ), 87, (87, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1024 , (3, 0, None, None) , 0 , )),
	(( u'CSTforIPI' , u'pVal' , ), 188, (188, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1028 , (3, 0, None, None) , 0 , )),
	(( u'CSTforIPI' , u'pVal' , ), 188, (188, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1032 , (3, 0, None, None) , 0 , )),
	(( u'CSTforPIS' , u'pVal' , ), 189, (189, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1036 , (3, 0, None, None) , 0 , )),
	(( u'CSTforPIS' , u'pVal' , ), 189, (189, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1040 , (3, 0, None, None) , 0 , )),
	(( u'CSTforCOFINS' , u'pVal' , ), 190, (190, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1044 , (3, 0, None, None) , 0 , )),
	(( u'CSTforCOFINS' , u'pVal' , ), 190, (190, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1048 , (3, 0, None, None) , 0 , )),
	(( u'CreditOriginCode' , u'pVal' , ), 191, (191, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1052 , (3, 0, None, None) , 0 , )),
	(( u'CreditOriginCode' , u'pVal' , ), 191, (191, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1056 , (3, 0, None, None) , 0 , )),
	(( u'WithoutInventoryMovement' , u'penumRsltVal' , ), 192, (192, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1060 , (3, 0, None, None) , 0 , )),
	(( u'WithoutInventoryMovement' , u'penumRsltVal' , ), 192, (192, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1064 , (3, 0, None, None) , 0 , )),
	(( u'AgreementNo' , u'ppRsltVal' , ), 193, (193, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1068 , (3, 0, None, None) , 0 , )),
	(( u'AgreementNo' , u'ppRsltVal' , ), 193, (193, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1072 , (3, 0, None, None) , 0 , )),
	(( u'AgreementRowNumber' , u'ppRsltVal' , ), 194, (194, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1076 , (3, 0, None, None) , 0 , )),
	(( u'AgreementRowNumber' , u'ppRsltVal' , ), 194, (194, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1080 , (3, 0, None, None) , 0 , )),
	(( u'ShipToDescription' , u'pVal' , ), 195, (195, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1084 , (3, 0, None, None) , 0 , )),
	(( u'ShipToDescription' , u'pVal' , ), 195, (195, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1088 , (3, 0, None, None) , 0 , )),
	(( u'ActualBaseEntry' , u'pVal' , ), 196, (196, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1092 , (3, 0, None, None) , 0 , )),
	(( u'ActualBaseEntry' , u'pVal' , ), 196, (196, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1096 , (3, 0, None, None) , 0 , )),
	(( u'ActualBaseLine' , u'pVal' , ), 197, (197, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1100 , (3, 0, None, None) , 0 , )),
	(( u'ActualBaseLine' , u'pVal' , ), 197, (197, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1104 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 198, (198, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1108 , (3, 0, None, None) , 0 , )),
	(( u'ImportProcesses' , u'ppipValue' , ), 199, (199, (), [ (16393, 10, None, "IID('{8A8F6C7B-BD55-45C5-A28C-C81A786B0EB8}')") , ], 1 , 2 , 4 , 0 , 1112 , (3, 0, None, None) , 0 , )),
	(( u'ExportProcesses' , u'ppepValue' , ), 200, (200, (), [ (16393, 10, None, "IID('{E3F9ACA7-17D5-4A5B-8AAF-91CB41E2896F}')") , ], 1 , 2 , 4 , 0 , 1116 , (3, 0, None, None) , 0 , )),
	(( u'Surpluses' , u'pVal' , ), 201, (201, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1120 , (3, 0, None, None) , 0 , )),
	(( u'Surpluses' , u'pVal' , ), 201, (201, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1124 , (3, 0, None, None) , 0 , )),
	(( u'DefectAndBreakup' , u'pVal' , ), 202, (202, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1128 , (3, 0, None, None) , 0 , )),
	(( u'DefectAndBreakup' , u'pVal' , ), 202, (202, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1132 , (3, 0, None, None) , 0 , )),
	(( u'Shortages' , u'pVal' , ), 203, (203, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1136 , (3, 0, None, None) , 0 , )),
	(( u'Shortages' , u'pVal' , ), 203, (203, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1140 , (3, 0, None, None) , 0 , )),
]

IDocument_LinesAdditionalExpenses_vtables_dispatch_ = 1
IDocument_LinesAdditionalExpenses_vtables_ = [
	(( u'LineNumber' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseCode' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseCode' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LineTotalFC' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LineTotalSys' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDate' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDateFC' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDateSys' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercent' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxSum' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxSumFC' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TaxSumSys' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSum' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSumFC' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSumSys' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'AquisitionTax' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaid' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaidFC' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaidSys' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxPercent' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxSum' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxFC' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxSys' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSum' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSumFC' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSumSys' , u'pVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 100, (100, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 101, (101, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 102, (102, (), [ ], 1 , 1 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 104, (104, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BaseGroup' , u'plVal' , ), 105, (105, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'BaseGroup' , u'plVal' , ), 105, (105, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 106, (106, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 106, (106, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 103, (103, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pVal' , ), 107, (107, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pVal' , ), 107, (107, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'TaxJurisdictions' , u'pVal' , ), 121, (121, (), [ (16393, 10, None, "IID('{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}')") , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 122, (122, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 122, (122, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 123, (123, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 123, (123, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 124, (124, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 124, (124, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 125, (125, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 125, (125, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 126, (126, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 126, (126, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'TaxSum' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
]

IDocument_SpecialLines_vtables_dispatch_ = 1
IDocument_SpecialLines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AfterLineNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AfterLineNumber' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'OrderNumber' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LineType' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'LineType' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Subtotal' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LineText' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LineText' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SubtotalFC' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SubtotalSC' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmount' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmountFC' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmountSC' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Freight1' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Freight1FC' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Freight1SC' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Freight2' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Freight2FC' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Freight2SC' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Freight3' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Freight3FC' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Freight3SC' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'GrossTotal' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'GrossTotalFC' , u'pVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'GrossTotalSC' , u'pVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
]

IDocuments_vtables_dispatch_ = 1
IDocuments_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{248B28DD-1281-4C6C-9780-22D19BA13D1F}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DocDueDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocDueDate' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'NumAtCard' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'NumAtCard' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DocTotal' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DocTotal' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'PaymentGroupCode' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'PaymentGroupCode' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DocTime' , u'pVal' , ), 21, (21, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DocTime' , u'pVal' , ), 21, (21, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'TransportationCode' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'TransportationCode' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Confirmed' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Confirmed' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'ImportFileNum' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'SummeryType' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'SummeryType' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ShowSCN' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ShowSCN' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 31, (31, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 31, (31, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'PartialSupply' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'PartialSupply' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AbsEntry' , u'Found' , ), 35, (35, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 37, (37, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 38, (38, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 48, (48, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 49, (49, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 49, (49, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReference' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 52, (52, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 53, (53, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'FinancialPeriod' , u'pVal' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'TransNum' , u'pVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'VatSum' , u'pVal' , ), 56, (56, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'VatSumSys' , u'pVal' , ), 57, (57, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'VatSumFc' , u'pVal' , ), 58, (58, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'NetProcedure' , u'pVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'DocTotalFc' , u'pVal' , ), 60, (60, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'DocTotalSys' , u'pVal' , ), 61, (61, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'Form1099' , u'pVal' , ), 62, (62, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'Form1099' , u'pVal' , ), 62, (62, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'Box1099' , u'pVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'RevisionPo' , u'pVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'RevisionPo' , u'pVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'RequriedDate' , u'pVal' , ), 65, (65, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'RequriedDate' , u'pVal' , ), 65, (65, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'CancelDate' , u'pVal' , ), 66, (66, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'CancelDate' , u'pVal' , ), 66, (66, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunning' , u'pVal' , ), 67, (67, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunning' , u'pVal' , ), 67, (67, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'Submitted' , u'pVal' , ), 68, (68, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'Segment' , u'pVal' , ), 69, (69, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'PickStatus' , u'pVal' , ), 70, (70, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'Pick' , u'pVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethod' , u'pVal' , ), 72, (72, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethod' , u'pVal' , ), 72, (72, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 73, (73, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockEntry' , u'pVal' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockEntry' , u'pVal' , ), 74, (74, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'CentralBankIndicator' , u'pVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'CentralBankIndicator' , u'pVal' , ), 75, (75, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'MaximumCashDiscount' , u'pVal' , ), 76, (76, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'MaximumCashDiscount' , u'pVal' , ), 76, (76, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'Reserve' , u'pVal' , ), 77, (77, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pVal' , ), 78, (78, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pVal' , ), 78, (78, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateFrom' , u'pVal' , ), 80, (80, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateFrom' , u'pVal' , ), 80, (80, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateTo' , u'pVal' , ), 81, (81, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionValidityDateTo' , u'pVal' , ), 81, (81, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'WareHouseUpdateType' , u'pVal' , ), 82, (82, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'WareHouseUpdateType' , u'pVal' , ), 82, (82, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'Expenses' , u'pVal' , ), 83, (83, (), [ (16393, 10, None, "IID('{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}')") , ], 1 , 2 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'Rounding' , u'pVal' , ), 84, (84, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'Rounding' , u'pVal' , ), 84, (84, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCorrectedDocNum' , u'pVal' , ), 89, (89, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'ExternalCorrectedDocNum' , u'pVal' , ), 89, (89, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'InternalCorrectedDocNum' , u'pVal' , ), 90, (90, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'InternalCorrectedDocNum' , u'pVal' , ), 90, (90, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'NextCorrectingDocument' , u'pVal' , ), 91, (91, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 92, (92, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTax' , u'pVal' , ), 92, (92, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptionLetterNum' , u'pVal' , ), 93, (93, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptionLetterNum' , u'pVal' , ), 93, (93, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'WTApplied' , u'pVal' , ), 94, (94, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'WTAppliedFC' , u'pVal' , ), 95, (95, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeReserved' , u'pVal' , ), 96, (96, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'AgentCode' , u'pVal' , ), 97, (97, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'AgentCode' , u'pVal' , ), 97, (97, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'WTAppliedSC' , u'pVal' , ), 98, (98, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTax' , u'pVal' , ), 99, (99, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTaxFC' , u'pVal' , ), 100, (100, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'TotalEqualizationTaxSC' , u'pVal' , ), 101, (101, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfInstallments' , u'pVal' , ), 102, (102, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfInstallments' , u'pVal' , ), 102, (102, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'ApplyTaxOnFirstInstallment' , u'pVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'ApplyTaxOnFirstInstallment' , u'pVal' , ), 103, (103, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'WTNonSubjectAmount' , u'pVal' , ), 104, (104, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'WTNonSubjectAmountSC' , u'pVal' , ), 105, (105, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'WTNonSubjectAmountFC' , u'pVal' , ), 106, (106, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'WTExemptedAmount' , u'pVal' , ), 107, (107, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'WTExemptedAmountSC' , u'pVal' , ), 108, (108, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'WTExemptedAmountFC' , u'pVal' , ), 109, (109, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'BaseAmountSC' , u'pVal' , ), 110, (110, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'BaseAmountFC' , u'pVal' , ), 111, (111, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 112, (112, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSC' , u'pVal' , ), 113, (113, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'BaseAmount' , u'pVal' , ), 114, (114, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 115, (115, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 116, (116, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 116, (116, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'ManualNumber' , u'pVal' , ), 117, (117, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'ManualNumber' , u'pVal' , ), 117, (117, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'UseShpdGoodsAct' , u'pVal' , ), 118, (118, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'UseShpdGoodsAct' , u'pVal' , ), 118, (118, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'FolioNumber' , u'pVal' , ), 119, (119, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'FolioNumber' , u'pVal' , ), 119, (119, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pVal' , ), 120, (120, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pVal' , ), 120, (120, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelCode' , u'pVal' , ), 121, (121, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelCode' , u'pVal' , ), 121, (121, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 122, (122, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 122, (122, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxData' , u'ppRsltVal' , ), 123, (123, (), [ (16393, 10, None, "IID('{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}')") , ], 1 , 2 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCodeEx' , u'pVal' , ), 124, (124, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCodeEx' , u'pVal' , ), 124, (124, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'Address2' , u'pVal' , ), 125, (125, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'Address2' , u'pVal' , ), 125, (125, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'DocumentStatus' , u'pVal' , ), 126, (126, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'PeriodIndicator' , u'pVal' , ), 127, (127, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'PayToCode' , u'pVal' , ), 129, (129, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'PayToCode' , u'pVal' , ), 129, (129, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'DocumentsOwner' , u'pVal' , ), 130, (130, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'DocumentsOwner' , u'pVal' , ), 130, (130, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'FolioPrefixString' , u'pVal' , ), 131, (131, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'FolioPrefixString' , u'pVal' , ), 131, (131, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'IsPayToBank' , u'pVal' , ), 132, (132, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'IsPayToBank' , u'pVal' , ), 132, (132, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCountry' , u'pVal' , ), 133, (133, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCountry' , u'pVal' , ), 133, (133, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCode' , u'pVal' , ), 134, (134, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCode' , u'pVal' , ), 134, (134, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankAccountNo' , u'pVal' , ), 135, (135, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankAccountNo' , u'pVal' , ), 135, (135, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankBranch' , u'pVal' , ), 136, (136, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankBranch' , u'pVal' , ), 136, (136, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 137, (137, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 138, (138, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'PaymentReference' , u'pVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'BPL_IDAssignedToInvoice' , u'pVal' , ), 139, (139, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'BPL_IDAssignedToInvoice' , u'pVal' , ), 139, (139, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 140, (140, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 140, (140, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'SequenceSerial' , u'pVal' , ), 141, (141, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'SequenceSerial' , u'pVal' , ), 141, (141, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'SequenceCode' , u'pVal' , ), 142, (142, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'SequenceCode' , u'pVal' , ), 142, (142, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'SeriesString' , u'pVal' , ), 143, (143, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'SeriesString' , u'pVal' , ), 143, (143, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'SubSeriesString' , u'pVal' , ), 144, (144, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'SubSeriesString' , u'pVal' , ), 144, (144, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'SequenceModel' , u'pVal' , ), 145, (145, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'SequenceModel' , u'pVal' , ), 145, (145, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'TaxExtension' , u'ppRsltVal' , ), 146, (146, (), [ (16393, 10, None, "IID('{8CC29ECE-02C3-4C7B-851B-5533D2C83627}')") , ], 1 , 2 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'DownPayment' , u'pdblRsltVal' , ), 147, (147, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'DownPayment' , u'pdblRsltVal' , ), 147, (147, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'ReserveInvoice' , u'penumRsltVal' , ), 148, (148, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 149, (149, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 149, (149, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'TrackingNumber' , u'pbstrRsltVal' , ), 150, (150, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'TrackingNumber' , u'pbstrRsltVal' , ), 150, (150, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
	(( u'PickRemark' , u'pbstrRsltVal' , ), 151, (151, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 916 , (3, 0, None, None) , 0 , )),
	(( u'PickRemark' , u'pbstrRsltVal' , ), 151, (151, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 920 , (3, 0, None, None) , 0 , )),
	(( u'ImportFileNum' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 924 , (3, 0, None, None) , 0 , )),
	(( u'UseCorrectionVATGroup' , u'pVal' , ), 152, (152, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 928 , (3, 0, None, None) , 0 , )),
	(( u'UseCorrectionVATGroup' , u'pVal' , ), 152, (152, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 932 , (3, 0, None, None) , 0 , )),
	(( u'TotalDiscount' , u'pVal' , ), 153, (153, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 936 , (3, 0, None, None) , 0 , )),
	(( u'Pick' , u'pVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 940 , (3, 0, None, None) , 0 , )),
	(( u'VatPercent' , u'pVal' , ), 154, (154, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 944 , (3, 0, None, None) , 0 , )),
	(( u'VatPercent' , u'pVal' , ), 154, (154, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 948 , (3, 0, None, None) , 0 , )),
	(( u'Packages' , u'pVal' , ), 155, (155, (), [ (16393, 10, None, "IID('{07F27714-4BA9-42E3-8E93-3418F73C55E4}')") , ], 1 , 2 , 4 , 0 , 952 , (3, 0, None, None) , 0 , )),
	(( u'Installments' , u'pVal' , ), 156, (156, (), [ (16393, 10, None, "IID('{3E64E5EC-70CA-4129-BC06-0CE9B2058843}')") , ], 1 , 2 , 4 , 0 , 956 , (3, 0, None, None) , 0 , )),
	(( u'SpecialLines' , u'pVal' , ), 157, (157, (), [ (16393, 10, None, "IID('{6ECD0990-1D31-4DDF-AF93-494A9DD7A104}')") , ], 1 , 2 , 4 , 0 , 960 , (3, 0, None, None) , 0 , )),
	(( u'ReserveInvoice' , u'penumRsltVal' , ), 148, (148, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 964 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentAmount' , u'pdblRsltVal' , ), 158, (158, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 968 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentPercentage' , u'pdblRsltVal' , ), 159, (159, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 972 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentPercentage' , u'pdblRsltVal' , ), 159, (159, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 976 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentType' , u'pVal' , ), 160, (160, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 980 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentType' , u'pVal' , ), 160, (160, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 984 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentsToDraw' , u'pVal' , ), 161, (161, (), [ (16393, 10, None, "IID('{DFF94208-9A06-4594-992D-8D758D296BD4}')") , ], 1 , 2 , 4 , 0 , 988 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentAmountFC' , u'pdblRsltVal' , ), 162, (162, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 992 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentAmountSC' , u'pdblRsltVal' , ), 163, (163, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 996 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentAmount' , u'pdblRsltVal' , ), 158, (158, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1000 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentAmountFC' , u'pdblRsltVal' , ), 162, (162, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1004 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentAmountSC' , u'pdblRsltVal' , ), 163, (163, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1008 , (3, 0, None, None) , 0 , )),
	(( u'OpeningRemarks' , u'pVal' , ), 164, (164, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1012 , (3, 0, None, None) , 0 , )),
	(( u'OpeningRemarks' , u'pVal' , ), 164, (164, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1016 , (3, 0, None, None) , 0 , )),
	(( u'ClosingRemarks' , u'pVal' , ), 165, (165, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1020 , (3, 0, None, None) , 0 , )),
	(( u'ClosingRemarks' , u'pVal' , ), 165, (165, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1024 , (3, 0, None, None) , 0 , )),
	(( u'RoundingDiffAmount' , u'pVal' , ), 166, (166, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1028 , (3, 0, None, None) , 0 , )),
	(( u'RoundingDiffAmount' , u'pVal' , ), 166, (166, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1032 , (3, 0, None, None) , 0 , )),
	(( u'RoundingDiffAmountFC' , u'pVal' , ), 167, (167, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1036 , (3, 0, None, None) , 0 , )),
	(( u'RoundingDiffAmountSC' , u'pVal' , ), 168, (168, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1040 , (3, 0, None, None) , 0 , )),
	(( u'Cancelled' , u'pVal' , ), 169, (169, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1044 , (3, 0, None, None) , 0 , )),
	(( u'Reopen' , u'ooErr' , ), 171, (171, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 1048 , (3, 0, None, None) , 0 , )),
	(( u'InsuranceOperation347' , u'pVal' , ), 170, (170, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1052 , (3, 0, None, None) , 0 , )),
	(( u'InsuranceOperation347' , u'pVal' , ), 170, (170, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1056 , (3, 0, None, None) , 0 , )),
	(( u'DocTotalFc' , u'pVal' , ), 60, (60, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1060 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1064 , (3, 0, None, None) , 0 , )),
	(( u'ServiceGrossProfitPercent' , u'ppRsltVal' , ), 172, (172, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1068 , (3, 0, None, None) , 0 , )),
	(( u'ServiceGrossProfitPercent' , u'ppRsltVal' , ), 172, (172, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1072 , (3, 0, None, None) , 0 , )),
	(( u'AddressExtension' , u'ppRsltVal' , ), 173, (173, (), [ (16393, 10, None, "IID('{7CBD5DDC-C99C-4D73-9ECC-C8B6CDF2FB92}')") , ], 1 , 2 , 4 , 0 , 1076 , (3, 0, None, None) , 0 , )),
	(( u'ControlAccount' , u'pVal' , ), 174, (174, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1080 , (3, 0, None, None) , 0 , )),
	(( u'ControlAccount' , u'pVal' , ), 174, (174, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1084 , (3, 0, None, None) , 0 , )),
	(( u'ArchiveNonremovableSalesQuotation' , u'pVal' , ), 175, (175, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1088 , (3, 0, None, None) , 0 , )),
	(( u'ArchiveNonremovableSalesQuotation' , u'pVal' , ), 175, (175, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1092 , (3, 0, None, None) , 0 , )),
	(( u'GTSChecker' , u'pVal' , ), 176, (176, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1096 , (3, 0, None, None) , 0 , )),
	(( u'GTSChecker' , u'pVal' , ), 176, (176, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1100 , (3, 0, None, None) , 0 , )),
	(( u'GTSPayee' , u'pVal' , ), 177, (177, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1104 , (3, 0, None, None) , 0 , )),
	(( u'GTSPayee' , u'pVal' , ), 177, (177, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1108 , (3, 0, None, None) , 0 , )),
	(( u'ExtraMonth' , u'pVal' , ), 178, (178, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1112 , (3, 0, None, None) , 0 , )),
	(( u'ExtraMonth' , u'pVal' , ), 178, (178, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1116 , (3, 0, None, None) , 0 , )),
	(( u'ExtraDays' , u'pVal' , ), 179, (179, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1120 , (3, 0, None, None) , 0 , )),
	(( u'ExtraDays' , u'pVal' , ), 179, (179, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1124 , (3, 0, None, None) , 0 , )),
	(( u'CashDiscountDateOffset' , u'pVal' , ), 180, (180, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1128 , (3, 0, None, None) , 0 , )),
	(( u'CashDiscountDateOffset' , u'pVal' , ), 180, (180, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1132 , (3, 0, None, None) , 0 , )),
	(( u'StartFrom' , u'pVal' , ), 181, (181, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1136 , (3, 0, None, None) , 0 , )),
	(( u'StartFrom' , u'pVal' , ), 181, (181, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1140 , (3, 0, None, None) , 0 , )),
	(( u'NTSApproved' , u'pVal' , ), 182, (182, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1144 , (3, 0, None, None) , 0 , )),
	(( u'NTSApproved' , u'pVal' , ), 182, (182, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1148 , (3, 0, None, None) , 0 , )),
	(( u'ETaxWebSite' , u'pVal' , ), 183, (183, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1152 , (3, 0, None, None) , 0 , )),
	(( u'ETaxWebSite' , u'pVal' , ), 183, (183, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1156 , (3, 0, None, None) , 0 , )),
	(( u'ETaxNumber' , u'pVal' , ), 184, (184, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1160 , (3, 0, None, None) , 0 , )),
	(( u'ETaxNumber' , u'pVal' , ), 184, (184, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1164 , (3, 0, None, None) , 0 , )),
	(( u'NTSApprovedNumber' , u'pVal' , ), 185, (185, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1168 , (3, 0, None, None) , 0 , )),
	(( u'NTSApprovedNumber' , u'pVal' , ), 185, (185, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1172 , (3, 0, None, None) , 0 , )),
	(( u'SignatureInputMessage' , u'pVal' , ), 186, (186, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1176 , (3, 0, None, None) , 0 , )),
	(( u'SignatureDigest' , u'pVal' , ), 187, (187, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1180 , (3, 0, None, None) , 0 , )),
	(( u'CertificationNumber' , u'pVal' , ), 188, (188, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1184 , (3, 0, None, None) , 0 , )),
	(( u'PrivateKeyVersion' , u'pVal' , ), 189, (189, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1188 , (3, 0, None, None) , 0 , )),
	(( u'GroupSeries' , u'pVal' , ), 190, (190, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1192 , (3, 0, None, None) , 0 , )),
	(( u'GroupSeries' , u'pVal' , ), 190, (190, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1196 , (3, 0, None, None) , 0 , )),
	(( u'GroupNumber' , u'pVal' , ), 191, (191, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1200 , (3, 0, None, None) , 0 , )),
	(( u'GroupNumber' , u'pVal' , ), 191, (191, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1204 , (3, 0, None, None) , 0 , )),
	(( u'GroupHandWritten' , u'pVal' , ), 192, (192, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1208 , (3, 0, None, None) , 0 , )),
	(( u'GroupHandWritten' , u'pVal' , ), 192, (192, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1212 , (3, 0, None, None) , 0 , )),
	(( u'ReopenOriginalDocument' , u'pVal' , ), 193, (193, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1216 , (3, 0, None, None) , 0 , )),
	(( u'ReopenOriginalDocument' , u'pVal' , ), 193, (193, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1220 , (3, 0, None, None) , 0 , )),
	(( u'ReopenManuallyClosedOrCanceledDocument' , u'pVal' , ), 194, (194, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1224 , (3, 0, None, None) , 0 , )),
	(( u'ReopenManuallyClosedOrCanceledDocument' , u'pVal' , ), 194, (194, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1228 , (3, 0, None, None) , 0 , )),
	(( u'EDocGenerationType' , u'penumRsltVal' , ), 195, (195, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1232 , (3, 0, None, None) , 0 , )),
	(( u'EDocGenerationType' , u'penumRsltVal' , ), 195, (195, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1236 , (3, 0, None, None) , 0 , )),
	(( u'EDocSeries' , u'pVal' , ), 196, (196, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1240 , (3, 0, None, None) , 0 , )),
	(( u'EDocSeries' , u'pVal' , ), 196, (196, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1244 , (3, 0, None, None) , 0 , )),
	(( u'EDocNum' , u'pVal' , ), 197, (197, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1248 , (3, 0, None, None) , 0 , )),
	(( u'EDocExportFormat' , u'pVal' , ), 198, (198, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1252 , (3, 0, None, None) , 0 , )),
	(( u'EDocExportFormat' , u'pVal' , ), 198, (198, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1256 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentStatus' , u'pVal' , ), 199, (199, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1260 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentStatus' , u'pVal' , ), 199, (199, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1264 , (3, 0, None, None) , 0 , )),
	(( u'CreateOnlineQuotation' , u'pVal' , ), 200, (200, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1268 , (3, 0, None, None) , 0 , )),
	(( u'CreateOnlineQuotation' , u'pVal' , ), 200, (200, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1272 , (3, 0, None, None) , 0 , )),
	(( u'POSEquipmentNumber' , u'pVal' , ), 201, (201, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1276 , (3, 0, None, None) , 0 , )),
	(( u'POSEquipmentNumber' , u'pVal' , ), 201, (201, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1280 , (3, 0, None, None) , 0 , )),
	(( u'POSManufacturerSerialNumber' , u'pVal' , ), 202, (202, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1284 , (3, 0, None, None) , 0 , )),
	(( u'POSManufacturerSerialNumber' , u'pVal' , ), 202, (202, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1288 , (3, 0, None, None) , 0 , )),
	(( u'POSCashierNumber' , u'pVal' , ), 203, (203, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1292 , (3, 0, None, None) , 0 , )),
	(( u'POSCashierNumber' , u'pVal' , ), 203, (203, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1296 , (3, 0, None, None) , 0 , )),
	(( u'ApplyCurrentVATRatesForDownPaymentsToDraw' , u'pVal' , ), 204, (204, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1300 , (3, 0, None, None) , 0 , )),
	(( u'ApplyCurrentVATRatesForDownPaymentsToDraw' , u'pVal' , ), 204, (204, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1304 , (3, 0, None, None) , 0 , )),
	(( u'ClosingOption' , u'pVal' , ), 210, (210, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1308 , (3, 0, None, None) , 0 , )),
	(( u'ClosingOption' , u'pVal' , ), 210, (210, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1312 , (3, 0, None, None) , 0 , )),
	(( u'SpecifiedClosingDate' , u'pVal' , ), 211, (211, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 1316 , (3, 0, None, None) , 0 , )),
	(( u'SpecifiedClosingDate' , u'pVal' , ), 211, (211, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 1320 , (3, 0, None, None) , 0 , )),
	(( u'OpenForLandedCosts' , u'pVal' , ), 212, (212, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1324 , (3, 0, None, None) , 0 , )),
	(( u'OpenForLandedCosts' , u'pVal' , ), 212, (212, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1328 , (3, 0, None, None) , 0 , )),
	(( u'SaveDraftToDocument' , u'ooErr' , ), 213, (213, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 1332 , (3, 0, None, None) , 0 , )),
	(( u'GetApprovalTemplates' , u'ooErr' , ), 214, (214, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 1336 , (3, 0, None, None) , 0 , )),
	(( u'Document_ApprovalRequests' , u'pVal' , ), 215, (215, (), [ (16393, 10, None, "IID('{CEDAC9E2-A77F-4518-A524-1403050FFD3D}')") , ], 1 , 2 , 4 , 0 , 1340 , (3, 0, None, None) , 0 , )),
	(( u'AuthorizationStatus' , u'pVal' , ), 216, (216, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1344 , (3, 0, None, None) , 0 , )),
	(( u'UpdateFromXML' , u'FileName' , u'ooErr' , ), 217, (217, (), [ (8, 1, None, None) , 
			(16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 1348 , (3, 0, None, None) , 0 , )),
	(( u'TotalDiscountFC' , u'pVal' , ), 218, (218, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1352 , (3, 0, None, None) , 0 , )),
	(( u'TotalDiscountSC' , u'pVal' , ), 219, (219, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1356 , (3, 0, None, None) , 0 , )),
	(( u'RelevantToGTS' , u'pVal' , ), 220, (220, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1360 , (3, 0, None, None) , 0 , )),
	(( u'RelevantToGTS' , u'pVal' , ), 220, (220, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1364 , (3, 0, None, None) , 0 , )),
	(( u'EDocStatus' , u'pVal' , ), 221, (221, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1368 , (3, 0, None, None) , 0 , )),
	(( u'EDocStatus' , u'pVal' , ), 221, (221, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1372 , (3, 0, None, None) , 0 , )),
	(( u'EDocErrorCode' , u'pVal' , ), 222, (222, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1376 , (3, 0, None, None) , 0 , )),
	(( u'EDocErrorCode' , u'pVal' , ), 222, (222, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1380 , (3, 0, None, None) , 0 , )),
	(( u'EDocErrorMessage' , u'pVal' , ), 223, (223, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1384 , (3, 0, None, None) , 0 , )),
	(( u'EDocErrorMessage' , u'pVal' , ), 223, (223, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1388 , (3, 0, None, None) , 0 , )),
	(( u'BPLName' , u'pVal' , ), 224, (224, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1392 , (3, 0, None, None) , 0 , )),
	(( u'VATRegNum' , u'pVal' , ), 225, (225, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1396 , (3, 0, None, None) , 0 , )),
	(( u'AnnualInvoiceDeclarationReference' , u'pVal' , ), 226, (226, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1400 , (3, 0, None, None) , 0 , )),
	(( u'AnnualInvoiceDeclarationReference' , u'pVal' , ), 226, (226, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1404 , (3, 0, None, None) , 0 , )),
	(( u'Supplier' , u'pVal' , ), 227, (227, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1408 , (3, 0, None, None) , 0 , )),
	(( u'Supplier' , u'pVal' , ), 227, (227, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1412 , (3, 0, None, None) , 0 , )),
	(( u'Releaser' , u'pVal' , ), 228, (228, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1416 , (3, 0, None, None) , 0 , )),
	(( u'Releaser' , u'pVal' , ), 228, (228, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1420 , (3, 0, None, None) , 0 , )),
	(( u'Receiver' , u'pVal' , ), 229, (229, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1424 , (3, 0, None, None) , 0 , )),
	(( u'Receiver' , u'pVal' , ), 229, (229, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1428 , (3, 0, None, None) , 0 , )),
	(( u'BlanketAgreementNumber' , u'pVal' , ), 230, (230, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1432 , (3, 0, None, None) , 0 , )),
	(( u'BlanketAgreementNumber' , u'pVal' , ), 230, (230, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1436 , (3, 0, None, None) , 0 , )),
	(( u'IsAlteration' , u'pVal' , ), 231, (231, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1440 , (3, 0, None, None) , 0 , )),
	(( u'IsAlteration' , u'pVal' , ), 231, (231, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1444 , (3, 0, None, None) , 0 , )),
]

IDocumentsAdditionalExpenses_vtables_dispatch_ = 1
IDocumentsAdditionalExpenses_vtables_ = [
	(( u'Count' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseCode' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseCode' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LineTotalFC' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LineTotalSys' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDate' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDateFC' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PaidToDateSys' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'DistributionMethod' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DistributionMethod' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxLiable' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxPercent' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TaxSum' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TaxSumFC' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'TaxSumSys' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSum' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSum' , u'pVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSumFC' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DeductibleTaxSumSys' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'AquisitionTax' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaid' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaidFC' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'TaxPaidSys' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxPercent' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxSum' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxFC' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxSys' , u'pVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSum' , u'pVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSumFC' , u'pVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotalSumSys' , u'pVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 35, (35, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocumentReference' , u'plRsltVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'plRsltVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'LastPurchasePrice' , u'penumRsltVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'LastPurchasePrice' , u'penumRsltVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Stock' , u'penumRsltVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'Stock' , u'penumRsltVal' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'TargetAbsEntry' , u'plRsltVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'TargetType' , u'plRsltVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'penumRsltVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'penumRsltVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'TaxJurisdictions' , u'pVal' , ), 61, (61, (), [ (16393, 10, None, "IID('{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}')") , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 64, (64, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'TaxSum' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
]

IDownPaymentsToDraw_vtables_dispatch_ = 1
IDownPaymentsToDraw_vtables_ = [
	(( u'SetCurrentLine' , u'LineNum' , ), 1, (1, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDraw' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDraw' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentType' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDrawFC' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDrawFC' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDrawSC' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDrawSC' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 19, (19, (), [ ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'RowNum' , u'plRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DocNumber' , u'plRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Tax' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxFC' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TaxSC' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDraw' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDraw' , u'pVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDrawFC' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDrawFC' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDrawSC' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDrawSC' , u'pVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'IsGrossLine' , u'penumRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentsToDrawDetails' , u'pVal' , ), 29, (29, (), [ (16393, 10, None, "IID('{A177F24C-3E47-498B-9013-8CC3EEC13F78}')") , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DocInternalID' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
]

IDownPaymentsToDrawDetails_vtables_dispatch_ = 1
IDownPaymentsToDrawDetails_vtables_ = [
	(( u'SetCurrentLine' , u'LineNum' , ), 1, (1, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'RowNum' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'RowNum' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SeqNum' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'VatGroupCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'VatGroupCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'VatPercent' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDraw' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDraw' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDrawFC' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDrawFC' , u'pVal' , ), 9, (9, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDrawSC' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AmountToDrawSC' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Tax' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxFC' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxSC' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'IsGrossLine' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDraw' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDraw' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDrawFC' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDrawFC' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDrawSC' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmountToDrawSC' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'LineType' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DocInternalID' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Tax' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TaxFC' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'TaxSC' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'TaxAdjust' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
]

IDunningLetters_vtables_dispatch_ = 1
IDunningLetters_vtables_ = [
	(( u'FeeCurrency' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'FeeCurrency' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LetterFormat' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LetterFormat' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Effectiveafter' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Effectiveafter' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalanceCurrency' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalanceCurrency' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Feeperletter' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Feeperletter' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CalcInterest' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CalcInterest' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalance' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalance' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 12, (12, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 13, (13, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 17, (17, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
]

IDunningTerm_vtables_dispatch_ = 1
IDunningTerm_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GroupingMethod' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GroupingMethod' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DaysInYear' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DaysInYear' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DaysInMonth' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'DaysInMonth' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CalculateInterestMethod' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CalculateInterestMethod' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateSelect' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateSelect' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'YearlyInterestRate' , u'ppRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'YearlyInterestRate' , u'ppRsltVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'LetterFee' , u'ppRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'LetterFee' , u'ppRsltVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'LetterFeeCurrency' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'LetterFeeCurrency' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalance' , u'ppRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalance' , u'ppRsltVal' , ), 20, (20, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalanceCurrency' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'MinimumBalanceCurrency' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'IncludeInterest' , u'penumRsltVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'IncludeInterest' , u'penumRsltVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ApplyHighestLetterTemplate' , u'penumRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ApplyHighestLetterTemplate' , u'penumRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DunningTermLines' , u'ppRsltVal' , ), 24, (24, (), [ (16393, 10, None, "IID('{831AB766-3423-4E64-8EB1-42614102CDC7}')") , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'AutomaticPosting' , u'penumRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'AutomaticPosting' , u'penumRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'InterestAccount' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'InterestAccount' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'FeeAccount' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'FeeAccount' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BaseDateSelect' , u'penumRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'BaseDateSelect' , u'penumRsltVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
]

IDunningTermLine_vtables_dispatch_ = 1
IDunningTermLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LevelNum' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LetterFormat' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LetterFormat' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Effectiveafter' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Effectiveafter' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LetterFee' , u'ppRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LetterFee' , u'ppRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LetterFeeCurrency' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LetterFeeCurrency' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MininumBalance' , u'ppRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MininumBalance' , u'ppRsltVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'MininumBalanceCurrency' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'MininumBalanceCurrency' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CalculateInterest' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'CalculateInterest' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IDunningTermLines_vtables_dispatch_ = 1
IDunningTermLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{D7B39E88-0C6D-4B8A-A083-AEC336746884}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{D7B39E88-0C6D-4B8A-A083-AEC336746884}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDunningTermParams_vtables_dispatch_ = 1
IDunningTermParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDunningTermsParams_vtables_dispatch_ = 1
IDunningTermsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IDunningTermsService_vtables_dispatch_ = 1
IDunningTermsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddDunningTerm' , u'pIDunningTerm' , u'ppIDunningTermParams' , ), 10, (10, (), [ (9, 1, None, "IID('{43A00E70-9D54-4A08-BE46-BD22286DF8EB}')") , 
			(16393, 10, None, "IID('{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDunningTerm' , u'pIDunningTerm' , ), 11, (11, (), [ (9, 1, None, "IID('{43A00E70-9D54-4A08-BE46-BD22286DF8EB}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteDunningTerm' , u'pIDunningTermParams' , ), 12, (12, (), [ (9, 1, None, "IID('{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetDunningTerm' , u'pIDunningTermParams' , u'ppIDunningTerm' , ), 13, (13, (), [ (9, 1, None, "IID('{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}')") , 
			(16393, 10, None, "IID('{43A00E70-9D54-4A08-BE46-BD22286DF8EB}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetDunningTermList' , u'ppIDunningTermsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{E0E5F6AB-18E3-45F8-A9DA-D2AB88B08A54}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IDynamicSystemStrings_vtables_dispatch_ = 1
IDynamicSystemStrings_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrFormId' , u'bstrItemNum' , u'bstrColNum' , u'pbRsltFound' , 
			), 6, (6, (), [ (8, 1, None, None) , (8, 1, None, None) , (8, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FormID' , u'pbstrRsltVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FormID' , u'pbstrRsltVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemID' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ItemID' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ColumnID' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ColumnID' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ItemString' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ItemString' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'IsBold' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'IsBold' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'IsItalics' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'IsItalics' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
]

IElectronicFileFormat_vtables_dispatch_ = 1
IElectronicFileFormat_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FormatID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Version' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SchemaVersion' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'OutputFilePath' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'MenuName' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'MenuPath' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IElectronicFileFormatParams_vtables_dispatch_ = 1
IElectronicFileFormatParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FormatID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FormatID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IElectronicFileFormatsParams_vtables_dispatch_ = 1
IElectronicFileFormatsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{B1D15948-E323-4C52-BA55-70E0678549CD}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{B1D15948-E323-4C52-BA55-70E0678549CD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IElectronicFileFormatsService_vtables_dispatch_ = 1
IElectronicFileFormatsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetElectronicFileFormat' , u'pIElectronicFileFormatParams' , u'ppIElectronicFileFormat' , ), 10, (10, (), [ (9, 1, None, "IID('{B1D15948-E323-4C52-BA55-70E0678549CD}')") , 
			(16393, 10, None, "IID('{F788A8C7-F4E4-47BD-BBC8-79670F3EAE61}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AddElectronicFileFormat' , u'pIImportFileParam' , u'ppIElectronicFileFormatParams' , ), 11, (11, (), [ (9, 1, None, "IID('{4AA87BC6-363C-4A35-9EB3-473BF6785478}')") , 
			(16393, 10, None, "IID('{B1D15948-E323-4C52-BA55-70E0678549CD}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteElectronicFileFormat' , u'pIElectronicFileFormatParams' , ), 12, (12, (), [ (9, 1, None, "IID('{B1D15948-E323-4C52-BA55-70E0678549CD}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetElectronicFileFormatList' , u'ppIElectronicFileFormatsParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{58E6063A-F616-4E44-AC69-8E40356F5830}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IElectronicSeries_vtables_dispatch_ = 1
IElectronicSeries_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ElectronicSeries' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'InitialNumber' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'InitialNumber' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'NextNumber' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LastNumber' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'LastNumber' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Prefix' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Prefix' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalYear' , u'plRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalYear' , u'plRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalNumber' , u'plRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalNumber' , u'plRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IElectronicSeriesCollection_vtables_dispatch_ = 1
IElectronicSeriesCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{2309689C-63EA-4D8E-B675-E6459533E27A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{2309689C-63EA-4D8E-B675-E6459533E27A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IElectronicSeriesParams_vtables_dispatch_ = 1
IElectronicSeriesParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ElectronicSeries' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ElectronicSeries' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IEmployeeAbsenceInfo_vtables_dispatch_ = 1
IEmployeeAbsenceInfo_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Reason' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Reason' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ApprovedBy' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ApprovedBy' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ConfirmerNumber' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ConfirmerNumber' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IEmployeeEducationInfo_vtables_dispatch_ = 1
IEmployeeEducationInfo_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'EducationType' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'EducationType' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Institute' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Institute' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Major' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Major' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Diploma' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Diploma' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

IEmployeeIDType_vtables_dispatch_ = 1
IEmployeeIDType_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'IDType' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'IDType' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IEmployeeIDTypeParams_vtables_dispatch_ = 1
IEmployeeIDTypeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'IDType' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'IDType' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IEmployeeIDTypeParamsCollection_vtables_dispatch_ = 1
IEmployeeIDTypeParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IEmployeeIDTypeService_vtables_dispatch_ = 1
IEmployeeIDTypeService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIEmployeeIDType' , u'ppIEmployeeIDTypeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{17F42A0A-DF72-432D-9953-1993A831A197}')") , 
			(16393, 10, None, "IID('{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pIEmployeeIDType' , ), 11, (11, (), [ (9, 1, None, "IID('{17F42A0A-DF72-432D-9953-1993A831A197}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIEmployeeIDTypeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIEmployeeIDTypeParams' , u'ppIEmployeeIDType' , ), 13, (13, (), [ (9, 1, None, "IID('{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}')") , 
			(16393, 10, None, "IID('{17F42A0A-DF72-432D-9953-1993A831A197}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppIEmployeeIDTypeParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{BDD8F465-17AF-49ED-AA8D-50A52B849D4F}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IEmployeePrevEmpoymentInfo_vtables_dispatch_ = 1
IEmployeePrevEmpoymentInfo_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FromDtae' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FromDtae' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Employer' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Employer' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IEmployeeReviewsInfo_vtables_dispatch_ = 1
IEmployeeReviewsInfo_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ReviewDescription' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ReviewDescription' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Manager' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Manager' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Grade' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Grade' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeNo' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IEmployeeRoleSetup_vtables_dispatch_ = 1
IEmployeeRoleSetup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TypeID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IEmployeeRoleSetupParams_vtables_dispatch_ = 1
IEmployeeRoleSetupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TypeID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TypeID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IEmployeeRoleSetupParamsCollection_vtables_dispatch_ = 1
IEmployeeRoleSetupParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IEmployeeRolesInfo_vtables_dispatch_ = 1
IEmployeeRolesInfo_vtables_ = [
	(( u'RoleID' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'RoleID' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IEmployeeRolesSetupService_vtables_dispatch_ = 1
IEmployeeRolesSetupService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddEmployeeRoleSetup' , u'pIEmployeeRoleSetup' , u'ppIEmployeeRoleSetupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{B9127E1F-9408-4957-B724-6A3A9AE42C74}')") , 
			(16393, 10, None, "IID('{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateEmployeeRoleSetup' , u'pIEmployeeRoleSetup' , ), 11, (11, (), [ (9, 1, None, "IID('{B9127E1F-9408-4957-B724-6A3A9AE42C74}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteEmployeeRoleSetup' , u'pIEmployeeRoleSetupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetEmployeeRoleSetup' , u'pIEmployeeRoleSetupParams' , u'ppIEmployeeRoleSetup' , ), 13, (13, (), [ (9, 1, None, "IID('{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}')") , 
			(16393, 10, None, "IID('{B9127E1F-9408-4957-B724-6A3A9AE42C74}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetEmployeeRoleSetupList' , u'ppIEmployeeRoleSetupParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{9A49C2D7-CC5F-4CEE-95B9-6A8B16CA2031}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IEmployeeSavingsPaymentInfo_vtables_dispatch_ = 1
IEmployeeSavingsPaymentInfo_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ContractName' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ContractName' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaymentNotes' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PaymentNotes' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AN' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AN' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ANcurrency' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ANcurrency' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'AG' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'AG' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'AGcurrency' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'AGcurrency' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BankName' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'BankName' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Sequence' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Sequence' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
]

IEmployeeTransfer_vtables_dispatch_ = 1
IEmployeeTransfer_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TransferID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TransferID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TransStartDate' , u'pdateRsltVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TransStartDate' , u'pdateRsltVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TransStartTime' , u'pdateRsltVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TransStartTime' , u'pdateRsltVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TransEndDate' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TransEndDate' , u'pdateRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TransEndTime' , u'pdateRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TransEndTime' , u'pdateRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeTransferDetails' , u'ppRsltVal' , ), 17, (17, (), [ (16393, 10, None, "IID('{9324B0F9-58FC-404D-81BB-5591BE9E6A27}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IEmployeeTransferDetail_vtables_dispatch_ = 1
IEmployeeTransferDetail_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TransferID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TransferedDate' , u'pdateRsltVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TransferedDate' , u'pdateRsltVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TransferedTime' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TransferedTime' , u'pdateRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IEmployeeTransferDetails_vtables_dispatch_ = 1
IEmployeeTransferDetails_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{0038F785-2853-4267-9629-3444A3CCC2AD}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{0038F785-2853-4267-9629-3444A3CCC2AD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IEmployeeTransferParams_vtables_dispatch_ = 1
IEmployeeTransferParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TransferID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TransferID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IEmployeeTransfersParams_vtables_dispatch_ = 1
IEmployeeTransfersParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IEmployeeTransfersService_vtables_dispatch_ = 1
IEmployeeTransfersService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetEmployeeTransfer' , u'pIEmployeeTransferParams' , u'ppIEmployeeTransfer' , ), 10, (10, (), [ (9, 1, None, "IID('{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')") , 
			(16393, 10, None, "IID('{B63DD56F-5008-48E8-B7FF-DA56720F422D}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AddEmployeeTransfer' , u'pIEmployeeTransfer' , u'ppIEmployeeTransferParams' , ), 11, (11, (), [ (9, 1, None, "IID('{B63DD56F-5008-48E8-B7FF-DA56720F422D}')") , 
			(16393, 10, None, "IID('{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UpdateEmployeeTransfer' , u'pIEmployeeTransfer' , ), 12, (12, (), [ (9, 1, None, "IID('{B63DD56F-5008-48E8-B7FF-DA56720F422D}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DeleteEmployeeTransfer' , u'pIEmployeeTransferParams' , ), 13, (13, (), [ (9, 1, None, "IID('{8080167A-3150-4B5F-8108-9BE2FA9DC31B}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetEmployeeTransferList' , u'ppIEmployeeTransfersParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{DFBE6ED2-7510-49C9-8C39-35B939DB586D}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IEmployeesInfo_vtables_dispatch_ = 1
IEmployeesInfo_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'EmployeeID' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'LastName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LastName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'FirstName' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FirstName' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'MiddleName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MiddleName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Gender' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Gender' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'JobTitle' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'JobTitle' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeType' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeType' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Department' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Department' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'WorkStreet' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'WorkStreet' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'WorkBlock' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'WorkBlock' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'WorkZipCode' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'WorkZipCode' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'WorkCity' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'WorkCity' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'WorkCounty' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'WorkCounty' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'WorkCountryCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'WorkCountryCode' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'WorkStateCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'WorkStateCode' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Manager' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Manager' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ApplicationUserID' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'ApplicationUserID' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'OfficePhone' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'OfficePhone' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'OfficeExtension' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'OfficeExtension' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Pager' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'HomePhone' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'HomePhone' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 35, (35, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'StatusCode' , u'pVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'StatusCode' , u'pVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'Salary' , u'pVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'Salary' , u'pVal' , ), 37, (37, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'SalaryUnit' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'SalaryUnit' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCosts' , u'pVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCosts' , u'pVal' , ), 39, (39, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCostUnit' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCostUnit' , u'pVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 41, (41, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 41, (41, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'TreminationReason' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'TreminationReason' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'BankBranch' , u'pVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'BankBranchNum' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'BankBranchNum' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'HomeStreet' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'HomeStreet' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'HomeBlock' , u'pVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'HomeBlock' , u'pVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'HomeZipCode' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'HomeZipCode' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'HomeCity' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'HomeCity' , u'pVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'HomeCounty' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'HomeCounty' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'HomeCountry' , u'pVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'HomeCountry' , u'pVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'HomeState' , u'pVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'HomeState' , u'pVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'DateOfBirth' , u'pVal' , ), 54, (54, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'DateOfBirth' , u'pVal' , ), 54, (54, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'CountryOfBirth' , u'pVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'CountryOfBirth' , u'pVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'MartialStatus' , u'pVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'MartialStatus' , u'pVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'NumOfChildren' , u'pVal' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'NumOfChildren' , u'pVal' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'IdNumber' , u'pVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'IdNumber' , u'pVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'CitizenshipCountryCode' , u'pVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'CitizenshipCountryCode' , u'pVal' , ), 59, (59, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'PassportNumber' , u'pVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'PassportNumber' , u'pVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'PassportExpirationDate' , u'pVal' , ), 61, (61, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'PassportExpirationDate' , u'pVal' , ), 61, (61, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 64, (64, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'SalaryCurrency' , u'pVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'SalaryCurrency' , u'pVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCostsCurrency' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeCostsCurrency' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'ReviewsInfo' , u'pVal' , ), 67, (67, (), [ (16393, 10, None, "IID('{C4397D01-E44E-4B76-80AB-4B888EEA10DD}')") , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'AbsenceInfo' , u'pVal' , ), 68, (68, (), [ (16393, 10, None, "IID('{CD47A725-AEA8-4224-93D3-F31848990C42}')") , ], 1 , 2 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'PreviousEmpoymentInfo' , u'pVal' , ), 69, (69, (), [ (16393, 10, None, "IID('{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}')") , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'EducationInfo' , u'pVal' , ), 70, (70, (), [ (16393, 10, None, "IID('{A5EC07B2-5898-4104-8015-F876A386D231}')") , ], 1 , 2 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeRolesInfo' , u'pVal' , ), 71, (71, (), [ (16393, 10, None, "IID('{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}')") , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 72, (72, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 73, (73, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'WorkBuildingFloorRoom' , u'pVal' , ), 74, (74, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'WorkBuildingFloorRoom' , u'pVal' , ), 74, (74, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'HomeBuildingFloorRoom' , u'pVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'HomeBuildingFloorRoom' , u'pVal' , ), 75, (75, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 76, (76, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 76, (76, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'plRsltVal' , ), 77, (77, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'plRsltVal' , ), 77, (77, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterCode' , u'pVal' , ), 91, (91, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterCode' , u'pVal' , ), 91, (91, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'CompanyNumber' , u'pVal' , ), 92, (92, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'CompanyNumber' , u'pVal' , ), 92, (92, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'VacationPreviousYear' , u'plRsltVal' , ), 93, (93, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'VacationPreviousYear' , u'plRsltVal' , ), 93, (93, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'VacationCurrentYear' , u'plRsltVal' , ), 94, (94, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'VacationCurrentYear' , u'plRsltVal' , ), 94, (94, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'MunicipalityKey' , u'pVal' , ), 95, (95, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'MunicipalityKey' , u'pVal' , ), 95, (95, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'TaxClass' , u'pVal' , ), 96, (96, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'TaxClass' , u'pVal' , ), 96, (96, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'IncomeTaxLiability' , u'pVal' , ), 97, (97, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'IncomeTaxLiability' , u'pVal' , ), 97, (97, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'Religion' , u'pVal' , ), 98, (98, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'Religion' , u'pVal' , ), 98, (98, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'PartnerReligion' , u'pVal' , ), 99, (99, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'PartnerReligion' , u'pVal' , ), 99, (99, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionAmount' , u'pVal' , ), 100, (100, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionAmount' , u'pVal' , ), 100, (100, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionUnit' , u'pVal' , ), 101, (101, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionUnit' , u'pVal' , ), 101, (101, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionCurrency' , u'pVal' , ), 102, (102, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionCurrency' , u'pVal' , ), 102, (102, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalAmount' , u'pVal' , ), 103, (103, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalAmount' , u'pVal' , ), 103, (103, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalUnit' , u'pVal' , ), 104, (104, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalUnit' , u'pVal' , ), 104, (104, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalCurrency' , u'pVal' , ), 105, (105, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalCurrency' , u'pVal' , ), 105, (105, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'TaxOfficeName' , u'pVal' , ), 106, (106, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'TaxOfficeName' , u'pVal' , ), 106, (106, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'TaxOfficeNumber' , u'pVal' , ), 107, (107, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'TaxOfficeNumber' , u'pVal' , ), 107, (107, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'HealthInsuranceName' , u'pVal' , ), 108, (108, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'HealthInsuranceName' , u'pVal' , ), 108, (108, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'HealthInsuranceCode' , u'pVal' , ), 109, (109, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'HealthInsuranceCode' , u'pVal' , ), 109, (109, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'HealthInsuranceType' , u'pVal' , ), 110, (110, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'HealthInsuranceType' , u'pVal' , ), 110, (110, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'SocialInsuranceNumber' , u'pVal' , ), 111, (111, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'SocialInsuranceNumber' , u'pVal' , ), 111, (111, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'ProfessionStatus' , u'pVal' , ), 112, (112, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'ProfessionStatus' , u'pVal' , ), 112, (112, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'EducationStatus' , u'pVal' , ), 113, (113, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'EducationStatus' , u'pVal' , ), 113, (113, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'PersonGroup' , u'pVal' , ), 114, (114, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'PersonGroup' , u'pVal' , ), 114, (114, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'JobTitleCode' , u'pVal' , ), 115, (115, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'JobTitleCode' , u'pVal' , ), 115, (115, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'BankCodeForDATEV' , u'pVal' , ), 116, (116, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'BankCodeForDATEV' , u'pVal' , ), 116, (116, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'DeviatingBankAccountOwner' , u'pVal' , ), 117, (117, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'DeviatingBankAccountOwner' , u'pVal' , ), 117, (117, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'SpouseFirstName' , u'pVal' , ), 118, (118, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'SpouseFirstName' , u'pVal' , ), 118, (118, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'SpouseSurname' , u'pVal' , ), 119, (119, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'SpouseSurname' , u'pVal' , ), 119, (119, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'ExternalEmployeeNumber' , u'pVal' , ), 120, (120, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'ExternalEmployeeNumber' , u'pVal' , ), 120, (120, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'BirthPlace' , u'pVal' , ), 121, (121, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'BirthPlace' , u'pVal' , ), 121, (121, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethod' , u'pVal' , ), 122, (122, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethod' , u'pVal' , ), 122, (122, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'SavingsPaymentInfo' , u'pVal' , ), 123, (123, (), [ (16393, 10, None, "IID('{669DAF62-7776-4DF5-AB51-B35DABFC4ACE}')") , ], 1 , 2 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'STDCode' , u'pVal' , ), 124, (124, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'STDCode' , u'pVal' , ), 124, (124, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'CPF' , u'pVal' , ), 125, (125, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'CPF' , u'pVal' , ), 125, (125, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'CRCNumber' , u'pVal' , ), 126, (126, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'CRCNumber' , u'pVal' , ), 126, (126, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'AccountantResponsible' , u'pVal' , ), 127, (127, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'AccountantResponsible' , u'pVal' , ), 127, (127, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'LegalRepresentative' , u'pVal' , ), 128, (128, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'LegalRepresentative' , u'pVal' , ), 128, (128, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'DIRFResponsible' , u'pVal' , ), 129, (129, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'DIRFResponsible' , u'pVal' , ), 129, (129, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'CRCState' , u'pVal' , ), 130, (130, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'CRCState' , u'pVal' , ), 130, (130, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'pVal' , ), 131, (131, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'pVal' , ), 131, (131, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'IDType' , u'pVal' , ), 132, (132, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'IDType' , u'pVal' , ), 132, (132, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 133, (133, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 133, (133, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
]

IExportProcesses_vtables_dispatch_ = 1
IExportProcesses_vtables_ = [
	(( u'ExportationDocumentTypeCode' , u'plValue' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ExportationDocumentTypeCode' , u'plValue' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ExportationDeclarationNumber' , u'plValue' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ExportationDeclarationNumber' , u'plValue' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ExportationDeclarationDate' , u'pdateValue' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ExportationDeclarationDate' , u'pdateValue' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ExportationNatureCode' , u'plValue' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ExportationNatureCode' , u'plValue' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ExportationRegistryNumber' , u'plValue' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ExportationRegistryNumber' , u'plValue' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ExportationRegistryDate' , u'pdateValue' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ExportationRegistryDate' , u'pdateValue' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LadingBillNumber' , u'pbstrValue' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LadingBillNumber' , u'pbstrValue' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'LadingBillDate' , u'pdateValue' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'LadingBillDate' , u'pdateValue' , ), 17, (17, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'MerchandiseLeftCustomsDate' , u'pdateValue' , ), 18, (18, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'MerchandiseLeftCustomsDate' , u'pdateValue' , ), 18, (18, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'LadingBillTypeCode' , u'plValue' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'LadingBillTypeCode' , u'plValue' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IExtendedAdminInfo_vtables_dispatch_ = 1
IExtendedAdminInfo_vtables_ = [
	(( u'AddressType' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'STDCode' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'STDCode' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'STDCodeForeign' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'STDCodeForeign' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'NatureOfCompanyCode' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'NatureOfCompanyCode' , u'pVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'EconomicActivityTypeCode' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'EconomicActivityTypeCode' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CreditContributionOriginCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CreditContributionOriginCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'IPIPeriodCode' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'IPIPeriodCode' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CooperativeAssociationTypeCode' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CooperativeAssociationTypeCode' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ProfitTaxationCode' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ProfitTaxationCode' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CompanyQualificationCode' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CompanyQualificationCode' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DeclarerTypeCode' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DeclarerTypeCode' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'IPITaxContributor' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'IPITaxContributor' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CommercialRegister' , u'pbstrRsltValue' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CommercialRegister' , u'pbstrRsltValue' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DateOfIncorporation' , u'pdtRsltValue' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DateOfIncorporation' , u'pdtRsltValue' , ), 19, (19, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'SPEDProfile' , u'pbstrRsltValue' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'SPEDProfile' , u'pbstrRsltValue' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'EnvironmentType' , u'plRsltValue' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'EnvironmentType' , u'plRsltValue' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Opting4ICMS' , u'penumRsltValue' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Opting4ICMS' , u'penumRsltValue' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'OKDPNumber' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'OKDPNumber' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
]

IExtendedTranslation_vtables_dispatch_ = 1
IExtendedTranslation_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SecondaryID' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SecondaryID' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SourceLanguage' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SourceLanguage' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CreateDate' , u'pdateRsltVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ExtendedTranslation_ItemLines' , u'ppRsltVal' , ), 17, (17, (), [ (16393, 10, None, "IID('{323B7F1F-31D3-45CE-A325-B81187DA9C0C}')") , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IExtendedTranslationParams_vtables_dispatch_ = 1
IExtendedTranslationParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SecondaryID' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SecondaryID' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IExtendedTranslation_ItemLine_vtables_dispatch_ = 1
IExtendedTranslation_ItemLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ItemType' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemType' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SlimType' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SlimType' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'MaxLength' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MaxLength' , u'plRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SourceText' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'SourceText' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ExtendedTranslation_ResultLines' , u'ppRsltVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{49836643-1102-4273-B5DC-F4ADEC94D843}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IExtendedTranslation_ItemLines_vtables_dispatch_ = 1
IExtendedTranslation_ItemLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{FFA101D6-62B7-4615-A050-5BEE79FBF640}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{FFA101D6-62B7-4615-A050-5BEE79FBF640}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IExtendedTranslation_ResultLine_vtables_dispatch_ = 1
IExtendedTranslation_ResultLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SubLineNumber' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TranslatedText' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TranslatedText' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IExtendedTranslation_ResultLines_vtables_dispatch_ = 1
IExtendedTranslation_ResultLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{50ACD964-9DDC-46E4-9719-56DB0EED92AB}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{50ACD964-9DDC-46E4-9719-56DB0EED92AB}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IExtendedTranslationsParams_vtables_dispatch_ = 1
IExtendedTranslationsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IExtendedTranslationsService_vtables_dispatch_ = 1
IExtendedTranslationsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddExtendedTranslation' , u'pIExtendedTranslation' , u'ppIExtendedTranslationParams' , ), 10, (10, (), [ (9, 1, None, "IID('{EB9E1080-A979-4BA0-895B-D424C68063BC}')") , 
			(16393, 10, None, "IID('{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateExtendedTranslation' , u'pIExtendedTranslation' , ), 11, (11, (), [ (9, 1, None, "IID('{EB9E1080-A979-4BA0-895B-D424C68063BC}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteExtendedTranslation' , u'pIExtendedTranslationParams' , ), 12, (12, (), [ (9, 1, None, "IID('{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetExtendedTranslation' , u'pIExtendedTranslationParams' , u'ppIExtendedTranslation' , ), 13, (13, (), [ (9, 1, None, "IID('{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}')") , 
			(16393, 10, None, "IID('{EB9E1080-A979-4BA0-895B-D424C68063BC}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetExtendedTranslationList' , u'ppIExtendedTranslationsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{57FF304C-3414-48FA-8059-4F3B10FB37C9}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IExternalCall_vtables_dispatch_ = 1
IExternalCall_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CreationTime' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdateDate' , u'pdateRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdateDate' , u'pdateRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdateTime' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdateTime' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdateUserCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdateUserCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CallArguments' , u'ppRsltVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{EBBCE4C7-AE00-46A4-A0BA-851F42E7CADF}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CallMessages' , u'ppRsltVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{1B562911-6C93-4858-B003-D2586E02BA48}')") , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IExternalCallParams_vtables_dispatch_ = 1
IExternalCallParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IExternalCallsService_vtables_dispatch_ = 1
IExternalCallsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SendCall' , u'pIExternalCall' , u'ppIExternalCallParams' , ), 10, (10, (), [ (9, 1, None, "IID('{B2BFF6DD-6309-40EB-BC59-75D1996BD77D}')") , 
			(16393, 10, None, "IID('{6AC1DA43-B01F-4E2E-8B5A-184BE9C05D80}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCall' , u'pIExternalCall' , ), 11, (11, (), [ (9, 1, None, "IID('{B2BFF6DD-6309-40EB-BC59-75D1996BD77D}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetCall' , u'pIExternalCallParams' , u'ppIExternalCall' , ), 12, (12, (), [ (9, 1, None, "IID('{6AC1DA43-B01F-4E2E-8B5A-184BE9C05D80}')") , 
			(16393, 10, None, "IID('{B2BFF6DD-6309-40EB-BC59-75D1996BD77D}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IFIFOLayers_vtables_dispatch_ = 1
IFIFOLayers_vtables_ = [
	(( u'TransactionSequenceNum' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'TransactionSequenceNum' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'LayerID' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'LayerID' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 6, (6, (), [ ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 8, (8, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IFactoringIndicators_vtables_dispatch_ = 1
IFactoringIndicators_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrCode' , u'pbRsltFound' , ), 6, (6, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'IndicatorCode' , u'pbstrRsltVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'IndicatorCode' , u'pbstrRsltVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'IndicatorName' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'IndicatorName' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IFeatureStatus_vtables_dispatch_ = 1
IFeatureStatus_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FeatureID' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Blocked' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IFeatureStatusCollection_vtables_dispatch_ = 1
IFeatureStatusCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{B551C968-0DE9-48FA-B48D-385284294F16}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{B551C968-0DE9-48FA-B48D-385284294F16}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IField_vtables_dispatch_ = 1
IField_vtables_ = [
	(( u'Name' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Size' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 4, (4, (), [ (16396, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 4, (4, (), [ (12, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ValidValue' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ValidValue' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ValidValues' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{48B89C08-2AE9-435F-B7C4-D7219E938E46}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SubType' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LinkedTable' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DefaultValue' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Mandatory' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'IsNull' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SetNullValue' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'FieldID' , u'plRsltValue' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Table' , u'pbstrRsltValue' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IFields_vtables_dispatch_ = 1
IFields_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 1 , )),
]

IFinancePeriod_vtables_dispatch_ = 1
IFinancePeriod_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PeriodCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PeriodCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PeriodName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PeriodName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PostingDateFrom' , u'pdtRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PostingDateFrom' , u'pdtRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PostingDateTo' , u'pdtRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PostingDateTo' , u'pdtRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ValueDateFrom' , u'pdtRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ValueDateFrom' , u'pdtRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ValueDateTo' , u'pdtRsltVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ValueDateTo' , u'pdtRsltVal' , ), 16, (16, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TaxDateFrom' , u'pdtRsltVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxDateFrom' , u'pdtRsltVal' , ), 17, (17, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TaxDateTo' , u'pdtRsltVal' , ), 18, (18, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TaxDateTo' , u'pdtRsltVal' , ), 18, (18, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ActiveforFeed' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ActiveforFeed' , u'penumRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'penumRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'penumRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalSubPeriods' , u'penumRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PeriodIndicator' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'PeriodIndicator' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'SubNum' , u'plRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PeriodStatus' , u'penumRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'PeriodStatus' , u'penumRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
]

IFinancePeriodParams_vtables_dispatch_ = 1
IFinancePeriodParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PeriodIndicator' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PeriodIndicator' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IFinancePeriods_vtables_dispatch_ = 1
IFinancePeriods_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{39DAE3AB-708D-4123-BC50-CC57F05D734E}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{39DAE3AB-708D-4123-BC50-CC57F05D734E}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IFinancialYear_vtables_dispatch_ = 1
IFinancialYear_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pdateRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AssessYear' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AssessYear' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IFinancialYearParams_vtables_dispatch_ = 1
IFinancialYearParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IFinancialYearsParams_vtables_dispatch_ = 1
IFinancialYearsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{83C6551A-5E1D-4651-8272-88BA8B56E728}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{83C6551A-5E1D-4651-8272-88BA8B56E728}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IFinancialYearsService_vtables_dispatch_ = 1
IFinancialYearsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddFinancialYear' , u'pIFinancialYear' , u'ppIFinancialYearParams' , ), 10, (10, (), [ (9, 1, None, "IID('{C29BB9BD-1EC7-4427-A484-E79EC58F7224}')") , 
			(16393, 10, None, "IID('{83C6551A-5E1D-4651-8272-88BA8B56E728}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateFinancialYear' , u'pIFinancialYear' , ), 11, (11, (), [ (9, 1, None, "IID('{C29BB9BD-1EC7-4427-A484-E79EC58F7224}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteFinancialYear' , u'pIFinancialYearParams' , ), 12, (12, (), [ (9, 1, None, "IID('{83C6551A-5E1D-4651-8272-88BA8B56E728}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetFinancialYear' , u'pIFinancialYearParams' , u'ppIFinancialYear' , ), 13, (13, (), [ (9, 1, None, "IID('{83C6551A-5E1D-4651-8272-88BA8B56E728}')") , 
			(16393, 10, None, "IID('{C29BB9BD-1EC7-4427-A484-E79EC58F7224}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetFinancialYearList' , u'ppIFinancialYearsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{9306DAC4-5FDE-4695-AF50-96349ABA5F74}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IFormPreferencesService_vtables_dispatch_ = 1
IFormPreferencesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetColumnsPreferences' , u'pIColumnsPreferencesParams' , u'ppIColumnsPreferences' , ), 10, (10, (), [ (9, 1, None, "IID('{3D83A354-89D4-46AF-841A-D659A0C2678E}')") , 
			(16393, 10, None, "IID('{5079035B-D0E5-4D0E-AFB1-6CB1FBAB11AE}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateColumnsPreferences' , u'pIColumnsPreferencesParams' , u'pIColumnsPreferences' , ), 11, (11, (), [ (9, 1, None, "IID('{3D83A354-89D4-46AF-841A-D659A0C2678E}')") , 
			(9, 1, None, "IID('{5079035B-D0E5-4D0E-AFB1-6CB1FBAB11AE}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IFormattedSearches_vtables_dispatch_ = 1
IFormattedSearches_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lIndex' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FormID' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'FormID' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ItemID' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ItemID' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ColumnID' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ColumnID' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Action' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Action' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'QueryID' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'QueryID' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Index' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Refresh' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Refresh' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FieldID' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'FieldID' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ForceRefresh' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ForceRefresh' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ByField' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ByField' , u'penumRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'UserValidValues' , u'ppRsltVal' , ), 20, (20, (), [ (16393, 10, None, "IID('{280836CC-E077-4487-8759-D06DC3E31076}')") , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
]

IForms1099_vtables_dispatch_ = 1
IForms1099_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lFormCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FormCode' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Form1099' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Form1099' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Boxes1099' , u'ppRsltVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{1C7661BB-2694-4ECF-94EF-588ECB0CB8AD}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IGLAccount_vtables_dispatch_ = 1
IGLAccount_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdtRsltVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdtRsltVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Debit' , u'pdblRsltVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Debit' , u'pdblRsltVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Credit' , u'pdblRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Credit' , u'pdblRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SystemDebit' , u'pdblRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SystemDebit' , u'pdblRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SystemCredit' , u'pdblRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'SystemCredit' , u'pdblRsltVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ForeignDebit' , u'pdblRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ForeignDebit' , u'pdblRsltVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ForeignCredit' , u'pdblRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ForeignCredit' , u'pdblRsltVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ForeignCurrency' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ForeignCurrency' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IGLAccounts_vtables_dispatch_ = 1
IGLAccounts_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IGTIParams_vtables_dispatch_ = 1
IGTIParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'InboundFile' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'InboundFile' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IGTIParamsCollection_vtables_dispatch_ = 1
IGTIParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IGTIsService_vtables_dispatch_ = 1
IGTIsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Import' , u'pIGTIParams' , u'ppIGTIsParams' , ), 10, (10, (), [ (9, 1, None, "IID('{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}')") , 
			(16393, 10, None, "IID('{DF63C280-18C5-4444-BDAF-59318E9ED979}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
]

IGeneralCollectionParams_vtables_dispatch_ = 1
IGeneralCollectionParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IGeneralData_vtables_dispatch_ = 1
IGeneralData_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Child' , u'bstrDataName' , u'pRsltIDispatch' , ), 8, (8, (), [ (8, 1, None, None) , 
			(16393, 10, None, "IID('{646FEBEB-91D7-4517-8CB0-B550DCA64490}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetProperty' , u'bstrPropertyName' , u'vtValue' , ), 9, (9, (), [ (8, 1, None, None) , 
			(16396, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetProperty' , u'bstrPropertyName' , u'vtValue' , ), 10, (10, (), [ (8, 1, None, None) , 
			(12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IGeneralDataCollection_vtables_dispatch_ = 1
IGeneralDataCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{C131D463-24C3-424A-B734-589D0F452D2E}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{C131D463-24C3-424A-B734-589D0F452D2E}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IGeneralDataParams_vtables_dispatch_ = 1
IGeneralDataParams_vtables_ = [
	(( u'GetProperty' , u'bstrPropertyName' , u'vtValue' , ), 9, (9, (), [ (8, 1, None, None) , 
			(16396, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetProperty' , u'bstrPropertyName' , u'vtValue' , ), 10, (10, (), [ (8, 1, None, None) , 
			(12, 1, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
]

IGeneralService_vtables_dispatch_ = 1
IGeneralService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIGeneralData' , u'ppIGeneralDataParams' , ), 10, (10, (), [ (9, 1, None, "IID('{C131D463-24C3-424A-B734-589D0F452D2E}')") , 
			(16393, 10, None, "IID('{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pIGeneralData' , ), 11, (11, (), [ (9, 1, None, "IID('{C131D463-24C3-424A-B734-589D0F452D2E}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIGeneralDataParams' , ), 12, (12, (), [ (9, 1, None, "IID('{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppIGeneralCollectionParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{ACAC0540-ACCA-4278-8EB8-2300D893ADD1}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetByParams' , u'pIGeneralDataParams' , u'ppIGeneralData' , ), 14, (14, (), [ (9, 1, None, "IID('{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')") , 
			(16393, 10, None, "IID('{C131D463-24C3-424A-B734-589D0F452D2E}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'pIGeneralDataParams' , ), 15, (15, (), [ (9, 1, None, "IID('{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'pIGeneralDataParams' , ), 16, (16, (), [ (9, 1, None, "IID('{137AD94C-2F5B-42AB-9DB5-309BD89EF224}')") , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'InvokeMethod' , u'pIInvokeParams' , u'pIGeneralData' , u'ppIInvokeParams' , ), 17, (17, (), [ 
			(9, 1, None, "IID('{D6BF90B4-5DE1-4A71-8463-FEB7AB1A9AB4}')") , (9, 1, None, "IID('{C131D463-24C3-424A-B734-589D0F452D2E}')") , (16393, 10, None, "IID('{D6BF90B4-5DE1-4A71-8463-FEB7AB1A9AB4}')") , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DoCommand' , u'pGeneralData' , u'Command_Name' , u'ppRsltIGeneralData' , ), 18, (18, (), [ 
			(9, 1, None, "IID('{C131D463-24C3-424A-B734-589D0F452D2E}')") , (8, 0, None, None) , (16393, 10, None, "IID('{C131D463-24C3-424A-B734-589D0F452D2E}')") , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IGetChangeLogParams_vtables_dispatch_ = 1
IGetChangeLogParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryKey' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryKey' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Object' , u'pbstrRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Object' , u'pbstrRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UDOObjectCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UDOObjectCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IHouseBankAccounts_vtables_dispatch_ = 1
IHouseBankAccounts_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsEntry' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AccNo' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AccNo' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'NextCheckNo' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'NextCheckNo' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BISR' , u'penumRsltVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BISR' , u'penumRsltVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ControlKey' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ControlKey' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'UserNo1' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'UserNo1' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'UserNo2' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'UserNo2' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'UserNo3' , u'pbstrRsltVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'UserNo3' , u'pbstrRsltVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'UserNo4' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'UserNo4' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'IBAN' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'DebtofDiscountedBillofExc' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'DebtofDiscountedBillofExc' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'ToleranceDays' , u'plRsltVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ToleranceDays' , u'plRsltVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'MinAmountofBillofExchang' , u'pdblRsltVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'MinAmountofBillofExchang' , u'pdblRsltVal' , ), 31, (31, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'MaxAmountofBillofExchan' , u'pdblRsltVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'MaxAmountofBillofExchan' , u'pdblRsltVal' , ), 32, (32, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'DiscountLimit' , u'pdblRsltVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'DiscountLimit' , u'pdblRsltVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'DaysInAdvance' , u'plRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'DaysInAdvance' , u'plRsltVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'BankonCollection' , u'pbstrRsltVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'BankonCollection' , u'pbstrRsltVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'BankonDiscounted' , u'pbstrRsltVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'BankonDiscounted' , u'pbstrRsltVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'GLInterimAccount' , u'pbstrRsltVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'GLInterimAccount' , u'pbstrRsltVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'BankKey' , u'plRsltVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'BankKey' , u'plRsltVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'LockChecksPrinting' , u'penumRsltVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'LockChecksPrinting' , u'penumRsltVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'TemplateName' , u'pbstrRsltVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'TemplateName' , u'pbstrRsltVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'MaximumLines' , u'plRslt' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'MaximumLines' , u'plRslt' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'PrintOn' , u'penumRsltVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'PrintOn' , u'penumRsltVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'CustomerIdNumber' , u'pbstrRsltVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'CustomerIdNumber' , u'pbstrRsltVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pbstrRsltVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'ISRBillerID' , u'pbstrRsltVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'ISRType' , u'plRsltVal' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'ISRType' , u'plRsltVal' , ), 50, (50, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'AccountCheckDigit' , u'pbstrRsltVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'AccountCheckDigit' , u'pbstrRsltVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'OurNumber' , u'plRslt' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'OurNumber' , u'plRslt' , ), 52, (52, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'AgreementNumber' , u'pbstrRsltVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'AgreementNumber' , u'pbstrRsltVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pbstrRsltVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pbstrRsltVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pbstrRsltVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pbstrRsltVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'Building' , u'pbstrRsltVal' , ), 56, (56, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'Building' , u'pbstrRsltVal' , ), 56, (56, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'IncomingPaymentSeries' , u'plRsltVal' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'IncomingPaymentSeries' , u'plRsltVal' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingPaymentSeries' , u'plRsltVal' , ), 58, (58, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingPaymentSeries' , u'plRsltVal' , ), 58, (58, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntrySeries' , u'plRsltVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntrySeries' , u'plRsltVal' , ), 59, (59, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'ImportFileName' , u'plRsltVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'ImportFileName' , u'plRsltVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 61, (61, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'BICSwiftCode' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'BICSwiftCode' , u'pVal' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'FineAccount' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'FineAccount' , u'pVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'InterestAccount' , u'pVal' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'InterestAccount' , u'pVal' , ), 64, (64, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'DiscountAccount' , u'pVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'DiscountAccount' , u'pVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'ServiceFeeAccount' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'ServiceFeeAccount' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'IOFTaxAccount' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'IOFTaxAccount' , u'pVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'OtherExpensesAccount' , u'pVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'OtherExpensesAccount' , u'pVal' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'OtherIncomesAccount' , u'pVal' , ), 69, (69, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'OtherIncomesAccount' , u'pVal' , ), 69, (69, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'RetornoFileName' , u'plRsltVal' , ), 70, (70, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'RetornoFileName' , u'plRsltVal' , ), 70, (70, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'BranchCheckDigit' , u'plRsltVal' , ), 71, (71, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'BranchCheckDigit' , u'plRsltVal' , ), 71, (71, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'CollectionCode' , u'plRsltVal' , ), 72, (72, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'CollectionCode' , u'plRsltVal' , ), 72, (72, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'FileSeqNextNumber' , u'plRsltVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'FileSeqNextNumber' , u'plRsltVal' , ), 73, (73, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
]

IImportFileParam_vtables_dispatch_ = 1
IImportFileParam_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FilePath' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'FilePath' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IImportProcesses_vtables_dispatch_ = 1
IImportProcesses_vtables_ = [
	(( u'ImportationDocumentTypeCode' , u'pbstrValue' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ImportationDocumentTypeCode' , u'pbstrValue' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ImportationDocumentNumber' , u'pbstrValue' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ImportationDocumentNumber' , u'pbstrValue' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'DateOfRegistry_DI_DSI_DA' , u'pdateValue' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DateOfRegistry_DI_DSI_DA' , u'pdateValue' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CustomsClearanceDate' , u'pdateValue' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CustomsClearanceDate' , u'pdateValue' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DrawbackRegimeConcessionAccountNumber' , u'pbstrValue' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DrawbackRegimeConcessionAccountNumber' , u'pbstrValue' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalNumber' , u'pbstrValue' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalNumber' , u'pbstrValue' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalItemDiscountValue' , u'pdblValue' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalItemDiscountValue' , u'pdblValue' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IIndustries_vtables_dispatch_ = 1
IIndustries_vtables_ = [
	(( u'IndustryDescription' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'IndustryDescription' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'IndustryName' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'IndustryName' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'IndustryCode' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Code' , u'Found' , ), 7, (7, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 8, (8, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IInventoryCycles_vtables_dispatch_ = 1
IInventoryCycles_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CycleCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CycleName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CycleName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Frequency' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Frequency' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Day' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Day' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Hour' , u'pdtRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Hour' , u'pdtRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'NextCountingDate' , u'pdtRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'NextCountingDate' , u'pdtRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IInvokeParams_vtables_dispatch_ = 1
IInvokeParams_vtables_ = [
	(( u'Value' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
]

IItemCycleCount_vtables_dispatch_ = 1
IItemCycleCount_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 3, (3, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'CycleCode' , u'plRsltVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'CycleCode' , u'plRsltVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Alert' , u'penumRsltVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Alert' , u'penumRsltVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'NextCountingDate' , u'pdtRsltVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NextCountingDate' , u'pdtRsltVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AlertTime' , u'pdtRsltVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AlertTime' , u'pdtRsltVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DestinationUser' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DestinationUser' , u'plRsltVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IItemGroups_vtables_dispatch_ = 1
IItemGroups_vtables_ = [
	(( u'PriceDifferencesAccount' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferencesAccount' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'MinimumOrderQuantity' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'MinimumOrderQuantity' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'OrderInterval' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'OrderInterval' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAccount' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAccount' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAccount' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAccount' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ProcurementMethod' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ProcurementMethod' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'InventorySystem' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'InventorySystem' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PlanningSystem' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PlanningSystem' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TransfersAccount' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'TransfersAccount' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'LeadTime' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'LeadTime' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'OrderMultiple' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'OrderMultiple' , u'pVal' , ), 20, (20, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'InventoryAccount' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'InventoryAccount' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAccount' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAccount' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAccount' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAccount' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAccount' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAccount' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Alert' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'Alert' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ExemptRevenuesAccount' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'ExemptRevenuesAccount' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAccount' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAccount' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'CycleCode' , u'pVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'CycleCode' , u'pVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'CostAccount' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'CostAccount' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'PAReturnAccount' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'PAReturnAccount' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'GroupName' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'GroupName' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'GroupCode' , u'Found' , ), 45, (45, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 46, (46, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 47, (47, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 48, (48, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAct' , u'pbstrRsltVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAct' , u'pbstrRsltVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseCreditAcc' , u'pbstrRsltVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseCreditAcc' , u'pbstrRsltVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'EUPurchaseCreditAcc' , u'pbstrRsltVal' , ), 56, (56, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'EUPurchaseCreditAcc' , u'pbstrRsltVal' , ), 56, (56, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'ForeignPurchaseCreditAcc' , u'pbstrRsltVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'ForeignPurchaseCreditAcc' , u'pbstrRsltVal' , ), 57, (57, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditAcc' , u'pbstrRsltVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditAcc' , u'pbstrRsltVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditEUAcc' , u'pbstrRsltVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditEUAcc' , u'pbstrRsltVal' , ), 59, (59, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'ExemptedCredits' , u'pbstrRsltVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'ExemptedCredits' , u'pbstrRsltVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditForeignAcc' , u'pbstrRsltVal' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditForeignAcc' , u'pbstrRsltVal' , ), 61, (61, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsetAccount' , u'pbstrRsltVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsetAccount' , u'pbstrRsltVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'NegativeInventoryAdjustmentAccount' , u'pVal' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'NegativeInventoryAdjustmentAccount' , u'pVal' , ), 64, (64, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'WHIncomingCenvatAccount' , u'pVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'WHIncomingCenvatAccount' , u'pVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'WHOutgoingCenvatAccount' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'WHOutgoingCenvatAccount' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'StockInTransitAccount' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'StockInTransitAccount' , u'pVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'WipOffsetProfitAndLossAccount' , u'pVal' , ), 71, (71, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'WipOffsetProfitAndLossAccount' , u'pVal' , ), 71, (71, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetProfitAndLossAccount' , u'pVal' , ), 72, (72, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetProfitAndLossAccount' , u'pVal' , ), 72, (72, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'ToleranceDays' , u'pVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'ToleranceDays' , u'pVal' , ), 73, (73, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
]

IItemLocalizationInfos_vtables_dispatch_ = 1
IItemLocalizationInfos_vtables_ = [
	(( u'Add' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNumber' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pRsltValue' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pRsltValue' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'IncomeNature' , u'pRsltValue' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'IncomeNature' , u'pRsltValue' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IItemProperties_vtables_dispatch_ = 1
IItemProperties_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lGroupCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PropertyName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PropertyName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IItemWarehouseInfo_vtables_dispatch_ = 1
IItemWarehouseInfo_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'MaximalStock' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'MaximalStock' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'MinimalOrder' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'MinimalOrder' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'StandardAveragePrice' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'StandardAveragePrice' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'InventoryAccount' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'InventoryAccount' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CostAccount' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CostAccount' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TransferAccount' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TransferAccount' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'VarienceAccount' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'VarienceAccount' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenueAcc' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenueAcc' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensAcc' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensAcc' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'ExemptIncomeAcc' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'ExemptIncomeAcc' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferenceAcc' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferenceAcc' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'MinimalStock' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'MinimalStock' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'InStock' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Committed' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Ordered' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'CountedQuantity' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'WasCounted' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Counted' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 31, (31, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'WipVarianceAccount' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'WipVarianceAccount' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAct' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAct' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseCreditAcc' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseCreditAcc' , u'pbstrRsltVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'EUPurchaseCreditAcc' , u'pbstrRsltVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'EUPurchaseCreditAcc' , u'pbstrRsltVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'ForeignPurchaseCreditAcc' , u'pbstrRsltVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'ForeignPurchaseCreditAcc' , u'pbstrRsltVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditAcc' , u'pbstrRsltVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditAcc' , u'pbstrRsltVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditEUAcc' , u'pbstrRsltVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditEUAcc' , u'pbstrRsltVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'ExemptedCredits' , u'pbstrRsltVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'ExemptedCredits' , u'pbstrRsltVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditForeignAcc' , u'pbstrRsltVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditForeignAcc' , u'pbstrRsltVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsettingAccount' , u'pbstrRsltVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsettingAccount' , u'pbstrRsltVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'WipAccount' , u'pbstrRsltVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'WipAccount' , u'pbstrRsltVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAcct' , u'pbstrRsltVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAcct' , u'pbstrRsltVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAcct' , u'pbstrRsltVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAcct' , u'pbstrRsltVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'ItemCycleCount' , u'ppRsltVal' , ), 46, (46, (), [ (16393, 10, None, "IID('{743A4F30-AC7F-4606-9AA3-5139F07E08A2}')") , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'NegativeInventoryAdjustmentAccount' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'NegativeInventoryAdjustmentAccount' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pbstrRsltVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pbstrRsltVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pbstrRsltVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pbstrRsltVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'GLDecreaseAcct' , u'pbstrRsltVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'GLDecreaseAcct' , u'pbstrRsltVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'GLIncreaseAcct' , u'pbstrRsltVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'GLIncreaseAcct' , u'pbstrRsltVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'PAReturnAcct' , u'pbstrRsltVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'PAReturnAcct' , u'pbstrRsltVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAcct' , u'pbstrRsltVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAcct' , u'pbstrRsltVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAcct' , u'pbstrRsltVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAcct' , u'pbstrRsltVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pbstrRsltVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pbstrRsltVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pbstrRsltVal' , ), 56, (56, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pbstrRsltVal' , ), 56, (56, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pbstrRsltVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pbstrRsltVal' , ), 57, (57, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pbstrRsltVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pbstrRsltVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'WHIncomingCenvatAccount' , u'pVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'WHIncomingCenvatAccount' , u'pVal' , ), 59, (59, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'WHOutgoingCenvatAccount' , u'pVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'WHOutgoingCenvatAccount' , u'pVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 61, (61, (), [ ], 1 , 1 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'StockInTransitAccount' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'StockInTransitAccount' , u'pVal' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'WipOffsetProfitAndLossAccount' , u'pVal' , ), 71, (71, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'WipOffsetProfitAndLossAccount' , u'pVal' , ), 71, (71, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetProfitAndLossAccount' , u'pVal' , ), 72, (72, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetProfitAndLossAccount' , u'pVal' , ), 72, (72, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
]

IItems_vtables_dispatch_ = 1
IItems_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ItemCode' , u'Found' , ), 3, (3, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ForeignName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ForeignName' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ItemsGroupCode' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemsGroupCode' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CustomsGroupCode' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CustomsGroupCode' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SalesVATGroup' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SalesVATGroup' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BarCode' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BarCode' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'VatLiable' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'VatLiable' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseItem' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseItem' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SalesItem' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SalesItem' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'InventoryItem' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'InventoryItem' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'IncomeAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'IncomeAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ExemptIncomeAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ExemptIncomeAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ExpanseAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ExpanseAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Mainsupplier' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Mainsupplier' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'SupplierCatalogNo' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'SupplierCatalogNo' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnit' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnit' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseItemsPerUnit' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseItemsPerUnit' , u'pVal' , ), 21, (21, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DesiredInventory' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DesiredInventory' , u'pVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'MinInventory' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'MinInventory' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnit' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnit' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'SalesItemsPerUnit' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'SalesItemsPerUnit' , u'pVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'User_Text' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'User_Text' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'SerialNum' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'SerialNum' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercent' , u'pVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CommissionPercent' , u'pVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'CommissionSum' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'CommissionSum' , u'pVal' , ), 30, (30, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroup' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroup' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'TreeType' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'AssetItem' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'AssetItem' , u'pVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitHeight' , u'pVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitHeight' , u'pVal' , ), 34, (34, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitVolume' , u'pVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitVolume' , u'pVal' , ), 36, (36, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'DataExportCode' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'DataExportCode' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Properties' , u'GroupNum' , u'pVal' , ), 38, (38, (), [ (3, 0, None, None) , 
			(16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'Properties' , u'GroupNum' , u'pVal' , ), 38, (38, (), [ (3, 0, None, None) , 
			(3, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 39, (39, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 41, (41, (), [ (16393, 10, None, "IID('{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}')") , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Manufacturer' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'Manufacturer' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'QuantityOnStock' , u'pVal' , ), 43, (43, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'QuantityOrderedFromVendors' , u'pVal' , ), 44, (44, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'QuantityOrderedByCustomers' , u'pVal' , ), 45, (45, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'ManageSerialNumbers' , u'pVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'ManageSerialNumbers' , u'pVal' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'ManageBatchNumbers' , u'pVal' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'ManageBatchNumbers' , u'pVal' , ), 50, (50, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'Valid' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'Valid' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pVal' , ), 52, (52, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pVal' , ), 52, (52, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pVal' , ), 53, (53, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pVal' , ), 53, (53, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'ValidRemarks' , u'pVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'ValidRemarks' , u'pVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'Frozen' , u'pVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'Frozen' , u'pVal' , ), 55, (55, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'FrozenFrom' , u'pVal' , ), 56, (56, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'FrozenFrom' , u'pVal' , ), 56, (56, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'FrozenTo' , u'pVal' , ), 57, (57, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'FrozenTo' , u'pVal' , ), 57, (57, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'FrozenRemarks' , u'pVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'FrozenRemarks' , u'pVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 59, (59, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'SalesPackagingUnit' , u'pVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'SalesPackagingUnit' , u'pVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'SalesQtyPerPackUnit' , u'pVal' , ), 61, (61, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'SalesQtyPerPackUnit' , u'pVal' , ), 61, (61, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitLength' , u'pVal' , ), 62, (62, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitLength' , u'pVal' , ), 62, (62, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWidth' , u'pVal' , ), 63, (63, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWidth' , u'pVal' , ), 63, (63, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'SalesVolumeUnit' , u'pVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'SalesVolumeUnit' , u'pVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWeight' , u'pVal' , ), 65, (65, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWeight' , u'pVal' , ), 65, (65, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'PurchasePackagingUnit' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'PurchasePackagingUnit' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseQtyPerPackUnit' , u'pVal' , ), 67, (67, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseQtyPerPackUnit' , u'pVal' , ), 67, (67, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitLength' , u'pVal' , ), 68, (68, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitLength' , u'pVal' , ), 68, (68, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWidth' , u'pVal' , ), 69, (69, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWidth' , u'pVal' , ), 69, (69, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitHeight' , u'pVal' , ), 70, (70, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitHeight' , u'pVal' , ), 70, (70, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitVolume' , u'pVal' , ), 71, (71, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitVolume' , u'pVal' , ), 71, (71, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseVolumeUnit' , u'pVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseVolumeUnit' , u'pVal' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWeight' , u'pVal' , ), 73, (73, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWeight' , u'pVal' , ), 73, (73, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseVATGroup' , u'pVal' , ), 74, (74, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseVATGroup' , u'pVal' , ), 74, (74, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor1' , u'pVal' , ), 75, (75, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor1' , u'pVal' , ), 75, (75, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor2' , u'pVal' , ), 76, (76, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor2' , u'pVal' , ), 76, (76, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor3' , u'pVal' , ), 77, (77, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor3' , u'pVal' , ), 77, (77, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor4' , u'pVal' , ), 78, (78, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'SalesFactor4' , u'pVal' , ), 78, (78, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor1' , u'pVal' , ), 79, (79, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor1' , u'pVal' , ), 79, (79, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor2' , u'pVal' , ), 80, (80, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor2' , u'pVal' , ), 80, (80, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor3' , u'pVal' , ), 81, (81, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor3' , u'pVal' , ), 81, (81, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor4' , u'pVal' , ), 82, (82, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseFactor4' , u'pVal' , ), 82, (82, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'MovingAveragePrice' , u'pVal' , ), 83, (83, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'SalesLengthUnit' , u'pVal' , ), 84, (84, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'SalesLengthUnit' , u'pVal' , ), 84, (84, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'SalesWidthUnit' , u'pVal' , ), 85, (85, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'SalesWidthUnit' , u'pVal' , ), 85, (85, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'SalesHeightUnit' , u'pVal' , ), 86, (86, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'SalesHeightUnit' , u'pVal' , ), 86, (86, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'SalesWeightUnit' , u'pVal' , ), 87, (87, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'SalesWeightUnit' , u'pVal' , ), 87, (87, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWidthUnit' , u'pVal' , ), 88, (88, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWidthUnit' , u'pVal' , ), 88, (88, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseLengthUnit' , u'pVal' , ), 89, (89, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseLengthUnit' , u'pVal' , ), 89, (89, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseHeightUnit' , u'pVal' , ), 90, (90, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseHeightUnit' , u'pVal' , ), 90, (90, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWeightUnit' , u'pVal' , ), 91, (91, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWeightUnit' , u'pVal' , ), 91, (91, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAccount' , u'pVal' , ), 92, (92, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAccount' , u'pVal' , ), 92, (92, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'ECRevenuesAccount' , u'pVal' , ), 93, (93, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'ECRevenuesAccount' , u'pVal' , ), 93, (93, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 94, (94, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 94, (94, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'ECExpensesAccount' , u'pVal' , ), 95, (95, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'ECExpensesAccount' , u'pVal' , ), 95, (95, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'AvgStdPrice' , u'pVal' , ), 96, (96, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'AvgStdPrice' , u'pVal' , ), 96, (96, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'DefaultWarehouse' , u'pVal' , ), 97, (97, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'DefaultWarehouse' , u'pVal' , ), 97, (97, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'ShipType' , u'pVal' , ), 98, (98, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'ShipType' , u'pVal' , ), 98, (98, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'GLMethod' , u'pVal' , ), 99, (99, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'GLMethod' , u'pVal' , ), 99, (99, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 100, (100, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'TaxType' , u'pVal' , ), 100, (100, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'WhsInfo' , u'pVal' , ), 101, (101, (), [ (16393, 10, None, "IID('{CDB52791-B0FC-4BE1-A712-06941AF91D52}')") , ], 1 , 2 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'MaxInventory' , u'pVal' , ), 102, (102, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'MaxInventory' , u'pVal' , ), 102, (102, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'ManageStockByWarehouse' , u'pVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'ManageStockByWarehouse' , u'pVal' , ), 103, (103, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseHeightUnit1' , u'pVal' , ), 104, (104, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseHeightUnit1' , u'pVal' , ), 104, (104, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitHeight1' , u'pVal' , ), 105, (105, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitHeight1' , u'pVal' , ), 105, (105, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseLengthUnit1' , u'pVal' , ), 106, (106, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseLengthUnit1' , u'pVal' , ), 106, (106, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitLength1' , u'pVal' , ), 107, (107, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitLength1' , u'pVal' , ), 107, (107, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWeightUnit1' , u'pVal' , ), 108, (108, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWeightUnit1' , u'pVal' , ), 108, (108, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWeight1' , u'pVal' , ), 109, (109, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWeight1' , u'pVal' , ), 109, (109, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWidthUnit1' , u'pVal' , ), 110, (110, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseWidthUnit1' , u'pVal' , ), 110, (110, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWidth1' , u'pVal' , ), 111, (111, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseUnitWidth1' , u'pVal' , ), 111, (111, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'SalesHeightUnit1' , u'pVal' , ), 112, (112, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'SalesHeightUnit1' , u'pVal' , ), 112, (112, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitHeight1' , u'pVal' , ), 113, (113, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitHeight1' , u'pVal' , ), 113, (113, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'SalesLengthUnit1' , u'pVal' , ), 114, (114, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'SalesLengthUnit1' , u'pVal' , ), 114, (114, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitLength1' , u'pVal' , ), 115, (115, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitLength1' , u'pVal' , ), 115, (115, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'SalesWeightUnit1' , u'pVal' , ), 116, (116, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'SalesWeightUnit1' , u'pVal' , ), 116, (116, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWeight1' , u'pVal' , ), 117, (117, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWeight1' , u'pVal' , ), 117, (117, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'SalesWidthUnit1' , u'pVal' , ), 118, (118, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'SalesWidthUnit1' , u'pVal' , ), 118, (118, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWidth1' , u'pVal' , ), 119, (119, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'SalesUnitWidth1' , u'pVal' , ), 119, (119, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'ForceSelectionOfSerialNumber' , u'pVal' , ), 120, (120, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'ForceSelectionOfSerialNumber' , u'pVal' , ), 120, (120, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
	(( u'ManageSerialNumbersOnReleaseOnly' , u'pVal' , ), 121, (121, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 916 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 122, (122, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 920 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 122, (122, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 924 , (3, 0, None, None) , 0 , )),
	(( u'BaseUnitName' , u'pVal' , ), 123, (123, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 928 , (3, 0, None, None) , 0 , )),
	(( u'BaseUnitName' , u'pVal' , ), 123, (123, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 932 , (3, 0, None, None) , 0 , )),
	(( u'ItemCountryOrg' , u'pVal' , ), 124, (124, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 936 , (3, 0, None, None) , 0 , )),
	(( u'ItemCountryOrg' , u'pVal' , ), 124, (124, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 940 , (3, 0, None, None) , 0 , )),
	(( u'SWW' , u'pVal' , ), 125, (125, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 944 , (3, 0, None, None) , 0 , )),
	(( u'SWW' , u'pVal' , ), 125, (125, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 948 , (3, 0, None, None) , 0 , )),
	(( u'ManageSerialNumbersOnReleaseOnly' , u'pVal' , ), 121, (121, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 952 , (3, 0, None, None) , 0 , )),
	(( u'ApTaxCode' , u'pbstrRsltVal' , ), 126, (126, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 956 , (3, 0, None, None) , 0 , )),
	(( u'ApTaxCode' , u'pbstrRsltVal' , ), 126, (126, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 960 , (3, 0, None, None) , 0 , )),
	(( u'ArTaxCode' , u'pbstrRsltVal' , ), 127, (127, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 964 , (3, 0, None, None) , 0 , )),
	(( u'ArTaxCode' , u'pbstrRsltVal' , ), 127, (127, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 968 , (3, 0, None, None) , 0 , )),
	(( u'CostAccountingMethod' , u'pVal' , ), 128, (128, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 972 , (3, 0, None, None) , 0 , )),
	(( u'CostAccountingMethod' , u'pVal' , ), 128, (128, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 976 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyTemplate' , u'pVal' , ), 129, (129, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 980 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyTemplate' , u'pVal' , ), 129, (129, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 984 , (3, 0, None, None) , 0 , )),
	(( u'IndirectTax' , u'penumRslt' , ), 130, (130, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 988 , (3, 0, None, None) , 0 , )),
	(( u'IndirectTax' , u'penumRslt' , ), 130, (130, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 992 , (3, 0, None, None) , 0 , )),
	(( u'IssueMethod' , u'pVal' , ), 131, (131, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 996 , (3, 0, None, None) , 0 , )),
	(( u'IssueMethod' , u'pVal' , ), 131, (131, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1000 , (3, 0, None, None) , 0 , )),
	(( u'SRIAndBatchManageMethod' , u'pVal' , ), 132, (132, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1004 , (3, 0, None, None) , 0 , )),
	(( u'SRIAndBatchManageMethod' , u'pVal' , ), 132, (132, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1008 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 133, (133, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 1012 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 134, (134, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 1016 , (3, 0, None, None) , 0 , )),
	(( u'IsPhantom' , u'penumRsltVal' , ), 135, (135, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1020 , (3, 0, None, None) , 0 , )),
	(( u'IsPhantom' , u'penumRsltVal' , ), 135, (135, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1024 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 136, (136, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1028 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 136, (136, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1032 , (3, 0, None, None) , 0 , )),
	(( u'PlanningSystem' , u'penumRsltVal' , ), 137, (137, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1036 , (3, 0, None, None) , 0 , )),
	(( u'PlanningSystem' , u'penumRsltVal' , ), 137, (137, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1040 , (3, 0, None, None) , 0 , )),
	(( u'ProcurementMethod' , u'penumRsltVal' , ), 138, (138, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1044 , (3, 0, None, None) , 0 , )),
	(( u'ProcurementMethod' , u'penumRsltVal' , ), 138, (138, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1048 , (3, 0, None, None) , 0 , )),
	(( u'OrderIntervals' , u'pbstrRsltVal' , ), 139, (139, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1052 , (3, 0, None, None) , 0 , )),
	(( u'OrderIntervals' , u'pbstrRsltVal' , ), 139, (139, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1056 , (3, 0, None, None) , 0 , )),
	(( u'OrderMultiple' , u'pdblRsltVal' , ), 140, (140, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1060 , (3, 0, None, None) , 0 , )),
	(( u'OrderMultiple' , u'pdblRsltVal' , ), 140, (140, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1064 , (3, 0, None, None) , 0 , )),
	(( u'LeadTime' , u'plRsltVal' , ), 141, (141, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1068 , (3, 0, None, None) , 0 , )),
	(( u'LeadTime' , u'plRsltVal' , ), 141, (141, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1072 , (3, 0, None, None) , 0 , )),
	(( u'MinOrderQuantity' , u'pdblRsltVal' , ), 142, (142, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 1076 , (3, 0, None, None) , 0 , )),
	(( u'MinOrderQuantity' , u'pdblRsltVal' , ), 142, (142, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 1080 , (3, 0, None, None) , 0 , )),
	(( u'ItemType' , u'penumRsltVal' , ), 143, (143, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1084 , (3, 0, None, None) , 0 , )),
	(( u'ItemType' , u'penumRsltVal' , ), 143, (143, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1088 , (3, 0, None, None) , 0 , )),
	(( u'ItemClass' , u'pVal' , ), 144, (144, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1092 , (3, 0, None, None) , 0 , )),
	(( u'ItemClass' , u'pVal' , ), 144, (144, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1096 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingServiceCode' , u'pVal' , ), 145, (145, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1100 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingServiceCode' , u'pVal' , ), 145, (145, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1104 , (3, 0, None, None) , 0 , )),
	(( u'IncomingServiceCode' , u'pVal' , ), 146, (146, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1108 , (3, 0, None, None) , 0 , )),
	(( u'IncomingServiceCode' , u'pVal' , ), 146, (146, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1112 , (3, 0, None, None) , 0 , )),
	(( u'ServiceGroup' , u'pVal' , ), 147, (147, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1116 , (3, 0, None, None) , 0 , )),
	(( u'ServiceGroup' , u'pVal' , ), 147, (147, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1120 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'pVal' , ), 148, (148, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1124 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'pVal' , ), 148, (148, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1128 , (3, 0, None, None) , 0 , )),
	(( u'MaterialType' , u'pVal' , ), 149, (149, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1132 , (3, 0, None, None) , 0 , )),
	(( u'MaterialType' , u'pVal' , ), 149, (149, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1136 , (3, 0, None, None) , 0 , )),
	(( u'MaterialGroup' , u'pVal' , ), 150, (150, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1140 , (3, 0, None, None) , 0 , )),
	(( u'MaterialGroup' , u'pVal' , ), 150, (150, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1144 , (3, 0, None, None) , 0 , )),
	(( u'ProductSource' , u'pVal' , ), 151, (151, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1148 , (3, 0, None, None) , 0 , )),
	(( u'ProductSource' , u'pVal' , ), 151, (151, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1152 , (3, 0, None, None) , 0 , )),
	(( u'AutoCreateSerialNumbersOnRelease' , u'pVal' , ), 152, (152, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1156 , (3, 0, None, None) , 0 , )),
	(( u'AutoCreateSerialNumbersOnRelease' , u'pVal' , ), 152, (152, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1160 , (3, 0, None, None) , 0 , )),
	(( u'DNFEntry' , u'pVal' , ), 153, (153, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1164 , (3, 0, None, None) , 0 , )),
	(( u'DNFEntry' , u'pVal' , ), 153, (153, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1168 , (3, 0, None, None) , 0 , )),
	(( u'GTSItemSpec' , u'pVal' , ), 154, (154, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1172 , (3, 0, None, None) , 0 , )),
	(( u'GTSItemSpec' , u'pVal' , ), 154, (154, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1176 , (3, 0, None, None) , 0 , )),
	(( u'GTSItemTaxCategory' , u'pVal' , ), 155, (155, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1180 , (3, 0, None, None) , 0 , )),
	(( u'GTSItemTaxCategory' , u'pVal' , ), 155, (155, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1184 , (3, 0, None, None) , 0 , )),
	(( u'PreferredVendors' , u'pVal' , ), 156, (156, (), [ (16393, 10, None, "IID('{9048203E-CE84-4B53-B4C7-61632BD2DEAC}')") , ], 1 , 2 , 4 , 0 , 1188 , (3, 0, None, None) , 0 , )),
	(( u'FuelID' , u'pVal' , ), 157, (157, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1192 , (3, 0, None, None) , 0 , )),
	(( u'FuelID' , u'pVal' , ), 157, (157, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1196 , (3, 0, None, None) , 0 , )),
	(( u'BeverageTableCode' , u'pVal' , ), 158, (158, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1200 , (3, 0, None, None) , 0 , )),
	(( u'BeverageTableCode' , u'pVal' , ), 158, (158, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1204 , (3, 0, None, None) , 0 , )),
	(( u'BeverageGroupCode' , u'pVal' , ), 159, (159, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 1208 , (3, 0, None, None) , 0 , )),
	(( u'BeverageGroupCode' , u'pVal' , ), 159, (159, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 1212 , (3, 0, None, None) , 0 , )),
	(( u'BeverageCommercialBrandCode' , u'pVal' , ), 160, (160, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1216 , (3, 0, None, None) , 0 , )),
	(( u'BeverageCommercialBrandCode' , u'pVal' , ), 160, (160, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1220 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 161, (161, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1224 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 161, (161, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1228 , (3, 0, None, None) , 0 , )),
	(( u'ToleranceDays' , u'pVal' , ), 162, (162, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 1232 , (3, 0, None, None) , 0 , )),
	(( u'ToleranceDays' , u'pVal' , ), 162, (162, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 1236 , (3, 0, None, None) , 0 , )),
	(( u'LocalizationInfos' , u'ppInfos' , ), 163, (163, (), [ (16393, 10, None, "IID('{04B4DCB9-A2CD-4C53-BD52-FA43B7754803}')") , ], 1 , 2 , 4 , 0 , 1240 , (3, 0, None, None) , 0 , )),
]

IItems_PreferredVendors_vtables_dispatch_ = 1
IItems_PreferredVendors_vtables_ = [
	(( u'BPCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 5, (5, (), [ ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IItems_Prices_vtables_dispatch_ = 1
IItems_Prices_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'PriceListName' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IJournalEntries_vtables_dispatch_ = 1
IJournalEntries_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{55053980-777B-44CF-8D76-84DD975171AA}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'JdtNum' , u'Found' , ), 4, (4, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate' , u'pVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate' , u'pVal' , ), 5, (5, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Memo' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'JdtNum' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 16, (16, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Indicator' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'UseAutoStorno' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'UseAutoStorno' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'StornoDate' , u'pVal' , ), 24, (24, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'StornoDate' , u'pVal' , ), 24, (24, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 1 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 27, (27, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 27, (27, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'StampTax' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'StampTax' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 32, (32, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 32, (32, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'AutoVAT' , u'penumRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'AutoVAT' , u'penumRsltVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'plRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'FolioNumber' , u'plRsltVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'FolioPrefixString' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ReportEU' , u'penumRsltVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ReportEU' , u'penumRsltVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Report347' , u'penumRsltVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Report347' , u'penumRsltVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'penumRsltVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'Original' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'BaseReference' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunningLetter' , u'penumRsltVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'BlockDunningLetter' , u'penumRsltVal' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'OriginalJournal' , u'penumRsltVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'AutomaticWT' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'AutomaticWT' , u'pVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'WTSum' , u'pVal' , ), 48, (48, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'WTSumSC' , u'pVal' , ), 49, (49, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'WTSumFC' , u'pVal' , ), 50, (50, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingTaxData' , u'ppRsltVal' , ), 51, (51, (), [ (16393, 10, None, "IID('{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}')") , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Corisptivi' , u'pVal' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'Corisptivi' , u'pVal' , ), 52, (52, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'SignatureInputMessage' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'SignatureDigest' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'CertificationNumber' , u'pVal' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'PrivateKeyVersion' , u'pVal' , ), 65, (65, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Reference3' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Reference3' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'BlanketAgreementNumber' , u'pVal' , ), 68, (68, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
]

IJournalEntries_Lines_vtables_dispatch_ = 1
IJournalEntries_Lines_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Line_ID' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Debit' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Debit' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Credit' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Credit' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'FCDebit' , u'pVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FCDebit' , u'pVal' , ), 9, (9, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'FCCredit' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'FCCredit' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'FCCurrency' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'FCCurrency' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ContraAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ContraAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'LineMemo' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'LineMemo' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate1' , u'pVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate1' , u'pVal' , ), 16, (16, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate2' , u'pVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ReferenceDate2' , u'pVal' , ), 17, (17, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 23, (23, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 23, (23, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BaseSum' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BaseSum' , u'pVal' , ), 24, (24, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DebitSys' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'CreditSys' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 28, (28, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 28, (28, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'VatLine' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'VatLine' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'SystemBaseAmount' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'SystemBaseAmount' , u'pVal' , ), 30, (30, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'VatAmount' , u'pVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'SystemVatAmount' , u'pVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'GrossValue' , u'pVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalReference' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalReference' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'CheckAbs' , u'plRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'GrossValue' , u'pVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'SystemVatAmount' , u'pVal' , ), 32, (32, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'VatAmount' , u'pVal' , ), 31, (31, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'DebitSys' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'CreditSys' , u'pVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode2' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode2' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode3' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode3' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode4' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode4' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'TaxPostAccount' , u'pVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'TaxPostAccount' , u'pVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 41, (41, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode5' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'CostingCode5' , u'pVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxAmount' , u'pVal' , ), 43, (43, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'SystemEqualizationTaxAmount' , u'pVal' , ), 44, (44, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'TotalTax' , u'pVal' , ), 45, (45, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'SystemTotalTax' , u'pVal' , ), 46, (46, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'WTLiable' , u'pVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'WTRow' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'WTRow' , u'pVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'ControlAccount' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'ControlAccount' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlock' , u'pVal' , ), 50, (50, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'BlockReason' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'BlockReason' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryFormItems' , u'pVal' , ), 53, (53, (), [ (16393, 10, None, "IID('{A0307CBF-64B1-49E8-B60D-38803E20D107}')") , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 61, (61, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 61, (61, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'BPLName' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'VATRegNum' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'PaymentOrdered' , u'pVal' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
]

IJournalEntryDocumentType_vtables_dispatch_ = 1
IJournalEntryDocumentType_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntryType' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntryType' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocTypeDescription' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocTypeDescription' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IJournalEntryDocumentTypeParams_vtables_dispatch_ = 1
IJournalEntryDocumentTypeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntryType' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntryType' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocTypeDescription' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ShortName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IJournalEntryDocumentTypeParamsCollection_vtables_dispatch_ = 1
IJournalEntryDocumentTypeParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IJournalEntryDocumentTypeService_vtables_dispatch_ = 1
IJournalEntryDocumentTypeService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIJournalEntryDocumentType' , u'ppIJournalEntryDocumentTypeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{56B7FEB9-ECC9-4A64-BDDF-0AB70C3746D0}')") , 
			(16393, 10, None, "IID('{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pIJournalEntryDocumentType' , ), 11, (11, (), [ (9, 1, None, "IID('{56B7FEB9-ECC9-4A64-BDDF-0AB70C3746D0}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIJournalEntryDocumentTypeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIJournalEntryDocumentTypeParams' , u'ppIJournalEntryDocumentType' , ), 13, (13, (), [ (9, 1, None, "IID('{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}')") , 
			(16393, 10, None, "IID('{56B7FEB9-ECC9-4A64-BDDF-0AB70C3746D0}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppIJournalEntryDocumentTypeParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{A0F06FB9-C420-4CA6-B1A5-D688A5322E8D}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IJournalVouchers_vtables_dispatch_ = 1
IJournalVouchers_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'JournalEntries' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{060F033E-2FC9-4266-90AE-3271AC203A59}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'LoadFromXML' , u'FileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveToXMLHierarchy' , u'FileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
]

IKPI_vtables_dispatch_ = 1
IKPI_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'KPICode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'KPICode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'KPIName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'KPIName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'KPIType' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'KPIType' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfColumns' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfColumns' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'KPI_ItemLines' , u'ppRsltVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{9D5AE661-24A0-4F2A-AE75-714F3FF59B91}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IKPIParams_vtables_dispatch_ = 1
IKPIParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'KPICode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'KPICode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'KPIName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IKPI_ItemLine_vtables_dispatch_ = 1
IKPI_ItemLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'KPICode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'KPILineNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'KPIName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'KPIName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue1' , u'ppRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue1' , u'ppRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue2' , u'ppRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue2' , u'ppRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue3' , u'ppRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue3' , u'ppRsltVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue4' , u'ppRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue4' , u'ppRsltVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue5' , u'ppRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue5' , u'ppRsltVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue6' , u'ppRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue6' , u'ppRsltVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue7' , u'ppRsltVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue7' , u'ppRsltVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue8' , u'ppRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue8' , u'ppRsltVal' , ), 20, (20, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue9' , u'ppRsltVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue9' , u'ppRsltVal' , ), 21, (21, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue10' , u'ppRsltVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue10' , u'ppRsltVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue11' , u'ppRsltVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue11' , u'ppRsltVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue12' , u'ppRsltVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue12' , u'ppRsltVal' , ), 24, (24, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue13' , u'ppRsltVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue13' , u'ppRsltVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue14' , u'ppRsltVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue14' , u'ppRsltVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue15' , u'ppRsltVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue15' , u'ppRsltVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue16' , u'ppRsltVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue16' , u'ppRsltVal' , ), 28, (28, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue17' , u'ppRsltVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue17' , u'ppRsltVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue18' , u'ppRsltVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue18' , u'ppRsltVal' , ), 30, (30, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue19' , u'ppRsltVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue19' , u'ppRsltVal' , ), 31, (31, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue20' , u'ppRsltVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue20' , u'ppRsltVal' , ), 32, (32, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue21' , u'ppRsltVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue21' , u'ppRsltVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue22' , u'ppRsltVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue22' , u'ppRsltVal' , ), 34, (34, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue23' , u'ppRsltVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue23' , u'ppRsltVal' , ), 35, (35, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue24' , u'ppRsltVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue24' , u'ppRsltVal' , ), 36, (36, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue25' , u'ppRsltVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue25' , u'ppRsltVal' , ), 37, (37, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue26' , u'ppRsltVal' , ), 38, (38, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue26' , u'ppRsltVal' , ), 38, (38, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue27' , u'ppRsltVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue27' , u'ppRsltVal' , ), 39, (39, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue28' , u'ppRsltVal' , ), 40, (40, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue28' , u'ppRsltVal' , ), 40, (40, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue29' , u'ppRsltVal' , ), 41, (41, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue29' , u'ppRsltVal' , ), 41, (41, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue30' , u'ppRsltVal' , ), 42, (42, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'KPIValue30' , u'ppRsltVal' , ), 42, (42, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
]

IKPI_ItemLines_vtables_dispatch_ = 1
IKPI_ItemLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{48D8151E-BF85-4760-B7F8-B5E7E1B47937}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{48D8151E-BF85-4760-B7F8-B5E7E1B47937}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IKPIsParams_vtables_dispatch_ = 1
IKPIsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{41A28682-1C73-4C77-ADC8-5F805700B244}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{41A28682-1C73-4C77-ADC8-5F805700B244}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IKPIsService_vtables_dispatch_ = 1
IKPIsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIKPI' , u'ppIKPIParams' , ), 10, (10, (), [ (9, 1, None, "IID('{087B9C04-C8CF-4606-A7B4-8FEC6CB8AE1D}')") , 
			(16393, 10, None, "IID('{41A28682-1C73-4C77-ADC8-5F805700B244}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pIKPI' , ), 11, (11, (), [ (9, 1, None, "IID('{087B9C04-C8CF-4606-A7B4-8FEC6CB8AE1D}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIKPIParams' , ), 12, (12, (), [ (9, 1, None, "IID('{41A28682-1C73-4C77-ADC8-5F805700B244}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIKPIParams' , u'ppIKPI' , ), 13, (13, (), [ (9, 1, None, "IID('{41A28682-1C73-4C77-ADC8-5F805700B244}')") , 
			(16393, 10, None, "IID('{087B9C04-C8CF-4606-A7B4-8FEC6CB8AE1D}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppIKPIsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{44F97BA6-22A5-4687-BFBF-863A346A414C}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IKnowledgeBaseSolutions_vtables_dispatch_ = 1
IKnowledgeBaseSolutions_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'SolutionCode' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CreatedBy' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdatedBy' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'LastUpdateDate' , u'pVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Solution' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Solution' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Symptom' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Symptom' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Cause' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Cause' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'SolutionCode' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
]

ILandedCost_vtables_dispatch_ = 1
ILandedCost_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LandedCostNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pdateRsltVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pdateRsltVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdateRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'VendorCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'VendorCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'VendorName' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'VendorName' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Broker' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Broker' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BrokerName' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BrokerName' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ClosedDocument' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ClosedDocument' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'FileNumber' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FileNumber' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCurrency' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCurrency' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DocumentRate' , u'ppRsltVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DocumentRate' , u'ppRsltVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ProjectedCustoms' , u'ppRsltVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ActualCustoms' , u'ppRsltVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ActualCustoms' , u'ppRsltVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Tax1' , u'ppRsltVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Tax1' , u'ppRsltVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Tax2' , u'ppRsltVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Tax2' , u'ppRsltVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'BeforeTax' , u'ppRsltVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Total' , u'ppRsltVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'TotalFreightCharges' , u'ppRsltVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ProjectedCustomsFC' , u'ppRsltVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Tax1FC' , u'ppRsltVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Tax1FC' , u'ppRsltVal' , ), 32, (32, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Tax2FC' , u'ppRsltVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Tax2FC' , u'ppRsltVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'BeforeTaxFC' , u'ppRsltVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'TotalFC' , u'ppRsltVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'TotalFreightChargesFC' , u'ppRsltVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'CustomsAffectsInventory' , u'penumRsltVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'CustomsAffectsInventory' , u'penumRsltVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'AmountToBalance' , u'ppRsltVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'AmountToBalanceFC' , u'ppRsltVal' , ), 40, (40, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'BillofLadingNumber' , u'pbstrRsltVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'BillofLadingNumber' , u'pbstrRsltVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'TransportType' , u'plRsltVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'TransportType' , u'plRsltVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'TransactionNumber' , u'plRsltVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pbstrRsltVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pbstrRsltVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'LandedCost_ItemLines' , u'ppRsltVal' , ), 45, (45, (), [ (16393, 10, None, "IID('{36143269-AD6C-4AD9-9A2E-AE3273141D8C}')") , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'LandedCost_CostLines' , u'ppRsltVal' , ), 46, (46, (), [ (16393, 10, None, "IID('{83CB8BC4-7FE1-4C02-81B4-35EE3C252DC8}')") , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ActualCustomsFC' , u'ppRsltVal' , ), 47, (47, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'ActualCustomsFC' , u'ppRsltVal' , ), 47, (47, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
]

ILandedCostParams_vtables_dispatch_ = 1
ILandedCostParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LandedCostNumber' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LandedCostNumber' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ILandedCost_CostLine_vtables_dispatch_ = 1
ILandedCost_CostLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LandedCostCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LandedCostCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AllocationBy' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AllocationBy' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'amount' , u'ppRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'amount' , u'ppRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AmountFC' , u'ppRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AmountFC' , u'ppRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'ppRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CostType' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CostType' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'IncludeForCustoms' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'IncludeForCustoms' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

ILandedCost_CostLines_vtables_dispatch_ = 1
ILandedCost_CostLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{7AF930C1-1211-4953-BD69-5F64B3743316}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{7AF930C1-1211-4953-BD69-5F64B3743316}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ILandedCost_ItemLine_vtables_dispatch_ = 1
ILandedCost_ItemLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocumentType' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocumentType' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BaseEntry' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BaseEntry' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Number' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'ppRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'ppRsltVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocumentPrice' , u'ppRsltVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocumentPrice' , u'ppRsltVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'ppRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ProjectedCustoms' , u'ppRsltVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ProjectedCustoms' , u'ppRsltVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ProjectedCustomsFC' , u'ppRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ProjectedCustomsFC' , u'ppRsltVal' , ), 20, (20, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Expenditure' , u'ppRsltVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Expenditure' , u'ppRsltVal' , ), 21, (21, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ExpenditureFC' , u'ppRsltVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ExpenditureFC' , u'ppRsltVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'WarehousePrice' , u'ppRsltVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'WarehousePriceFC' , u'ppRsltVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'LineTotal' , u'ppRsltVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'LineTotalFC' , u'ppRsltVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Volume' , u'ppRsltVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Volume' , u'ppRsltVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'VolumeUoM' , u'plRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'VolumeUoM' , u'plRsltVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Weight1' , u'ppRsltVal' , ), 29, (29, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Weight1' , u'ppRsltVal' , ), 29, (29, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Weight1UnitCode' , u'plRsltVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Weight1UnitCode' , u'plRsltVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Weight2' , u'ppRsltVal' , ), 31, (31, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Weight2' , u'ppRsltVal' , ), 31, (31, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Weight2UnitCode' , u'plRsltVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Weight2UnitCode' , u'plRsltVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'VendorCode' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'FactorWithoutCustoms' , u'ppRsltVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'FactorWithCustoms' , u'ppRsltVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'BlockNumber' , u'pbstrRsltVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'BlockNumber' , u'pbstrRsltVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ImportLog' , u'pbstrRsltVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ImportLog' , u'pbstrRsltVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'OriginalWarehouse' , u'pbstrRsltVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ReleaseNumber' , u'plRsltVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'VariantCosts' , u'ppRsltVal' , ), 43, (43, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'FixCosts' , u'ppRsltVal' , ), 44, (44, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'VariantCostsFC' , u'ppRsltVal' , ), 45, (45, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'FixCostsFC' , u'ppRsltVal' , ), 46, (46, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Customs' , u'ppRsltVal' , ), 47, (47, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'CustomsFC' , u'ppRsltVal' , ), 48, (48, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocumentValueLineTotal' , u'ppRsltVal' , ), 49, (49, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocumentValueLineTotalFC' , u'ppRsltVal' , ), 50, (50, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'AllocatedUnitCostsLineTotal' , u'ppRsltVal' , ), 51, (51, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'AllocatedUnitCostsLineTotal' , u'ppRsltVal' , ), 51, (51, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'AllocatedUnitCostsLineTotalFC' , u'ppRsltVal' , ), 52, (52, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'AllocatedUnitCostsLineTotalFC' , u'ppRsltVal' , ), 52, (52, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'CustomsValue' , u'ppRsltVal' , ), 53, (53, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'CustomsValue' , u'ppRsltVal' , ), 53, (53, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'CustomsValueFC' , u'ppRsltVal' , ), 54, (54, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'CustomsValueFC' , u'ppRsltVal' , ), 54, (54, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'TotalCosts' , u'ppRsltVal' , ), 55, (55, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'TotalCostsFC' , u'ppRsltVal' , ), 56, (56, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'TotalVolume' , u'ppRsltVal' , ), 57, (57, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'TotalVolume' , u'ppRsltVal' , ), 57, (57, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'BaseLine' , u'plRsltVal' , ), 58, (58, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'BaseLine' , u'plRsltVal' , ), 58, (58, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'TotalLineProjectedCustoms' , u'ppRsltVal' , ), 59, (59, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'AllocatedCostsLineTotal' , u'ppRsltVal' , ), 60, (60, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'FOBandIncludedCosts' , u'ppRsltVal' , ), 61, (61, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'FOBandIncludedCostsFC' , u'ppRsltVal' , ), 62, (62, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 64, (64, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'plRsltVal' , ), 69, (69, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'plRsltVal' , ), 69, (69, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'AutomaticExpenditure' , u'penumRsltVal' , ), 70, (70, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'AutomaticExpenditure' , u'penumRsltVal' , ), 70, (70, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'InventoryValuation' , u'penumRsltVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'InventoryValuation' , u'penumRsltVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'OriginLine' , u'plRsltVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'OriginLine' , u'plRsltVal' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pbstrRsltVal' , ), 73, (73, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pbstrRsltVal' , ), 73, (73, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'CustomsGroupRate' , u'plRsltVal' , ), 74, (74, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
]

ILandedCost_ItemLines_vtables_dispatch_ = 1
ILandedCost_ItemLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{052A6BA1-A1AA-4A04-ABDE-23FE11833711}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{052A6BA1-A1AA-4A04-ABDE-23FE11833711}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ILandedCostsCodes_vtables_dispatch_ = 1
ILandedCostsCodes_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrCode' , u'pbRsltFound' , ), 6, (6, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AllocationBy' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AllocationBy' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'LandedCostsAllocationAccount' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'LandedCostsAllocationAccount' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

ILandedCostsParams_vtables_dispatch_ = 1
ILandedCostsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ILandedCostsService_vtables_dispatch_ = 1
ILandedCostsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddLandedCost' , u'pILandedCost' , u'ppILandedCostParams' , ), 10, (10, (), [ (9, 1, None, "IID('{069837FF-A1F4-4442-92EF-DFEA56C23992}')") , 
			(16393, 10, None, "IID('{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateLandedCost' , u'pILandedCost' , ), 11, (11, (), [ (9, 1, None, "IID('{069837FF-A1F4-4442-92EF-DFEA56C23992}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetLandedCost' , u'pILandedCostParams' , u'ppILandedCost' , ), 12, (12, (), [ (9, 1, None, "IID('{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')") , 
			(16393, 10, None, "IID('{069837FF-A1F4-4442-92EF-DFEA56C23992}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetLandedCostList' , u'ppILandedCostsParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{F5221870-4600-47CC-AFA3-779B11403820}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CloseLandedCost' , u'pILandedCostParams' , ), 14, (14, (), [ (9, 1, None, "IID('{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CancelLandedCost' , u'pILandedCostParams' , ), 15, (15, (), [ (9, 1, None, "IID('{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ILayer_vtables_dispatch_ = 1
ILayer_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TransactionSequenceNum' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TransactionSequenceNum' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LayerID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LayerID' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocNumber' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'EntryDate' , u'pdtRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CurrentCost' , u'pdblRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'OpenQty' , u'pdblRsltVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

ILayers_vtables_dispatch_ = 1
ILayers_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{9739A029-5EB0-499A-9E72-967B98D55ECF}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{9739A029-5EB0-499A-9E72-967B98D55ECF}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ILegalData_vtables_dispatch_ = 1
ILegalData_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SourceObjectType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SourceObjectType' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SourceObjectEntry' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SourceObjectEntry' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DateOfPrinting' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DateOfPrinting' , u'pdateRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TimeOfPrinting' , u'ptimeRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TimeOfPrinting' , u'ptimeRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PrinterBrand' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PrinterBrand' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PrinterType' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PrinterType' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'PrinterModel' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PrinterModel' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PrinterFirmwareVersion' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'PrinterFirmwareVersion' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PrinterDllVersion' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PrinterDllVersion' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'FiscalSeries' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'FiscalSeries' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'FiscalNumber' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'FiscalNumber' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'FiscalUserID' , u'plRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'FiscalUserID' , u'plRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'LegalDataDetailCollection' , u'ppRsltVal' , ), 24, (24, (), [ (16393, 10, None, "IID('{70CF9E47-2388-4A02-BC90-6F7CA6220DCB}')") , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
]

ILegalDataDetail_vtables_dispatch_ = 1
ILegalDataDetail_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineSequence' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LineType' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LineType' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxRate' , u'ppRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxRate' , u'ppRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'amount' , u'ppRsltVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'amount' , u'ppRsltVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ILegalDataDetailCollection_vtables_dispatch_ = 1
ILegalDataDetailCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{86767BCE-5E50-43DB-98D1-AB217A925BF9}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{86767BCE-5E50-43DB-98D1-AB217A925BF9}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ILegalDataParams_vtables_dispatch_ = 1
ILegalDataParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SourceObjectType' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SourceObjectEntry' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ILegalDataParamsCollection_vtables_dispatch_ = 1
ILegalDataParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ILegalDataService_vtables_dispatch_ = 1
ILegalDataService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pILegalData' , u'ppILegalDataParams' , ), 10, (10, (), [ (9, 1, None, "IID('{59837FCB-2720-45D3-85BF-9F075D5D6560}')") , 
			(16393, 10, None, "IID('{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pILegalData' , ), 11, (11, (), [ (9, 1, None, "IID('{59837FCB-2720-45D3-85BF-9F075D5D6560}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pILegalDataParams' , u'ppILegalData' , ), 12, (12, (), [ (9, 1, None, "IID('{69FA8A61-A978-4B0A-AF72-0419D377EDF2}')") , 
			(16393, 10, None, "IID('{59837FCB-2720-45D3-85BF-9F075D5D6560}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

ILengthMeasures_vtables_dispatch_ = 1
ILengthMeasures_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lUnitCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UnitCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UnitDisplay' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UnitDisplay' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UnitName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UnitName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UnitCodeforQuantityDisplay' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'UnitCodeforQuantityDisplay' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'UnitLengthinmm' , u'pdblRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'UnitLengthinmm' , u'pdblRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

ILocalEra_vtables_dispatch_ = 1
ILocalEra_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrCode' , u'pbRsltFound' , ), 6, (6, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'EraName' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdtRsltVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IManufacturers_vtables_dispatch_ = 1
IManufacturers_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IMaterialGroup_vtables_dispatch_ = 1
IMaterialGroup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'MaterialGroupCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'MaterialGroupCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IMaterialGroupParams_vtables_dispatch_ = 1
IMaterialGroupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'MaterialGroupCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IMaterialGroupsParams_vtables_dispatch_ = 1
IMaterialGroupsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IMaterialGroupsService_vtables_dispatch_ = 1
IMaterialGroupsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddMaterialGroup' , u'pIMaterialGroup' , u'ppIMaterialGroupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{CF683F67-7A73-4D71-9C10-821A1E7715DC}')") , 
			(16393, 10, None, "IID('{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateMaterialGroup' , u'pIMaterialGroup' , ), 11, (11, (), [ (9, 1, None, "IID('{CF683F67-7A73-4D71-9C10-821A1E7715DC}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteMaterialGroup' , u'pIMaterialGroupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetMaterialGroup' , u'pIMaterialGroupParams' , u'ppIMaterialGroup' , ), 13, (13, (), [ (9, 1, None, "IID('{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}')") , 
			(16393, 10, None, "IID('{CF683F67-7A73-4D71-9C10-821A1E7715DC}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetMaterialGroupList' , u'ppIMaterialGroupsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{9AA94F66-6356-43C6-A77E-C638B796511B}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IMaterialRevaluation_vtables_dispatch_ = 1
IMaterialRevaluation_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{038A3F8E-2465-435E-8D05-F510620533C3}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 4, (4, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 4, (4, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocTime' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AbsEntry' , u'Found' , ), 12, (12, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 13, (13, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 14, (14, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 21, (21, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 22, (22, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TransNum' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'RevalType' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'RevalType' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationIncomeAccount' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationIncomeAccount' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationExpenseAccount' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationExpenseAccount' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DataSource' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'InflationRevaluation' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'InflationRevaluation' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
]

IMaterialRevaluationFIFO_vtables_dispatch_ = 1
IMaterialRevaluationFIFO_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Layers' , u'ppRsltVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{6C589BC6-9ACE-4A99-8097-038E9AC52155}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IMaterialRevaluationFIFOParams_vtables_dispatch_ = 1
IMaterialRevaluationFIFOParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LocationType' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LocationType' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ShowIssuedLayers' , u'pbstrRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ShowIssuedLayers' , u'pbstrRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IMaterialRevaluationFIFOService_vtables_dispatch_ = 1
IMaterialRevaluationFIFOService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetMaterialRevaluationFIFO' , u'pIMaterialRevaluationFIFOParams' , u'ppIMaterialRevaluationFIFO' , ), 10, (10, (), [ (9, 1, None, "IID('{C1DD2F9D-7198-47C3-936D-46E421503333}')") , 
			(16393, 10, None, "IID('{F5C29BC7-F643-4A93-9026-C045A11D564A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
]

IMaterialRevaluation_lines_vtables_dispatch_ = 1
IMaterialRevaluation_lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 9, (9, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ActualPrice' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'OnHand' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DebitCredit' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DebitCredit' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationDecrementAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationDecrementAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationIncrementAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'RevaluationIncrementAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'RevalAmountToStock' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'FIFOLayers' , u'pVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{2C4B93F4-860D-481D-85C5-020876095197}')") , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
]

IMessage_vtables_dispatch_ = 1
IMessage_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'User' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'User' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Text' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Text' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Attachment' , u'plRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Attachment' , u'plRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MessageDataColumns' , u'ppRsltVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{002ACD1C-A740-40C7-9927-33E4CB58536F}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'MessageDataColumns' , u'ppRsltVal' , ), 19, (19, (), [ (9, 1, None, "IID('{002ACD1C-A740-40C7-9927-33E4CB58536F}')") , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'RecipientCollection' , u'ppRsltVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{2C728EFB-8BF9-4D0A-8135-E53AD4CDC064}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'RecipientCollection' , u'ppRsltVal' , ), 21, (21, (), [ (9, 1, None, "IID('{2C728EFB-8BF9-4D0A-8135-E53AD4CDC064}')") , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

IMessageDataColumn_vtables_dispatch_ = 1
IMessageDataColumn_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ColumnName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ColumnName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Link' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Link' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'MessageDataLines' , u'ppRsltVal' , ), 13, (13, (), [ (16393, 10, None, "IID('{38FD1577-2135-4D5F-A037-E5388B413F83}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'MessageDataLines' , u'ppRsltVal' , ), 13, (13, (), [ (9, 1, None, "IID('{38FD1577-2135-4D5F-A037-E5388B413F83}')") , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IMessageDataColumns_vtables_dispatch_ = 1
IMessageDataColumns_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IMessageDataLine_vtables_dispatch_ = 1
IMessageDataLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Object' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Object' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ObjectKey' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ObjectKey' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IMessageDataLines_vtables_dispatch_ = 1
IMessageDataLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IMessageHeader_vtables_dispatch_ = 1
IMessageHeader_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Received' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Read' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ReceivedDate' , u'pdtRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ReceivedTime' , u'pdtRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SentDate' , u'pdtRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SentTime' , u'pldtsltVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IMessageHeaders_vtables_dispatch_ = 1
IMessageHeaders_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IMessages_vtables_dispatch_ = 1
IMessages_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'MessageText' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'MessageText' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'AddDataColumn' , u'Title' , u'Text' , u'Object' , u'ObjectKey' , 
			), 7, (7, (), [ (8, 0, None, None) , (8, 0, None, None) , (3, 0, None, None) , (8, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Recipients' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{F408B086-B6E4-4EE0-9B95-710C117E56F0}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IMessagesService_vtables_dispatch_ = 1
IMessagesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetInbox' , u'ppRsltIMessageHeaders' , ), 10, (10, (), [ (16393, 10, None, "IID('{CBAB706D-E5DE-4D36-BB28-C6705D247335}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetOutbox' , u'ppRsltIMessageHeaders' , ), 11, (11, (), [ (16393, 10, None, "IID('{CBAB706D-E5DE-4D36-BB28-C6705D247335}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetSentMessages' , u'ppRsltIMessageHeaders' , ), 12, (12, (), [ (16393, 10, None, "IID('{CBAB706D-E5DE-4D36-BB28-C6705D247335}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetMessage' , u'pMessageHeader' , u'ppRsltIMessage' , ), 13, (13, (), [ (9, 1, None, "IID('{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')") , 
			(16393, 10, None, "IID('{32E2CAC3-EEFA-4C2B-B916-C43A8A39BEAE}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SendMessage' , u'pMessage' , u'ppRsltIMessageHeader' , ), 14, (14, (), [ (9, 1, None, "IID('{32E2CAC3-EEFA-4C2B-B916-C43A8A39BEAE}')") , 
			(16393, 10, None, "IID('{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IMultiLanguageTranslations_vtables_dispatch_ = 1
IMultiLanguageTranslations_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsEntry' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FieldAlias' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'FieldAlias' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryKeyofobject' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryKeyofobject' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TranslationsInUserLanguages' , u'ppRslt' , ), 17, (17, (), [ (16393, 10, None, "IID('{2AC79865-8E0D-42CD-8A97-AA4ADF24B4EE}')") , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IMultiplePayment_vtables_dispatch_ = 1
IMultiplePayment_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BankStatmentLineID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ListLineID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocumentIdentifier' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocumentIdentifier' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AmountLC' , u'ppRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AmountLC' , u'ppRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AmountFC' , u'ppRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AmountFC' , u'ppRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'IsDebit' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'IsDebit' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IMultiplePayments_vtables_dispatch_ = 1
IMultiplePayments_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{738D011A-EA2A-4205-B009-53C7C64D73DD}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{738D011A-EA2A-4205-B009-53C7C64D73DD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

INCMCodeSetup_vtables_dispatch_ = 1
INCMCodeSetup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

INCMCodeSetupParams_vtables_dispatch_ = 1
INCMCodeSetupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NCMCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

INCMCodeSetupParamsCollection_vtables_dispatch_ = 1
INCMCodeSetupParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{C48ABD4C-43C8-4776-87E7-337D661050C2}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{C48ABD4C-43C8-4776-87E7-337D661050C2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

INCMCodesSetupService_vtables_dispatch_ = 1
INCMCodesSetupService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddNCMCodeSetup' , u'pINCMCodeSetup' , u'ppINCMCodeSetupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{8ED60CF1-3116-4C89-A77D-B67ED48F2F22}')") , 
			(16393, 10, None, "IID('{C48ABD4C-43C8-4776-87E7-337D661050C2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateNCMCodeSetup' , u'pINCMCodeSetup' , ), 11, (11, (), [ (9, 1, None, "IID('{8ED60CF1-3116-4C89-A77D-B67ED48F2F22}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteNCMCodeSetup' , u'pINCMCodeSetupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{C48ABD4C-43C8-4776-87E7-337D661050C2}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetNCMCodeSetup' , u'pINCMCodeSetupParams' , u'ppINCMCodeSetup' , ), 13, (13, (), [ (9, 1, None, "IID('{C48ABD4C-43C8-4776-87E7-337D661050C2}')") , 
			(16393, 10, None, "IID('{8ED60CF1-3116-4C89-A77D-B67ED48F2F22}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetNCMCodeSetupList' , u'ppINCMCodeSetupParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{B14AF4AA-36E3-4C09-9BEF-6DCED4B5EBFB}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

INFModel_vtables_dispatch_ = 1
INFModel_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'NFMName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NFMName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'NFMDescription' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'NFMDescription' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'NFMCode' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'NFMCode' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

INFModelParams_vtables_dispatch_ = 1
INFModelParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NFMName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'NFMDescription' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'NFMCode' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

INFModelsParams_vtables_dispatch_ = 1
INFModelsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

INFModelsService_vtables_dispatch_ = 1
INFModelsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pINFModel' , u'ppINFModelParams' , ), 10, (10, (), [ (9, 1, None, "IID('{35E59851-3F5C-40B3-9613-BCC32E3B97B8}')") , 
			(16393, 10, None, "IID('{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pINFModel' , ), 11, (11, (), [ (9, 1, None, "IID('{35E59851-3F5C-40B3-9613-BCC32E3B97B8}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pINFModelParams' , ), 12, (12, (), [ (9, 1, None, "IID('{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pINFModelParams' , u'ppINFModel' , ), 13, (13, (), [ (9, 1, None, "IID('{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}')") , 
			(16393, 10, None, "IID('{35E59851-3F5C-40B3-9613-BCC32E3B97B8}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppINFModelsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{85830213-6564-4BBA-95DD-246624D1A4D2}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

INatureOfAssessee_vtables_dispatch_ = 1
INatureOfAssessee_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AssesseeType' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AssesseeType' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

INatureOfAssesseeParams_vtables_dispatch_ = 1
INatureOfAssesseeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

INatureOfAssesseesParams_vtables_dispatch_ = 1
INatureOfAssesseesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{27D88079-2713-4D2E-94D4-3C6F14D18140}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{27D88079-2713-4D2E-94D4-3C6F14D18140}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

INatureOfAssesseesService_vtables_dispatch_ = 1
INatureOfAssesseesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddNatureOfAssessee' , u'pINatureOfAssessee' , u'ppINatureOfAssesseeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{69A099F3-3B67-46A2-A4EB-6DC399C64078}')") , 
			(16393, 10, None, "IID('{27D88079-2713-4D2E-94D4-3C6F14D18140}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateNatureOfAssessee' , u'pINatureOfAssessee' , ), 11, (11, (), [ (9, 1, None, "IID('{69A099F3-3B67-46A2-A4EB-6DC399C64078}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteNatureOfAssessee' , u'pINatureOfAssesseeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{27D88079-2713-4D2E-94D4-3C6F14D18140}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetNatureOfAssessee' , u'pINatureOfAssesseeParams' , u'ppINatureOfAssessee' , ), 13, (13, (), [ (9, 1, None, "IID('{27D88079-2713-4D2E-94D4-3C6F14D18140}')") , 
			(16393, 10, None, "IID('{69A099F3-3B67-46A2-A4EB-6DC399C64078}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetNatureOfAssesseeList' , u'ppINatureOfAssesseesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{CD0EAC7A-0E3F-4ED3-A9BF-42D4100A3FBB}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

INotaFiscalCFOP_vtables_dispatch_ = 1
INotaFiscalCFOP_vtables_ = [
	(( u'UserFields' , u'ppRsltIUserFields' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Application' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Application' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ID' , u'Found' , ), 8, (8, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 11, (11, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

INotaFiscalCST_vtables_dispatch_ = 1
INotaFiscalCST_vtables_ = [
	(( u'UserFields' , u'ppRsltIUserFields' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Situation' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Situation' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ID' , u'Found' , ), 8, (8, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 10, (10, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxCategory' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxCategory' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeOutgoing' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeOutgoing' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DescriptionOutgoing' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DescriptionOutgoing' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

INotaFiscalUsage_vtables_dispatch_ = 1
INotaFiscalUsage_vtables_ = [
	(( u'UserFields' , u'ppRsltIUserFields' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ID' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Usage' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Usage' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ID' , u'Found' , ), 7, (7, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 10, (10, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'IncomingInStateCFOPCode' , u'pIISCFOPCode' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'IncomingInStateCFOPCode' , u'pIISCFOPCode' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'IncomingOutStateCFOPCode' , u'pIOSCFOPCode' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'IncomingOutStateCFOPCode' , u'pIOSCFOPCode' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'IncomingImportCFOPCode' , u'pIICFOPCode' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'IncomingImportCFOPCode' , u'pIICFOPCode' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingInStateCFOPCode' , u'pOISCFOPCode' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingInStateCFOPCode' , u'pOISCFOPCode' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingOutStateCFOPCode' , u'pOOSCFOPCode' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingOutStateCFOPCode' , u'pOOSCFOPCode' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingExportCFOPCode' , u'pOECFOPCode' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingExportCFOPCode' , u'pOECFOPCode' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrValue' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrValue' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
]

IOccurenceCode_vtables_dispatch_ = 1
IOccurenceCode_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Note' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Note' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'RequestedBoeStatus' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'RequestedBoeStatus' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'IsMovement' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'IsMovement' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IOccurenceCodeParams_vtables_dispatch_ = 1
IOccurenceCodeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Note' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'RequestedBoeStatus' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'IsMovement' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'IsMovement' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IOccurenceCodeParamsCollection_vtables_dispatch_ = 1
IOccurenceCodeParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IOccurrenceCodesService_vtables_dispatch_ = 1
IOccurrenceCodesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIOccurenceCode' , u'ppIOccurenceCodeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{04305B71-95D2-4327-B7A5-ED12DFB5FB1B}')") , 
			(16393, 10, None, "IID('{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pIOccurenceCode' , ), 11, (11, (), [ (9, 1, None, "IID('{04305B71-95D2-4327-B7A5-ED12DFB5FB1B}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIOccurenceCodeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIOccurenceCodeParams' , u'ppIOccurenceCode' , ), 13, (13, (), [ (9, 1, None, "IID('{418E7FC7-70AC-4443-B526-E3C154E6DA4B}')") , 
			(16393, 10, None, "IID('{04305B71-95D2-4327-B7A5-ED12DFB5FB1B}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppIOccurenceCodeParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{116B0B02-4096-48F9-A00C-E99E6EE7ADA1}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IOpenningBalanceAccount_vtables_dispatch_ = 1
IOpenningBalanceAccount_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'OpenBalanceAccount' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'OpenBalanceAccount' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pdtRsltVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Date' , u'pdtRsltVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Ref1' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Ref1' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Ref2' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Ref2' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IOriginalItem_vtables_dispatch_ = 1
IOriginalItem_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AlternativeItems' , u'ppRsltVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{416CFADF-9DA6-47BD-A490-09AC890FC530}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IOriginalItemParams_vtables_dispatch_ = 1
IOriginalItemParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IPackagesTypes_vtables_dispatch_ = 1
IPackagesTypes_vtables_ = [
	(( u'Type' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IPartnersSetup_vtables_dispatch_ = 1
IPartnersSetup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DefaultRelationship' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DefaultRelationship' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'RelatedBP' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RelatedBP' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IPartnersSetupParams_vtables_dispatch_ = 1
IPartnersSetupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PartnerID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PartnerID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DefaultRelationship' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'RelatedBP' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IPartnersSetupsParams_vtables_dispatch_ = 1
IPartnersSetupsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IPartnersSetupsService_vtables_dispatch_ = 1
IPartnersSetupsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIPartnersSetup' , u'ppIPartnersSetupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{4DB4395A-231C-4BE3-B582-F6C7C70D109E}')") , 
			(16393, 10, None, "IID('{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pIPartnersSetup' , ), 11, (11, (), [ (9, 1, None, "IID('{4DB4395A-231C-4BE3-B582-F6C7C70D109E}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIPartnersSetupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIPartnersSetupParams' , u'ppIPartnersSetup' , ), 13, (13, (), [ (9, 1, None, "IID('{23BBD185-4EAB-45D4-950E-194CD4A96BE2}')") , 
			(16393, 10, None, "IID('{4DB4395A-231C-4BE3-B582-F6C7C70D109E}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppIPartnersSetupsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{65C62A16-791E-4D58-A0F9-1ED312BE7ACB}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IPathAdmin_vtables_dispatch_ = 1
IPathAdmin_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'WordTemplateFolderPath' , u'pbstrRsltVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'WordTemplateFolderPath' , u'pbstrRsltVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PicturesFolderPath' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PicturesFolderPath' , u'pbstrRsltVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentsFolderPath' , u'pbstrRsltVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentsFolderPath' , u'pbstrRsltVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionsFolderPath' , u'pbstrRsltVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionsFolderPath' , u'pbstrRsltVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PrintId' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IPaymentBlock_vtables_dispatch_ = 1
IPaymentBlock_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IPaymentBlockParams_vtables_dispatch_ = 1
IPaymentBlockParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBlockCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IPaymentBlocksParams_vtables_dispatch_ = 1
IPaymentBlocksParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IPaymentBlocksService_vtables_dispatch_ = 1
IPaymentBlocksService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddPaymentBlock' , u'pIPaymentBlock' , u'ppIPaymentBlockParams' , ), 10, (10, (), [ (9, 1, None, "IID('{F6964AD5-EB4F-4E38-824E-60026EA9F159}')") , 
			(16393, 10, None, "IID('{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdatePaymentBlock' , u'pIPaymentBlock' , ), 11, (11, (), [ (9, 1, None, "IID('{F6964AD5-EB4F-4E38-824E-60026EA9F159}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeletePaymentBlock' , u'pIPaymentBlockParams' , ), 12, (12, (), [ (9, 1, None, "IID('{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetPaymentBlock' , u'pIPaymentBlockParams' , u'ppIPaymentBlock' , ), 13, (13, (), [ (9, 1, None, "IID('{59DB637B-BF84-4D38-A0ED-1383F2556CA9}')") , 
			(16393, 10, None, "IID('{F6964AD5-EB4F-4E38-824E-60026EA9F159}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetPaymentBlockList' , u'ppIPaymentBlocksParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{954AC9A0-5402-436F-A20B-38E093F0A636}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IPaymentRunExport_vtables_dispatch_ = 1
IPaymentRunExport_vtables_ = [
	(( u'GetByKey' , u'PaymentRunExportCode' , u'Found' , ), 1, (1, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{917BA077-4D88-46A8-B78A-E396315D7E59}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 3, (3, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 4, (4, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RunDate' , u'pVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CustomerNum' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethod' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FiscalYear' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Countery' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CompanyTaxNum' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PayeeName' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PayeePostalCode' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PayeeCity' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PayeeStreet' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PayeeCountry' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PayeeState' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankName' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankZip' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCity' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankStreet' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCountry' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankAccount' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCode' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCtrlKey' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankSwiftNum' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankIBAN' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pVal' , ), 29, (29, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BankIBAN' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DocAmountLocal' , u'pVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrnecy' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DocAmountForign' , u'pVal' , ), 38, (38, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DocCashDiscount' , u'pVal' , ), 39, (39, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DocCashDiscountForign' , u'pVal' , ), 40, (40, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DocNumOffieldPaid' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 42, (42, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'WizCode' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'CollectionAuthorization' , u'pVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankPostOffice' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankNextCheckNumber' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankHouseBank' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankBlock' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankCounty' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankState' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankBISR' , u'pVal' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankUserNum1' , u'pVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankUserNum2' , u'pVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankUserNum3' , u'pVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankUserNum4' , u'pVal' , ), 56, (56, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'InstructionKey' , u'pVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'PaymentFormat' , u'pVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'CompanyName' , u'pVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'CompanyAddress' , u'pVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 61, (61, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'CompIsrBillerID' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'VendorIsrBillerID' , u'pVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalIdNumber' , u'pVal' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'OrganizationNumber' , u'pVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'PayeeBankBranch' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankBranch' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'UserEMail' , u'pVal' , ), 69, (69, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'UserMobilePhoneNumber' , u'pVal' , ), 70, (70, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'UserFaxNumber' , u'pVal' , ), 71, (71, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'UserDepartment' , u'pVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'DebitMemo' , u'pVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'EUInternalTransfer' , u'pVal' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'FilePath' , u'pVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'OrderingParty' , u'pVal' , ), 76, (76, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankControlKey' , u'pVal' , ), 77, (77, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'PayeeTaxNumber' , u'pVal' , ), 78, (78, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'PaymentKeyCode' , u'pVal' , ), 79, (79, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'PayeeReferenceDetails' , u'pVal' , ), 80, (80, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'FormatName' , u'pVal' , ), 81, (81, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 82, (82, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 83, (83, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDonewithCheck' , u'penumRsltVal' , ), 85, (85, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'CompanyBlock' , u'pbstrRsltVal' , ), 86, (86, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'CompanyCity' , u'pbstrRsltVal' , ), 87, (87, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'CompanyCounty' , u'pbstrRsltVal' , ), 88, (88, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'CompanyState' , u'pbstrRsltVal' , ), 89, (89, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'CompanyStreet' , u'pbstrRsltVal' , ), 90, (90, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'CompanyZipCode' , u'pbstrRsltVal' , ), 91, (91, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankCharges' , u'pbstrRsltVal' , ), 92, (92, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankUserNo1' , u'pbstrRsltVal' , ), 93, (93, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankUserNo2' , u'pbstrRsltVal' , ), 94, (94, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankUserNo3' , u'pbstrRsltVal' , ), 95, (95, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankUserNo4' , u'pbstrRsltVal' , ), 96, (96, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'PaymentBankChargesAllocationCode' , u'pbstrRsltVal' , ), 97, (97, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'PaymentOrderNum' , u'pVal' , ), 98, (98, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'FreeText1' , u'pbstrRsltVal' , ), 99, (99, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'FreeText2' , u'pbstrRsltVal' , ), 100, (100, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'FreeText3' , u'pbstrRsltVal' , ), 101, (101, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'RowType' , u'pVal' , ), 102, (102, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
]

IPaymentRunExport_Lines_vtables_dispatch_ = 1
IPaymentRunExport_Lines_vtables_ = [
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DateOfPaymentRun' , u'pVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'PaymentWizardCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'VendorNumber' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CustomerNumber' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMeans' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDocNum' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FiscalYear' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'VendorRefNum' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DocumentObjectType' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocumentPostingDate' , u'pVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTaxDate' , u'pVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'BPDebitPayableAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCurrency' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DocumentRate' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTotal' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTotalFC' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTaxAmount' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTaxAmountFC' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DocumentRemarks' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DocumentPaymentTerms' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PaymentDocReference' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DocumentLocalCurrency' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTermsPeriod' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DocumentObjectTypeEx' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'plRsltVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'PaymentNumber' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'PaymentOrderNum' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'FreeText1' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'FreeText2' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'FreeText3' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
]

IPaymentTermsTypes_vtables_dispatch_ = 1
IPaymentTermsTypes_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'GroupNum' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GroupNumber' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTermsGroupName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTermsGroupName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'StartFrom' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'StartFrom' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfAdditionalMonths' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfAdditionalMonths' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfAdditionalDays' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfAdditionalDays' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CreditLimit' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CreditLimit' , u'pVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'GeneralDiscount' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GeneralDiscount' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'InterestOnArrears' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'InterestOnArrears' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'LoadLimit' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'LoadLimit' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'OpenReceipt' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'OpenReceipt' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DiscountCode' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DiscountCode' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DunningCode' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DunningCode' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BaselineDate' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'BaselineDate' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfInstallments' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfToleranceDays' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfToleranceDays' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 25, (25, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
]

IPayments_vtables_dispatch_ = 1
IPayments_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'RctEntry' , u'Found' , ), 4, (4, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocTypte' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocTypte' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CashSum' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'CashSum' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CheckAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CheckAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TransferAccount' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'TransferAccount' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'TransferSum' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'TransferSum' , u'pVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'TransferDate' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'TransferDate' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TransferReference' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'TransferReference' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'LocalCurrency' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'LocalCurrency' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DocRate' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'CounterReference' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'CounterReference' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ApplyVAT' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ApplyVAT' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 32, (32, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 32, (32, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'BankAccount' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'Checks' , u'pVal' , ), 36, (36, (), [ (16393, 10, None, "IID('{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}')") , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'Invoices' , u'pVal' , ), 37, (37, (), [ (16393, 10, None, "IID('{AB7947CF-8191-498D-8B3C-8E04A00957E7}')") , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'CreditCards' , u'pVal' , ), 38, (38, (), [ (16393, 10, None, "IID('{CC3579ED-1C61-4864-8E51-208A3DCDFC93}')") , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'AccountPayments' , u'pVal' , ), 39, (39, (), [ (16393, 10, None, "IID('{231A13D7-5DA8-4467-A263-FDE84A268AC9}')") , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 45, (45, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'pVal' , ), 47, (47, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'DeductionPercent' , u'pVal' , ), 47, (47, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'DeductionSum' , u'pVal' , ), 48, (48, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'DeductionSum' , u'pVal' , ), 48, (48, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'CashSumFC' , u'pVal' , ), 49, (49, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'CashSumSys' , u'pVal' , ), 50, (50, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'BoeAccount' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'BoeAccount' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAmount' , u'pVal' , ), 52, (52, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAmount' , u'pVal' , ), 52, (52, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeStatus' , u'pVal' , ), 53, (53, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeStatus' , u'pVal' , ), 53, (53, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchange' , u'pVal' , ), 54, (54, (), [ (16393, 10, None, "IID('{741AA803-AB33-4FD7-B664-63116291D6CE}')") , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAmountFC' , u'pVal' , ), 55, (55, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAmountSC' , u'pVal' , ), 56, (56, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAgent' , u'pVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'BillOfExchangeAgent' , u'pVal' , ), 57, (57, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 59, (59, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 59, (59, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 60, (60, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSC' , u'pVal' , ), 61, (61, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'WTAccount' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'WTTaxableAmount' , u'pVal' , ), 63, (63, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'Proforma' , u'pVal' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'Proforma' , u'pVal' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'PaymentPriority' , u'pVal' , ), 65, (65, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'PaymentPriority' , u'pVal' , ), 65, (65, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankAccountNo' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankAccountNo' , u'pVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'PayToCode' , u'pVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'PayToCode' , u'pVal' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCountry' , u'pVal' , ), 69, (69, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCountry' , u'pVal' , ), 69, (69, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'IsPayToBank' , u'pVal' , ), 70, (70, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'IsPayToBank' , u'pVal' , ), 70, (70, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCode' , u'pVal' , ), 74, (74, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankCode' , u'pVal' , ), 74, (74, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankBranch' , u'pVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'PayToBankBranch' , u'pVal' , ), 75, (75, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 76, (76, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 77, (77, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeAmount' , u'pVal' , ), 78, (78, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeAmount' , u'pVal' , ), 78, (78, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeAmountInFC' , u'pVal' , ), 79, (79, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeAmountInSC' , u'pVal' , ), 80, (80, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 81, (81, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'VatDate' , u'pVal' , ), 81, (81, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pVal' , ), 82, (82, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCode' , u'pVal' , ), 82, (82, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'PaymentType' , u'pVal' , ), 83, (83, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'PaymentType' , u'pVal' , ), 83, (83, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'TransferRealAmount' , u'pVal' , ), 84, (84, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'TransferRealAmount' , u'pVal' , ), 84, (84, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'UnderOverpaymentdifference' , u'pdblRsltVal' , ), 85, (85, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'UnderOverpaymentdiffSC' , u'pdblRsltVal' , ), 86, (86, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'WtBaseSum' , u'pdblRsltVal' , ), 87, (87, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'WtBaseSum' , u'pdblRsltVal' , ), 87, (87, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'WtBaseSumFC' , u'pdblRsltVal' , ), 88, (88, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'WtBaseSumSC' , u'pdblRsltVal' , ), 89, (89, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 90, (90, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 90, (90, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 91, (91, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 91, (91, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'Cancelled' , u'pVal' , ), 92, (92, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'ControlAccount' , u'pVal' , ), 100, (100, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'ControlAccount' , u'pVal' , ), 100, (100, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'UnderOverpaymentdiffFC' , u'pdblRsltVal' , ), 101, (101, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryFormItems' , u'pVal' , ), 102, (102, (), [ (16393, 10, None, "IID('{A0307CBF-64B1-49E8-B60D-38803E20D107}')") , ], 1 , 2 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'SaveDraftToDocument' , u'ooErr' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'GetApprovalTemplates' , u'ooErr' , ), 104, (104, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'Payments_ApprovalRequests' , u'pVal' , ), 105, (105, (), [ (16393, 10, None, "IID('{8276E7F7-9178-409D-88DB-5A8D41DED6E5}')") , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'AuthorizationStatus' , u'pVal' , ), 106, (106, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 111, (111, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 111, (111, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'BPLName' , u'pVal' , ), 112, (112, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'VATRegNum' , u'pVal' , ), 113, (113, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
]

IPayments_Accounts_vtables_dispatch_ = 1
IPayments_Accounts_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AccountCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SumPaid' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SumPaid' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Decription' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Decription' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'VatGroup' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AccountName' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmount' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GrossAmount' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'VatAmount' , u'pVal' , ), 15, (15, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'VatAmount' , u'pVal' , ), 15, (15, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pbstrRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter2' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter2' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter3' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter3' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter4' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter4' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter5' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ProfitCenter5' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationVatAmount' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
]

IPayments_ApprovalRequests_vtables_dispatch_ = 1
IPayments_ApprovalRequests_vtables_ = [
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalTemplatesID' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IPayments_Checks_vtables_dispatch_ = 1
IPayments_Checks_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CheckNumber' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AccounttNum' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AccounttNum' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Trnsfrable' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Trnsfrable' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'CheckSum' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CheckSum' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'CountryCode' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'CheckAbsEntry' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CheckAccount' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'CheckAccount' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ManualCheck' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ManualCheck' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
]

IPayments_CreditCards_vtables_dispatch_ = 1
IPayments_CreditCards_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CreditCard' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CreditCard' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CreditAcct' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CreditAcct' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardNumber' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CreditCardNumber' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CardValidUntil' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CardValidUntil' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'VoucherNum' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'VoucherNum' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'OwnerIdNum' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'OwnerIdNum' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'OwnerPhone' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'OwnerPhone' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'NumOfPayments' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'NumOfPayments' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'FirstPaymentDue' , u'pVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'FirstPaymentDue' , u'pVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'FirstPaymentSum' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'FirstPaymentSum' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalPaymentSum' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalPaymentSum' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CreditSum' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'CreditSum' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ConfirmationNum' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ConfirmationNum' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'NumOfCreditPayments' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'NumOfCreditPayments' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'CreditType' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'CreditType' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'SplitPayments' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'SplitPayments' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
]

IPayments_Invoices_vtables_dispatch_ = 1
IPayments_Invoices_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SumApplied' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SumApplied' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AppliedFC' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AppliedFC' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DocLine' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocLine' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceType' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'InvoiceType' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PaidSum' , u'pVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'InstallmentId' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'InstallmentId' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'WitholdingTaxApplied' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'WitholdingTaxAppliedFC' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'WitholdingTaxAppliedSC' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'LinkDate' , u'pVal' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'plRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'plRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TotalDiscount' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'TotalDiscount' , u'pVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'TotalDiscountFC' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'TotalDiscountFC' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'TotalDiscountSC' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
]

IPeriodCategory_vtables_dispatch_ = 1
IPeriodCategory_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BeginningofFinancialYear' , u'pdtRsltVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BeginningofFinancialYear' , u'pdtRsltVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DebitorsFollowUpAccount' , u'pbstrRsltVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DebitorsFollowUpAccount' , u'pbstrRsltVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PeriodName' , u'pbstrRsltVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PeriodName' , u'pbstrRsltVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AccountforOutgoingChecks' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AccountforOutgoingChecks' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AccountforCashReceipt' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'AccountforCashReceipt' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CustomersDeductionatSource' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CustomersDeductionatSource' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CommissionAccountDefault' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CommissionAccountDefault' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseTax' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseTax' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ForeignAccountsReceivables' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ForeignAccountsReceivables' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'CreditorsFollowUpAccount' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CreditorsFollowUpAccount' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingChecksAccount' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingChecksAccount' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingCashAccount' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingCashAccount' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'AccountforCreditMemoPayme' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'AccountforCreditMemoPayme' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'InputTaxAccount' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'InputTaxAccount' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinition' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinition' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'WithholodingTax' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'WithholodingTax' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'OpeningBalancesAccount' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'OpeningBalancesAccount' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'DefaultSaleAccount' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'DefaultSaleAccount' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptRevenuesDefault' , u'pbstrRsltVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'TaxExemptRevenuesDefault' , u'pbstrRsltVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccountDefault' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccountDefault' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccountForeign' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccountForeign' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'SalesRevenueEU' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'SalesRevenueEU' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccountForeign' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesAccountForeign' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'RateDifferencesDefaultAcc' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'RateDifferencesDefaultAcc' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAcc' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAcc' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'ReconciliationDifference' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'ReconciliationDifference' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'AcountforOpeningWHBalance' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'AcountforOpeningWHBalance' , u'pbstrRsltVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'APCashDiscountAccount' , u'pbstrRsltVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'APCashDiscountAccount' , u'pbstrRsltVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'APLossCashDiscountAccount' , u'pbstrRsltVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'APLossCashDiscountAccount' , u'pbstrRsltVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'APLossRealizedExchangeDif' , u'pbstrRsltVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'APLossRealizedExchangeDif' , u'pbstrRsltVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'ARCashDiscountAccount' , u'pbstrRsltVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'ARCashDiscountAccount' , u'pbstrRsltVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'ARLossRealizedExchangeDi' , u'pbstrRsltVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'ARLossRealizedExchangeDi' , u'pbstrRsltVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'RoundingAccount' , u'pbstrRsltVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'RoundingAccount' , u'pbstrRsltVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'APGainRealizedExchngeDif' , u'pbstrRsltVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'APGainRealizedExchngeDif' , u'pbstrRsltVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'ARGainRealizedExchngeDif' , u'pbstrRsltVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'ARGainRealizedExchngeDif' , u'pbstrRsltVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pbstrRsltVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pbstrRsltVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'SalesReturns' , u'pbstrRsltVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'SalesReturns' , u'pbstrRsltVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'CostOfGoodsSold' , u'pbstrRsltVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'CostOfGoodsSold' , u'pbstrRsltVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'AllocationAcc' , u'pbstrRsltVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'AllocationAcc' , u'pbstrRsltVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAcc' , u'pbstrRsltVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAcc' , u'pbstrRsltVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferenceAccount' , u'pbstrRsltVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferenceAccount' , u'pbstrRsltVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'CustomerDownPaymentsAccount' , u'pbstrRsltVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'CustomerDownPaymentsAccount' , u'pbstrRsltVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'VendorDownPaymentsAccount' , u'pbstrRsltVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'VendorDownPaymentsAccount' , u'pbstrRsltVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeAccountsRece' , u'pbstrRsltVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'BillofExchangeAccountsRece' , u'pbstrRsltVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'CustBillofExchangeonC' , u'pbstrRsltVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'CustBillofExchangeonC' , u'pbstrRsltVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangePres' , u'pbstrRsltVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchangePres' , u'pbstrRsltVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchngeDisc' , u'pbstrRsltVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'CustomerBillofExchngeDisc' , u'pbstrRsltVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'CustomerUnpaidBoE' , u'pbstrRsltVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'CustomerUnpaidBoE' , u'pbstrRsltVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'BoEAccountsPayable' , u'pbstrRsltVal' , ), 56, (56, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'BoEAccountsPayable' , u'pbstrRsltVal' , ), 56, (56, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'BoEAccountsPayable2' , u'pbstrRsltVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'BoEAccountsPayable2' , u'pbstrRsltVal' , ), 57, (57, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'CustomerDoubtfulDebtsAcct' , u'pbstrRsltVal' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'CustomerDoubtfulDebtsAcct' , u'pbstrRsltVal' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'VendorDoubtfulDebtsAcct' , u'pbstrRsltVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'VendorDoubtfulDebtsAcct' , u'pbstrRsltVal' , ), 59, (59, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pbstrRsltVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pbstrRsltVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseReturnAccount' , u'pbstrRsltVal' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseReturnAccount' , u'pbstrRsltVal' , ), 61, (61, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pbstrRsltVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pbstrRsltVal' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'EOYControlAccount' , u'pbstrRsltVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'EOYControlAccount' , u'pbstrRsltVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAcct' , u'pbstrRsltVal' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAcct' , u'pbstrRsltVal' , ), 64, (64, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAcc' , u'pbstrRsltVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAcc' , u'pbstrRsltVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAccount' , u'pbstrRsltVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseClearingAccount' , u'pbstrRsltVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsetAccount' , u'pbstrRsltVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsetAccount' , u'pbstrRsltVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'CostofSaleRevaluationAcct' , u'pbstrRsltVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'CostofSaleRevaluationAcct' , u'pbstrRsltVal' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'RepomoAccount' , u'pbstrRsltVal' , ), 69, (69, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'RepomoAccount' , u'pbstrRsltVal' , ), 69, (69, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pbstrRsltVal' , ), 70, (70, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pbstrRsltVal' , ), 70, (70, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentVATAcctSale' , u'pbstrRsltVal' , ), 71, (71, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentVATAcctSale' , u'pbstrRsltVal' , ), 71, (71, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentVATAcctPurch' , u'pbstrRsltVal' , ), 72, (72, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentVATAcctPurch' , u'pbstrRsltVal' , ), 72, (72, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentSClearingAcct' , u'pbstrRsltVal' , ), 73, (73, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentSClearingAcct' , u'pbstrRsltVal' , ), 73, (73, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentPClearingAcct' , u'pbstrRsltVal' , ), 74, (74, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentPClearingAcct' , u'pbstrRsltVal' , ), 74, (74, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseVarianceAccount' , u'pbstrRsltVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseVarianceAccount' , u'pbstrRsltVal' , ), 75, (75, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'CostofSaleRevOffsetAcct' , u'pbstrRsltVal' , ), 76, (76, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'CostofSaleRevOffsetAcct' , u'pbstrRsltVal' , ), 76, (76, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'EUExpenseAccount' , u'pbstrRsltVal' , ), 77, (77, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'EUExpenseAccount' , u'pbstrRsltVal' , ), 77, (77, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'StockAccount' , u'pbstrRsltVal' , ), 78, (78, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
	(( u'StockAccount' , u'pbstrRsltVal' , ), 78, (78, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 612 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetIncrease' , u'pbstrRsltVal' , ), 79, (79, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 616 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetIncrease' , u'pbstrRsltVal' , ), 79, (79, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 620 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetDecrease' , u'pbstrRsltVal' , ), 80, (80, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 624 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetDecrease' , u'pbstrRsltVal' , ), 80, (80, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 628 , (3, 0, None, None) , 0 , )),
	(( u'VendorAssetsAccount' , u'pbstrRsltVal' , ), 81, (81, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 632 , (3, 0, None, None) , 0 , )),
	(( u'VendorAssetsAccount' , u'pbstrRsltVal' , ), 81, (81, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 636 , (3, 0, None, None) , 0 , )),
	(( u'StockRevaluationAccount' , u'pbstrRsltVal' , ), 82, (82, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 640 , (3, 0, None, None) , 0 , )),
	(( u'StockRevaluationAccount' , u'pbstrRsltVal' , ), 82, (82, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 644 , (3, 0, None, None) , 0 , )),
	(( u'StockRevaluationOffsetAcct' , u'pbstrRsltVal' , ), 83, (83, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 648 , (3, 0, None, None) , 0 , )),
	(( u'StockRevaluationOffsetAcct' , u'pbstrRsltVal' , ), 83, (83, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 652 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pbstrRsltVal' , ), 84, (84, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 656 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pbstrRsltVal' , ), 84, (84, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 660 , (3, 0, None, None) , 0 , )),
	(( u'InvoicePaymentBP' , u'pbstrRsltVal' , ), 85, (85, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 664 , (3, 0, None, None) , 0 , )),
	(( u'InvoicePaymentBP' , u'pbstrRsltVal' , ), 85, (85, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 668 , (3, 0, None, None) , 0 , )),
	(( u'GLRevaluationOffsetAccount' , u'pbstrRsltVal' , ), 86, (86, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 672 , (3, 0, None, None) , 0 , )),
	(( u'GLRevaluationOffsetAccount' , u'pbstrRsltVal' , ), 86, (86, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 676 , (3, 0, None, None) , 0 , )),
	(( u'OverpaymentsAPAccount' , u'pbstrRsltVal' , ), 87, (87, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 680 , (3, 0, None, None) , 0 , )),
	(( u'OverpaymentsAPAccount' , u'pbstrRsltVal' , ), 87, (87, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 684 , (3, 0, None, None) , 0 , )),
	(( u'UnderpaymentsAPAccount' , u'pbstrRsltVal' , ), 88, (88, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 688 , (3, 0, None, None) , 0 , )),
	(( u'UnderpaymentsAPAccount' , u'pbstrRsltVal' , ), 88, (88, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 692 , (3, 0, None, None) , 0 , )),
	(( u'OverpaymentsARAccount' , u'pbstrRsltVal' , ), 89, (89, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 696 , (3, 0, None, None) , 0 , )),
	(( u'OverpaymentsARAccount' , u'pbstrRsltVal' , ), 89, (89, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 700 , (3, 0, None, None) , 0 , )),
	(( u'UnderpaymentsARAccount' , u'pbstrRsltVal' , ), 90, (90, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 704 , (3, 0, None, None) , 0 , )),
	(( u'UnderpaymentsARAccount' , u'pbstrRsltVal' , ), 90, (90, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 708 , (3, 0, None, None) , 0 , )),
	(( u'SubPeriodType' , u'penumRsltVal' , ), 94, (94, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 712 , (3, 0, None, None) , 0 , )),
	(( u'SubPeriodType' , u'penumRsltVal' , ), 94, (94, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 716 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfPeriods' , u'plRsltVal' , ), 95, (95, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 720 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfPeriods' , u'plRsltVal' , ), 95, (95, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 724 , (3, 0, None, None) , 0 , )),
	(( u'PeriodCategory' , u'pbstrRsltVal' , ), 96, (96, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 728 , (3, 0, None, None) , 0 , )),
	(( u'PeriodCategory' , u'pbstrRsltVal' , ), 96, (96, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 732 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseCreditAcc' , u'pbstrRsltVal' , ), 98, (98, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 736 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseCreditAcc' , u'pbstrRsltVal' , ), 98, (98, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 740 , (3, 0, None, None) , 0 , )),
	(( u'EUPurchaseCreditAcc' , u'pbstrRsltVal' , ), 99, (99, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 744 , (3, 0, None, None) , 0 , )),
	(( u'EUPurchaseCreditAcc' , u'pbstrRsltVal' , ), 99, (99, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 748 , (3, 0, None, None) , 0 , )),
	(( u'ForeignPurchaseCreditAcc' , u'pbstrRsltVal' , ), 100, (100, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 752 , (3, 0, None, None) , 0 , )),
	(( u'ForeignPurchaseCreditAcc' , u'pbstrRsltVal' , ), 100, (100, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 756 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditAcc' , u'pbstrRsltVal' , ), 101, (101, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 760 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditAcc' , u'pbstrRsltVal' , ), 101, (101, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 764 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditEUAcc' , u'pbstrRsltVal' , ), 102, (102, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 768 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditEUAcc' , u'pbstrRsltVal' , ), 102, (102, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 772 , (3, 0, None, None) , 0 , )),
	(( u'ExemptedCredits' , u'pbstrRsltVal' , ), 103, (103, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 776 , (3, 0, None, None) , 0 , )),
	(( u'ExemptedCredits' , u'pbstrRsltVal' , ), 103, (103, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 780 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditForeignAcc' , u'pbstrRsltVal' , ), 104, (104, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 784 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditForeignAcc' , u'pbstrRsltVal' , ), 104, (104, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 788 , (3, 0, None, None) , 0 , )),
	(( u'FromPostingDate' , u'pdtRsltVal' , ), 110, (110, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 792 , (3, 0, None, None) , 0 , )),
	(( u'FromPostingDate' , u'pdtRsltVal' , ), 110, (110, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 796 , (3, 0, None, None) , 0 , )),
	(( u'ToPostingDate' , u'pdtRsltVal' , ), 111, (111, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 800 , (3, 0, None, None) , 0 , )),
	(( u'ToPostingDate' , u'pdtRsltVal' , ), 111, (111, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 804 , (3, 0, None, None) , 0 , )),
	(( u'FromDueDate' , u'pdtRsltVal' , ), 112, (112, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 808 , (3, 0, None, None) , 0 , )),
	(( u'FromDueDate' , u'pdtRsltVal' , ), 112, (112, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 812 , (3, 0, None, None) , 0 , )),
	(( u'ToDueDate' , u'pdtRsltVal' , ), 113, (113, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 816 , (3, 0, None, None) , 0 , )),
	(( u'ToDueDate' , u'pdtRsltVal' , ), 113, (113, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 820 , (3, 0, None, None) , 0 , )),
	(( u'FromDocumentDate' , u'pdtRsltVal' , ), 114, (114, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 824 , (3, 0, None, None) , 0 , )),
	(( u'FromDocumentDate' , u'pdtRsltVal' , ), 114, (114, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 828 , (3, 0, None, None) , 0 , )),
	(( u'ToDocumentDate' , u'pdtRsltVal' , ), 115, (115, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 832 , (3, 0, None, None) , 0 , )),
	(( u'ToDocumentDate' , u'pdtRsltVal' , ), 115, (115, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 836 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingTaxAccount' , u'pbstrRsltVal' , ), 116, (116, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 840 , (3, 0, None, None) , 0 , )),
	(( u'OutgoingTaxAccount' , u'pbstrRsltVal' , ), 116, (116, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 844 , (3, 0, None, None) , 0 , )),
	(( u'NegativeInventoryAdjustmentAccount' , u'pVal' , ), 117, (117, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 848 , (3, 0, None, None) , 0 , )),
	(( u'NegativeInventoryAdjustmentAccount' , u'pVal' , ), 117, (117, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 852 , (3, 0, None, None) , 0 , )),
	(( u'FinancialYear' , u'plRsltVal' , ), 118, (118, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 856 , (3, 0, None, None) , 0 , )),
	(( u'FinancialYear' , u'plRsltVal' , ), 118, (118, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 860 , (3, 0, None, None) , 0 , )),
	(( u'SelfInvoiceRevenueAccount' , u'pbstrRsltVal' , ), 119, (119, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 864 , (3, 0, None, None) , 0 , )),
	(( u'SelfInvoiceRevenueAccount' , u'pbstrRsltVal' , ), 119, (119, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 868 , (3, 0, None, None) , 0 , )),
	(( u'SelfInvoiceExpenseAccount' , u'pbstrRsltVal' , ), 120, (120, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 872 , (3, 0, None, None) , 0 , )),
	(( u'SelfInvoiceExpenseAccount' , u'pbstrRsltVal' , ), 120, (120, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 876 , (3, 0, None, None) , 0 , )),
	(( u'StockInTransitAccount' , u'pVal' , ), 121, (121, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 880 , (3, 0, None, None) , 0 , )),
	(( u'StockInTransitAccount' , u'pVal' , ), 121, (121, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 884 , (3, 0, None, None) , 0 , )),
	(( u'EUAccountsReceivable' , u'pbstrRsltVal' , ), 122, (122, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 888 , (3, 0, None, None) , 0 , )),
	(( u'EUAccountsReceivable' , u'pbstrRsltVal' , ), 122, (122, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 892 , (3, 0, None, None) , 0 , )),
	(( u'EUAccountsPayable' , u'pbstrRsltVal' , ), 123, (123, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 896 , (3, 0, None, None) , 0 , )),
	(( u'EUAccountsPayable' , u'pbstrRsltVal' , ), 123, (123, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 900 , (3, 0, None, None) , 0 , )),
	(( u'SalesDownPaymentInterimAccount' , u'pbstrRsltVal' , ), 124, (124, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 904 , (3, 0, None, None) , 0 , )),
	(( u'SalesDownPaymentInterimAccount' , u'pbstrRsltVal' , ), 124, (124, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 908 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseDownPaymentInterimAccount' , u'pbstrRsltVal' , ), 125, (125, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 912 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseDownPaymentInterimAccount' , u'pbstrRsltVal' , ), 125, (125, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 916 , (3, 0, None, None) , 0 , )),
	(( u'WipOffsetProfitAndLossAccount' , u'pVal' , ), 131, (131, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 920 , (3, 0, None, None) , 0 , )),
	(( u'WipOffsetProfitAndLossAccount' , u'pVal' , ), 131, (131, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 924 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetProfitAndLossAccount' , u'pVal' , ), 132, (132, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 928 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetProfitAndLossAccount' , u'pVal' , ), 132, (132, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 932 , (3, 0, None, None) , 0 , )),
	(( u'DunningInterestAccount' , u'pVal' , ), 133, (133, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 936 , (3, 0, None, None) , 0 , )),
	(( u'DunningInterestAccount' , u'pVal' , ), 133, (133, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 940 , (3, 0, None, None) , 0 , )),
	(( u'DunningFeeAccount' , u'pVal' , ), 134, (134, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 944 , (3, 0, None, None) , 0 , )),
	(( u'DunningFeeAccount' , u'pVal' , ), 134, (134, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 948 , (3, 0, None, None) , 0 , )),
]

IPeriodCategoryParams_vtables_dispatch_ = 1
IPeriodCategoryParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IPeriodCategoryParamsCollection_vtables_dispatch_ = 1
IPeriodCategoryParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IPickLists_vtables_dispatch_ = 1
IPickLists_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsEntry' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'OwnerCode' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'OwnerCode' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'OwnerName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PickDate' , u'pdtRsltVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PickDate' , u'pdtRsltVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ObjectType' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{8C5A86ED-4B60-46EB-A0D5-9F529DDF069E}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
]

IPickLists_Lines_vtables_dispatch_ = 1
IPickLists_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'OrderEntry' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'OrderEntry' , u'plRsltVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'OrderRowID' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'OrderRowID' , u'plRsltVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PickedQuantity' , u'pdblRsltVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PickedQuantity' , u'pdblRsltVal' , ), 9, (9, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PickStatus' , u'penumRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ReleasedQuantity' , u'pdblRsltVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ReleasedQuantity' , u'pdblRsltVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PreviouslyReleasedQuantity' , u'pdblRsltVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BaseObjectType' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BaseObjectType' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumbers' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{93E5E52B-181E-46B8-96CB-1C066AC04DCA}')") , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BatchNumbers' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{1FEF5698-93E1-4167-AEA0-4BB151792623}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IPredefinedText_vtables_dispatch_ = 1
IPredefinedText_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TextCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TextCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Text' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Text' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IPredefinedTextParams_vtables_dispatch_ = 1
IPredefinedTextParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TextCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IPredefinedTextsParams_vtables_dispatch_ = 1
IPredefinedTextsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IPredefinedTextsService_vtables_dispatch_ = 1
IPredefinedTextsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddPredefinedText' , u'pIPredefinedText' , u'ppIPredefinedTextParams' , ), 10, (10, (), [ (9, 1, None, "IID('{BFFF366B-1B1C-4EF6-8546-27C9BFF735CE}')") , 
			(16393, 10, None, "IID('{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdatePredefinedText' , u'pIPredefinedText' , ), 11, (11, (), [ (9, 1, None, "IID('{BFFF366B-1B1C-4EF6-8546-27C9BFF735CE}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeletePredefinedText' , u'pIPredefinedTextParams' , ), 12, (12, (), [ (9, 1, None, "IID('{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetPredefinedText' , u'pIPredefinedTextParams' , u'ppIPredefinedText' , ), 13, (13, (), [ (9, 1, None, "IID('{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}')") , 
			(16393, 10, None, "IID('{BFFF366B-1B1C-4EF6-8546-27C9BFF735CE}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetPredefinedTextList' , u'ppIPredefinedTextsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{A22E33CF-C423-4581-8C7C-382E5D59B301}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IPriceLists_vtables_dispatch_ = 1
IPriceLists_vtables_ = [
	(( u'GetByKey' , u'QueueID' , u'Found' , ), 1, (1, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 3, (3, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'RoundingMethod' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GroupNum' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GroupNum' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BasePriceList' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BasePriceList' , u'pVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PriceListName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PriceListName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IProductTrees_vtables_dispatch_ = 1
IProductTrees_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 3, (3, (), [ (8, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Items' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TreeCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TreeCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TreeType' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TreeType' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 13, (13, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
]

IProductTrees_Lines_vtables_dispatch_ = 1
IProductTrees_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 9, (9, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'IssueMethod' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'IssueMethod' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ParentItem' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ParentItem' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 18, (18, (), [ ], 1 , 1 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
]

IProductionOrders_vtables_dispatch_ = 1
IProductionOrders_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lAbsEntry' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AbsoluteEntry' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderStatus' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderStatus' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderType' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderType' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'PlannedQuantity' , u'pdbllRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'PlannedQuantity' , u'pdbllRsltVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CompletedQuantity' , u'pdblRsltVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'RejectedQuantity' , u'pdblRsltVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pdtRsltVal' , ), 21, (21, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PostingDate' , u'pdtRsltVal' , ), 21, (21, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdtRsltVal' , ), 22, (22, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pdtRsltVal' , ), 22, (22, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOriginEntry' , u'plRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOriginEntry' , u'plRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOriginNumber' , u'plRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOrigin' , u'penumRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderOrigin' , u'penumRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'plRsltVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pdtRsltVal' , ), 28, (28, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'ReleaseDate' , u'pdtRsltVal' , ), 29, (29, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'InventoryUOM' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'TransactionNumber' , u'plRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pdtRsltVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 36, (36, (), [ (16393, 10, None, "IID('{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}')") , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pdtRsltVal' , ), 28, (28, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'SalesOrderLines' , u'pVal' , ), 44, (44, (), [ (16393, 10, None, "IID('{DF6C475B-AD8D-4E52-A412-9500E69DB54B}')") , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
]

IProductionOrders_Lines_vtables_dispatch_ = 1
IProductionOrders_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'DocumentAbsoluteEntry' , u'plRsltVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pbstrRsltVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BaseQuantity' , u'pdblRsltVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BaseQuantity' , u'pdblRsltVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PlannedQuantity' , u'pdblRsltVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'IssuedQuantity' , u'pdblRsltVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderIssueType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ProductionOrderIssueType' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'VisualOrder' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'PlannedQuantity' , u'pdblRsltVal' , ), 9, (9, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'LocationCode' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 16, (16, (), [ ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Project' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
]

IProductionOrders_SalesOrderLines_vtables_dispatch_ = 1
IProductionOrders_SalesOrderLines_vtables_ = [
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BaseNumber' , u'plRsltVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'BaseAbsEntry' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BaseLine' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IProfitCenter_vtables_dispatch_ = 1
IProfitCenter_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CenterCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CenterCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CenterName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CenterName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'InWhichDimension' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'InWhichDimension' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterType' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CostCenterType' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pdateRsltVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pdateRsltVal' , ), 16, (16, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'EffectiveTo' , u'pdateRsltVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'EffectiveTo' , u'pdateRsltVal' , ), 17, (17, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
]

IProfitCenterParams_vtables_dispatch_ = 1
IProfitCenterParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CenterCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CenterCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CenterName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IProfitCentersParams_vtables_dispatch_ = 1
IProfitCentersParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{98F79F87-3825-465E-8E69-E7E416534B7B}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{98F79F87-3825-465E-8E69-E7E416534B7B}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IProfitCentersService_vtables_dispatch_ = 1
IProfitCentersService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddProfitCenter' , u'pIProfitCenter' , u'ppIProfitCenterParams' , ), 10, (10, (), [ (9, 1, None, "IID('{F29A5E07-7C8B-4706-99D7-9BFB85180358}')") , 
			(16393, 10, None, "IID('{98F79F87-3825-465E-8E69-E7E416534B7B}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateProfitCenter' , u'pIProfitCenter' , ), 11, (11, (), [ (9, 1, None, "IID('{F29A5E07-7C8B-4706-99D7-9BFB85180358}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteProfitCenter' , u'pIProfitCenterParams' , ), 12, (12, (), [ (9, 1, None, "IID('{98F79F87-3825-465E-8E69-E7E416534B7B}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetProfitCenter' , u'pIProfitCenterParams' , u'ppIProfitCenter' , ), 13, (13, (), [ (9, 1, None, "IID('{98F79F87-3825-465E-8E69-E7E416534B7B}')") , 
			(16393, 10, None, "IID('{F29A5E07-7C8B-4706-99D7-9BFB85180358}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetProfitCenterList' , u'ppIProfitCentersParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{BF7FD103-23BD-401E-8A87-DBAFBBB7DB37}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IProject_vtables_dispatch_ = 1
IProject_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pdateRsltVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ValidFrom' , u'pdateRsltVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pdateRsltVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ValidTo' , u'pdateRsltVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IProjectParams_vtables_dispatch_ = 1
IProjectParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IProjectsParams_vtables_dispatch_ = 1
IProjectsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{563777FD-DD54-40BC-BC70-3DF2EA78F859}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{563777FD-DD54-40BC-BC70-3DF2EA78F859}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IProjectsService_vtables_dispatch_ = 1
IProjectsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddProject' , u'pIProject' , u'ppIProjectParams' , ), 10, (10, (), [ (9, 1, None, "IID('{C7DF4768-56A6-45D9-9C2B-916008846E76}')") , 
			(16393, 10, None, "IID('{563777FD-DD54-40BC-BC70-3DF2EA78F859}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateProject' , u'pIProject' , ), 11, (11, (), [ (9, 1, None, "IID('{C7DF4768-56A6-45D9-9C2B-916008846E76}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteProject' , u'pIProjectParams' , ), 12, (12, (), [ (9, 1, None, "IID('{563777FD-DD54-40BC-BC70-3DF2EA78F859}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetProjectList' , u'ppIProjectsParams' , ), 13, (13, (), [ (16393, 10, None, "IID('{44AB2C0B-390B-43A1-8BCD-529BA39C52C3}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetProject' , u'pIProjectParams' , u'ppIProject' , ), 14, (14, (), [ (9, 1, None, "IID('{563777FD-DD54-40BC-BC70-3DF2EA78F859}')") , 
			(16393, 10, None, "IID('{C7DF4768-56A6-45D9-9C2B-916008846E76}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IQueryCategories_vtables_dispatch_ = 1
IQueryCategories_vtables_ = [
	(( u'Code' , u'plVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Permissions' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Permissions' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IQueue_vtables_dispatch_ = 1
IQueue_vtables_ = [
	(( u'QueueID' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'QueueID' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'QueueManager' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'QueueManager' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'QueueEmail' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'QueueEmail' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'QueueMembers' , u'ppRsltVal' , ), 58, (58, (), [ (16393, 10, None, "IID('{A6D332DA-630B-44C7-AA91-69F2C1A2501D}')") , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrQueueID' , u'Found' , ), 9, (9, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 10, (10, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IQueueMembers_vtables_dispatch_ = 1
IQueueMembers_vtables_ = [
	(( u'QueueID' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'QueueID' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'MemberUserID' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'MemberUserID' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 3, (3, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 5, (5, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 6, (6, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IRecipient_vtables_dispatch_ = 1
IRecipient_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'NameTo' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'NameTo' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SendEmail' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SendEmail' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SendSMS' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SendSMS' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SendFax' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SendFax' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CellularNumber' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CellularNumber' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserType' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'UserType' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SendInternal' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'SendInternal' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
]

IRecipientCollection_vtables_dispatch_ = 1
IRecipientCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{BFC32883-8D3F-49F9-A985-3F9B3B37260F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{BFC32883-8D3F-49F9-A985-3F9B3B37260F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IRecipients_vtables_dispatch_ = 1
IRecipients_vtables_ = [
	(( u'Count' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'NameTo' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'NameTo' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SendEmail' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SendEmail' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SendSMS' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SendSMS' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SendFax' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SendFax' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CellularNumber' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CellularNumber' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'EmailAddress' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'UserType' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'UserType' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SendInternal' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SendInternal' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IRecordset_vtables_dispatch_ = 1
IRecordset_vtables_ = [
	(( u'Fields' , u'pVal' , ), 0, (0, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'MoveNext' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'MovePrevious' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'BoF' , u'pVal' , ), 5, (5, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'EoF' , u'pVal' , ), 6, (6, (), [ (16395, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DoQuery' , u'QueryStr' , ), 7, (7, (), [ (8, 0, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RecordCount' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 9, (9, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MoveFirst' , ), 10, (10, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'MoveLast' , ), 11, (11, (), [ ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Command' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}')") , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'GetFixedXML' , u'xmlMode' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , 
			(16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'GetFixedSchema' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IRelationships_vtables_dispatch_ = 1
IRelationships_vtables_ = [
	(( u'RelationshipDescription' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipDescription' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipCode' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IReportFilterService_vtables_dispatch_ = 1
IReportFilterService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetTaxReportFilter' , u'pITaxReportFilterParams' , u'ppRsltITaxReportFilter' , ), 11, (11, (), [ (9, 1, None, "IID('{A5CDC033-47D7-4019-801A-8443F14D52D0}')") , 
			(16393, 10, None, "IID('{3503F7F1-5A0C-4D08-A498-0D9619097C09}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateTaxReportFilter' , u'pITaxReportFilter' , ), 12, (12, (), [ (9, 1, None, "IID('{3503F7F1-5A0C-4D08-A498-0D9619097C09}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AddTaxReportFilter' , u'pITaxReportFilter' , u'ppRsltITaxReportFilterParams' , ), 13, (13, (), [ (9, 1, None, "IID('{3503F7F1-5A0C-4D08-A498-0D9619097C09}')") , 
			(16393, 10, None, "IID('{A5CDC033-47D7-4019-801A-8443F14D52D0}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetTaxReportFilterList' , u'pITaxReportFilterParams' , u'ppRsltITaxReportFiltersParams' , ), 14, (14, (), [ (9, 1, None, "IID('{A5CDC033-47D7-4019-801A-8443F14D52D0}')") , 
			(16393, 10, None, "IID('{813B8F2A-F8BC-4C70-A043-CF099057F3B8}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DeleteTaxReportFilter' , u'pITaxReportFilterParams' , ), 15, (15, (), [ (9, 1, None, "IID('{A5CDC033-47D7-4019-801A-8443F14D52D0}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IReportLayout_vtables_dispatch_ = 1
IReportLayout_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'Value' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'Value' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Author' , u'Value' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Author' , u'Value' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'Value' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'Value' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Width' , u'Value' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Width' , u'Value' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Height' , u'Value' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Height' , u'Value' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'LeftMargin' , u'Value' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'LeftMargin' , u'Value' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'RightMargin' , u'Value' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'RightMargin' , u'Value' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TopMargin' , u'Value' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TopMargin' , u'Value' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BottomMargin' , u'Value' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BottomMargin' , u'Value' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Editable' , u'Value' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PaperSize' , u'Value' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PaperSize' , u'Value' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Orientation' , u'Value' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Orientation' , u'Value' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'GridSize' , u'Value' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'GridSize' , u'Value' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'GridType' , u'Value' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'GridType' , u'Value' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ShowGrid' , u'Value' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ShowGrid' , u'Value' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'SnapToGrid' , u'Value' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'SnapToGrid' , u'Value' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'Value' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Picture' , u'Value' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'TypeCode' , u'Value' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'TypeCode' , u'Value' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ForeignLanguageReport' , u'Value' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ForeignLanguageReport' , u'Value' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Sortable' , u'Value' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'LeaderReport' , u'Value' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'LeaderReport' , u'Value' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'FollowUpReport' , u'Value' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'FollowUpReport' , u'Value' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'ConvertFontInPrintPreview' , u'Value' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ConvertFontInPrintPreview' , u'Value' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'PreviewPrintingFont' , u'Value' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'PreviewPrintingFont' , u'Value' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ChangeFontSizeInPreview' , u'Value' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ChangeFontSizeInPreview' , u'Value' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ConvertFontForEMail' , u'Value' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'ConvertFontForEMail' , u'Value' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'EMailFont' , u'Value' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'EMailFont' , u'Value' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'ChangeFontSizeForEMail' , u'Value' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'ChangeFontSizeForEMail' , u'Value' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Query' , u'Value' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'Query' , u'Value' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'QueryType' , u'Value' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'QueryType' , u'Value' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'language' , u'Value' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'language' , u'Value' , ), 41, (41, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'ImpExpObjCode' , u'Value' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'ImpExpObjCode' , u'Value' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionName' , u'Value' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionName' , u'Value' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionErrorAction' , u'Value' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionErrorAction' , u'Value' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'RepetitiveAreasNumber' , u'Value' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'AllignFooterToBottom' , u'Value' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'AllignFooterToBottom' , u'Value' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'ReportLayoutItems' , u'ppRsltVal' , ), 47, (47, (), [ (16393, 10, None, "IID('{E7092C39-C3B3-4928-A5AB-B0FF9B885D5E}')") , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'ReportLayoutItems' , u'ppRsltVal' , ), 47, (47, (), [ (9, 1, None, "IID('{E7092C39-C3B3-4928-A5AB-B0FF9B885D5E}')") , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'LayoutCode' , u'Value' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'Value' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'Value' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'Printer' , u'Value' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'Printer' , u'Value' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'PrinterFirstPage' , u'Value' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'PrinterFirstPage' , u'Value' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfCopies' , u'Value' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfCopies' , u'Value' , ), 52, (52, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'Localization' , u'Value' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'Localization' , u'Value' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'UseFirstPrinter' , u'Value' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'UseFirstPrinter' , u'Value' , ), 54, (54, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'B1Version' , u'Value' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'B1Version' , u'Value' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'CRVersion' , u'Value' , ), 56, (56, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'CRVersion' , u'Value' , ), 56, (56, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'TranslationLines' , u'ppRsltVal' , ), 57, (57, (), [ (16393, 10, None, "IID('{33201180-255B-46DF-A8C4-E8A7E2855353}')") , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'TypeDetail' , u'Value' , ), 58, (58, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'TypeDetail' , u'Value' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
]

IReportLayoutItem_vtables_dispatch_ = 1
IReportLayoutItem_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ParentType' , u'Value' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ParentType' , u'Value' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'Value' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'Value' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Visible' , u'Value' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Visible' , u'Value' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SuppressZeros' , u'Value' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SuppressZeros' , u'Value' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Left' , u'Value' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Left' , u'Value' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Top' , u'Value' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Top' , u'Value' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Width' , u'Value' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Width' , u'Value' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Height' , u'Value' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Height' , u'Value' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'LeftMargin' , u'Value' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'LeftMargin' , u'Value' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'RightMargin' , u'Value' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'RightMargin' , u'Value' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'TopMargin' , u'Value' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TopMargin' , u'Value' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'BottomMargin' , u'Value' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BottomMargin' , u'Value' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'LeftBorderLineThickness' , u'Value' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'LeftBorderLineThickness' , u'Value' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'RightBorderLineThickness' , u'Value' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'RightBorderLineThickness' , u'Value' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'TopBorderLineThickness' , u'Value' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TopBorderLineThickness' , u'Value' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'BottomBorderLineThickness' , u'Value' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'BottomBorderLineThickness' , u'Value' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'ShadowThickness' , u'Value' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'ShadowThickness' , u'Value' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BackgroundRed' , u'Value' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BackgroundRed' , u'Value' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'BackgroundGreen' , u'Value' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'BackgroundGreen' , u'Value' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'BackgroundBlue' , u'Value' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'BackgroundBlue' , u'Value' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'TextRed' , u'Value' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'TextRed' , u'Value' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'TextGreen' , u'Value' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'TextGreen' , u'Value' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'TextBlue' , u'Value' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'TextBlue' , u'Value' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'HighlightRed' , u'Value' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'HighlightRed' , u'Value' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'HighlightGreen' , u'Value' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'HighlightGreen' , u'Value' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'HighlightBlue' , u'Value' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'HighlightBlue' , u'Value' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'BorderRed' , u'Value' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'BorderRed' , u'Value' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'BorderGreen' , u'Value' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'BorderGreen' , u'Value' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'BorderBlue' , u'Value' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'BorderBlue' , u'Value' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'GroupNumber' , u'Value' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'GroupNumber' , u'Value' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'FontName' , u'Value' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'FontName' , u'Value' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'FontSize' , u'Value' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'FontSize' , u'Value' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'TextStyle' , u'Value' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'TextStyle' , u'Value' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'HorizontalAlignment' , u'Value' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'HorizontalAlignment' , u'Value' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'LineBreak' , u'Value' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'LineBreak' , u'Value' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'PictureSize' , u'Value' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'PictureSize' , u'Value' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'DataSource' , u'Value' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'DataSource' , u'Value' , ), 49, (49, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'String' , u'Value' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'String' , u'Value' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'VariableNumber' , u'Value' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'VariableNumber' , u'Value' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'Value' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'Value' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'FieldName' , u'Value' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'FieldName' , u'Value' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'DisplayDescription' , u'Value' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'DisplayDescription' , u'Value' , ), 54, (54, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'Editable' , u'Value' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'Editable' , u'Value' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'ItemNumber' , u'Value' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'ItemNumber' , u'Value' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'VerticalAlignment' , u'Value' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'VerticalAlignment' , u'Value' , ), 59, (59, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'SortLevel' , u'Value' , ), 60, (60, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'SortLevel' , u'Value' , ), 60, (60, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'ReverseSort' , u'Value' , ), 61, (61, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'ReverseSort' , u'Value' , ), 61, (61, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'SortType' , u'Value' , ), 62, (62, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'SortType' , u'Value' , ), 62, (62, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'Unique' , u'Value' , ), 63, (63, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'Unique' , u'Value' , ), 63, (63, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'SetAsGroup' , u'Value' , ), 64, (64, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'SetAsGroup' , u'Value' , ), 64, (64, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'NewPage' , u'Value' , ), 65, (65, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'NewPage' , u'Value' , ), 65, (65, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'PrintAsBarCode' , u'Value' , ), 66, (66, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'PrintAsBarCode' , u'Value' , ), 66, (66, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'LinkToField' , u'Value' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'LinkToField' , u'Value' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'BarCodeStandard' , u'Value' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'BarCodeStandard' , u'Value' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'DisplayTotalAsAWord' , u'Value' , ), 73, (73, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'DisplayTotalAsAWord' , u'Value' , ), 73, (73, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'BlockFontChange' , u'Value' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'BlockFontChange' , u'Value' , ), 74, (74, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'ParentIndex' , u'Value' , ), 76, (76, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'ParentIndex' , u'Value' , ), 76, (76, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'ItemIndex' , u'Value' , ), 77, (77, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'ItemIndex' , u'Value' , ), 77, (77, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'StringLength' , u'Value' , ), 78, (78, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'StringLength' , u'Value' , ), 78, (78, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'StringFiller' , u'Value' , ), 79, (79, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'StringFiller' , u'Value' , ), 79, (79, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'RelateToField' , u'Value' , ), 80, (80, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'RelateToField' , u'Value' , ), 80, (80, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'NextSegmentItemNumber' , u'Value' , ), 81, (81, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'NextSegmentItemNumber' , u'Value' , ), 81, (81, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'HeightAdjustments' , u'Value' , ), 82, (82, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'HeightAdjustments' , u'Value' , ), 82, (82, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'DuplicateRepetitiveArea' , u'Value' , ), 83, (83, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'DuplicateRepetitiveArea' , u'Value' , ), 83, (83, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfLinesInRepetitiveArea' , u'Value' , ), 84, (84, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'NumberOfLinesInRepetitiveArea' , u'Value' , ), 84, (84, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'DistanceToRepetitiveDuplicate' , u'Value' , ), 85, (85, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'DistanceToRepetitiveDuplicate' , u'Value' , ), 85, (85, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'FieldIdentifier' , u'Value' , ), 86, (86, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'FieldIdentifier' , u'Value' , ), 86, (86, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'HideRepetitiveAreaIfEmpty' , u'Value' , ), 87, (87, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'HideRepetitiveAreaIfEmpty' , u'Value' , ), 87, (87, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'DisplayRepetitiveAreaFooterOnAllPages' , u'Value' , ), 88, (88, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'DisplayRepetitiveAreaFooterOnAllPages' , u'Value' , ), 88, (88, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
]

IReportLayoutItems_vtables_dispatch_ = 1
IReportLayoutItems_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{2691123A-50EC-4554-9180-490532131218}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{2691123A-50EC-4554-9180-490532131218}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IReportLayoutParams_vtables_dispatch_ = 1
IReportLayoutParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LayoutCode' , u'Value' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LayoutCode' , u'Value' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LayoutName' , u'Value' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'Value' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IReportLayoutPrintParams_vtables_dispatch_ = 1
IReportLayoutPrintParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LayoutCode' , u'Value' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LayoutCode' , u'Value' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'Value' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'Value' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IReportLayout_TranslationLine_vtables_dispatch_ = 1
IReportLayout_TranslationLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'Value' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'Value' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocName' , u'Value' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocName' , u'Value' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'Value' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCode' , u'Value' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CreateDate' , u'Value' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CreateDate' , u'Value' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'Value' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'Value' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CreateTime' , u'Value' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CreateTime' , u'Value' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'UpdateTime' , u'Value' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'UpdateTime' , u'Value' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
]

IReportLayout_TranslationLines_vtables_dispatch_ = 1
IReportLayout_TranslationLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{86A368F0-8603-466A-906F-9FC811B1B711}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{86A368F0-8603-466A-906F-9FC811B1B711}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IReportLayoutsParams_vtables_dispatch_ = 1
IReportLayoutsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IReportLayoutsService_vtables_dispatch_ = 1
IReportLayoutsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SetDefaultReport' , u'ppIDefaultReportParams' , ), 10, (10, (), [ (9, 1, None, "IID('{90E9CFE3-0440-4E26-B8E7-975A9A4638B4}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetDefaultReport' , u'pIReportParams' , u'ppRsltIDefaultReportParams' , ), 11, (11, (), [ (9, 1, None, "IID('{0B4E873F-65FD-4638-9339-84D197CF8109}')") , 
			(16393, 10, None, "IID('{90E9CFE3-0440-4E26-B8E7-975A9A4638B4}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AddReportLayout' , u'pIReportLayout' , u'ppRsltIReportLayoutParams' , ), 12, (12, (), [ (9, 1, None, "IID('{77C5B820-63C3-4825-9279-964224F7BE00}')") , 
			(16393, 10, None, "IID('{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DeleteReportLayout' , u'pIReportLayoutParams' , ), 13, (13, (), [ (9, 1, None, "IID('{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetReportLayout' , u'pIReportLayoutParams' , u'ppRsltIReportLayout' , ), 14, (14, (), [ (9, 1, None, "IID('{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')") , 
			(16393, 10, None, "IID('{77C5B820-63C3-4825-9279-964224F7BE00}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GetDefaultReportLayout' , u'pIReportParams' , u'ppRsltIReportLayout' , ), 15, (15, (), [ (9, 1, None, "IID('{0B4E873F-65FD-4638-9339-84D197CF8109}')") , 
			(16393, 10, None, "IID('{77C5B820-63C3-4825-9279-964224F7BE00}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetReportLayoutList' , u'pIReportParams' , u'ppRsltIReportLayoutsParams' , ), 16, (16, (), [ (9, 1, None, "IID('{0B4E873F-65FD-4638-9339-84D197CF8109}')") , 
			(16393, 10, None, "IID('{16209A8A-D1E6-4820-A4B4-DB43EBEE8BFA}')") , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UpdateLanguageReport' , u'ppIReportLayout' , ), 17, (17, (), [ (9, 1, None, "IID('{77C5B820-63C3-4825-9279-964224F7BE00}')") , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AddReportLayoutToMenu' , u'ppIReportLayout' , u'MenuID' , u'ppRsltIReportLayoutParams' , ), 18, (18, (), [ 
			(9, 1, None, "IID('{77C5B820-63C3-4825-9279-964224F7BE00}')") , (8, 1, None, None) , (16393, 10, None, "IID('{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')") , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DeleteReportLayoutAndMenu' , u'ppIReportLayoutParams' , ), 19, (19, (), [ (9, 1, None, "IID('{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}')") , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Print' , u'ppIReportLayoutPrintParams' , ), 20, (20, (), [ (9, 1, None, "IID('{A86FB678-5037-4F08-AD65-6C281693C16F}')") , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IReportParams_vtables_dispatch_ = 1
IReportParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ReportCode' , u'Value' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ReportCode' , u'Value' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'Value' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'Value' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'Value' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'Value' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IReportType_vtables_dispatch_ = 1
IReportType_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TypeCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TypeName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TypeName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DefaultReportLayout' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DefaultReportLayout' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AddonName' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'AddonName' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'AddonFormType' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'AddonFormType' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'MenuID' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MenuID' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IReportTypeParams_vtables_dispatch_ = 1
IReportTypeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TypeCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TypeCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TypeName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'AddonName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AddonFormType' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'MenuID' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IReportTypesParams_vtables_dispatch_ = 1
IReportTypesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IReportTypesService_vtables_dispatch_ = 1
IReportTypesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetReportType' , u'pIReportTypeParams' , u'ppIReportType' , ), 10, (10, (), [ (9, 1, None, "IID('{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')") , 
			(16393, 10, None, "IID('{41776B28-16AF-4699-B4FC-475989790FB8}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AddReportType' , u'pIReportType' , u'ppIReportTypeParams' , ), 11, (11, (), [ (9, 1, None, "IID('{41776B28-16AF-4699-B4FC-475989790FB8}')") , 
			(16393, 10, None, "IID('{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UpdateReportType' , u'pIReportType' , ), 12, (12, (), [ (9, 1, None, "IID('{41776B28-16AF-4699-B4FC-475989790FB8}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DeleteReportType' , u'pIReportType' , ), 13, (13, (), [ (9, 1, None, "IID('{41776B28-16AF-4699-B4FC-475989790FB8}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetReportTypeList' , u'ppIReportTypesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{343A6016-2B36-4522-B0E9-477A062EF6DB}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IRetornoCode_vtables_dispatch_ = 1
IRetornoCode_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'OccurenceCode' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'OccurenceCode' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MovementCode' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'MovementCode' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BOEStatus' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BOEStatus' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Color' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Color' , u'plRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'FileFormat' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'FileFormat' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IRetornoCodeParams_vtables_dispatch_ = 1
IRetornoCodeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'OccurenceCode' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MovementCode' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BOEStatus' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Color' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FileFormat' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'BankCode' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IRetornoCodeParamsCollection_vtables_dispatch_ = 1
IRetornoCodeParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IRetornoCodesService_vtables_dispatch_ = 1
IRetornoCodesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pIRetornoCode' , u'ppIRetornoCodeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{2C08600E-B9F0-432D-9D95-F934DDC01165}')") , 
			(16393, 10, None, "IID('{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pIRetornoCode' , ), 11, (11, (), [ (9, 1, None, "IID('{2C08600E-B9F0-432D-9D95-F934DDC01165}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pIRetornoCodeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pIRetornoCodeParams' , u'ppIRetornoCode' , ), 13, (13, (), [ (9, 1, None, "IID('{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}')") , 
			(16393, 10, None, "IID('{2C08600E-B9F0-432D-9D95-F934DDC01165}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppIRetornoCodeParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{6692DB25-3CF4-44C4-932D-1F6D13DF6E7C}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IRoundedData_vtables_dispatch_ = 1
IRoundedData_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'ppRsltVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

ISBObob_vtables_dispatch_ = 1
ISBObob_vtables_ = [
	(( u'GetBPList' , u'CardType' , u'pVal' , ), 1, (1, (), [ (3, 0, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDueDate' , u'CardCode' , u'refDate' , u'pVal' , ), 2, (2, (), [ 
			(8, 1, None, None) , (7, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetSystemCurrency' , u'pVal' , ), 3, (3, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetLocalCurrency' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetCurrencyRate' , u'Currency' , u'Date' , u'pVal' , ), 5, (5, (), [ 
			(8, 1, None, None) , (7, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetIndexRate' , u'Index' , u'Date' , u'pVal' , ), 6, (6, (), [ 
			(8, 1, None, None) , (7, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetItemPrice' , u'CardCode' , u'ItemCode' , u'amount' , u'Date' , 
			u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , (8, 1, None, None) , (5, 1, None, None) , 
			(7, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetItemList' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GetUserList' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetWareHouseList' , u'pVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrencyRate' , u'Currency' , u'Date' , u'Value' , u'Update' , 
			), 11, (11, (), [ (8, 1, None, None) , (7, 1, None, None) , (5, 1, None, None) , (11, 49, 'False', None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetContactEmployees' , u'CardCode' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Format_DateToString' , u'inDate' , u'pVal' , ), 13, (13, (), [ (7, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Format_StringToDate' , u'inStr' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Format_MoneyToString' , u'inMoney' , u'inPrecision' , u'pVal' , ), 15, (15, (), [ 
			(5, 1, None, None) , (3, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'GetObjectKeyBySingleValue' , u'ObjNum' , u'PropName' , u'Value' , u'Condition' , 
			u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , (8, 1, None, None) , (8, 1, None, None) , 
			(3, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ConvertEnumValueToValidValue' , u'enumName' , u'enumValue' , u'retValidValue' , ), 18, (18, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ConvertValidValueToEnumValue' , u'enumName' , u'ValidValue' , u'retEnumValue' , ), 19, (19, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'GetValidValueDescription' , u'ObjNum' , u'ObjectName' , u'PropertyName' , u'enumValue' , 
			u'Description' , ), 20, (20, (), [ (3, 1, None, None) , (8, 1, None, None) , (8, 1, None, None) , 
			(3, 1, None, None) , (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'GetAccountSegmentsByCode' , u'AccountCode' , u'AddSeperator' , u'pVal' , ), 21, (21, (), [ 
			(8, 1, None, None) , (11, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GetTableFieldList' , u'TableName' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GetFieldValidValues' , u'TableName' , u'FieldName' , u'pVal' , ), 23, (23, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'GetObjectPermission' , u'Object' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , 
			(16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'GetTableList' , u'pVal' , ), 25, (25, (), [ (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'GetSystemPermission' , u'UserName' , u'PermissionID' , u'pVal' , ), 26, (26, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16393, 10, None, "IID('{8CA3AB92-1930-4511-4AA8-82D53C3150C3}')") , ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'SetSystemPermission' , u'UserName' , u'PermissionID' , u'Permission' , ), 27, (27, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (3, 1, None, None) , ], 1 , 1 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'GetEwaParameters' , u'bstrKey' , u'pbstrRsltEwaUserName' , u'pbstrRsltEwaPassword' , ), 28, (28, (), [ 
			(8, 1, None, None) , (16392, 2, None, None) , (16392, 2, None, None) , ], 1 , 1 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PutEwaParameters' , u'bstrKey' , u'bstrEwaUserName' , u'bstrEwaPassword' , ), 29, (29, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
]

ISalesForecast_vtables_dispatch_ = 1
ISalesForecast_vtables_ = [
	(( u'ForecastStartDate' , u'pVal' , ), 1, (1, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ForecastStartDate' , u'pVal' , ), 1, (1, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ForecastEndDate' , u'pVal' , ), 2, (2, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ForecastEndDate' , u'pVal' , ), 2, (2, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ForecastCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ForecastCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ForecastName' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ForecastName' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 8, (8, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 9, (9, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 10, (10, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'ppRsltVal' , ), 58, (58, (), [ (16393, 10, None, "IID('{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'pVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 61, (61, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'View' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'View' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
]

ISalesForecast_Lines_vtables_dispatch_ = 1
ISalesForecast_Lines_vtables_ = [
	(( u'Quantity' , u'pVal' , ), 1, (1, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 1, (1, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ForecastedDay' , u'pVal' , ), 2, (2, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ForecastedDay' , u'pVal' , ), 2, (2, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunities_vtables_dispatch_ = 1
ISalesOpportunities_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'OpprId' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SequentialNo' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SalesPerson' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SalesPerson' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Source' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Source' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'InterestField1' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'InterestField1' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'InterestField2' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'InterestField2' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'InterestField3' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'InterestField3' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'InterestLevel' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'InterestLevel' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 18, (18, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 18, (18, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PredictedClosingDate' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'PredictedClosingDate' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'MaxLocalTotal' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'MaxSystemTotal' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'WeightedSumLC' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'WeightedSumSC' , u'pVal' , ), 24, (24, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfit' , u'pVal' , ), 25, (25, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfit' , u'pVal' , ), 25, (25, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitTotalLocal' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitTotalLocal' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'GrossProfitTotalSystem' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'ReasonForClosing' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'ReasonForClosing' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'TotalAmountLocal' , u'pVal' , ), 32, (32, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'TotalAmountLocal' , u'pVal' , ), 32, (32, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'TotalAmounSystem' , u'pVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'ClosingGrossProfitLocal' , u'pVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ClosingGrossProfitSystem' , u'pVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ClosingPercentage' , u'pVal' , ), 36, (36, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'CurrentStageNo' , u'pVal' , ), 37, (37, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 38, (38, (), [ (16393, 10, None, "IID('{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}')") , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Competition' , u'pVal' , ), 39, (39, (), [ (16393, 10, None, "IID('{19E6540E-4E64-48C1-9525-29D5710D1FFD}')") , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Partners' , u'pVal' , ), 40, (40, (), [ (16393, 10, None, "IID('{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}')") , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'OpportunityName' , u'pVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'OpportunityName' , u'pVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'LinkedDocumentType' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipfield' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipfield' , u'pVal' , ), 44, (44, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'StatusRemarks' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'StatusRemarks' , u'pVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelName' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelName' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCheckbox' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'LinkedDocumentNumber' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'Territory' , u'pVal' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'Territory' , u'pVal' , ), 52, (52, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 53, (53, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 54, (54, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelCode' , u'pVal' , ), 55, (55, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelCode' , u'pVal' , ), 55, (55, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'ClosingType' , u'pVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'ClosingType' , u'pVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'Interests' , u'ppRsltVal' , ), 57, (57, (), [ (16393, 10, None, "IID('{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}')") , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'Reasons' , u'ppRsltVal' , ), 58, (58, (), [ (16393, 10, None, "IID('{D4A7CE6F-B909-4273-8499-C210F94ED2D1}')") , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 62, (62, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 62, (62, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'CurrentStageNumber' , u'pVal' , ), 63, (63, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesCompetition_vtables_dispatch_ = 1
ISalesOpportunitiesCompetition_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RowNo' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Competition' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Competition' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'WonOrLost' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'WonOrLost' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesInterests_vtables_dispatch_ = 1
ISalesOpportunitiesInterests_vtables_ = [
	(( u'RowNo' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryInterest' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryInterest' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'InterestId' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'InterestId' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 7, (7, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesLines_vtables_dispatch_ = 1
ISalesOpportunitiesLines_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SalesPerson' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SalesPerson' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'StageKey' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'StageKey' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PercentageRate' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PercentageRate' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'MaxLocalTotal' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'MaxLocalTotal' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'MaxSystemTotal' , u'pVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Contact' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'WeightedAmountLocal' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'WeightedAmountSystem' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCheckbox' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DocumentCheckbox' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelName' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelName' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelCode' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'BPChanelCode' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipfield' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DataOwnershipfield' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BPChannelContact' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesPartners_vtables_dispatch_ = 1
ISalesOpportunitiesPartners_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RowNo' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Partners' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Partners' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipCode' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'RelationshipCode' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitiesReasons_vtables_dispatch_ = 1
ISalesOpportunitiesReasons_vtables_ = [
	(( u'RowNo' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Reason' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Reason' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityCompetitorSetup_vtables_dispatch_ = 1
ISalesOpportunityCompetitorSetup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ThreatLevel' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ThreatLevel' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityCompetitorSetupParams_vtables_dispatch_ = 1
ISalesOpportunityCompetitorSetupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ThreatLevel' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityCompetitorSetupParamsCollection_vtables_dispatch_ = 1
ISalesOpportunityCompetitorSetupParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityCompetitorsSetupService_vtables_dispatch_ = 1
ISalesOpportunityCompetitorsSetupService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddSalesOpportunityCompetitorSetup' , u'pISalesOpportunityCompetitorSetup' , u'ppISalesOpportunityCompetitorSetupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{BED262F2-5DAF-4D1B-91C6-B5DCABE54A90}')") , 
			(16393, 10, None, "IID('{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateSalesOpportunityCompetitorSetup' , u'pISalesOpportunityCompetitorSetup' , ), 11, (11, (), [ (9, 1, None, "IID('{BED262F2-5DAF-4D1B-91C6-B5DCABE54A90}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteSalesOpportunityCompetitorSetup' , u'pISalesOpportunityCompetitorSetupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetSalesOpportunityCompetitorSetup' , u'pISalesOpportunityCompetitorSetupParams' , u'ppISalesOpportunityCompetitorSetup' , ), 13, (13, (), [ (9, 1, None, "IID('{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}')") , 
			(16393, 10, None, "IID('{BED262F2-5DAF-4D1B-91C6-B5DCABE54A90}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetSalesOpportunityCompetitorSetupList' , u'ppISalesOpportunityCompetitorSetupParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{892F8759-3131-447C-804C-73A754C51B42}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityInterestSetup_vtables_dispatch_ = 1
ISalesOpportunityInterestSetup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Sort' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Sort' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityInterestSetupParams_vtables_dispatch_ = 1
ISalesOpportunityInterestSetupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityInterestSetupParamsCollection_vtables_dispatch_ = 1
ISalesOpportunityInterestSetupParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{61408D92-9E9A-4A1F-B5B0-A60332828007}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{61408D92-9E9A-4A1F-B5B0-A60332828007}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityInterestsSetupService_vtables_dispatch_ = 1
ISalesOpportunityInterestsSetupService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddSalesOpportunityInterestSetup' , u'pISalesOpportunityInterestSetup' , u'ppISalesOpportunityInterestSetupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{C38D34A0-DA36-4B9A-9211-21F9228EC20D}')") , 
			(16393, 10, None, "IID('{61408D92-9E9A-4A1F-B5B0-A60332828007}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateSalesOpportunityInterestSetup' , u'pISalesOpportunityInterestSetup' , ), 11, (11, (), [ (9, 1, None, "IID('{C38D34A0-DA36-4B9A-9211-21F9228EC20D}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteSalesOpportunityInterestSetup' , u'pISalesOpportunityInterestSetupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{61408D92-9E9A-4A1F-B5B0-A60332828007}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetSalesOpportunityInterestSetup' , u'pISalesOpportunityInterestSetupParams' , u'ppISalesOpportunityInterestSetup' , ), 13, (13, (), [ (9, 1, None, "IID('{61408D92-9E9A-4A1F-B5B0-A60332828007}')") , 
			(16393, 10, None, "IID('{C38D34A0-DA36-4B9A-9211-21F9228EC20D}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetSalesOpportunityInterestSetupList' , u'ppISalesOpportunityInterestSetupParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{BC177C74-40FA-4140-8374-ED45F9FCFF87}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityReasonSetup_vtables_dispatch_ = 1
ISalesOpportunityReasonSetup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Sort' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Sort' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityReasonSetupParams_vtables_dispatch_ = 1
ISalesOpportunityReasonSetupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityReasonSetupParamsCollection_vtables_dispatch_ = 1
ISalesOpportunityReasonSetupParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{E60CDE47-FBBE-4719-BCFF-022E70710702}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{E60CDE47-FBBE-4719-BCFF-022E70710702}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunityReasonsSetupService_vtables_dispatch_ = 1
ISalesOpportunityReasonsSetupService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddSalesOpportunityReasonSetup' , u'pISalesOpportunityReasonSetup' , u'ppISalesOpportunityReasonSetupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{5128D2EC-8CF5-47BD-A12F-B53211A1CE54}')") , 
			(16393, 10, None, "IID('{E60CDE47-FBBE-4719-BCFF-022E70710702}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateSalesOpportunityReasonSetup' , u'pISalesOpportunityReasonSetup' , ), 11, (11, (), [ (9, 1, None, "IID('{5128D2EC-8CF5-47BD-A12F-B53211A1CE54}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteSalesOpportunityReasonSetup' , u'pISalesOpportunityReasonSetupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{E60CDE47-FBBE-4719-BCFF-022E70710702}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetSalesOpportunityReasonSetup' , u'pISalesOpportunityReasonSetupParams' , u'ppISalesOpportunityReasonSetup' , ), 13, (13, (), [ (9, 1, None, "IID('{E60CDE47-FBBE-4719-BCFF-022E70710702}')") , 
			(16393, 10, None, "IID('{5128D2EC-8CF5-47BD-A12F-B53211A1CE54}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetSalesOpportunityReasonSetupList' , u'ppISalesOpportunityReasonSetupParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{475F9BBF-F860-48CE-8FD7-71E461BD7D95}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitySourceSetup_vtables_dispatch_ = 1
ISalesOpportunitySourceSetup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Sort' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Sort' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitySourceSetupParams_vtables_dispatch_ = 1
ISalesOpportunitySourceSetupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitySourceSetupParamsCollection_vtables_dispatch_ = 1
ISalesOpportunitySourceSetupParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{AC935452-7934-4093-810F-D66BD350A247}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{AC935452-7934-4093-810F-D66BD350A247}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ISalesOpportunitySourcesSetupService_vtables_dispatch_ = 1
ISalesOpportunitySourcesSetupService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddSalesOpportunitySourceSetup' , u'pISalesOpportunitySourceSetup' , u'ppISalesOpportunitySourceSetupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{6B52A2CD-C166-404E-9A92-A0D4B812488A}')") , 
			(16393, 10, None, "IID('{AC935452-7934-4093-810F-D66BD350A247}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateSalesOpportunitySourceSetup' , u'pISalesOpportunitySourceSetup' , ), 11, (11, (), [ (9, 1, None, "IID('{6B52A2CD-C166-404E-9A92-A0D4B812488A}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteSalesOpportunitySourceSetup' , u'pISalesOpportunitySourceSetupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{AC935452-7934-4093-810F-D66BD350A247}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetSalesOpportunitySourceSetup' , u'pISalesOpportunitySourceSetupParams' , u'ppISalesOpportunitySourceSetup' , ), 13, (13, (), [ (9, 1, None, "IID('{AC935452-7934-4093-810F-D66BD350A247}')") , 
			(16393, 10, None, "IID('{6B52A2CD-C166-404E-9A92-A0D4B812488A}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetSalesOpportunitySourceSetupList' , u'ppISalesOpportunitySourceSetupParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{6C123256-BF67-4AA6-BE6B-4C085AB0731A}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISalesPersons_vtables_dispatch_ = 1
ISalesPersons_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lSlpCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployeeCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployeeName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployeeName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CommissionForSalesEmployee' , u'pdblRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CommissionForSalesEmployee' , u'pdblRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroup' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CommissionGroup' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
]

ISalesStages_vtables_dispatch_ = 1
ISalesStages_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lNum' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SequenceNo' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Stageno' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Stageno' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ClosingPercentage' , u'pdblRsltVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ClosingPercentage' , u'pdblRsltVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Cancelled' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Cancelled' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

ISalesTaxAuthorities_vtables_dispatch_ = 1
ISalesTaxAuthorities_vtables_ = [
	(( u'UseTaxAccount' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'UseTaxAccount' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AOrRTaxAccount' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AOrRTaxAccount' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'AOrPTaxAccount' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'AOrPTaxAccount' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductiblePrecent' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductiblePrecent' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductibleAccount' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductibleAccount' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTaxAccount' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTaxAccount' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Code' , u'Type' , u'Found' , ), 13, (13, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 14, (14, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'MinTaxableAmount' , u'pVal' , ), 20, (20, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'MinTaxableAmount' , u'pVal' , ), 20, (20, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'MaxTaxableAmount' , u'pVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'MaxTaxableAmount' , u'pVal' , ), 21, (21, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'FlatTaxAmount' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'FlatTaxAmount' , u'pVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'TaxDefinitions' , u'pVal' , ), 23, (23, (), [ (16393, 10, None, "IID('{9AA8D14C-3AB3-44F0-BEDD-0AB156BD2A9D}')") , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
]

ISalesTaxAuthoritiesTypes_vtables_dispatch_ = 1
ISalesTaxAuthoritiesTypes_vtables_ = [
	(( u'UserSignature' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'VAT' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'VAT' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Numerator' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

ISalesTaxCodes_vtables_dispatch_ = 1
ISalesTaxCodes_vtables_ = [
	(( u'ValidForAR' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ValidForAR' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ValidForAP' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ValidForAP' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Freight' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Freight' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{98DF1BF3-2F28-46C7-8003-FB8D11276237}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 10, (10, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 11, (11, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'IsItemLevel' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'IsItemLevel' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
]

ISalesTaxCodes_Lines_vtables_dispatch_ = 1
ISalesTaxCodes_Lines_vtables_ = [
	(( u'STATaxOnTaxType' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'STATaxOnTaxType' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'STATaxonTaxCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'STATaxonTaxCode' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'STCCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'STAType' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'STAType' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'STACode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'STACode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'EffectiveRate' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 8, (8, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 10, (10, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 11, (11, (), [ ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ISection_vtables_dispatch_ = 1
ISection_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ECode' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ECode' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ISectionParams_vtables_dispatch_ = 1
ISectionParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ISectionsParams_vtables_dispatch_ = 1
ISectionsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ISectionsService_vtables_dispatch_ = 1
ISectionsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddSection' , u'pISection' , u'ppISectionParams' , ), 10, (10, (), [ (9, 1, None, "IID('{D9D5A329-257D-45AE-8897-AFD53838C099}')") , 
			(16393, 10, None, "IID('{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateSection' , u'pISection' , ), 11, (11, (), [ (9, 1, None, "IID('{D9D5A329-257D-45AE-8897-AFD53838C099}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteSection' , u'pISectionParams' , ), 12, (12, (), [ (9, 1, None, "IID('{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetSection' , u'pISectionParams' , u'ppISection' , ), 13, (13, (), [ (9, 1, None, "IID('{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}')") , 
			(16393, 10, None, "IID('{D9D5A329-257D-45AE-8897-AFD53838C099}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetSectionList' , u'ppISectionsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{3EFBE347-7427-4459-A969-37AE80D0AFEF}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISerialNumberDetail_vtables_dispatch_ = 1
ISerialNumberDetail_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'MfrSerialNo' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'MfrSerialNo' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumber' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumber' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LotNumber' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LotNumber' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SystemNumber' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'AdmissionDate' , u'pdateRsltVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'AdmissionDate' , u'pdateRsltVal' , ), 17, (17, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturingDate' , u'pdateRsltVal' , ), 18, (18, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturingDate' , u'pdateRsltVal' , ), 18, (18, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pdateRsltVal' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ExpirationDate' , u'pdateRsltVal' , ), 19, (19, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'MfrWarrantyStart' , u'pdateRsltVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'MfrWarrantyStart' , u'pdateRsltVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'MFrWarrantyEnd' , u'pdateRsltVal' , ), 21, (21, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'MFrWarrantyEnd' , u'pdateRsltVal' , ), 21, (21, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Details' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 24, (24, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
]

ISerialNumberDetailParams_vtables_dispatch_ = 1
ISerialNumberDetailParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ISerialNumberDetailsService_vtables_dispatch_ = 1
ISerialNumberDetailsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pISerialNumberDetail' , ), 10, (10, (), [ (9, 1, None, "IID('{43CA4B0F-FF52-4C9A-9BB9-601CDFE3AD6D}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pISerialNumberDetailParams' , u'ppISerialNumberDetail' , ), 11, (11, (), [ (9, 1, None, "IID('{C392F1DC-DD79-4692-8FBA-7CAD03877993}')") , 
			(16393, 10, None, "IID('{43CA4B0F-FF52-4C9A-9BB9-601CDFE3AD6D}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

ISerialNumbers_vtables_dispatch_ = 1
ISerialNumbers_vtables_ = [
	(( u'Count' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 3, (3, (), [ ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNumber' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNumber' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNumber' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNumber' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ExpiryDate' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ExpiryDate' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ManufactureDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ManufactureDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ReceptionDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ReceptionDate' , u'pVal' , ), 8, (8, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyStart' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyStart' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyEnd' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'WarrantyEnd' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Notes' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'BatchID' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'BatchID' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SystemSerialNumber' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'SystemSerialNumber' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'BaseLineNumber' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'BaseLineNumber' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
]

ISeries_vtables_dispatch_ = 1
ISeries_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Document' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'InitialNumber' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'InitialNumber' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LastNumber' , u'plRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LastNumber' , u'plRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'NextNumber' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'NextNumber' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Prefix' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Prefix' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Suffix' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Suffix' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'penumRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'penumRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'penumRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'penumRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PeriodIndicator' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'PeriodIndicator' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DocumentSubType' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'IsDigitalSeries' , u'penumRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'IsDigitalSeries' , u'penumRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'DigitNumber' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DigitNumber' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'SeriesType' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'SeriesType' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'plRsltVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'plRsltVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
]

ISeriesCollection_vtables_dispatch_ = 1
ISeriesCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{21B9721D-5933-4547-A8F9-2AFB83B6735F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{21B9721D-5933-4547-A8F9-2AFB83B6735F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ISeriesLine_vtables_dispatch_ = 1
ISeriesLine_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Prefix' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Prefix' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FirstNum' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FirstNum' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'NextNum' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LastNum' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LastNum' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

ISeriesLines_vtables_dispatch_ = 1
ISeriesLines_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{022D793A-3706-459F-A7FE-4169894754D8}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{022D793A-3706-459F-A7FE-4169894754D8}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ISeriesParams_vtables_dispatch_ = 1
ISeriesParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ISeriesService_vtables_dispatch_ = 1
ISeriesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddSeries' , u'pISeries' , u'ppRsltISeriesParam' , ), 10, (10, (), [ (9, 1, None, "IID('{21B9721D-5933-4547-A8F9-2AFB83B6735F}')") , 
			(16393, 10, None, "IID('{DB4F4E62-87CD-4113-8EA9-4EAAC1555DBD}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'RemoveSeries' , u'pISeriesParam' , ), 11, (11, (), [ (9, 1, None, "IID('{DB4F4E62-87CD-4113-8EA9-4EAAC1555DBD}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AttachSeriesToDocument' , u'pIDocumentSeriesParams' , ), 12, (12, (), [ (9, 1, None, "IID('{E24C2504-36B4-4EE4-A990-0F487E774211}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UnattachSeriesFromDocument' , u'pIDocumentSeriesParams' , ), 13, (13, (), [ (9, 1, None, "IID('{E24C2504-36B4-4EE4-A990-0F487E774211}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetDefaultSeriesForAllUsers' , u'pIDocumentSeriesParams' , ), 14, (14, (), [ (9, 1, None, "IID('{E24C2504-36B4-4EE4-A990-0F487E774211}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetDefaultSeriesForCurrentUser' , u'pIDocumentSeriesParams' , ), 15, (15, (), [ (9, 1, None, "IID('{E24C2504-36B4-4EE4-A990-0F487E774211}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SetDefaultSeriesForUser' , u'pIDocumentSeriesUserParams' , ), 16, (16, (), [ (9, 1, None, "IID('{AADAC0AA-6CBA-47EC-B923-05B029715123}')") , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UpdateSeries' , u'pISeries' , ), 17, (17, (), [ (9, 1, None, "IID('{21B9721D-5933-4547-A8F9-2AFB83B6735F}')") , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetDefaultSeries' , u'pIDocumentTypeParams' , u'ppRsltISeries' , ), 18, (18, (), [ (9, 1, None, "IID('{B5196CD2-270C-42E8-81F5-735A99BECEA6}')") , 
			(16393, 10, None, "IID('{21B9721D-5933-4547-A8F9-2AFB83B6735F}')") , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetDocumentSeries' , u'pIDocumentTypeParams' , u'ppRsltISeriesCollection' , ), 19, (19, (), [ (9, 1, None, "IID('{B5196CD2-270C-42E8-81F5-735A99BECEA6}')") , 
			(16393, 10, None, "IID('{D48F490F-CB1F-46B9-A941-D1A84FCE1DB2}')") , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'GetSeries' , u'pSeriesParams' , u'ppISeries' , ), 20, (20, (), [ (9, 1, None, "IID('{DB4F4E62-87CD-4113-8EA9-4EAAC1555DBD}')") , 
			(16393, 10, None, "IID('{21B9721D-5933-4547-A8F9-2AFB83B6735F}')") , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'GetDocumentChangedMenuName' , u'pIDocumentTypeParams' , u'pIDocumentChangeMenuName' , ), 21, (21, (), [ (9, 1, None, "IID('{B5196CD2-270C-42E8-81F5-735A99BECEA6}')") , 
			(16393, 10, None, "IID('{9A5FCF99-FC73-47E0-A68D-A8156EB864E5}')") , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ChangeDocumentMenuName' , u'pIDocumentChangeMenuName' , ), 22, (22, (), [ (9, 1, None, "IID('{9A5FCF99-FC73-47E0-A68D-A8156EB864E5}')") , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetElectronicSeries' , u'pElectronicSeriesParams' , u'ppIElectronicSeries' , ), 23, (23, (), [ (9, 1, None, "IID('{135ACD20-6799-42E5-8ECC-4077CEF72812}')") , 
			(16393, 10, None, "IID('{2309689C-63EA-4D8E-B675-E6459533E27A}')") , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'AddElectronicSeries' , u'pIElectronicSeries' , u'ppRsltIElectronicSeriesParam' , ), 24, (24, (), [ (9, 1, None, "IID('{2309689C-63EA-4D8E-B675-E6459533E27A}')") , 
			(16393, 10, None, "IID('{135ACD20-6799-42E5-8ECC-4077CEF72812}')") , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'RemoveElectronicSeries' , u'pIElectronicSeriesParam' , ), 25, (25, (), [ (9, 1, None, "IID('{135ACD20-6799-42E5-8ECC-4077CEF72812}')") , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'UpdateElectronicSeries' , u'pIElectronicSeries' , ), 26, (26, (), [ (9, 1, None, "IID('{2309689C-63EA-4D8E-B675-E6459533E27A}')") , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GetDefaultElectronicSeries' , u'pISeriesParams' , u'ppRsltIElectronicSeriesParams' , ), 27, (27, (), [ (9, 1, None, "IID('{DB4F4E62-87CD-4113-8EA9-4EAAC1555DBD}')") , 
			(16393, 10, None, "IID('{135ACD20-6799-42E5-8ECC-4077CEF72812}')") , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SetDefaultElectronicSeries' , u'pIDefaultElectronicSeriesParams' , ), 28, (28, (), [ (9, 1, None, "IID('{C9379AB8-CDE2-4A35-99CE-DB1CE9D7950E}')") , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
]

IServiceCallActivities_vtables_dispatch_ = 1
IServiceCallActivities_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ActivityCode' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ActivityCode' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallInventoryExpenses_vtables_dispatch_ = 1
IServiceCallInventoryExpenses_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PartType' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocumentPostingDate' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DocumentNumber' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'StockTransferDirection' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'StockTransferDirection' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 12, (12, (), [ ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IServiceCallOrigin_vtables_dispatch_ = 1
IServiceCallOrigin_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'OriginID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IServiceCallOriginParams_vtables_dispatch_ = 1
IServiceCallOriginParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'OriginID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'OriginID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallOriginParamsCollection_vtables_dispatch_ = 1
IServiceCallOriginParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{AC21F36A-556F-4374-AAB0-96949C7469FF}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{AC21F36A-556F-4374-AAB0-96949C7469FF}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceCallOriginsService_vtables_dispatch_ = 1
IServiceCallOriginsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddServiceCallOrigin' , u'pIServiceCallOrigin' , u'ppIServiceCallOriginParams' , ), 10, (10, (), [ (9, 1, None, "IID('{9FEF81F9-9C21-4B0B-9EDA-0EF9A5C98739}')") , 
			(16393, 10, None, "IID('{AC21F36A-556F-4374-AAB0-96949C7469FF}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateServiceCallOrigin' , u'pIServiceCallOrigin' , ), 11, (11, (), [ (9, 1, None, "IID('{9FEF81F9-9C21-4B0B-9EDA-0EF9A5C98739}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteServiceCallOrigin' , u'pIServiceCallOriginParams' , ), 12, (12, (), [ (9, 1, None, "IID('{AC21F36A-556F-4374-AAB0-96949C7469FF}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallOrigin' , u'pIServiceCallOriginParams' , u'ppIServiceCallOrigin' , ), 13, (13, (), [ (9, 1, None, "IID('{AC21F36A-556F-4374-AAB0-96949C7469FF}')") , 
			(16393, 10, None, "IID('{9FEF81F9-9C21-4B0B-9EDA-0EF9A5C98739}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallOriginList' , u'ppIServiceCallOriginParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{13B1D6B4-A9ED-4787-8B8B-24AAE9525342}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallProblemType_vtables_dispatch_ = 1
IServiceCallProblemType_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ProblemTypeID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IServiceCallProblemTypeParams_vtables_dispatch_ = 1
IServiceCallProblemTypeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ProblemTypeID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ProblemTypeID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallProblemTypeParamsCollection_vtables_dispatch_ = 1
IServiceCallProblemTypeParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{0B24F304-D586-4E29-8820-90E334D034D5}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{0B24F304-D586-4E29-8820-90E334D034D5}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceCallProblemTypesService_vtables_dispatch_ = 1
IServiceCallProblemTypesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddServiceCallProblemType' , u'pIServiceCallProblemType' , u'ppIServiceCallProblemTypeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{943EB4D4-ED2B-4815-B6D8-3CA50DF8D139}')") , 
			(16393, 10, None, "IID('{0B24F304-D586-4E29-8820-90E334D034D5}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateServiceCallProblemType' , u'pIServiceCallProblemType' , ), 11, (11, (), [ (9, 1, None, "IID('{943EB4D4-ED2B-4815-B6D8-3CA50DF8D139}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteServiceCallProblemType' , u'pIServiceCallProblemTypeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{0B24F304-D586-4E29-8820-90E334D034D5}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallProblemType' , u'pIServiceCallProblemTypeParams' , u'ppIServiceCallProblemType' , ), 13, (13, (), [ (9, 1, None, "IID('{0B24F304-D586-4E29-8820-90E334D034D5}')") , 
			(16393, 10, None, "IID('{943EB4D4-ED2B-4815-B6D8-3CA50DF8D139}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallProblemTypeList' , u'ppIServiceCallProblemTypeParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{4DC9AE34-8FF4-4900-8021-D641EF898358}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallSolutionStatus_vtables_dispatch_ = 1
IServiceCallSolutionStatus_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StatusId' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IServiceCallSolutionStatusParams_vtables_dispatch_ = 1
IServiceCallSolutionStatusParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StatusId' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'StatusId' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallSolutionStatusParamsCollection_vtables_dispatch_ = 1
IServiceCallSolutionStatusParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{7276D73A-6B18-4F86-B517-6DB9363FC772}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{7276D73A-6B18-4F86-B517-6DB9363FC772}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceCallSolutionStatusService_vtables_dispatch_ = 1
IServiceCallSolutionStatusService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddServiceCallSolutionStatus' , u'pIServiceCallSolutionStatus' , u'ppIServiceCallSolutionStatusParams' , ), 10, (10, (), [ (9, 1, None, "IID('{22219181-9047-4C89-BAC3-4BB311AE77E4}')") , 
			(16393, 10, None, "IID('{7276D73A-6B18-4F86-B517-6DB9363FC772}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateServiceCallSolutionStatus' , u'pIServiceCallSolutionStatus' , ), 11, (11, (), [ (9, 1, None, "IID('{22219181-9047-4C89-BAC3-4BB311AE77E4}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteServiceCallSolutionStatus' , u'pIServiceCallSolutionStatusParams' , ), 12, (12, (), [ (9, 1, None, "IID('{7276D73A-6B18-4F86-B517-6DB9363FC772}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallSolutionStatus' , u'pIServiceCallSolutionStatusParams' , u'ppIServiceCallSolutionStatus' , ), 13, (13, (), [ (9, 1, None, "IID('{7276D73A-6B18-4F86-B517-6DB9363FC772}')") , 
			(16393, 10, None, "IID('{22219181-9047-4C89-BAC3-4BB311AE77E4}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallSolutionStatusList' , u'ppIServiceCallSolutionStatusParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{9316E5DC-6A1E-4D66-A31D-40576A355AB9}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallSolutions_vtables_dispatch_ = 1
IServiceCallSolutions_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SolutionID' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SolutionID' , u'pVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallStatus_vtables_dispatch_ = 1
IServiceCallStatus_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StatusId' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IServiceCallStatusParams_vtables_dispatch_ = 1
IServiceCallStatusParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'StatusId' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'StatusId' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallStatusParamsCollection_vtables_dispatch_ = 1
IServiceCallStatusParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceCallStatusService_vtables_dispatch_ = 1
IServiceCallStatusService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddServiceCallStatus' , u'pIServiceCallStatus' , u'ppIServiceCallStatusParams' , ), 10, (10, (), [ (9, 1, None, "IID('{0E2CBAD1-1857-4E2F-8AE4-5246D1F6725E}')") , 
			(16393, 10, None, "IID('{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateServiceCallStatus' , u'pIServiceCallStatus' , ), 11, (11, (), [ (9, 1, None, "IID('{0E2CBAD1-1857-4E2F-8AE4-5246D1F6725E}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteServiceCallStatus' , u'pIServiceCallStatusParams' , ), 12, (12, (), [ (9, 1, None, "IID('{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallStatus' , u'pIServiceCallStatusParams' , u'ppIServiceCallStatus' , ), 13, (13, (), [ (9, 1, None, "IID('{5D29B8B0-A8BC-4905-B713-7DE4207A130A}')") , 
			(16393, 10, None, "IID('{0E2CBAD1-1857-4E2F-8AE4-5246D1F6725E}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallStatusList' , u'ppIServiceCallStatusParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{106B8134-EDB5-4417-BFAC-4A3A2A7B9419}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallType_vtables_dispatch_ = 1
IServiceCallType_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CallTypeID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IServiceCallTypeParams_vtables_dispatch_ = 1
IServiceCallTypeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'CallTypeID' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CallTypeID' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCallTypeParamsCollection_vtables_dispatch_ = 1
IServiceCallTypeParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{72274C66-4457-4D17-8F61-014F5520C434}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{72274C66-4457-4D17-8F61-014F5520C434}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceCallTypesService_vtables_dispatch_ = 1
IServiceCallTypesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddServiceCallType' , u'pIServiceCallType' , u'ppIServiceCallTypeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{A68554D5-F932-4B92-980E-6060777F59F4}')") , 
			(16393, 10, None, "IID('{72274C66-4457-4D17-8F61-014F5520C434}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateServiceCallType' , u'pIServiceCallType' , ), 11, (11, (), [ (9, 1, None, "IID('{A68554D5-F932-4B92-980E-6060777F59F4}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteServiceCallType' , u'pIServiceCallTypeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{72274C66-4457-4D17-8F61-014F5520C434}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallType' , u'pIServiceCallTypeParams' , u'ppIServiceCallType' , ), 13, (13, (), [ (9, 1, None, "IID('{72274C66-4457-4D17-8F61-014F5520C434}')") , 
			(16393, 10, None, "IID('{A68554D5-F932-4B92-980E-6060777F59F4}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceCallTypeList' , u'ppIServiceCallTypeParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{475E4307-5C54-4449-BFCA-2CCCBBEB6448}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceCalls_vtables_dispatch_ = 1
IServiceCalls_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ServiceCallID' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ServiceCallID' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Subject' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'ContractID' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ContractEndDate' , u'pVal' , ), 17, (17, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionDate' , u'pVal' , ), 18, (18, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionDate' , u'pVal' , ), 18, (18, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 19, (19, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Origin' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Origin' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroupCode' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Priority' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'CallType' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'CallType' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ProblemType' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ProblemType' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'AssigneeCode' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'AssigneeCode' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'TechnicianCode' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'TechnicianCode' , u'pVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Resolution' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Resolution' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Activities' , u'pVal' , ), 35, (35, (), [ (16393, 10, None, "IID('{0207412D-F955-46BA-AE96-E749573B4106}')") , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Expenses' , u'pVal' , ), 36, (36, (), [ (16393, 10, None, "IID('{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}')") , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Solutions' , u'pVal' , ), 37, (37, (), [ (16393, 10, None, "IID('{FA8FD318-6971-4E8B-B6E9-959A938455C6}')") , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 38, (38, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CreationTime' , u'pVal' , ), 39, (39, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'Responder' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'UpdatedTime' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'BelongsToAQueue' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'BelongsToAQueue' , u'pVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'ResponseByTime' , u'pVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'ResponseByDate' , u'pVal' , ), 45, (45, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionOnDate' , u'pVal' , ), 46, (46, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'ResponseOnTime' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'ResponseOnDate' , u'pVal' , ), 48, (48, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ClosingTime' , u'pVal' , ), 49, (49, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'AssignedDate' , u'pVal' , ), 50, (50, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'Queue' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'Queue' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'ResponseAssignee' , u'pVal' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'EntitledforService' , u'pVal' , ), 53, (53, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionOnTime' , u'pVal' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'AssignedTime' , u'pVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'ClosingDate' , u'pVal' , ), 56, (56, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'ContractID' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 59, (59, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 60, (60, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 60, (60, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 61, (61, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'HandWritten' , u'pVal' , ), 61, (61, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'PeriodIndicator' , u'pVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 63, (63, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pdateRsltVal' , ), 63, (63, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'StartTime' , u'ptimeRsltVal' , ), 64, (64, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'StartTime' , u'ptimeRsltVal' , ), 64, (64, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'EndDuedate' , u'pdateRsltVal' , ), 65, (65, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'EndDuedate' , u'pdateRsltVal' , ), 65, (65, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'EndTime' , u'ptimeRsltVal' , ), 66, (66, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'EndTime' , u'ptimeRsltVal' , ), 66, (66, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'Duration' , u'ppRsltVal' , ), 67, (67, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'Duration' , u'ppRsltVal' , ), 67, (67, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'DurationType' , u'penumRsltVal' , ), 68, (68, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'DurationType' , u'penumRsltVal' , ), 68, (68, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'Reminder' , u'penumRsltVal' , ), 69, (69, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'Reminder' , u'penumRsltVal' , ), 69, (69, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'ReminderPeriod' , u'ppRsltVal' , ), 70, (70, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'ReminderPeriod' , u'ppRsltVal' , ), 70, (70, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'ReminderType' , u'penumRsltVal' , ), 71, (71, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'ReminderType' , u'penumRsltVal' , ), 71, (71, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'plRsltVal' , ), 72, (72, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'plRsltVal' , ), 72, (72, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 73, (73, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'AddressName' , u'pVal' , ), 73, (73, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pbstrRsltVal' , ), 74, (74, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pbstrRsltVal' , ), 74, (74, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 75, (75, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 75, (75, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 76, (76, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 76, (76, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'Room' , u'pbstrRsltVal' , ), 77, (77, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'Room' , u'pbstrRsltVal' , ), 77, (77, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 78, (78, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 78, (78, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 79, (79, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 79, (79, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'DisplayInCalendar' , u'penumRsltVal' , ), 80, (80, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'DisplayInCalendar' , u'penumRsltVal' , ), 80, (80, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
]

IServiceContract_Lines_vtables_dispatch_ = 1
IServiceContract_Lines_vtables_ = [
	(( u'UserFields' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerSerialNum' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'InternalSerialNum' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ItemName' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroup' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroup' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ItemGroupName' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 14, (14, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 14, (14, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
]

IServiceContracts_vtables_dispatch_ = 1
IServiceContracts_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ContractID' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ContractID' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CustomerCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CustomerName' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ContactCode' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Owner' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ContractTemplate' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ContractTemplate' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ContractType' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ContractType' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Renewal' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Renewal' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ReminderTime' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ReminderTime' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'RemindUnit' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'DurationOfCoverage' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 19, (19, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'StartDate' , u'pVal' , ), 19, (19, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'EndDate' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionTime' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionUnit' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'ResolutionUnit' , u'pVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnabled' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnabled' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnabled' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnabled' , u'pVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnabled' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnabled' , u'pVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnabled' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnabled' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnabled' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnabled' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnabled' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnabled' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnabled' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnabled' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'MondayStart' , u'pVal' , ), 32, (32, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'MondayStart' , u'pVal' , ), 32, (32, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnd' , u'pVal' , ), 33, (33, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'MondayEnd' , u'pVal' , ), 33, (33, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayStart' , u'pVal' , ), 34, (34, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayStart' , u'pVal' , ), 34, (34, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnd' , u'pVal' , ), 35, (35, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'TuesdayEnd' , u'pVal' , ), 35, (35, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayStart' , u'pVal' , ), 36, (36, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayStart' , u'pVal' , ), 36, (36, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnd' , u'pVal' , ), 37, (37, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'WednesdayEnd' , u'pVal' , ), 37, (37, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayStart' , u'pVal' , ), 38, (38, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayStart' , u'pVal' , ), 38, (38, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnd' , u'pVal' , ), 39, (39, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'ThursdayEnd' , u'pVal' , ), 39, (39, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'FridayStart' , u'pVal' , ), 40, (40, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'FridayStart' , u'pVal' , ), 40, (40, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnd' , u'pVal' , ), 41, (41, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'FridayEnd' , u'pVal' , ), 41, (41, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayStart' , u'pVal' , ), 42, (42, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayStart' , u'pVal' , ), 42, (42, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnd' , u'pVal' , ), 43, (43, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'SaturdayEnd' , u'pVal' , ), 43, (43, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'SundayStart' , u'pVal' , ), 44, (44, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'SundayStart' , u'pVal' , ), 44, (44, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnd' , u'pVal' , ), 45, (45, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'SundayEnd' , u'pVal' , ), 45, (45, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'IncludeParts' , u'pVal' , ), 46, (46, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'IncludeParts' , u'pVal' , ), 46, (46, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'IncludeLabor' , u'pVal' , ), 47, (47, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'IncludeLabor' , u'pVal' , ), 47, (47, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'IncludeTravel' , u'pVal' , ), 48, (48, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'IncludeTravel' , u'pVal' , ), 48, (48, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'Attachments' , u'pVal' , ), 49, (49, (), [ (16393, 10, None, "IID('{B728546D-EA5F-4122-9FE0-759C89BF95D0}')") , ], 1 , 2 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'TemplateRemarks' , u'pVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 53, (53, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 54, (54, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 55, (55, (), [ (16393, 10, None, "IID('{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}')") , ], 1 , 2 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'IncludeHolidays' , u'pVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'IncludeHolidays' , u'pVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'ServiceType' , u'pVal' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'ServiceType' , u'pVal' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'ResponseUnit' , u'pVal' , ), 58, (58, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'ResponseUnit' , u'pVal' , ), 58, (58, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'ResponseTime' , u'pVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'ResponseTime' , u'pVal' , ), 59, (59, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 60, (60, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'TerminationDate' , u'pVal' , ), 60, (60, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 63, (63, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'AttachmentEntry' , u'plRsltVal' , ), 63, (63, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
]

IServiceGroup_vtables_dispatch_ = 1
IServiceGroup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ServiceGroupCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ServiceGroupCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IServiceGroupParams_vtables_dispatch_ = 1
IServiceGroupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ServiceGroupCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceGroupsParams_vtables_dispatch_ = 1
IServiceGroupsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{C9A336DC-4108-44D2-8161-5420E75E8475}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{C9A336DC-4108-44D2-8161-5420E75E8475}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceGroupsService_vtables_dispatch_ = 1
IServiceGroupsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddServiceGroup' , u'pIServiceGroup' , u'ppIServiceGroupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{A55338A2-5402-41BB-9588-39EC814AB644}')") , 
			(16393, 10, None, "IID('{C9A336DC-4108-44D2-8161-5420E75E8475}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateServiceGroup' , u'pIServiceGroup' , ), 11, (11, (), [ (9, 1, None, "IID('{A55338A2-5402-41BB-9588-39EC814AB644}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteServiceGroup' , u'pIServiceGroupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{C9A336DC-4108-44D2-8161-5420E75E8475}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceGroup' , u'pIServiceGroupParams' , u'ppIServiceGroup' , ), 13, (13, (), [ (9, 1, None, "IID('{C9A336DC-4108-44D2-8161-5420E75E8475}')") , 
			(16393, 10, None, "IID('{A55338A2-5402-41BB-9588-39EC814AB644}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetServiceGroupList' , u'ppIServiceGroupsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{74490BE7-8344-4F48-90C9-2A811E54AA49}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IServiceTaxPostingParams_vtables_dispatch_ = 1
IServiceTaxPostingParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceTaxPostingParamsCollection_vtables_dispatch_ = 1
IServiceTaxPostingParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IServiceTaxPostingService_vtables_dispatch_ = 1
IServiceTaxPostingService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'PostServiceTax' , u'pIServiceTaxPostingParams' , ), 10, (10, (), [ (9, 1, None, "IID('{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetTaxableDeliveries' , u'ppIServiceTaxPostingParamsCollection' , ), 11, (11, (), [ (16393, 10, None, "IID('{16E2EB82-A981-4E4F-A378-6D4E53B17134}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IShippingTypes_vtables_dispatch_ = 1
IShippingTypes_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Website' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Website' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
]

IShowDifferenceParams_vtables_dispatch_ = 1
IShowDifferenceParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryKey' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'PrimaryKey' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Object' , u'pbstrRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Object' , u'pbstrRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'LogInstance2' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LogInstance2' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LogInstance' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LogInstance' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UDOObjectCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UDOObjectCode' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ISpecialPrices_vtables_dispatch_ = 1
ISpecialPrices_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'ItemCode' , u'CardCode' , u'Found' , ), 10, (10, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'AutoUpdate' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'AutoUpdate' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 12, (12, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPricesDataAreas' , u'pVal' , ), 13, (13, (), [ (16393, 10, None, "IID('{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'GetByKeyDiscounts' , u'ItemCode' , u'PriceListNum' , u'Found' , ), 17, (17, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
]

ISpecialPricesDataAreas_vtables_dispatch_ = 1
ISpecialPricesDataAreas_vtables_ = [
	(( u'PriceCurrency' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'AutoUpdate' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AutoUpdate' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Dateto' , u'pVal' , ), 3, (3, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Dateto' , u'pVal' , ), 3, (3, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Discount' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Discount' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPrice' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPrice' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DateFrom' , u'pVal' , ), 6, (6, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DateFrom' , u'pVal' , ), 6, (6, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNo' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 13, (13, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 14, (14, (), [ ], 1 , 1 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPricesQuantityAreas' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{34995651-4568-4AAE-B831-60693B932A35}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 16, (16, (), [ ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

ISpecialPricesQuantityAreas_vtables_dispatch_ = 1
ISpecialPricesQuantityAreas_vtables_ = [
	(( u'Quantity' , u'pVal' , ), 1, (1, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 1, (1, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SPDARowNumber' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPrice' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SpecialPrice' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemNo' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BPCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Discountin' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Discountin' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 11, (11, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 12, (12, (), [ ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 13, (13, (), [ ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IState_vtables_dispatch_ = 1
IState_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IStateParams_vtables_dispatch_ = 1
IStateParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IStatesParams_vtables_dispatch_ = 1
IStatesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IStatesService_vtables_dispatch_ = 1
IStatesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'AddState' , u'pIState' , u'ppIStateParams' , ), 10, (10, (), [ (9, 1, None, "IID('{9E37320F-F058-462C-9483-AD67BC65191B}')") , 
			(16393, 10, None, "IID('{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateState' , u'pIState' , ), 11, (11, (), [ (9, 1, None, "IID('{9E37320F-F058-462C-9483-AD67BC65191B}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DeleteState' , u'pIStateParams' , ), 12, (12, (), [ (9, 1, None, "IID('{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetState' , u'pIStateParams' , u'ppIState' , ), 13, (13, (), [ (9, 1, None, "IID('{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}')") , 
			(16393, 10, None, "IID('{9E37320F-F058-462C-9483-AD67BC65191B}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetStateList' , u'ppIStatesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{3443DB6C-7014-4BC3-A860-F4934E449818}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IStockTaking_vtables_dispatch_ = 1
IStockTaking_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Counted' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Counted' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 7, (7, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrItemCode' , u'bstrWhsCode' , u'Found' , ), 11, (11, (), [ 
			(8, 1, None, None) , (8, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IStockTransfer_vtables_dispatch_ = 1
IStockTransfer_vtables_ = [
	(( u'Lines' , u'pVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'AbsEntry' , u'Found' , ), 3, (3, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 7, (7, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CardName' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Reference1' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Reference2' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'JournalMemo' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PriceList' , u'pVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'SalesPersonCode' , u'pVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'FromWarehouse' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'FromWarehouse' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 23, (23, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 24, (24, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'FinancialPeriod' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'TransNum' , u'pVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 28, (28, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 29, (29, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 29, (29, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 31, (31, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'FolioPrefixString' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'FolioPrefixString' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'FolioNumber' , u'pVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'FolioNumber' , u'pVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'TaxExtension' , u'pVal' , ), 36, (36, (), [ (16393, 10, None, "IID('{F510FF2B-D307-487F-9ECC-EE436A6EBF10}')") , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'DocObjectCode' , u'pVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 38, (38, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'DueDate' , u'pVal' , ), 38, (38, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'GetApprovalTemplates' , u'ooErr' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'SaveDraftToDocument' , u'ooErr' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'StockTransfer_ApprovalRequests' , u'pVal' , ), 41, (41, (), [ (16393, 10, None, "IID('{DACFE08E-8A02-43ED-B762-5E664186FB0E}')") , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'AuthorizationStatus' , u'pVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'BPLName' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'VATRegNum' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
]

IStockTransfer_ApprovalRequests_vtables_dispatch_ = 1
IStockTransfer_ApprovalRequests_vtables_ = [
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ApprovalTemplatesID' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Remarks' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
]

IStockTransfer_Lines_vtables_dispatch_ = 1
IStockTransfer_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Quantity' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Price' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Currency' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 11, (11, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'DiscountPercent' , u'pVal' , ), 11, (11, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'VendorNum' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumber' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumber' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ProjectCode' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'pVal' , ), 16, (16, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Factor' , u'pVal' , ), 16, (16, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Factor2' , u'pVal' , ), 17, (17, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Factor2' , u'pVal' , ), 17, (17, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Factor3' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Factor3' , u'pVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Factor4' , u'pVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Factor4' , u'pVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'SerialNumbers' , u'pVal' , ), 20, (20, (), [ (16393, 10, None, "IID('{93E5E52B-181E-46B8-96CB-1C066AC04DCA}')") , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'BatchNumbers' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{1FEF5698-93E1-4167-AEA0-4BB151792623}')") , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'UseBaseUnits' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'UseBaseUnits' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'MeasureUnit' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'MeasureUnit' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'UnitsOfMeasurment' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'UnitsOfMeasurment' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 32, (32, (), [ ], 1 , 1 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule2' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule3' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule4' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'DistributionRule5' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'penumRsltVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'penumRsltVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'BaseLine' , u'plRsltVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'BaseLine' , u'plRsltVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'BaseEntry' , u'plRsltVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'BaseEntry' , u'plRsltVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'UnitPrice' , u'pVal' , ), 41, (41, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'UnitPrice' , u'pVal' , ), 41, (41, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
]

IStockTransfer_TaxExtension_vtables_dispatch_ = 1
IStockTransfer_TaxExtension_vtables_ = [
	(( u'SupportVAT' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SupportVAT' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'FormNumber' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FormNumber' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCategory' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TransactionCategory' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITargetGroup_vtables_dispatch_ = 1
ITargetGroup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupsDetails' , u'ppRsltVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{BC23E72E-CE89-4492-BEEC-6F5FE1D694A2}')") , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ITargetGroupParams_vtables_dispatch_ = 1
ITargetGroupParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ITargetGroupsDetail_vtables_dispatch_ = 1
ITargetGroupsDetail_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TargetGroupCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BusinessPartnerCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'BusinessPartnerCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'BusinessPartnerName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'BusinessPartnerName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'GroupCode' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Industry' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ActiveStatus' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Title' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Title' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'E_Mail' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'E_Mail' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Telephone' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Telephone' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhone' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Fax' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Building' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Building' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
]

ITargetGroupsDetails_vtables_dispatch_ = 1
ITargetGroupsDetails_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{6F49AA78-C540-44BD-B70F-050870C5BBF0}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{6F49AA78-C540-44BD-B70F-050870C5BBF0}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ITargetGroupsParams_vtables_dispatch_ = 1
ITargetGroupsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITargetGroupsService_vtables_dispatch_ = 1
ITargetGroupsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pITargetGroup' , u'ppITargetGroupParams' , ), 10, (10, (), [ (9, 1, None, "IID('{5C87125B-3FCE-4FC7-9AD9-430D8E555426}')") , 
			(16393, 10, None, "IID('{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pITargetGroup' , ), 11, (11, (), [ (9, 1, None, "IID('{5C87125B-3FCE-4FC7-9AD9-430D8E555426}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pITargetGroupParams' , ), 12, (12, (), [ (9, 1, None, "IID('{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pITargetGroupParams' , u'ppITargetGroup' , ), 13, (13, (), [ (9, 1, None, "IID('{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}')") , 
			(16393, 10, None, "IID('{5C87125B-3FCE-4FC7-9AD9-430D8E555426}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppITargetGroupsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{D1B282C5-C219-48C7-93E3-6BD01735EFD5}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ITaxCodeDetermination_vtables_dispatch_ = 1
ITaxCodeDetermination_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'BusinessArea' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'BusinessArea' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Condition1' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Condition1' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable1' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable1' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue1' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue1' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'StringValue1' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'StringValue1' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue1' , u'ppRsltVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue1' , u'ppRsltVal' , ), 18, (18, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Condition2' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Condition2' , u'penumRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable2' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable2' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue2' , u'plRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue2' , u'plRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'StringValue2' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'StringValue2' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue2' , u'ppRsltVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue2' , u'ppRsltVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Condition3' , u'penumRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Condition3' , u'penumRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable3' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable3' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue3' , u'plRsltVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue3' , u'plRsltVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'StringValue3' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'StringValue3' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue3' , u'ppRsltVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue3' , u'ppRsltVal' , ), 28, (28, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Condition4' , u'penumRsltVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Condition4' , u'penumRsltVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable4' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable4' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue4' , u'plRsltVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue4' , u'plRsltVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'StringValue4' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'StringValue4' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue4' , u'ppRsltVal' , ), 33, (33, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue4' , u'ppRsltVal' , ), 33, (33, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Condition5' , u'penumRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Condition5' , u'penumRsltVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable5' , u'pbstrRsltVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'UDFTable5' , u'pbstrRsltVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue5' , u'plRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'NumberValue5' , u'plRsltVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'StringValue5' , u'pbstrRsltVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'StringValue5' , u'pbstrRsltVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue5' , u'ppRsltVal' , ), 38, (38, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'MoneyValue5' , u'ppRsltVal' , ), 38, (38, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pbstrRsltVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'TaxCode' , u'pbstrRsltVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'FreightRowTax' , u'pbstrRsltVal' , ), 41, (41, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'FreightRowTax' , u'pbstrRsltVal' , ), 41, (41, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'FreightHeaderTax' , u'pbstrRsltVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'FreightHeaderTax' , u'pbstrRsltVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias1' , u'pbstrRsltVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias1' , u'pbstrRsltVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias2' , u'pbstrRsltVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias2' , u'pbstrRsltVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias3' , u'pbstrRsltVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias3' , u'pbstrRsltVal' , ), 45, (45, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias4' , u'pbstrRsltVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias4' , u'pbstrRsltVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias5' , u'pbstrRsltVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'UDFAlias5' , u'pbstrRsltVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
]

ITaxCodeDeterminationParams_vtables_dispatch_ = 1
ITaxCodeDeterminationParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxCodeDeterminationsParams_vtables_dispatch_ = 1
ITaxCodeDeterminationsParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{7A54452F-A767-4700-B3B5-880084053C0C}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{7A54452F-A767-4700-B3B5-880084053C0C}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxCodeDeterminationsService_vtables_dispatch_ = 1
ITaxCodeDeterminationsService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetTaxCodeDetermination' , u'pITaxCodeDeterminationParams' , u'ppITaxCodeDetermination' , ), 10, (10, (), [ (9, 1, None, "IID('{7A54452F-A767-4700-B3B5-880084053C0C}')") , 
			(16393, 10, None, "IID('{03111771-050A-41FF-A2EA-A17B8C7E99FE}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AddTaxCodeDetermination' , u'pITaxCodeDetermination' , u'ppITaxCodeDeterminationParams' , ), 11, (11, (), [ (9, 1, None, "IID('{03111771-050A-41FF-A2EA-A17B8C7E99FE}')") , 
			(16393, 10, None, "IID('{7A54452F-A767-4700-B3B5-880084053C0C}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UpdateTaxCodeDetermination' , u'pITaxCodeDetermination' , ), 12, (12, (), [ (9, 1, None, "IID('{03111771-050A-41FF-A2EA-A17B8C7E99FE}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DeleteTaxCodeDetermination' , u'pITaxCodeDeterminationParams' , ), 13, (13, (), [ (9, 1, None, "IID('{7A54452F-A767-4700-B3B5-880084053C0C}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetTaxCodeDeterminationList' , u'ppITaxCodeDeterminationsParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{A8AB919D-856C-4883-959D-57D7CB9C51F2}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ITaxDefinitions_vtables_dispatch_ = 1
ITaxDefinitions_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pVal' , ), 4, (4, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pVal' , ), 4, (4, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 5, (5, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxExtension_vtables_dispatch_ = 1
ITaxExtension_vtables_ = [
	(( u'TaxId0' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'TaxId0' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'TaxId1' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'TaxId1' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'TaxId2' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TaxId2' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TaxId3' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TaxId3' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TaxId4' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TaxId4' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TaxId5' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxId5' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxId6' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxId6' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxId7' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'TaxId7' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxId8' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxId8' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TaxId9' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxId9' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Incoterms' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Incoterms' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Vehicle' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Vehicle' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'VehicleState' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'VehicleState' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'NFRef' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'NFRef' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Carrier' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Carrier' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'PackQuantity' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'PackQuantity' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'PackDescription' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'PackDescription' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Brand' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Brand' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ShipUnitNo' , u'pVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ShipUnitNo' , u'pVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'NetWeight' , u'pVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'NetWeight' , u'pVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'GrossWeight' , u'pVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'GrossWeight' , u'pVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 24, (24, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'StreetS' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'StreetS' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'BlockS' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'BlockS' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'BuildingS' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'BuildingS' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CityS' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'CityS' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'ZipCodeS' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'ZipCodeS' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'CountyS' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'CountyS' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'StateS' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'StateS' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'CountryS' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'CountryS' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'StreetB' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'StreetB' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'BlockB' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'BlockB' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'BuildingB' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'BuildingB' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'CityB' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'CityB' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'ZipCodeB' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'ZipCodeB' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'CountyB' , u'pVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'CountyB' , u'pVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'StateB' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'StateB' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'CountryB' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'CountryB' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'ImportOrExport' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'ImportOrExport' , u'pVal' , ), 41, (41, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'MainUsage' , u'plValue' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'MainUsage' , u'plValue' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
]

ITaxInvoice_Lines_vtables_dispatch_ = 1
ITaxInvoice_Lines_vtables_ = [
	(( u'BaseEntry' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Reference' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 7, (7, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ITaxInvoice_OperationCodes_vtables_dispatch_ = 1
ITaxInvoice_OperationCodes_vtables_ = [
	(( u'BaseEntry' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'OpCode' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'OpCode' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ITaxInvoices_vtables_dispatch_ = 1
ITaxInvoices_vtables_ = [
	(( u'DocEntry' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'DocNum' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Printed' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocDate' , u'pVal' , ), 5, (5, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'CardCode' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UpdateDate' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DocDueDate' , u'pVal' , ), 9, (9, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'DocDueDate' , u'pVal' , ), 9, (9, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Segment' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ContactPersonCode' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'pVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Comments' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ShipToCode' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Address2' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Address2' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CurrencySource' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'CurrencySource' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'DocCurrency' , u'pVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 20, (20, (), [ (16393, 10, None, "IID('{D1DD9101-9264-450A-9FAC-C9D899078775}')") , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'DocEntry' , u'Found' , ), 23, (23, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 24, (24, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 26, (26, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 27, (27, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'CustomerOrVendorRefNo' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'CustomerOrVendorRefNo' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'CustomerOrVendorName' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'CustomerOrVendorName' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'CancelDate' , u'pVal' , ), 33, (33, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'DocumentTotal' , u'pVal' , ), 34, (34, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'TaxTotal' , u'pVal' , ), 35, (35, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'PaymentRefNo' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'PaymentRefNo' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'PaymentRefDate' , u'pVal' , ), 37, (37, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'PaymentRefDate' , u'pVal' , ), 37, (37, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'OperationCodes' , u'pVal' , ), 38, (38, (), [ (16393, 10, None, "IID('{5BCB48BA-A4A6-4087-B1FD-1E9F076EFD33}')") , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'AlterationRevision' , u'pVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'AlterationRevision' , u'pVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
]

ITaxJurisdictions_vtables_dispatch_ = 1
ITaxJurisdictions_vtables_ = [
	(( u'JurisdictionCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'JurisdictionCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'JurisdictionType' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'JurisdictionType' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmount' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmount' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmountSC' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TaxAmountFC' , u'pVal' , ), 5, (5, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TaxRate' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 100, (100, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 101, (101, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 102, (102, (), [ ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 103, (103, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'DocEntry' , u'pVal' , ), 104, (104, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'pVal' , ), 105, (105, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'LineNumber' , u'pVal' , ), 105, (105, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'RowSequence' , u'pVal' , ), 106, (106, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

ITaxReportAccount_vtables_dispatch_ = 1
ITaxReportAccount_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxReportAccounts_vtables_dispatch_ = 1
ITaxReportAccounts_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{32ABB501-14BB-4467-8D98-597A9420D8C6}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{32ABB501-14BB-4467-8D98-597A9420D8C6}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxReportBusinessPartner_vtables_dispatch_ = 1
ITaxReportBusinessPartner_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxReportBusinessPartners_vtables_dispatch_ = 1
ITaxReportBusinessPartners_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxReportDocument_vtables_dispatch_ = 1
ITaxReportDocument_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'FromNumber' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FromNumber' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ToNumber' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ToNumber' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

ITaxReportDocuments_vtables_dispatch_ = 1
ITaxReportDocuments_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{28DD7AE7-0602-49B2-80EB-827454AA99E7}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{28DD7AE7-0602-49B2-80EB-827454AA99E7}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxReportFilter_vtables_dispatch_ = 1
ITaxReportFilter_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ReportLayout' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ReportLayout' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'FirstPrintedNumber' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'FirstPrintedNumber' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pdtRsltVal' , ), 15, (15, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'FromDate' , u'pdtRsltVal' , ), 15, (15, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pdtRsltVal' , ), 16, (16, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ToDate' , u'pdtRsltVal' , ), 16, (16, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TaxDate' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'RoundAmount' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'RoundAmount' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'DeclarationType' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'DeclarationType' , u'penumRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FilterType' , u'penumRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'FilterType' , u'penumRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'ExcludeWT' , u'penumRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'ExcludeWT' , u'penumRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'IncludeCustomers' , u'penumRsltVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'IncludeCustomers' , u'penumRsltVal' , ), 22, (22, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'IncludeVendors' , u'penumRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'IncludeVendors' , u'penumRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Period' , u'penumRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Period' , u'penumRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Quarter' , u'plRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Quarter' , u'plRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Year' , u'plRsltVal' , ), 26, (26, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Year' , u'plRsltVal' , ), 26, (26, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'FirstRegisterNumber' , u'plRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'FirstRegisterNumber' , u'plRsltVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'IncludeGLAccounts' , u'penumRsltVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'IncludeGLAccounts' , u'penumRsltVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'AppendixOorPSelection' , u'penumRsltVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'AppendixOorPSelection' , u'penumRsltVal' , ), 30, (30, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'OpeningAndClosingBalance' , u'penumRsltVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'OpeningAndClosingBalance' , u'penumRsltVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'FromSeries' , u'plRsltVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'FromSeries' , u'plRsltVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ToSeries' , u'plRsltVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ToSeries' , u'plRsltVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Cancellation' , u'penumRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'Cancellation' , u'penumRsltVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'HideTaxWithoutTransaction' , u'penumRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'HideTaxWithoutTransaction' , u'penumRsltVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'IncludeSeriesFilter' , u'penumRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'IncludeSeriesFilter' , u'penumRsltVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'IncludeDocumentType' , u'penumRsltVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'IncludeDocumentType' , u'penumRsltVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'DiplayCreditMemosInSeparateColumn' , u'penumRsltVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'DiplayCreditMemosInSeparateColumn' , u'penumRsltVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'ShowPaymentsWithDeferredTax' , u'penumRsltVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'ShowPaymentsWithDeferredTax' , u'penumRsltVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'QuarterOrDates' , u'penumRsltVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'QuarterOrDates' , u'penumRsltVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'TaxReportGroups' , u'ppRsltVal' , ), 41, (41, (), [ (16393, 10, None, "IID('{5EE41EF0-1319-400C-807D-7CAA21FBA466}')") , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'TaxReportBusinessPartners' , u'ppRsltVal' , ), 42, (42, (), [ (16393, 10, None, "IID('{CA7F3C6F-4074-46E9-8B96-3CBDDFC9C320}')") , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'TaxReportDocuments' , u'ppRsltVal' , ), 43, (43, (), [ (16393, 10, None, "IID('{FC030AB5-B942-4D71-A5BF-1EAA5D9BC808}')") , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'TaxReportSeriesCollection' , u'ppRsltVal' , ), 44, (44, (), [ (16393, 10, None, "IID('{71AE6937-9F02-409F-93D0-869D4E6DDE9A}')") , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'TaxReportAccounts' , u'ppRsltVal' , ), 45, (45, (), [ (16393, 10, None, "IID('{009BFAE6-2701-4E63-B9EA-1335C9658CC0}')") , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
]

ITaxReportFilterParams_vtables_dispatch_ = 1
ITaxReportFilterParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'FilterType' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'FilterType' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ITaxReportFiltersParams_vtables_dispatch_ = 1
ITaxReportFiltersParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{A5CDC033-47D7-4019-801A-8443F14D52D0}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{A5CDC033-47D7-4019-801A-8443F14D52D0}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxReportGroup_vtables_dispatch_ = 1
ITaxReportGroup_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Sum' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Sum' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ITaxReportGroups_vtables_dispatch_ = 1
ITaxReportGroups_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{6076F945-EB54-4BA8-B00C-891BB860356A}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{6076F945-EB54-4BA8-B00C-891BB860356A}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxReportSeries_vtables_dispatch_ = 1
ITaxReportSeries_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DocumentType' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SeriesCode' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SeriesCode' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ITaxReportSeriesCollection_vtables_dispatch_ = 1
ITaxReportSeriesCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{308CD5F0-5908-47B2-BE56-A1104C45FCF7}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{308CD5F0-5908-47B2-BE56-A1104C45FCF7}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxWebSite_vtables_dispatch_ = 1
ITaxWebSite_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'WebSiteName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'WebSiteName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'WebSiteURL' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'WebSiteURL' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

ITaxWebSiteParams_vtables_dispatch_ = 1
ITaxWebSiteParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'AbsEntry' , u'plRsltVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'WebSiteName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ITaxWebSitesParams_vtables_dispatch_ = 1
ITaxWebSitesParams_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITaxWebSitesService_vtables_dispatch_ = 1
ITaxWebSitesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetTaxWebSite' , u'pITaxWebSiteParams' , u'ppITaxWebSite' , ), 10, (10, (), [ (9, 1, None, "IID('{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')") , 
			(16393, 10, None, "IID('{EE912DF0-9D0E-49BE-999D-B88AA59B305D}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'AddTaxWebSite' , u'pITaxWebSite' , u'ppITaxWebSiteParams' , ), 11, (11, (), [ (9, 1, None, "IID('{EE912DF0-9D0E-49BE-999D-B88AA59B305D}')") , 
			(16393, 10, None, "IID('{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UpdateTaxWebSite' , u'pITaxWebSite' , ), 12, (12, (), [ (9, 1, None, "IID('{EE912DF0-9D0E-49BE-999D-B88AA59B305D}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'RemoveTaxWebSite' , u'pITaxWebSiteParams' , ), 13, (13, (), [ (9, 1, None, "IID('{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetTaxWebSiteList' , u'ppITaxWebSitesParams' , ), 14, (14, (), [ (16393, 10, None, "IID('{AB9A1501-E84C-4EC2-9869-8A843FBCCBB6}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetAsDefault' , u'pITaxWebSiteParams' , ), 15, (15, (), [ (9, 1, None, "IID('{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')") , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'GetDefaultWebSite' , u'ppITaxWebSiteParams' , ), 16, (16, (), [ (16393, 10, None, "IID('{F7E00222-C717-40BF-9DC0-A95200B0FEEB}')") , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

ITeamMembers_vtables_dispatch_ = 1
ITeamMembers_vtables_ = [
	(( u'UserFields' , u'ppRsltVal' , ), 1, (1, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'TeamID' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'EmployeeID' , u'plRsltVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'RoleInTeam' , u'penumRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'RoleInTeam' , u'penumRsltVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ITeams_vtables_dispatch_ = 1
ITeams_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lTeamID' , u'pbRsltIsFound' , ), 9, (9, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TeamID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TeamName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TeamName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TeamMembers' , u'ppRsltVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{09C6E920-908C-4FD2-9CBF-21C3F4329A33}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

ITerritories_vtables_dispatch_ = 1
ITerritories_vtables_ = [
	(( u'TerritoryID' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'LocationIndex' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LocationIndex' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Parent' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Parent' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lID' , u'Found' , ), 9, (9, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 10, (10, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 12, (12, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

ITransactionCode_vtables_dispatch_ = 1
ITransactionCode_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

ITransactionCodeParams_vtables_dispatch_ = 1
ITransactionCodeParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ITransactionCodeParamsCollection_vtables_dispatch_ = 1
ITransactionCodeParamsCollection_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{63A44BC7-2798-4F4A-B0C7-B407EA917702}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{63A44BC7-2798-4F4A-B0C7-B407EA917702}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

ITransactionCodesService_vtables_dispatch_ = 1
ITransactionCodesService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'pITransactionCode' , u'ppITransactionCodeParams' , ), 10, (10, (), [ (9, 1, None, "IID('{49703681-AAAE-49B5-B2AA-402D622EE537}')") , 
			(16393, 10, None, "IID('{63A44BC7-2798-4F4A-B0C7-B407EA917702}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'pITransactionCode' , ), 11, (11, (), [ (9, 1, None, "IID('{49703681-AAAE-49B5-B2AA-402D622EE537}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , u'pITransactionCodeParams' , ), 12, (12, (), [ (9, 1, None, "IID('{63A44BC7-2798-4F4A-B0C7-B407EA917702}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Get' , u'pITransactionCodeParams' , u'ppITransactionCode' , ), 13, (13, (), [ (9, 1, None, "IID('{63A44BC7-2798-4F4A-B0C7-B407EA917702}')") , 
			(16393, 10, None, "IID('{49703681-AAAE-49B5-B2AA-402D622EE537}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'GetList' , u'ppITransactionCodeParamsCollection' , ), 14, (14, (), [ (16393, 10, None, "IID('{12A99320-EEE7-4398-90E2-74BC014F5CE2}')") , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

ITranslationsInUserLanguages_vtables_dispatch_ = 1
ITranslationsInUserLanguages_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'KeyFromHeaderTable' , u'plRsltVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCodeOfUserLanguage' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'LanguageCodeOfUserLanguage' , u'plRsltVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Translationscontent' , u'pbstrRsltVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Translationscontent' , u'pbstrRsltVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IUserActionRecord_vtables_dispatch_ = 1
IUserActionRecord_vtables_ = [
	(( u'UserCode' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Action' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ActionBy' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ClientIP' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ClientName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ActionDate' , u'pVal' , ), 7, (7, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ActionTime' , u'pVal' , ), 8, (8, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 11, (11, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
]

IUserBranchAssignment_vtables_dispatch_ = 1
IUserBranchAssignment_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 4, (4, (), [ ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IUserDefaultGroups_vtables_dispatch_ = 1
IUserDefaultGroups_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrCode' , u'pbRsltFound' , ), 6, (6, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Warehouse' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployee' , u'plRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'SalesEmployee' , u'plRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BPforInvoicePayment' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BPforInvoicePayment' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CashAccount' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CheckingAcct' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'CheckingAcct' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'PrintReceipt' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'PrintReceipt' , u'penumRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'PrintInvoiceandPaymentinS' , u'penumRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'PrintInvoiceandPaymentinS' , u'penumRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'WindowsColor' , u'plRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'WindowsColor' , u'plRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Address' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'PrintingHeader' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'PrintingHeader' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber1' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber1' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber2' , u'pbstrRsltVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber2' , u'pbstrRsltVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'AddressinForeignLanguage' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'AddressinForeignLanguage' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'PrintingHeaderInForeignLangu' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'PrintingHeaderInForeignLangu' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber1ForeignLang' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber1ForeignLang' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber2ForeignLang' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'PhoneNumber2ForeignLang' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumberForeignLang' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumberForeignLang' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTaxCode' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'DefaultTaxCode' , u'pbstrRsltVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalIdNumber' , u'pbstrRsltVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'AdditionalIdNumber' , u'pbstrRsltVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'plRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'UseTax' , u'penumRsltVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'UseTax' , u'penumRsltVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'UseWarehouseAddressinAPD' , u'penumRsltVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'UseWarehouseAddressinAPD' , u'penumRsltVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'DefaultCreditCards' , u'ppRsltVal' , ), 39, (39, (), [ (16393, 10, None, "IID('{5923A153-B41F-4676-A5B6-1FAD645FDD7B}')") , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'DefaultDocuments' , u'ppRsltVal' , ), 40, (40, (), [ (16393, 10, None, "IID('{38EFFD46-32F0-4190-A769-E13A5CCC3F47}')") , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'BPLID' , u'pVal' , ), 51, (51, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
]

IUserFields_vtables_dispatch_ = 1
IUserFields_vtables_ = [
	(( u'Fields' , u'pVal' , ), 0, (0, (), [ (16393, 10, None, "IID('{DE680833-445E-4AF0-A7E3-377D5135268B}')") , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
]

IUserFieldsMD_vtables_dispatch_ = 1
IUserFieldsMD_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'TableName' , u'FieldID' , u'Found' , ), 5, (5, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ValidValues' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{D435C006-B504-4847-B217-8AEA5439B779}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'pVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Size' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Size' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'SubType' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'SubType' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'LinkedTable' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'LinkedTable' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'DefaultValue' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'DefaultValue' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FieldID' , u'pVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'EditSize' , u'pVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'EditSize' , u'pVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Mandatory' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Mandatory' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'LinkedUDO' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'LinkedUDO' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
]

IUserKeysMD_vtables_dispatch_ = 1
IUserKeysMD_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'TableName' , u'KeyIndex' , u'Found' , ), 4, (4, (), [ 
			(8, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Elements' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{ED79A1AF-2F5B-418E-A90C-1F504B49E364}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'KeyIndex' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'KeyName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'KeyName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Unique' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Unique' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 16, (16, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
]

IUserKeysMD_Elements_vtables_dispatch_ = 1
IUserKeysMD_Elements_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SubKeyIndex' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IUserLanguages_vtables_dispatch_ = 1
IUserLanguages_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LanguageShortName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LanguageShortName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LanguageFullName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LanguageFullName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'RelatedSystemLanguage' , u'plRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'RelatedSystemLanguage' , u'plRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IUserLicenseParams_vtables_dispatch_ = 1
IUserLicenseParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'LicenseType' , u'penumRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'LicenseType' , u'penumRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'LicenseUpdateType' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'LicenseUpdateType' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IUserMenuItem_vtables_dispatch_ = 1
IUserMenuItem_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'plRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'plRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LinkedObjType' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LinkedObjType' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'LinkedObjKey' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'LinkedObjKey' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'LinkedFormMenuID' , u'plRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'LinkedFormMenuID' , u'plRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'LinkedFormNum' , u'plRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'LinkedFormNum' , u'plRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ReportPath' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ReportPath' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserMenuItems' , u'ppRsltVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'UserMenuItems' , u'ppRsltVal' , ), 21, (21, (), [ (9, 1, None, "IID('{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}')") , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
]

IUserMenuItems_vtables_dispatch_ = 1
IUserMenuItems_vtables_ = [
	(( u'_NewEnum' , u'pRsltVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 1 , )),
	(( u'Item' , u'vtIndex' , u'ppRsltVal' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}')") , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'plRsltVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ppRsltVal' , ), 2, (2, (), [ (16393, 10, None, "IID('{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLFile' , u'bstrFileName' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'vtIndex' , ), 6, (6, (), [ (12, 1, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IUserMenuParams_vtables_dispatch_ = 1
IUserMenuParams_vtables_ = [
	(( u'ToXMLFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ToXMLString' , u'pbstrXML' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetXMLSchema' , u'pbstrXML' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLFile' , u'bstrFileName' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FromXMLString' , u'bstrXML' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UserID' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IUserMenuService_vtables_dispatch_ = 1
IUserMenuService_vtables_ = [
	(( u'GetDataInterface' , u'enumMSDI' , u'pRsltIDispatch' , ), 1, (1, (), [ (3, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLFile' , u'bstrFileName' , u'pRsltIDispatch' , ), 2, (2, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetDataInterfaceFromXMLString' , u'bstrXMLString' , u'pRsltIDispatch' , ), 3, (3, (), [ (8, 1, None, None) , 
			(16393, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetUserMenu' , u'pIUserMenuParams' , u'ppRsltIUserMenuItems' , ), 10, (10, (), [ (9, 1, None, "IID('{6446D947-9BED-41FE-876C-B89334D5D85F}')") , 
			(16393, 10, None, "IID('{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}')") , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UpdateUserMenu' , u'pIUserMenuParams' , u'pIUserMenuItems' , ), 11, (11, (), [ (9, 1, None, "IID('{6446D947-9BED-41FE-876C-B89334D5D85F}')") , 
			(9, 1, None, "IID('{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}')") , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetCurrentUserMenu' , u'ppRsltIUserMenuItems' , ), 12, (12, (), [ (16393, 10, None, "IID('{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}')") , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'UpdateCurrentUserMenu' , u'pIUserMenuItems' , ), 13, (13, (), [ (9, 1, None, "IID('{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}')") , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
]

IUserObjectMD_ChildTables_vtables_dispatch_ = 1
IUserObjectMD_ChildTables_vtables_ = [
	(( u'SonNumber' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'LogTableName' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LogTableName' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ObjectName' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ObjectName' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
]

IUserObjectMD_EnhancedFormColumns_vtables_dispatch_ = 1
IUserObjectMD_EnhancedFormColumns_vtables_ = [
	(( u'Code' , u'pbstrRsltVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ColumnNumber' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ColumnNumber' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ChildNumber' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ChildNumber' , u'pVal' , ), 3, (3, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ColumnDescription' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ColumnDescription' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ColumnIsUsed' , u'penumRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ColumnIsUsed' , u'penumRsltVal' , ), 6, (6, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 8, (8, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 9, (9, (), [ ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Editable' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Editable' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IUserObjectMD_FindColumns_vtables_dispatch_ = 1
IUserObjectMD_FindColumns_vtables_ = [
	(( u'ColumnNumber' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'ColumnAlias' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'ColumnDescription' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ColumnDescription' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IUserObjectMD_FormColumns_vtables_dispatch_ = 1
IUserObjectMD_FormColumns_vtables_ = [
	(( u'FormColumnAlias' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'FormColumnAlias' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'FormColumnDescription' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'FormColumnDescription' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FormColumnNumber' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'SonNumber' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'SonNumber' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 7, (7, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Editable' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Editable' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
]

IUserObjectsMD_vtables_dispatch_ = 1
IUserObjectsMD_vtables_ = [
	(( u'TableName' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'LogTableName' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'LogTableName' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'CanCreateDefaultForm' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'CanCreateDefaultForm' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ObjectType' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ObjectType' , u'pVal' , ), 5, (5, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'ExtensionName' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CanCancel' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CanCancel' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CanDelete' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'CanDelete' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'CanLog' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CanLog' , u'pVal' , ), 9, (9, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ManageSeries' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ManageSeries' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CanFind' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CanFind' , u'pVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'CanYearTransfer' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'CanYearTransfer' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CanClose' , u'pVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Code' , u'Found' , ), 16, (16, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'FindColumns' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}')") , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'FormColumns' , u'pVal' , ), 22, (22, (), [ (16393, 10, None, "IID('{0C607D21-E148-42CE-AF58-E8C38EB26275}')") , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ChildTables' , u'pVal' , ), 23, (23, (), [ (16393, 10, None, "IID('{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}')") , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'CanClose' , u'pVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'OverwriteDllfile' , u'penumRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'OverwriteDllfile' , u'penumRsltVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 26, (26, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'UseUniqueFormType' , u'penumRsltVal' , ), 27, (27, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'UseUniqueFormType' , u'penumRsltVal' , ), 27, (27, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'CanArchive' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'CanArchive' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'MenuItem' , u'penumRsltVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'MenuItem' , u'penumRsltVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'MenuCaption' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'MenuCaption' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'FatherMenuID' , u'pVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'FatherMenuID' , u'pVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Position' , u'pVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'MenuUID' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'MenuUID' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'EnableEnhancedForm' , u'pVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'EnableEnhancedForm' , u'pVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'RebuildEnhancedForm' , u'pVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'RebuildEnhancedForm' , u'pVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'FormSRF' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'FormSRF' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'EnhancedFormColumns' , u'pVal' , ), 37, (37, (), [ (16393, 10, None, "IID('{F09D2D1D-1BB3-4D09-946B-71AE1263D6AC}')") , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
]

IUserPermission_vtables_dispatch_ = 1
IUserPermission_vtables_ = [
	(( u'UserCode' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Permission' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Permission' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 7, (7, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 8, (8, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IUserPermissionForms_vtables_dispatch_ = 1
IUserPermissionForms_vtables_ = [
	(( u'FormType' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'FormType' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DisplayOrder' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'DisplayOrder' , u'pVal' , ), 2, (2, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 6, (6, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 7, (7, (), [ ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
]

IUserPermissionTree_vtables_dispatch_ = 1
IUserPermissionTree_vtables_ = [
	(( u'UserSignature' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'pVal' , ), 1, (1, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'DisplayOrder' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'PermissionID' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Options' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Options' , u'pVal' , ), 4, (4, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Levels' , u'pVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'IsItem' , u'pVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'IsItem' , u'pVal' , ), 7, (7, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ParentID' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ParentID' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UserPermissionForms' , u'pVal' , ), 9, (9, (), [ (16393, 10, None, "IID('{24464254-073D-4148-A045-3CFDB71DE48C}')") , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'PermissionID' , u'Found' , ), 11, (11, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 12, (12, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 14, (14, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
]

IUserQueries_vtables_dispatch_ = 1
IUserQueries_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lInternalKey' , u'lQcategory' , u'pbRsltFound' , ), 6, (6, (), [ 
			(3, 1, None, None) , (3, 1, None, None) , (16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'InternalKey' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'QueryCategory' , u'plRsltVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'QueryCategory' , u'plRsltVal' , ), 11, (11, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'QueryDescription' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'QueryDescription' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Query' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Query' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IUserTable_vtables_dispatch_ = 1
IUserTable_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'Key' , u'Found' , ), 4, (4, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TableDescription' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ArchiveDate' , u'pVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ArchiveDate' , u'pVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IUserTables_vtables_dispatch_ = 1
IUserTables_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 1 , )),
]

IUserTablesMD_vtables_dispatch_ = 1
IUserTablesMD_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'TableName' , u'Found' , ), 5, (5, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'TableName' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'TableDescription' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TableDescription' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TableType' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TableType' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 11, (11, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Archivable' , u'pVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Archivable' , u'pVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ArchiveDateField' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ArchiveDateField' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
]

IUserValidValues_vtables_dispatch_ = 1
IUserValidValues_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'FieldValue' , u'pbstrRsltVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'FieldValue' , u'pbstrRsltVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
]

IUsers_vtables_dispatch_ = 1
IUsers_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'InternalKey' , u'Found' , ), 5, (5, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Close' , u'ooErr' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'InternalKey' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'UserPassword' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UserPassword' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UserCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UserName' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Superuser' , u'pVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'Superuser' , u'pVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'eMail' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhoneNumber' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'MobilePhoneNumber' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'Defaults' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Defaults' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'FaxNumber' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'Department' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Department' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 20, (20, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'UserPermission' , u'pVal' , ), 21, (21, (), [ (16393, 10, None, "IID('{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}')") , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Locked' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Group' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'MaxDiscountGeneral' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'MaxDiscountGeneral' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'MaxDiscountSales' , u'pVal' , ), 27, (27, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'MaxDiscountSales' , u'pVal' , ), 27, (27, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'MaxDiscountPurchase' , u'pVal' , ), 28, (28, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'MaxDiscountPurchase' , u'pVal' , ), 28, (28, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'CashLimit' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'CashLimit' , u'pVal' , ), 29, (29, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'MaxCashAmtForIncmngPayts' , u'pVal' , ), 30, (30, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'MaxCashAmtForIncmngPayts' , u'pVal' , ), 30, (30, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'LastLogoutDate' , u'pVal' , ), 41, (41, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'LastLoginTime' , u'pVal' , ), 42, (42, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'LastLogoutTime' , u'pVal' , ), 43, (43, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'LastPasswordChangeTime' , u'pVal' , ), 44, (44, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'LastPasswordChangedBy' , u'pVal' , ), 45, (45, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'UserActionRecord' , u'pVal' , ), 46, (46, (), [ (16393, 10, None, "IID('{19F3C51D-AE7A-4293-A027-CEA9C9C20B98}')") , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'UserBranchAssignment' , u'pVal' , ), 61, (61, (), [ (16393, 10, None, "IID('{EC084090-ED29-4B85-BAF8-8058B245EA06}')") , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
]

IValidValue_vtables_dispatch_ = 1
IValidValue_vtables_ = [
	(( u'Value' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
]

IValidValues_vtables_dispatch_ = 1
IValidValues_vtables_ = [
	(( u'Item' , u'Index' , u'pItem' , ), 0, (0, (), [ (12, 1, None, None) , 
			(16393, 10, None, "IID('{013F0389-85E2-4B8B-9285-18843E4236F3}')") , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'_NewEnum' , u'pVal' , ), -4, (-4, (), [ (16397, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 1 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
]

IValidValuesMD_vtables_dispatch_ = 1
IValidValuesMD_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Value' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Delete' , ), 6, (6, (), [ ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
]

IVatGroups_vtables_dispatch_ = 1
IVatGroups_vtables_ = [
	(( u'GetByKey' , u'bstrGroupCode' , u'pbRsltFound' , ), 1, (1, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 3, (3, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 5, (5, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 6, (6, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxAccount' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxAccount' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'EU' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'EU' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TriangularDeal' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TriangularDeal' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'AcquisitionReverse' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'AcquisitionReverse' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'NonDeduct' , u'pdblRsltVal' , ), 19, (19, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'NonDeduct' , u'pdblRsltVal' , ), 19, (19, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'AcquisitionTax' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'AcquisitionTax' , u'pbstrRsltVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'GoodsShipment' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'GoodsShipment' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductAcc' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'NonDeductAcc' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTaxAcc' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'DeferredTaxAcc' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Correction' , u'penumRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Correction' , u'penumRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'VatCorrection' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'VatCorrection' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'VatGroups_Lines' , u'ppRsltVal' , ), 26, (26, (), [ (16393, 10, None, "IID('{6AA927D2-EF50-4064-AE3F-A65ADF1026B1}')") , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxAccount' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTaxAccount' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ServiceSupply' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ServiceSupply' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'penumRsltVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'penumRsltVal' , ), 31, (31, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'TaxTypeBlackList' , u'penumRsltVal' , ), 32, (32, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'TaxTypeBlackList' , u'penumRsltVal' , ), 32, (32, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'Report349Code' , u'penumRsltVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'Report349Code' , u'penumRsltVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pbstrRsltVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentTaxOffsetAccount' , u'pbstrRsltVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'DownPaymentTaxOffsetAccount' , u'pbstrRsltVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'CashDiscountAccount' , u'pbstrRsltVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CashDiscountAccount' , u'pbstrRsltVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
]

IVatGroups_Lines_vtables_dispatch_ = 1
IVatGroups_Lines_vtables_ = [
	(( u'SetCurrentLine' , u'LineNum' , ), 1, (1, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 2, (2, (), [ ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 3, (3, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pdtRsltVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pdtRsltVal' , ), 5, (5, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pdblRsltVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pdblRsltVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTax' , u'pdblRsltVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'EqualizationTax' , u'pdblRsltVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'DatevCode' , u'pdblRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'DatevCode' , u'pdblRsltVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
]

IWarehouseLocations_vtables_dispatch_ = 1
IWarehouseLocations_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Code' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'Name' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'LSTVATNumber' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'LSTVATNumber' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CSTNumber' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'CSTNumber' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionNumber' , u'pbstrRsltVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ExemptionNumber' , u'pbstrRsltVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'TANNumber' , u'pbstrRsltVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'TANNumber' , u'pbstrRsltVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'ServiceTaxNumber' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'ServiceTaxNumber' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'AssesseeType' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'AssesseeType' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'CompanyType' , u'pbstrRsltVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CompanyType' , u'pbstrRsltVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'NatureOfBusiness' , u'pbstrRsltVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'NatureOfBusiness' , u'pbstrRsltVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'TINNumber' , u'pbstrRsltVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'TINNumber' , u'pbstrRsltVal' , ), 19, (19, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'RegistrationType' , u'pbstrRsltVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'EccNumber' , u'pbstrRsltVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'EccNumber' , u'pbstrRsltVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'CERange' , u'pbstrRsltVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'CERange' , u'pbstrRsltVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'CEDivision' , u'pbstrRsltVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'CEDivision' , u'pbstrRsltVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'CECommissionerate' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'CECommissionerate' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerCode' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'ManufacturerCode' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'Jurisdiction' , u'pbstrRsltVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'Jurisdiction' , u'pbstrRsltVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'PANNumber' , u'pbstrRsltVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'PANNumber' , u'pbstrRsltVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'CERegisterNumber' , u'pbstrRsltVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'CERegisterNumber' , u'pbstrRsltVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pbstrRsltVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pbstrRsltVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
]

IWarehouses_vtables_dispatch_ = 1
IWarehouses_vtables_ = [
	(( u'Street' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Street' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pVal' , ), 2, (2, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationOffsetAccount' , u'pVal' , ), 2, (2, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ZipCode' , u'pVal' , ), 3, (3, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 4, (4, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'DecreasingAccount' , u'pVal' , ), 4, (4, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseAccount' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'EURevenuesAccount' , u'pVal' , ), 6, (6, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 7, (7, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ReturningAccount' , u'pVal' , ), 7, (7, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pVal' , ), 8, (8, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ShippedGoodsAccount' , u'pVal' , ), 8, (8, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'StockInflationAdjustAccount' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'AllowUseTax' , u'pVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'AllowUseTax' , u'pVal' , ), 10, (10, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationAccount' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'ForeignExpensesAccount' , u'pVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'EUExpensesAccount' , u'pVal' , ), 13, (13, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CostInflationOffsetAccount' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesClearingAccount' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'ExpensesClearingAccount' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseReturningAccount' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseReturningAccount' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'VATInRevenueAccount' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 18, (18, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'FederalTaxID' , u'pVal' , ), 18, (18, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'pVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 20, (20, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'Block' , u'pVal' , ), 20, (20, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccount' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseAccount' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAccount' , u'pVal' , ), 22, (22, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'DecreaseGLAccount' , u'pVal' , ), 22, (22, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 23, (23, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'RevenuesAccount' , u'pVal' , ), 23, (23, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'TaxGroup' , u'pVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ExemptRevenuesAccount' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ExemptRevenuesAccount' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseOffsetAccount' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'CostOfGoodsSold' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'CostOfGoodsSold' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseCode' , u'pVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'State' , u'pVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'City' , u'pVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferencesAccount' , u'pVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'PriceDifferencesAccount' , u'pVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAccount' , u'pVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'VarianceAccount' , u'pVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'Country' , u'pVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'IncreaseGLAccount' , u'pVal' , ), 34, (34, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAccount' , u'pVal' , ), 35, (35, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'ExchangeRateDifferencesAccount' , u'pVal' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pVal' , ), 36, (36, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialAccount' , u'pVal' , ), 36, (36, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseName' , u'pVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'WarehouseName' , u'pVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'DropShip' , u'pVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'DropShip' , u'pVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pVal' , ), 39, (39, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'WIPMaterialVarianceAccount' , u'pVal' , ), 39, (39, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'TransfersAcc' , u'pVal' , ), 40, (40, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'TransfersAcc' , u'pVal' , ), 40, (40, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'InternalKey' , u'pVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAcc' , u'pVal' , ), 42, (42, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'ForeignRevenuesAcc' , u'pVal' , ), 42, (42, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 43, (43, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'BuildingFloorRoom' , u'pVal' , ), 43, (43, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 44, (44, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'County' , u'pVal' , ), 44, (44, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'Nettable' , u'pVal' , ), 45, (45, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'Nettable' , u'pVal' , ), 45, (45, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAcc' , u'pVal' , ), 46, (46, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'IncreasingAcc' , u'pVal' , ), 46, (46, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsetingAct' , u'pVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'ExpenseOffsetingAct' , u'pVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAcc' , u'pVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'GoodsClearingAcc' , u'pVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'StockAccount' , u'pVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'StockAccount' , u'pVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'ooErr' , ), 50, (50, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 51, (51, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'ooErr' , ), 52, (52, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'WhsCode' , u'Found' , ), 53, (53, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 54, (54, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 55, (55, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltVal' , ), 56, (56, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 57, (57, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 58, (58, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 448 , (3, 0, None, None) , 0 , )),
	(( u'BusinessPlaceID' , u'pVal' , ), 59, (59, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 452 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseCreditAcc' , u'pbstrRsltVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 456 , (3, 0, None, None) , 0 , )),
	(( u'PurchaseCreditAcc' , u'pbstrRsltVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 460 , (3, 0, None, None) , 0 , )),
	(( u'EUPurchaseCreditAcc' , u'pbstrRsltVal' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 464 , (3, 0, None, None) , 0 , )),
	(( u'EUPurchaseCreditAcc' , u'pbstrRsltVal' , ), 61, (61, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 468 , (3, 0, None, None) , 0 , )),
	(( u'ForeignPurchaseCreditAcc' , u'pbstrRsltVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 472 , (3, 0, None, None) , 0 , )),
	(( u'ForeignPurchaseCreditAcc' , u'pbstrRsltVal' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 476 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditAcc' , u'pbstrRsltVal' , ), 63, (63, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 480 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditAcc' , u'pbstrRsltVal' , ), 63, (63, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 484 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditEUAcc' , u'pbstrRsltVal' , ), 64, (64, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 488 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditEUAcc' , u'pbstrRsltVal' , ), 64, (64, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 492 , (3, 0, None, None) , 0 , )),
	(( u'ExemptedCredits' , u'pbstrRsltVal' , ), 65, (65, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 496 , (3, 0, None, None) , 0 , )),
	(( u'ExemptedCredits' , u'pbstrRsltVal' , ), 65, (65, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 500 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditForeignAcc' , u'pbstrRsltVal' , ), 66, (66, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 504 , (3, 0, None, None) , 0 , )),
	(( u'SalesCreditForeignAcc' , u'pbstrRsltVal' , ), 66, (66, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 508 , (3, 0, None, None) , 0 , )),
	(( u'NegativeInventoryAdjustmentAccount' , u'pVal' , ), 67, (67, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 512 , (3, 0, None, None) , 0 , )),
	(( u'NegativeInventoryAdjustmentAccount' , u'pVal' , ), 67, (67, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 516 , (3, 0, None, None) , 0 , )),
	(( u'WHShipToName' , u'pVal' , ), 68, (68, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 520 , (3, 0, None, None) , 0 , )),
	(( u'WHShipToName' , u'pVal' , ), 68, (68, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 524 , (3, 0, None, None) , 0 , )),
	(( u'Excisable' , u'pVal' , ), 69, (69, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 528 , (3, 0, None, None) , 0 , )),
	(( u'Excisable' , u'pVal' , ), 69, (69, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 532 , (3, 0, None, None) , 0 , )),
	(( u'WHIncomingCenvatAccount' , u'pVal' , ), 70, (70, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 536 , (3, 0, None, None) , 0 , )),
	(( u'WHIncomingCenvatAccount' , u'pVal' , ), 70, (70, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 540 , (3, 0, None, None) , 0 , )),
	(( u'WHOutgoingCenvatAccount' , u'pVal' , ), 71, (71, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 544 , (3, 0, None, None) , 0 , )),
	(( u'WHOutgoingCenvatAccount' , u'pVal' , ), 71, (71, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 548 , (3, 0, None, None) , 0 , )),
	(( u'StockInTransitAccount' , u'pVal' , ), 72, (72, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 552 , (3, 0, None, None) , 0 , )),
	(( u'StockInTransitAccount' , u'pVal' , ), 72, (72, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 556 , (3, 0, None, None) , 0 , )),
	(( u'WipOffsetProfitAndLossAccount' , u'pVal' , ), 91, (91, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 560 , (3, 0, None, None) , 0 , )),
	(( u'WipOffsetProfitAndLossAccount' , u'pVal' , ), 91, (91, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 564 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetProfitAndLossAccount' , u'pVal' , ), 92, (92, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 568 , (3, 0, None, None) , 0 , )),
	(( u'InventoryOffsetProfitAndLossAccount' , u'pVal' , ), 92, (92, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 572 , (3, 0, None, None) , 0 , )),
	(( u'BusinessPlaceID' , u'pVal' , ), 59, (59, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 576 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pVal' , ), 101, (101, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 580 , (3, 0, None, None) , 0 , )),
	(( u'AddressType' , u'pVal' , ), 101, (101, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 584 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pVal' , ), 102, (102, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 588 , (3, 0, None, None) , 0 , )),
	(( u'StreetNo' , u'pVal' , ), 102, (102, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 592 , (3, 0, None, None) , 0 , )),
	(( u'Storekeeper' , u'pVal' , ), 103, (103, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 596 , (3, 0, None, None) , 0 , )),
	(( u'Storekeeper' , u'pVal' , ), 103, (103, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 600 , (3, 0, None, None) , 0 , )),
	(( u'Shipper' , u'pVal' , ), 104, (104, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 604 , (3, 0, None, None) , 0 , )),
	(( u'Shipper' , u'pVal' , ), 104, (104, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 608 , (3, 0, None, None) , 0 , )),
]

IWeightMeasures_vtables_dispatch_ = 1
IWeightMeasures_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'lUnitCode' , u'pbRsltFound' , ), 6, (6, (), [ (3, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'UnitCode' , u'plRsltVal' , ), 10, (10, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'UnitDisplay' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'UnitDisplay' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'UnitName' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'UnitName' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'UnitWeightinmg' , u'pdblRsltVal' , ), 13, (13, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'UnitWeightinmg' , u'pdblRsltVal' , ), 13, (13, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
]

IWithholdingTaxCodes_vtables_dispatch_ = 1
IWithholdingTaxCodes_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrWtCode' , u'pbRsltFound' , ), 6, (6, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pbstrRsltVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'WTName' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'WTName' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'penumRsltVal' , ), 12, (12, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'penumRsltVal' , ), 12, (12, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'BaseAmount' , u'pdblRsltVal' , ), 14, (14, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'BaseAmount' , u'pdblRsltVal' , ), 14, (14, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'OfficialCode' , u'pbstrRsltVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'OfficialCode' , u'pbstrRsltVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'Account' , u'pbstrRsltVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Account' , u'pbstrRsltVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingType' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingType' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'RoundingType' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'RoundingType' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'ppRsltVal' , ), 19, (19, (), [ (16393, 10, None, "IID('{3302B4B4-1F71-4D62-8D6E-85DEAB64B4EB}')") , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'Section' , u'plRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Section' , u'plRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Threshold' , u'pdblRsltVal' , ), 21, (21, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'Threshold' , u'pdblRsltVal' , ), 21, (21, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'Surcharge' , u'pdblRsltVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Surcharge' , u'pdblRsltVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Concessional' , u'penumRsltVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Concessional' , u'penumRsltVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'Assessee' , u'plRsltVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'Assessee' , u'plRsltVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'APTDSAccount' , u'pbstrRsltVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'APTDSAccount' , u'pbstrRsltVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'APSurchargeAccount' , u'pbstrRsltVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'APSurchargeAccount' , u'pbstrRsltVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'APCessAccount' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'APCessAccount' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'APHSCAccount' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'APHSCAccount' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'ARTDSAccount' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'ARTDSAccount' , u'pbstrRsltVal' , ), 29, (29, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'ARSurchargeAccount' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'ARSurchargeAccount' , u'pbstrRsltVal' , ), 30, (30, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'ARCessAccount' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'ARCessAccount' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'ARHSCAccount' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'ARHSCAccount' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'plRsltVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'Location' , u'plRsltVal' , ), 33, (33, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'ReturnType' , u'penumRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'ReturnType' , u'penumRsltVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'penumRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'Inactive' , u'penumRsltVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeIncomingID' , u'plRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeIncomingID' , u'plRsltVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeOutgoingID' , u'plRsltVal' , ), 37, (37, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeOutgoingID' , u'plRsltVal' , ), 37, (37, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'NatureOfCalculationBaseCode' , u'pbstrRsltVal' , ), 38, (38, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'NatureOfCalculationBaseCode' , u'pbstrRsltVal' , ), 38, (38, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'TypeID' , u'plRsltVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'TypeID' , u'plRsltVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
]

IWithholdingTaxCodes_Lines_vtables_dispatch_ = 1
IWithholdingTaxCodes_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 2, (2, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 4, (4, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pdtRsltVal' , ), 5, (5, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Effectivefrom' , u'pdtRsltVal' , ), 5, (5, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pdblRsltVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pdblRsltVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'TDSRate' , u'pdblRsltVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TDSRate' , u'pdblRsltVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'SurchargeRate' , u'pdblRsltVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'SurchargeRate' , u'pdblRsltVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'CessRate' , u'pdblRsltVal' , ), 9, (9, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'CessRate' , u'pdblRsltVal' , ), 9, (9, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'HSCRate' , u'pdblRsltVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'HSCRate' , u'pdblRsltVal' , ), 10, (10, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 11, (11, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
]

IWithholdingTaxData_vtables_dispatch_ = 1
IWithholdingTaxData_vtables_ = [
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSys' , u'pVal' , ), 2, (2, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSys' , u'pVal' , ), 2, (2, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingType' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountinSys' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountinSys' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountFC' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountFC' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmount' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmount' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'RoundingType' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Criteria' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 20, (20, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 21, (21, (), [ ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocumentReference' , u'plRsltVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'penumRsltVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'TargetAbsEntry' , u'plRsltVal' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'TargetDocumentType' , u'plRsltVal' , ), 31, (31, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
]

IWithholdingTaxLines_vtables_dispatch_ = 1
IWithholdingTaxLines_vtables_ = [
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'WTCode' , u'pVal' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSys' , u'pVal' , ), 2, (2, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountSys' , u'pVal' , ), 2, (2, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 3, (3, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'WTAmountFC' , u'pVal' , ), 3, (3, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 4, (4, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'WTAmount' , u'pVal' , ), 4, (4, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'WithholdingType' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountinSys' , u'pVal' , ), 6, (6, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountinSys' , u'pVal' , ), 6, (6, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountFC' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmountFC' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmount' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'TaxableAmount' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'RoundingType' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'Rate' , u'pVal' , ), 10, (10, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'Criteria' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'Category' , u'pVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'BaseType' , u'pVal' , ), 13, (13, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltVal' , ), 18, (18, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 20, (20, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'Add' , ), 21, (21, (), [ ], 1 , 1 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'LineNum' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocEntry' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocLine' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'BaseDocType' , u'pVal' , ), 25, (25, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeIncoming' , u'pVal' , ), 26, (26, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeIncoming' , u'pVal' , ), 26, (26, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeOutgoing' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'CSTCodeOutgoing' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
]

IWizardPaymentMethods_vtables_dispatch_ = 1
IWizardPaymentMethods_vtables_ = [
	(( u'SaveToFile' , u'bstrFileName' , ), 1, (1, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'pbstrFileName' , ), 2, (2, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 3, (3, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'ppRsltIDataBrowser' , ), 4, (4, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'ppRsltIUserFields' , ), 5, (5, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'bstrCode' , u'pbRsltFound' , ), 6, (6, (), [ (8, 1, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Add' , u'plRsltVal' , ), 7, (7, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'plRsltVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Remove' , u'plRsltVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMethodCode' , u'pbstrRsltVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'Description' , u'pbstrRsltVal' , ), 12, (12, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'penumRsltVal' , ), 13, (13, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'Type' , u'penumRsltVal' , ), 13, (13, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMeans' , u'penumRsltVal' , ), 14, (14, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'PaymentMeans' , u'penumRsltVal' , ), 14, (14, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'CheckAddress' , u'penumRsltVal' , ), 15, (15, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'CheckAddress' , u'penumRsltVal' , ), 15, (15, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'CheckBankDetails' , u'penumRsltVal' , ), 16, (16, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'CheckBankDetails' , u'penumRsltVal' , ), 16, (16, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'CollectionAuthorizationCheck' , u'penumRsltVal' , ), 17, (17, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'CollectionAuthorizationCheck' , u'penumRsltVal' , ), 17, (17, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'BlockForeignPayment' , u'penumRsltVal' , ), 18, (18, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'BlockForeignPayment' , u'penumRsltVal' , ), 18, (18, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'BlockForeignBank' , u'penumRsltVal' , ), 19, (19, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'BlockForeignBank' , u'penumRsltVal' , ), 19, (19, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'CurrencyRestriction' , u'penumRsltVal' , ), 20, (20, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'CurrencyRestriction' , u'penumRsltVal' , ), 20, (20, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'PostOfficeBank' , u'penumRsltVal' , ), 21, (21, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'PostOfficeBank' , u'penumRsltVal' , ), 21, (21, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'MinimumAmount' , u'pdblRsltVal' , ), 22, (22, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'MinimumAmount' , u'pdblRsltVal' , ), 22, (22, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'MaximumAmount' , u'pdblRsltVal' , ), 23, (23, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'MaximumAmount' , u'pdblRsltVal' , ), 23, (23, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBank' , u'pbstrRsltVal' , ), 24, (24, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'DefaultBank' , u'pbstrRsltVal' , ), 24, (24, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'UserSignature' , u'plRsltVal' , ), 25, (25, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'CreationDate' , u'pdtRsltVal' , ), 26, (26, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pbstrRsltVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'BankCountry' , u'pbstrRsltVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'DefaultAccount' , u'pbstrRsltVal' , ), 28, (28, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'DefaultAccount' , u'pbstrRsltVal' , ), 28, (28, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'GLAccount' , u'pbstrRsltVal' , ), 29, (29, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'Branch' , u'pbstrRsltVal' , ), 30, (30, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'KeyCode' , u'pbstrRsltVal' , ), 31, (31, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'KeyCode' , u'pbstrRsltVal' , ), 31, (31, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'TransactionType' , u'pbstrRsltVal' , ), 32, (32, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'TransactionType' , u'pbstrRsltVal' , ), 32, (32, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'Format' , u'pbstrRsltVal' , ), 33, (33, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
	(( u'Format' , u'pbstrRsltVal' , ), 33, (33, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 228 , (3, 0, None, None) , 0 , )),
	(( u'AgentCollection' , u'penumRsltVal' , ), 34, (34, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 232 , (3, 0, None, None) , 0 , )),
	(( u'AgentCollection' , u'penumRsltVal' , ), 34, (34, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 236 , (3, 0, None, None) , 0 , )),
	(( u'SendforAcceptance' , u'penumRsltVal' , ), 35, (35, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 240 , (3, 0, None, None) , 0 , )),
	(( u'SendforAcceptance' , u'penumRsltVal' , ), 35, (35, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 244 , (3, 0, None, None) , 0 , )),
	(( u'GroupByDate' , u'penumRsltVal' , ), 36, (36, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 248 , (3, 0, None, None) , 0 , )),
	(( u'GroupByDate' , u'penumRsltVal' , ), 36, (36, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 252 , (3, 0, None, None) , 0 , )),
	(( u'DepositNorm' , u'pbstrRsltVal' , ), 37, (37, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 256 , (3, 0, None, None) , 0 , )),
	(( u'DepositNorm' , u'pbstrRsltVal' , ), 37, (37, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 260 , (3, 0, None, None) , 0 , )),
	(( u'DebitMemo' , u'penumRsltVal' , ), 38, (38, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 264 , (3, 0, None, None) , 0 , )),
	(( u'DebitMemo' , u'penumRsltVal' , ), 38, (38, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 268 , (3, 0, None, None) , 0 , )),
	(( u'GroupByPaymentReference' , u'penumRsltVal' , ), 39, (39, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 272 , (3, 0, None, None) , 0 , )),
	(( u'GroupByPaymentReference' , u'penumRsltVal' , ), 39, (39, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 276 , (3, 0, None, None) , 0 , )),
	(( u'GroupInvoicesbyPay' , u'penumRsltVal' , ), 40, (40, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 280 , (3, 0, None, None) , 0 , )),
	(( u'GroupInvoicesbyPay' , u'penumRsltVal' , ), 40, (40, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 284 , (3, 0, None, None) , 0 , )),
	(( u'DueDateSelection' , u'penumRsltVal' , ), 41, (41, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 288 , (3, 0, None, None) , 0 , )),
	(( u'DueDateSelection' , u'penumRsltVal' , ), 41, (41, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 292 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTermsCode' , u'plRsltVal' , ), 42, (42, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 296 , (3, 0, None, None) , 0 , )),
	(( u'PaymentTermsCode' , u'plRsltVal' , ), 42, (42, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 300 , (3, 0, None, None) , 0 , )),
	(( u'PosttoGLInterimAccount' , u'penumRsltVal' , ), 43, (43, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 304 , (3, 0, None, None) , 0 , )),
	(( u'PosttoGLInterimAccount' , u'penumRsltVal' , ), 43, (43, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 308 , (3, 0, None, None) , 0 , )),
	(( u'BankAccountKey' , u'plRsltVal' , ), 44, (44, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 312 , (3, 0, None, None) , 0 , )),
	(( u'CurrencyRestrictions' , u'ppRsltVal' , ), 46, (46, (), [ (16393, 10, None, "IID('{E6144A85-69CC-4178-A0B2-BDC8BED4930E}')") , ], 1 , 2 , 4 , 0 , 316 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pbstrRsltVal' , ), 47, (47, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 320 , (3, 0, None, None) , 0 , )),
	(( u'DocType' , u'pbstrRsltVal' , ), 47, (47, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 324 , (3, 0, None, None) , 0 , )),
	(( u'Accepted' , u'pbstrRsltVal' , ), 48, (48, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 328 , (3, 0, None, None) , 0 , )),
	(( u'Accepted' , u'pbstrRsltVal' , ), 48, (48, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 332 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioID' , u'pbstrRsltVal' , ), 49, (49, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 336 , (3, 0, None, None) , 0 , )),
	(( u'PortfolioID' , u'pbstrRsltVal' , ), 49, (49, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 340 , (3, 0, None, None) , 0 , )),
	(( u'CurCode' , u'pbstrRsltVal' , ), 50, (50, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 344 , (3, 0, None, None) , 0 , )),
	(( u'CurCode' , u'pbstrRsltVal' , ), 50, (50, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 348 , (3, 0, None, None) , 0 , )),
	(( u'Instruction1' , u'pbstrRsltVal' , ), 51, (51, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 352 , (3, 0, None, None) , 0 , )),
	(( u'Instruction1' , u'pbstrRsltVal' , ), 51, (51, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 356 , (3, 0, None, None) , 0 , )),
	(( u'Instruction2' , u'pbstrRsltVal' , ), 52, (52, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 360 , (3, 0, None, None) , 0 , )),
	(( u'Instruction2' , u'pbstrRsltVal' , ), 52, (52, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 364 , (3, 0, None, None) , 0 , )),
	(( u'PaymentPlace' , u'pbstrRsltVal' , ), 53, (53, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 368 , (3, 0, None, None) , 0 , )),
	(( u'PaymentPlace' , u'pbstrRsltVal' , ), 53, (53, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 372 , (3, 0, None, None) , 0 , )),
	(( u'BarcodeDll' , u'pbstrRsltVal' , ), 54, (54, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 376 , (3, 0, None, None) , 0 , )),
	(( u'BarcodeDll' , u'pbstrRsltVal' , ), 54, (54, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 380 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 55, (55, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 384 , (3, 0, None, None) , 0 , )),
	(( u'Active' , u'penumRsltVal' , ), 55, (55, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 388 , (3, 0, None, None) , 0 , )),
	(( u'GroupInvoicesByPayToBank' , u'penumRsltVal' , ), 56, (56, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 392 , (3, 0, None, None) , 0 , )),
	(( u'GroupInvoicesByPayToBank' , u'penumRsltVal' , ), 56, (56, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 396 , (3, 0, None, None) , 0 , )),
	(( u'GroupInvoicesByCurrency' , u'penumRsltVal' , ), 57, (57, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 400 , (3, 0, None, None) , 0 , )),
	(( u'GroupInvoicesByCurrency' , u'penumRsltVal' , ), 57, (57, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 404 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeRate' , u'pbstrRsltVal' , ), 58, (58, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 408 , (3, 0, None, None) , 0 , )),
	(( u'BankChargeRate' , u'pbstrRsltVal' , ), 58, (58, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 412 , (3, 0, None, None) , 0 , )),
	(( u'ReportCode' , u'pbstrRsltVal' , ), 59, (59, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 416 , (3, 0, None, None) , 0 , )),
	(( u'ReportCode' , u'pbstrRsltVal' , ), 59, (59, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 420 , (3, 0, None, None) , 0 , )),
	(( u'CancelInstruction' , u'pbstrRsltVal' , ), 60, (60, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 424 , (3, 0, None, None) , 0 , )),
	(( u'CancelInstruction' , u'pbstrRsltVal' , ), 60, (60, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 428 , (3, 0, None, None) , 0 , )),
	(( u'OccurenceCode' , u'pbstrRsltVal' , ), 61, (61, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 432 , (3, 0, None, None) , 0 , )),
	(( u'OccurenceCode' , u'pbstrRsltVal' , ), 61, (61, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 436 , (3, 0, None, None) , 0 , )),
	(( u'MovementCode' , u'pbstrRsltVal' , ), 62, (62, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 440 , (3, 0, None, None) , 0 , )),
	(( u'MovementCode' , u'pbstrRsltVal' , ), 62, (62, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 444 , (3, 0, None, None) , 0 , )),
]

IWorkOrder_Lines_vtables_dispatch_ = 1
IWorkOrder_Lines_vtables_ = [
	(( u'Add' , ), 1, (1, (), [ ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'Count' , u'pVal' , ), 2, (2, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'SetCurrentLine' , u'LineNum' , ), 3, (3, (), [ (3, 0, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'RowNumber' , u'pVal' , ), 4, (4, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 5, (5, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'ItemCode' , u'pVal' , ), 5, (5, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'ItemDescription' , u'pVal' , ), 6, (6, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'ItemQuantity' , u'pVal' , ), 7, (7, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'ItemQuantity' , u'pVal' , ), 7, (7, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'ItemPrice' , u'pVal' , ), 8, (8, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'ItemPrice' , u'pVal' , ), 8, (8, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 9, (9, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'PriceCurrency' , u'pVal' , ), 9, (9, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ItemWarehouse' , u'pVal' , ), 10, (10, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ItemWarehouse' , u'pVal' , ), 10, (10, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccountCode' , u'pVal' , ), 11, (11, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccountCode' , u'pVal' , ), 11, (11, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'WorkSum' , u'pVal' , ), 12, (12, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'WorkSum' , u'pVal' , ), 12, (12, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 15, (15, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
]

IWorkOrders_vtables_dispatch_ = 1
IWorkOrders_vtables_ = [
	(( u'Add' , u'ooErr' , ), 1, (1, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 28 , (3, 0, None, None) , 0 , )),
	(( u'GetByKey' , u'WkoKey' , u'Found' , ), 2, (2, (), [ (3, 0, None, None) , 
			(16395, 10, None, None) , ], 1 , 1 , 4 , 0 , 32 , (3, 0, None, None) , 0 , )),
	(( u'Update' , u'ooErr' , ), 3, (3, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 36 , (3, 0, None, None) , 0 , )),
	(( u'SaveXML' , u'FileName' , ), 5, (5, (), [ (16392, 3, None, None) , ], 1 , 1 , 4 , 0 , 40 , (3, 0, None, None) , 0 , )),
	(( u'Browser' , u'pVal' , ), 6, (6, (), [ (16393, 10, None, "IID('{A52E0922-634E-4827-9B4A-10D6D46ECE74}')") , ], 1 , 2 , 4 , 0 , 44 , (3, 0, None, None) , 0 , )),
	(( u'Lines' , u'pVal' , ), 7, (7, (), [ (16393, 10, None, "IID('{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}')") , ], 1 , 2 , 4 , 0 , 48 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 8, (8, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 52 , (3, 0, None, None) , 0 , )),
	(( u'Status' , u'pVal' , ), 8, (8, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 56 , (3, 0, None, None) , 0 , )),
	(( u'Canceled' , u'pVal' , ), 9, (9, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 60 , (3, 0, None, None) , 0 , )),
	(( u'OrderDate' , u'pVal' , ), 10, (10, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 64 , (3, 0, None, None) , 0 , )),
	(( u'OrderDate' , u'pVal' , ), 10, (10, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 68 , (3, 0, None, None) , 0 , )),
	(( u'WorkStartDate' , u'pVal' , ), 11, (11, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 72 , (3, 0, None, None) , 0 , )),
	(( u'WorkStartDate' , u'pVal' , ), 11, (11, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 76 , (3, 0, None, None) , 0 , )),
	(( u'ExpectedCompletionDate' , u'pVal' , ), 12, (12, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 80 , (3, 0, None, None) , 0 , )),
	(( u'ExpectedCompletionDate' , u'pVal' , ), 12, (12, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 84 , (3, 0, None, None) , 0 , )),
	(( u'WorkFinishDate' , u'pVal' , ), 13, (13, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 88 , (3, 0, None, None) , 0 , )),
	(( u'WorkFinishDate' , u'pVal' , ), 13, (13, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 92 , (3, 0, None, None) , 0 , )),
	(( u'ReceiverName' , u'pVal' , ), 14, (14, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 96 , (3, 0, None, None) , 0 , )),
	(( u'ReceiverName' , u'pVal' , ), 14, (14, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 100 , (3, 0, None, None) , 0 , )),
	(( u'OrdererCode' , u'pVal' , ), 15, (15, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 104 , (3, 0, None, None) , 0 , )),
	(( u'OrdererCode' , u'pVal' , ), 15, (15, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 108 , (3, 0, None, None) , 0 , )),
	(( u'OrdererName' , u'pVal' , ), 16, (16, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 112 , (3, 0, None, None) , 0 , )),
	(( u'OrdererName' , u'pVal' , ), 16, (16, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 116 , (3, 0, None, None) , 0 , )),
	(( u'CustomerRefNo' , u'pVal' , ), 17, (17, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 120 , (3, 0, None, None) , 0 , )),
	(( u'CustomerRefNo' , u'pVal' , ), 17, (17, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 124 , (3, 0, None, None) , 0 , )),
	(( u'OrderTotal' , u'pVal' , ), 18, (18, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 128 , (3, 0, None, None) , 0 , )),
	(( u'TotalCurrency' , u'pVal' , ), 19, (19, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 132 , (3, 0, None, None) , 0 , )),
	(( u'GenerationTime' , u'pVal' , ), 20, (20, (), [ (16391, 10, None, None) , ], 1 , 2 , 4 , 0 , 136 , (3, 0, None, None) , 0 , )),
	(( u'GenerationTime' , u'pVal' , ), 20, (20, (), [ (7, 1, None, None) , ], 1 , 4 , 4 , 0 , 140 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pVal' , ), 21, (21, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 144 , (3, 0, None, None) , 0 , )),
	(( u'Comment' , u'pVal' , ), 21, (21, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 148 , (3, 0, None, None) , 0 , )),
	(( u'InstructionNumber' , u'pVal' , ), 22, (22, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 152 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 23, (23, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 156 , (3, 0, None, None) , 0 , )),
	(( u'ContactPerson' , u'pVal' , ), 23, (23, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 160 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 24, (24, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 164 , (3, 0, None, None) , 0 , )),
	(( u'Series' , u'pVal' , ), 24, (24, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 168 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccountCode' , u'pVal' , ), 25, (25, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 172 , (3, 0, None, None) , 0 , )),
	(( u'ActiveAccountCode' , u'pVal' , ), 25, (25, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 176 , (3, 0, None, None) , 0 , )),
	(( u'WorkSum' , u'pVal' , ), 26, (26, (), [ (16389, 10, None, None) , ], 1 , 2 , 4 , 0 , 180 , (3, 0, None, None) , 0 , )),
	(( u'WorkSum' , u'pVal' , ), 26, (26, (), [ (5, 1, None, None) , ], 1 , 4 , 4 , 0 , 184 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pVal' , ), 27, (27, (), [ (16392, 10, None, None) , ], 1 , 2 , 4 , 0 , 188 , (3, 0, None, None) , 0 , )),
	(( u'JournalRemarks' , u'pVal' , ), 27, (27, (), [ (8, 1, None, None) , ], 1 , 4 , 4 , 0 , 192 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 28, (28, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 196 , (3, 0, None, None) , 0 , )),
	(( u'PriceListNum' , u'pVal' , ), 28, (28, (), [ (3, 1, None, None) , ], 1 , 4 , 4 , 0 , 200 , (3, 0, None, None) , 0 , )),
	(( u'FinancialPeriod' , u'pVal' , ), 29, (29, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 204 , (3, 0, None, None) , 0 , )),
	(( u'Cancel' , u'ooErr' , ), 30, (30, (), [ (16387, 10, None, None) , ], 1 , 1 , 4 , 0 , 208 , (3, 0, None, None) , 0 , )),
	(( u'UserFields' , u'pVal' , ), 32, (32, (), [ (16393, 10, None, "IID('{CC279FBE-7088-42E9-A579-EB2E3E971076}')") , ], 1 , 2 , 4 , 0 , 212 , (3, 0, None, None) , 0 , )),
	(( u'OrderNum' , u'pVal' , ), 33, (33, (), [ (16387, 10, None, None) , ], 1 , 2 , 4 , 0 , 216 , (3, 0, None, None) , 0 , )),
	(( u'GetAsXML' , u'pVal' , ), 34, (34, (), [ (16392, 10, None, None) , ], 1 , 1 , 4 , 0 , 220 , (3, 0, None, None) , 0 , )),
	(( u'SaveToFile' , u'FileName' , ), 35, (35, (), [ (8, 1, None, None) , ], 1 , 1 , 4 , 0 , 224 , (3, 0, None, None) , 0 , )),
]

I_GenArrObj_vtables_dispatch_ = 1
I_GenArrObj_vtables_ = [
]

RecordMap = {
}

CLSIDToClassMap = {
	'{9E334DDA-DD14-48A7-8482-292392B27A13}' : EmployeePrevEmpoymentInfo,
	'{948C7B32-1518-45ED-99A3-94AA328CD7FF}' : IApprovalTemplateUsers,
	'{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}' : IJournalEntryDocumentTypeParams,
	'{1AD8B5F7-8076-488A-8493-1E430FF9EEAA}' : IExternalCallsService,
	'{4DC221EF-0E47-4EB3-A14C-A92F31E956DD}' : CallArgument,
	'{8B560D21-5616-4D85-ACA9-BC8145B30A73}' : SalesForecast_Lines,
	'{5C594028-D730-4298-952E-4616C5047BC6}' : IServiceContracts,
	'{B2CC6793-FFCF-4389-980D-B5FF458B2EC8}' : ProductTrees,
	'{ADDFFAB7-1BA1-4C06-8229-D3CE76605700}' : BusinessPlaces,
	'{0B0ADBC6-6CCA-48DF-92A9-2D0633AED84B}' : DNFCodeSetupService,
	'{05167588-6D3A-4C0E-AEFA-284CFDA23B7E}' : ICampaignBusinessPartners,
	'{284C40A5-FADD-4910-90EF-21825F75E6FD}' : DocumentSeriesParams,
	'{26C5C696-EC20-43DC-BCD9-010F00F40843}' : BranchesService,
	'{1C764D4F-63DA-46FE-BD81-56548EEDB2F6}' : IPeriodCategory,
	'{B50BD947-38AC-4ACE-97F4-8EA9ECD9AB77}' : ClosingDateProcedure,
	'{77166E02-41E6-47C8-9EBE-66348C1C9D9E}' : BrazilFuelIndexersService,
	'{1DB2C7ED-919B-49BA-9A7F-35E9F3262C3E}' : BOEDocumentTypes,
	'{68C30771-F870-4567-8F0A-D7E21756D2BB}' : WithholdingTaxCodes_Lines,
	'{C18E808F-F2E2-4D1D-8F5F-5CCE8C2D274B}' : DunningTermsService,
	'{EB892090-5B7A-48F1-849C-5F4A0048B2DA}' : IBrazilMultiIndexer,
	'{2FA0FB01-DCC0-436C-8677-44654831D6E6}' : AlertManagementDocument,
	'{EE047C63-413F-4CEA-B8BC-A4223AA6B482}' : IShippingTypes,
	'{E21D5CB9-5B51-4598-8989-75A702DFC29E}' : IBlanketAgreements_DetailsLine,
	'{417DC595-38A9-48E4-ABC1-AD08B2C0070B}' : ElectronicFileFormatParams,
	'{F2353C93-5EBC-4DDC-B750-717E97F41CF2}' : IAccountCategoryService,
	'{24242AF5-F1A3-4688-9AB3-6CC76EB08D78}' : DNFCodeSetup,
	'{FC23201F-196D-40E5-A3CA-C8DA72FC63B2}' : BPBranchAssignment,
	'{414D11BE-00FC-4AF1-BEDF-C0B3308E1A40}' : IAcctSegmnt_Categories,
	'{910C52B1-ABDC-409F-80EE-D6219E33497E}' : IDynamicSystemStrings,
	'{34995651-4568-4AAE-B831-60693B932A35}' : ISpecialPricesQuantityAreas,
	'{E78A5751-F0F7-4A5A-BDE0-B59BC461F57C}' : IAccrualTypesService,
	'{E7843EA1-A67D-4C9A-B61D-EABDE49D4692}' : SalesOpportunities,
	'{9E52D02D-16FC-4E2C-87FC-CD070F5D646A}' : IAlertManagement,
	'{53651CC7-0892-4713-AE45-FE246FCA0F07}' : ChooseFromList_Lines,
	'{5EC86D5B-840B-4676-8D5B-6154AD738D09}' : Activity,
	'{16521FC3-2B92-47B4-89E1-3145EE333649}' : AdminInfo,
	'{46BCE59C-FCA9-4AC3-8A3D-07090C41E5F2}' : IBankChargesAllocationCodesParams,
	'{F0070DD3-7081-46DD-A17E-0DCAF223D213}' : BOELineParams,
	'{097DDC08-E989-4426-87DB-9EFAD0FF64C3}' : Relationships,
	'{FA8FD318-6971-4E8B-B6E9-959A938455C6}' : IServiceCallSolutions,
	'{A6EE3F95-9556-4409-9BCB-9DC06E009E22}' : ICashFlowLineItemParams,
	'{87ED882F-80FA-487D-8DA1-058E42B6BFA8}' : IBOELines,
	'{E432B857-5835-4E67-A3E1-BF6ED7AED2D2}' : MaterialGroupParams,
	'{26767B5A-7011-4E58-A9FE-D6D1F8568B0F}' : IEmployeeRolesSetupService,
	'{9D04BDB8-F941-49C2-A9C1-E11A71681BAA}' : GLAccount,
	'{99A581A7-0EC0-41CB-A273-D205125DB608}' : AccrualTypesService,
	'{9EB0E81A-9442-4C9A-B096-93C6134E684D}' : IContractTemplates,
	'{CC279FBE-7088-42E9-A579-EB2E3E971076}' : IUserFields,
	'{28729C80-FAA2-449D-8847-926D8A225E6A}' : ReportLayoutItems,
	'{7AF930C1-1211-4953-BD69-5F64B3743316}' : ILandedCost_CostLine,
	'{95968C8C-6866-4B59-BB03-E08A96684591}' : IBankChargesAllocationCode,
	'{B5BF5462-BCF6-49F4-925B-510460F45EFC}' : WizardPaymentMethods,
	'{5C87125B-3FCE-4FC7-9AD9-430D8E555426}' : ITargetGroup,
	'{D2EDF723-F433-4A0A-A4A9-5D8E628CC3E3}' : ICashFlowLineItem,
	'{E56E576E-555C-4F31-8170-0EFA192411E2}' : GeneralDataParams,
	'{33201180-255B-46DF-A8C4-E8A7E2855353}' : IReportLayout_TranslationLines,
	'{DF33FA96-E656-4AF6-A877-AAC7D5A8D586}' : IUserLanguages,
	'{EB49B71E-C20E-4D6D-8ECD-A641B0BAAA35}' : EmployeesInfo,
	'{ED5A21FE-3751-472D-B058-198D6E2FEB9F}' : CreditPaymentMethods,
	'{975B187C-4395-4FE4-ABEB-B347B279215B}' : DeductionTaxSubGroupParams,
	'{881C8CF2-FDB4-43ED-866F-4F6A4827E02C}' : IBOEPortfolios,
	'{4EF2A7BE-CB39-473A-977B-C2AAE73210AF}' : AlertManagementService,
	'{6410A92E-B2C4-432B-B421-01FDD7835CEF}' : ApprovalStageParams,
	'{5F05E0D7-EA2B-4FA6-B7DB-D436CB1AAD63}' : Message,
	'{914845C0-9411-4A9C-9D0D-DC85177ACFA9}' : CallMessages,
	'{F12BD69F-83F6-46F0-A602-3E374B2400FB}' : SalesOpportunitySourceSetup,
	'{7E9C6F20-F9A1-470C-B50D-D1EA112B030A}' : IBankStatementRows,
	'{026951FA-5BBD-4559-BA2D-771C19E66BBD}' : ElectronicSeriesParams,
	'{DA6203BB-DE30-4AC7-9567-5822C3463335}' : IFinancePeriodParams,
	'{CF683F67-7A73-4D71-9C10-821A1E7715DC}' : IMaterialGroup,
	'{5B9ECA1D-2E75-42EC-BCF2-FBD84756B8B1}' : ReportParams,
	'{C4E7259B-2770-4451-9C0F-0757F5BE9FD7}' : CertificateSeriesService,
	'{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}' : IProductTrees_Lines,
	'{208C7E76-4919-4468-AE9E-13976C9BE255}' : UserKeysMD,
	'{43AFB8C0-18E3-4452-B1F0-CDA85C1F463F}' : UserMenuItems,
	'{38DA089C-BF1E-457E-B486-F1E35293F5F1}' : IBusinessPartnerProperty,
	'{2E2720A5-8F7C-45D3-BF5A-DD5BE3769F84}' : IUserObjectsMD,
	'{2A2351A9-3BB7-4FD0-807C-2D1FEAB7477D}' : OccurenceCode,
	'{FE19123D-05AC-4D3F-8E3D-4A3155ECF43D}' : ITransactionCodesService,
	'{03811867-1D7D-4ED8-B42B-040839C0EC4C}' : BrazilMultiIndexer,
	'{989D909A-FA21-488B-B144-A7AA6B920308}' : NFModelsParams,
	'{4631570A-DAE1-43BB-9E4A-BA9957E593E1}' : IOriginalItem,
	'{4211C5EE-D841-47F4-85CE-752D2DB519C2}' : NFModelParams,
	'{38038B4E-6B7A-441F-81C6-9B699CC4DE6A}' : BusinessPartnerPropertiesService,
	'{8A8F6C7B-BD55-45C5-A28C-C81A786B0EB8}' : IImportProcesses,
	'{52C8673B-CA79-4476-9F2E-28109AE17545}' : IContactEmployees,
	'{12788346-93BB-4D1C-8649-A3266A413D3F}' : Currencies,
	'{038A3F8E-2465-435E-8D05-F510620533C3}' : IMaterialRevaluation_lines,
	'{EFFD365E-5096-4B19-9187-986F83D337E0}' : IApprovalTemplateTerms,
	'{98DF1BF3-2F28-46C7-8003-FB8D11276237}' : ISalesTaxCodes_Lines,
	'{08186613-A26E-4BC9-9832-3422FC4621D5}' : ServiceCallSolutionStatusParams,
	'{6AD3FECD-43C9-4993-B8F5-0340C8299AEE}' : BrazilMultiIndexersService,
	'{5EE7C7ED-EEC8-48E4-A394-BBAECC769C43}' : ProfitCentersParams,
	'{F5221870-4600-47CC-AFA3-779B11403820}' : ILandedCostsParams,
	'{48D8151E-BF85-4760-B7F8-B5E7E1B47937}' : IKPI_ItemLine,
	'{060F033E-2FC9-4266-90AE-3271AC203A59}' : IJournalEntries,
	'{AADAC0AA-6CBA-47EC-B923-05B029715123}' : IDocumentSeriesUserParams,
	'{900A8956-ACED-4E66-B254-78EB55F7089F}' : ICheckLine,
	'{56B7FEB9-ECC9-4A64-BDDF-0AB70C3746D0}' : IJournalEntryDocumentType,
	'{E8AB066D-E193-4433-AD85-0E1AA6F490A3}' : BudgetCostAccounting_Lines,
	'{9FEF81F9-9C21-4B0B-9EDA-0EF9A5C98739}' : IServiceCallOrigin,
	'{9C536750-5FC9-45DF-AF6E-62DB9ACCAEA8}' : CommandParams,
	'{45B16468-2569-43A8-A330-D6E7F5275CAD}' : ChangeLogDifferencesParams,
	'{41501B90-66B9-49BC-920E-EAEF90F119B2}' : ServiceCalls,
	'{E985FCDC-43E0-47C4-821D-7F60D4BC9009}' : IActivityStatus,
	'{FC571383-8375-4B7D-BDEF-4EF2B91B7751}' : IUserTablesMD,
	'{7B45A310-CED5-4D41-9A54-BED0F11B6950}' : IBOEDocumentTypeParams,
	'{65CA8D95-BE2F-4E7E-9E56-42BA0FE0FB49}' : CashFlowLineItemParams,
	'{90E9CFE3-0440-4E26-B8E7-975A9A4638B4}' : IDefaultReportParams,
	'{B52CCF14-E084-48A9-AE48-2E1B38CAD704}' : AlertManagement,
	'{210393EC-DEF3-4E55-965C-C2891393A73C}' : Items,
	'{E2174012-44BF-4A47-B117-283D13C66C5E}' : StockTransfer,
	'{9E538356-9693-4627-A806-D01D07823616}' : BrazilNumericIndexerParams,
	'{0278D428-E7EE-4F0D-ACE4-1CBADAE17BC2}' : CallMessageArgument,
	'{CD47A725-AEA8-4224-93D3-F31848990C42}' : IEmployeeAbsenceInfo,
	'{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}' : ISalesOpportunitiesLines,
	'{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}' : IPredefinedTextParams,
	'{738D011A-EA2A-4205-B009-53C7C64D73DD}' : IMultiplePayment,
	'{731625D2-901C-40C1-A06C-C6A72FC00D8C}' : ICertificateSeriesParamsCollection,
	'{93BF348F-60F8-4803-8621-9E3DB48B1852}' : DepositParams,
	'{2DBFED56-4DB4-455A-9C22-E2C01C052D39}' : IBillOfExchangeTransaction_Lines,
	'{23BACDC0-773E-4283-BE9C-BB2D0A216961}' : PickLists,
	'{4F0A05FF-FCE7-48C8-9F39-8768444639BF}' : TaxCodeDeterminationsService,
	'{D7B39E88-0C6D-4B8A-A083-AEC336746884}' : IDunningTermLine,
	'{D9811035-C659-4D43-B92F-56378C1CC50C}' : SeriesLines,
	'{BACE2904-08D9-41F7-A963-FA3E550D9BF9}' : BankChargesAllocationCodeParams,
	'{32ABB501-14BB-4467-8D98-597A9420D8C6}' : ITaxReportAccount,
	'{36143269-AD6C-4AD9-9A2E-AE3273141D8C}' : ILandedCost_ItemLines,
	'{B9FED360-AD27-45E1-AB8A-714FB217B022}' : SalesOpportunitiesLines,
	'{C7037B05-9DF8-47CA-8819-4D9460F03794}' : IBrazilFuelIndexersParams,
	'{BB7C303A-1C58-4718-98BA-318FBCDB3502}' : SalesOpportunityCompetitorSetupParams,
	'{301718D4-11C9-4C5F-88DD-3609C5FA21FF}' : IStockTaking,
	'{CDF64DE9-D2B8-4180-983C-457ABAA5EFB1}' : BOEPortfolios,
	'{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}' : IBrazilMultiIndexerParams,
	'{0577F672-2A66-452A-9597-5008904A3940}' : IBranchesService,
	'{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}' : IDepositParams,
	'{343A6016-2B36-4522-B0E9-477A062EF6DB}' : IReportTypesParams,
	'{006B6314-B29C-407F-A8F8-11717E779A2A}' : IDashboardPackageParams,
	'{9316E5DC-6A1E-4D66-A31D-40576A355AB9}' : IServiceCallSolutionStatusParamsCollection,
	'{B743C51D-0E51-400E-8245-91331C0A6762}' : IMaterialRevaluationFIFOService,
	'{96C491DF-52C0-42C6-802A-5890F273BE5A}' : ElectronicSeries,
	'{43AC045C-DCA2-4150-B937-AB205DCA22E6}' : IWarehouses,
	'{813B8F2A-F8BC-4C70-A043-CF099057F3B8}' : ITaxReportFiltersParams,
	'{E097B000-F885-401A-A265-5E46F074A5F4}' : CertificateSeriesParamsCollection,
	'{9CE26B68-F839-4799-A385-D31DDAB92BEB}' : PaymentBlocksParams,
	'{3E64E5EC-70CA-4129-BC06-0CE9B2058843}' : IDocument_Installments,
	'{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}' : IActivityInstanceParams,
	'{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}' : IUserMenuItems,
	'{57DED1E0-70C3-46C1-97BC-69B0F683D66C}' : DeductionTaxHierarchies,
	'{57B97799-106E-4EA3-8203-1B30B6B7D463}' : _ICompanyEvents,
	'{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}' : ISectionParams,
	'{1A645E6A-B777-419D-84A6-6074EB069C86}' : DepositsService,
	'{F00B2064-7046-4E6A-9286-1284170CFA80}' : WithholdingTaxData,
	'{E053D931-2878-44FD-88A0-2E572EA10DB0}' : ISectionsService,
	'{CBAB706D-E5DE-4D36-BB28-C6705D247335}' : IMessageHeaders,
	'{3FFD991B-9010-4832-89C6-903CBB33AD7D}' : IDepositsParams,
	'{6C88DC52-9869-4BB8-8DBB-C2F536138943}' : CertificateSeriesParams,
	'{5881CB86-9E3A-403D-A3C8-D1B888F3C4F7}' : UserQueries,
	'{F041210F-6968-47CD-B441-40A059D76A1A}' : MultiLanguageTranslations,
	'{727B34C7-DD01-4B31-9213-F5B02C5E3276}' : BPPaymentDates,
	'{E08287E7-64BE-4C4F-B25D-78EEEB40A94C}' : ExtendedTranslation_ItemLines,
	'{6D4864DD-75DF-4305-A8CB-C7E2381DD7B3}' : UserPermissionForms,
	'{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}' : IStateParams,
	'{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}' : IGLAccount,
	'{B0338FF7-542D-4AEA-A097-A51DECA7E671}' : ICreditLineParams,
	'{65ABB505-DD62-4C94-8E7B-BF63BC35E51E}' : Teams,
	'{9306DAC4-5FDE-4695-AF50-96349ABA5F74}' : IFinancialYearsParams,
	'{EFA05C0F-B878-48E4-AA66-4E266FA5CC1A}' : IBlanketAgreementsDocuments,
	'{AC817068-3E5F-49B3-A301-189558534ED5}' : BusinessPartnerPropertiesParams,
	'{793B4DFE-8628-4E29-BE9F-2C81E26FE82C}' : SeriesLine,
	'{B4CCEAAF-2511-4E3A-916F-8F0F7B6479C5}' : IDepartment,
	'{59837FCB-2720-45D3-85BF-9F075D5D6560}' : ILegalData,
	'{13B5A261-F351-4DB5-8D4A-5A6C9083CF19}' : ICustomsDeclarationService,
	'{177775C1-0633-42DE-8711-AF5D5DD650D8}' : IFormPreferencesService,
	'{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}' : IReportTypeParams,
	'{9370956A-E63B-4B62-9AA0-EA32A0673B8A}' : ITaxInvoices,
	'{F9779E16-EDDF-4C59-B80D-A24F34EA1ECE}' : UserPermission,
	'{EA05A4CC-F1C8-41C4-8F84-64A9D9CA9883}' : StatesService,
	'{D0A0837D-25C5-4511-9C31-B749CA452C8F}' : IGTIsService,
	'{B03EE5C0-48D5-4E20-A33A-FF2DBE5AF478}' : Territories,
	'{F3F8DF1B-8D02-467D-AFFB-CCF42B3C168E}' : ServiceCallProblemType,
	'{48528290-6FDA-4F13-ABDE-8B3DE992ACCA}' : TaxReportBusinessPartners,
	'{36E908CF-6A46-413F-8BD6-C027651A58EA}' : SpecialPricesQuantityAreas,
	'{4DA92EEC-3781-4B5B-B466-4001E7B6F439}' : ICheckLines,
	'{A3C87BAE-49A3-4A53-A50B-D20716733709}' : BusinessPartnerGroups,
	'{5D08DA01-1E53-4A29-BDCC-5CE3FDFEC343}' : BOEDocumentType,
	'{80DB1499-68B7-473B-B0A7-CE7F0F1FCECF}' : StatesParams,
	'{605E409B-D305-4DB4-8FC2-FFE8E3AD8EE9}' : FeatureStatus,
	'{D63B7918-80EA-4553-A01E-A574620DCEF6}' : ElectronicFileFormat,
	'{3FF0DED0-0DD1-4D92-85A8-6120FD8E3040}' : TransactionCodeParams,
	'{D48F490F-CB1F-46B9-A941-D1A84FCE1DB2}' : ISeriesCollection,
	'{E7092C39-C3B3-4928-A5AB-B0FF9B885D5E}' : IReportLayoutItems,
	'{DB0B495A-9C94-4B49-8DB1-DEA4B58C73C2}' : DistributionRuleParams,
	'{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}' : ISalesOpportunityCompetitorSetupParams,
	'{EF86275D-924A-4AC9-9461-E9AAF80894B6}' : IRoundedData,
	'{9324B0F9-58FC-404D-81BB-5591BE9E6A27}' : IEmployeeTransferDetails,
	'{EE912DF0-9D0E-49BE-999D-B88AA59B305D}' : ITaxWebSite,
	'{3267FC28-5E07-4BA5-B072-C8F160D7C1C4}' : ServiceContracts,
	'{92196C1E-B89A-4F4E-8E37-A1F2FAC71C5C}' : IApprovalRequest,
	'{FA06709C-FEAA-4E4B-85F1-063578C32965}' : IChangeLogDifferencesParams,
	'{81305C7E-36A1-4336-A7D6-FEDB889A790B}' : FinancialYearParams,
	'{4583DECC-E80D-46AE-B3C0-308FC33C58E9}' : IAdminInfo,
	'{C7224CA0-BA56-4141-84AA-9E45D75208EF}' : CustomsGroups,
	'{E2C5A384-883B-4963-A4A4-30C6F553818F}' : INotaFiscalUsage,
	'{913C6394-89AD-47A9-9390-1B8686E65312}' : IUserKeysMD,
	'{455B78FC-1F3F-4178-A67B-026130220693}' : StockTransfer_TaxExtension,
	'{7F3611B7-822C-41C3-82DB-2D8909B59C7A}' : Document_LinesAdditionalExpenses,
	'{CD0EAC7A-0E3F-4ED3-A9BF-42D4100A3FBB}' : INatureOfAssesseesParams,
	'{F788A8C7-F4E4-47BD-BBC8-79670F3EAE61}' : IElectronicFileFormat,
	'{1FEF5698-93E1-4167-AEA0-4BB151792623}' : IBatchNumbers,
	'{C473B788-84C8-4B04-B63F-AB4F7348BF1F}' : PeriodCategoryParams,
	'{FAB3EB8B-22A5-4530-908D-9ADBBD88774D}' : ApprovalRequestDecision,
	'{ED08E4CF-0DC1-40F4-9769-770663082515}' : AccrualType,
	'{58A42D29-DF69-4C14-9467-656666D09CD5}' : IFinancialYearsService,
	'{5751679D-4E34-4E74-B169-03D440F1F9D1}' : ChangeLogsService,
	'{15DB95C7-BC17-4B52-94E3-E8D252DB6F03}' : PartnersSetupsService,
	'{5C3925BA-87A6-4C77-B1DE-ABB68B9814FA}' : EmployeeIDType,
	'{1C7661BB-2694-4ECF-94EF-588ECB0CB8AD}' : IBoxes1099,
	'{F656351C-32B3-4FE5-9054-221B5988B7E7}' : IAccountCategory,
	'{6692DB25-3CF4-44C4-932D-1F6D13DF6E7C}' : IRetornoCodeParamsCollection,
	'{2165070A-0BA0-4409-AC85-52A47508F236}' : IDeductionTaxSubGroupParams,
	'{AABB98FA-CCB5-4F0D-A6B6-5684708886C9}' : IAccountCategoriesParams,
	'{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}' : IAlertManagementDocument,
	'{2BFFCB89-7037-4E72-AA73-9E5667B51A78}' : Department,
	'{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}' : IDunningTermParams,
	'{64572B16-A58D-40D4-B869-10787D0A8EE2}' : MaterialRevaluation_lines,
	'{FB002972-8E0A-4819-AC30-B955B37C4772}' : IApprovalRequestDecision,
	'{6F49AA78-C540-44BD-B70F-050870C5BBF0}' : ITargetGroupsDetail,
	'{03664F1A-4FCF-401A-84E1-934D1F101EA4}' : IApprovalStagesParams,
	'{0119B251-4EBE-410F-AD86-1F2D401D28F3}' : UserBranchAssignment,
	'{86FB8743-E265-47A1-BE6C-7A5E9FEEAAAB}' : IBlobTableKeySegments,
	'{1B31BF62-5F56-4A20-876D-1B7BC75824C9}' : IWithholdingTaxCodes,
	'{CEDAC9E2-A77F-4518-A524-1403050FFD3D}' : IDocument_ApprovalRequests,
	'{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}' : IBPPaymentDates,
	'{FE490117-D92F-4CFD-A046-641F27A4FD94}' : SectionsParams,
	'{53845C38-AC44-41AE-B21A-9A9EE1018A4D}' : MaterialRevaluationFIFO,
	'{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}' : IMessageDataColumn,
	'{F68C8591-8115-4DC6-B1EF-5071C5CEB367}' : ICampaignItem,
	'{5F9B7943-CA8C-482F-A5EB-B412ADB51007}' : CheckLine,
	'{F563A16D-0B24-4D00-A668-C12DF72F6EE9}' : DashboardPackageImportParams,
	'{B4BD2994-B72F-4AEE-8A80-8B94E2E34E4A}' : BlanketAgreements_DetailsLine,
	'{A3C28485-77EA-4396-9D1F-FAD7279A74A1}' : IBlanketAgreementParams,
	'{A2E1CAAE-481E-4DD3-A6D7-EEF4CC1A96E7}' : ReportFilterService,
	'{AEA80754-8283-49E8-A4A5-2523BA860D5F}' : ProductionOrders_SalesOrderLines,
	'{DE0B0369-F5A1-4BCC-AD4A-47AE8F410EF4}' : TransactionCodeParamsCollection,
	'{6AEEDCED-BA23-49D4-9853-D371A33AA311}' : MaterialRevaluationFIFOService,
	'{A2A9F005-92C0-4949-B2D7-92B7D8AAA784}' : PaymentRunExport_Lines,
	'{8AEF84A8-9762-4736-A6BC-778EA10CA4C2}' : UserObjectsMD,
	'{5C9EBDA2-D0B1-487D-BEA0-DCDB44D6A56B}' : Recipient,
	'{BFFCB767-876B-4A47-BB72-7B8ECAD30228}' : SeriesParams,
	'{E79D3C41-BFE7-4C5A-B586-4F627E021A1C}' : IPayments,
	'{83CB8BC4-7FE1-4C02-81B4-35EE3C252DC8}' : ILandedCost_CostLines,
	'{F018FAC9-48EF-435B-9D4A-0EFE1337EABB}' : CostCenterTypesParams,
	'{A60820F4-BCF8-4153-8E22-34DDF1E4F1E9}' : INatureOfAssesseesService,
	'{DF6C475B-AD8D-4E52-A412-9500E69DB54B}' : IProductionOrders_SalesOrderLines,
	'{DE680833-445E-4AF0-A7E3-377D5135268B}' : IFields,
	'{FEC7996F-BF4C-4850-9576-FF3B3AF66851}' : DeductionTaxSubGroup,
	'{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}' : IAlternativeItem,
	'{03111771-050A-41FF-A2EA-A17B8C7E99FE}' : ITaxCodeDetermination,
	'{950BE47C-4B36-49F3-A313-57146222DC3C}' : UserPermissionTree,
	'{7B78B94A-9F54-4A05-9A64-0A1E89484ECB}' : IDiscountGroups,
	'{1A4FDB5D-78F8-4BC7-BBDD-3854B3B374BF}' : BlanketAgreementParams,
	'{C27CB0AA-2304-4D4E-B292-8ED9651F34A3}' : SalesOpportunitiesCompetition,
	'{6AC1DA43-B01F-4E2E-8B5A-184BE9C05D80}' : IExternalCallParams,
	'{CFD28E0F-8394-4B7D-87A0-52D3AD73254E}' : IDNFCodeSetupService,
	'{A52E0922-634E-4827-9B4A-10D6D46ECE74}' : IDataBrowser,
	'{F2637576-718A-48FF-9B0E-355645D088E3}' : ServiceGroupsService,
	'{8CC29ECE-02C3-4C7B-851B-5533D2C83627}' : ITaxExtension,
	'{E00CB643-DBC7-492C-8D65-FE84540E425A}' : CostCenterTypesService,
	'{C5649BC6-2AF9-4C88-B065-1D14E80A6B1E}' : TransactionCodesService,
	'{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}' : IBrazilNumericIndexerParams,
	'{FB23BF90-F362-4CE6-AD2B-B5F45DE7EAC2}' : BlanketAgreement,
	'{D9F478E8-7891-4C69-A96D-39D5881CFE39}' : ProductTrees_Lines,
	'{F0380309-A375-4E72-BEF1-D983C80D0F8C}' : ServiceCallSolutionStatus,
	'{C50A9BDA-E5A7-4458-A7CE-0029E035B1B7}' : DepartmentsService,
	'{A7A2DCAC-BFE4-4CAA-B5D0-A337C4783C60}' : IDepartmentsParams,
	'{D435C006-B504-4847-B217-8AEA5439B779}' : IValidValuesMD,
	'{A177F24C-3E47-498B-9013-8CC3EEC13F78}' : IDownPaymentsToDrawDetails,
	'{A302DDF1-F725-46B9-8CC4-19E5766CEAC0}' : IBatchNumberDetail,
	'{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}' : IBPWithholdingTax,
	'{71AE6937-9F02-409F-93D0-869D4E6DDE9A}' : ITaxReportSeriesCollection,
	'{AF0F5509-8F7B-402A-A7D5-2AC98461825F}' : IServiceCallStatusService,
	'{431269A1-6E83-4195-A446-19D355C7E6A0}' : JournalEntryDocumentType,
	'{AECE9766-707E-4C6C-86BA-FD9ABE43B67A}' : CostCenterType,
	'{9E01385A-524C-4A76-87AD-9FF9058E0185}' : DimensionsService,
	'{38EFFD46-32F0-4190-A769-E13A5CCC3F47}' : IDefaultDocuments,
	'{C56982FE-CF84-47FD-9FE3-5E983ED0C419}' : DunningTerm,
	'{E5CFF30C-8D7D-4F36-A505-B2BA0EC0CB21}' : IReportLayoutsService,
	'{22F927F7-9B09-4F79-8D9E-564CB2047BCE}' : DistributionRulesParams,
	'{7444C348-853B-4932-924E-14D1314F9D32}' : Boxes1099,
	'{BABAB22E-0679-48A4-B7BD-BB0BF14F927F}' : IActivitiesService,
	'{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}' : ICallMessageArgument,
	'{3E8F0EBB-ED4D-4C8D-B14C-5012989DC570}' : ExtendedAdminInfo,
	'{A994F7F0-BF16-4C8E-B03C-74CE9EF2ECF5}' : UserFields,
	'{2E9D54CC-66FD-4688-9DA0-6AEE9C263D7E}' : IChooseFromList_Lines,
	'{224BFAE2-6275-450B-B64A-D6D8521EE697}' : MaterialGroupsService,
	'{748FD7AC-AA7D-4D4D-A206-8E5898BDF94F}' : DecimalData,
	'{EA7AF142-F7C4-4E1A-BA6A-B5DBFCB71C3C}' : BillOfExchange,
	'{A46D71C0-8C65-4B7E-BBA7-F6228CA0FE76}' : ICashDiscount,
	'{35E59851-3F5C-40B3-9613-BCC32E3B97B8}' : INFModel,
	'{29A116DF-AE12-4A45-A5F0-3436E170B26B}' : IDeposit,
	'{6AFDF201-9B72-4E70-B1B0-BECC5508D8FD}' : SalesOpportunityReasonsSetupService,
	'{50CED8F8-E378-4B24-80C5-FFF89AE44EC7}' : ServiceCallProblemTypesService,
	'{59DB637B-BF84-4D38-A0ED-1383F2556CA9}' : IPaymentBlockParams,
	'{A95C4C3D-71D5-475B-B6D9-BB75D22E1931}' : ISalesOpportunityReasonsSetupService,
	'{12696EFB-62EF-4BD0-9B7B-456F3999DAEF}' : IBrazilNumericIndexersParams,
	'{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}' : IMaterialGroupParams,
	'{7A1600FC-7942-4604-8D55-1923FF369965}' : IAccountSegmentations,
	'{7B951C46-49D0-4E0C-8832-48B62F4EF0BD}' : ICreditPaymentMethods,
	'{56F2B212-48C0-453C-9298-380C6F7350F2}' : ICertificateSeries,
	'{39DAE3AB-708D-4123-BC50-CC57F05D734E}' : IFinancePeriod,
	'{EAA25EB5-36C7-4AC8-936E-6AA6CF421FDD}' : DynamicSystemStrings,
	'{BCE76DC7-889C-4A7A-B77F-842FC7D0684E}' : IBrazilStringIndexer,
	'{7CBD5DDC-C99C-4D73-9ECC-C8B6CDF2FB92}' : IAddressExtension,
	'{681D8515-EF90-42C7-9463-3CE0B14E72C5}' : IActivityInstancesParams,
	'{80B626C7-6F5E-4C42-BBD0-36A311400BAE}' : IDNFCodeSetupParamsCollection,
	'{B9DC5AFA-1DC2-4BCB-B2D3-B84A889A9B0E}' : IServiceCallProblemTypesService,
	'{F9D49CC8-76E7-4387-AA71-ED03A361F510}' : IAttachments2_Lines,
	'{ED79A1AF-2F5B-418E-A90C-1F504B49E364}' : IUserKeysMD_Elements,
	'{16403B63-EB90-4781-9C89-05EF77769731}' : IDeductionTaxSubGroup,
	'{BF695196-36EF-4BEE-AEA9-AB35D9B40D22}' : MaterialGroup,
	'{9739A029-5EB0-499A-9E72-967B98D55ECF}' : ILayer,
	'{EAD60362-CE52-4064-BA2B-E76EA5297CB3}' : NCMCodeSetup,
	'{E73F2CD8-14C2-4BDD-AEB2-7D7DCFF21571}' : IBankChargesAllocationCodesService,
	'{539EA80F-E53D-45C1-9610-C1D138699EFB}' : IAccrualTypes,
	'{7DB5BDE8-AC90-4159-8B34-33A41A886FCE}' : AlertManagementParamsCollection,
	'{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}' : IGTIParams,
	'{63E62D10-4344-4575-9C8C-FCEE9779316C}' : Dimension,
	'{B829E078-BAC8-4EC5-BFDD-7F4230AE8BF2}' : IServiceCallTypesService,
	'{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}' : IBOEInstructionParams,
	'{C49DD31B-4B54-43B9-9E44-119635A4759A}' : CustomsDeclarationParams,
	'{B1AB765A-A1F6-4365-BC25-D0C63B496C77}' : IProjectsService,
	'{A93CD1FA-F12F-47B0-8FAB-859692B8A653}' : IServiceCalls,
	'{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}' : IChangeLogDifferenceParams,
	'{910426DC-C7C4-4EBC-8FB3-97BC2805C81D}' : IBOEInstructionsParams,
	'{3302B4B4-1F71-4D62-8D6E-85DEAB64B4EB}' : IWithholdingTaxCodes_Lines,
	'{6A5583E4-CC36-4360-982B-135BAD6BBFD2}' : ReportTypeParams,
	'{91C11377-CA6F-484B-9761-E7341517FD59}' : SerialNumberDetailsService,
	'{29A38C16-BE81-444A-B50B-6BAA2931CFC8}' : UserActionRecord,
	'{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}' : ICountryParams,
	'{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}' : ISalesOpportunitiesInterests,
	'{8C5A86ED-4B60-46EB-A0D5-9F529DDF069E}' : IPickLists_Lines,
	'{7DDA3A4A-07A5-43A7-885E-B34217076D17}' : IApprovalTemplates,
	'{EEC2D22B-97A3-4AC4-9823-7DBC2A9A1C53}' : BrazilBeverageIndexer,
	'{69A099F3-3B67-46A2-A4EB-6DC399C64078}' : INatureOfAssessee,
	'{FD7AA643-4DD4-4E5C-AC36-C0B782A6A3E4}' : ApprovalRequestLines,
	'{54E2DDD8-87FE-415D-AA8E-2AC62C936C7A}' : INotaFiscalCST,
	'{F9528D0C-E227-4693-B99E-E481C2B90BB7}' : CampaignBusinessPartners,
	'{6AA927D2-EF50-4064-AE3F-A65ADF1026B1}' : IVatGroups_Lines,
	'{84FAFD4C-5213-4CB8-9F2F-7FECB428F0ED}' : PackagesTypes,
	'{BD563FC1-66EC-4D79-AFF0-CB3057D01161}' : DownPaymentsToDraw,
	'{BA6EBBED-CE1B-4EB3-9B32-FE16126BFFC2}' : GeneralCollectionParams,
	'{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}' : IUserObjectMD_ChildTables,
	'{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}' : ICockpitsParams,
	'{7A54452F-A767-4700-B3B5-880084053C0C}' : ITaxCodeDeterminationParams,
	'{41A28682-1C73-4C77-ADC8-5F805700B244}' : IKPIParams,
	'{43CA4B0F-FF52-4C9A-9BB9-601CDFE3AD6D}' : ISerialNumberDetail,
	'{68D4BD48-09E9-4F7E-B8FC-43E3FA23F86F}' : VatGroups_Lines,
	'{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}' : IBOELine,
	'{B5196CD2-270C-42E8-81F5-735A99BECEA6}' : IDocumentTypeParams,
	'{04B4DCB9-A2CD-4C53-BD52-FA43B7754803}' : IItemLocalizationInfos,
	'{9AA94F66-6356-43C6-A77E-C638B796511B}' : IMaterialGroupsParams,
	'{871E4EA1-65DD-402C-AD85-7739F14D13F1}' : KPIsService,
	'{27A32FF4-4CC4-4D4A-860F-83E81EC52F3A}' : IDeductionTaxHierarchies_Lines,
	'{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}' : IActivityParams,
	'{44F97BA6-22A5-4687-BFBF-863A346A414C}' : IKPIsParams,
	'{A6DA575B-E105-4585-9F4B-50CC4044EEDD}' : IDocuments,
	'{03B794A4-682F-46BD-B17D-5373BEADF08D}' : AccrualTypes,
	'{BAEEDA1A-8CBE-4C07-B23A-CBC9BCE6AE37}' : IAlternativeItemsService,
	'{578B1918-60ED-440F-9729-7C59AEE459E8}' : BPFiscalTaxID,
	'{67D0EFEB-7047-4726-98B7-C60B83F0F98D}' : ITargetGroupsService,
	'{F09A4CB0-F8CA-4342-A44D-82DE3395B011}' : IPaymentTermsTypes,
	'{60A224F4-B8DA-4288-B9DC-1380D60DFD4C}' : KPI,
	'{D0D6E022-B36B-44E9-BD9A-24E3169AD532}' : IDashboardPackageImportParams,
	'{4B03F542-E836-450B-89AC-04E7609E6B35}' : IBOEInstructions,
	'{F675D408-2207-4E44-AE93-3BFDA7DE7CA3}' : IAlertManagementRecipients,
	'{259FA540-F962-4A5D-9BF5-E9772AF43A31}' : IBPCode,
	'{B139E51C-5D68-4216-969D-7511566847B2}' : BlanketAgreements_ItemsLines,
	'{49ABC0B0-082C-4F04-913B-199D08444440}' : ReportLayout_TranslationLines,
	'{6398CC93-68AB-4886-9C3A-0EAC9F5814AA}' : AccountSegmentationCategories,
	'{D2D6E703-7339-4D1A-BC4B-6BFF83622871}' : ISalesStages,
	'{449F96E1-0BA8-4C26-BD2F-DB0139B6ADBA}' : AccountCategoryParams,
	'{CC51470B-7859-4DC8-B636-E3856A52C02D}' : IAlertManagementParams,
	'{20C0F904-66E3-4784-965E-65FC991D8FE8}' : DeductionTaxHierarchies_Lines,
	'{1EFBEFDD-F21B-44B1-B275-3091E89031B7}' : Document_Installments,
	'{2DC337EF-DA9D-4A0B-AA09-34795D4CA674}' : ApprovalStage,
	'{3B3E22F6-114F-4F15-9864-319ABBEF75EB}' : CashFlowLineItem,
	'{1FE6EEB5-6D21-4EE0-AC7C-8A2B181080C8}' : ActivityLocations,
	'{094BA05B-B730-4D86-8BCF-91F788C16057}' : ActivityTypes,
	'{9048203E-CE84-4B53-B4C7-61632BD2DEAC}' : IItems_PreferredVendors,
	'{D68B336E-19AF-4033-8308-BA6A03D3C535}' : BankStatement,
	'{BE8AA2E1-EFFD-4AD5-AC95-47CB1C20BA57}' : DefaultCreditCards,
	'{8FDEBBA0-2EDA-4AFE-9EC1-3A45913C68DA}' : AddressExtension,
	'{BC55E0FC-ADC0-4DF6-9F2A-5CD35E4F5A75}' : INFModelsService,
	'{979EB99E-C8C7-4558-ADF5-DCB1BED01451}' : TargetGroup,
	'{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}' : IApprovalTemplateQuery,
	'{0B6BCB38-6594-4EAB-88A8-5EEB856FF1EB}' : Field,
	'{717F1B41-306E-4695-8F4E-7DACA54EA87B}' : SalesTaxAuthoritiesTypes,
	'{49836643-1102-4273-B5DC-F4ADEC94D843}' : IExtendedTranslation_ResultLines,
	'{B83BBBFA-E5AF-48B4-B147-2DE092BF1E64}' : IHouseBankAccounts,
	'{A59ECD2A-FD2C-47A5-8D59-BD3410E5E408}' : ServiceCallType,
	'{F183C834-5321-46B5-96B6-0BC50D1726E8}' : IChooseFromList,
	'{2C4B93F4-860D-481D-85C5-020876095197}' : IFIFOLayers,
	'{5F2AE736-E6D3-4D3A-BCB5-F9EE3A45872A}' : ItemGroups,
	'{B25EF557-1E57-4CA8-BDD3-B2AF96815278}' : IBOEDocumentTypesParams,
	'{36EA48A3-B828-45D8-B5E2-AE3584E54AE3}' : IBPPriorities,
	'{061EDFD2-1326-4FC7-B95A-CD30593B6448}' : DocumentPackageItems,
	'{6AAAB602-C1E1-4988-BF5D-ECE369936FC0}' : IExtendedAdminInfo,
	'{475F9BBF-F860-48CE-8FD7-71E461BD7D95}' : ISalesOpportunityReasonSetupParamsCollection,
	'{EEA5B4B4-F1E5-4CC2-9514-C80EE92DF9C2}' : BusinessPartnersService,
	'{5004E453-F544-4559-BE4D-76D7C6E1278C}' : UserLanguages,
	'{A67C6121-4F92-41C5-9517-38E9D760A0C0}' : DefaultReportParams,
	'{E7838784-BDDC-4EC2-A812-C96B19D169C5}' : IBlob,
	'{1BB54C50-66D7-4907-807C-92F58119C21D}' : ApprovalStageApprovers,
	'{45CD0988-1275-4D2C-BF2C-5D04CB984489}' : IBrazilFuelIndexer,
	'{FC78A30F-5B21-4311-B9C3-7C684E870590}' : TaxCodeDeterminationsParams,
	'{6140412B-302D-4CC8-9B65-4D554892B2FF}' : SeriesService,
	'{4CA3F302-7EC4-4514-9F07-CB688C56A2ED}' : IFinancePeriods,
	'{8BC443FC-F05C-40F1-A27E-BCCB4A568CB2}' : BlanketAgreementsParams,
	'{F8DE7AAE-13BF-46BD-A4B0-CD9535AAED63}' : IDunningLetters,
	'{9B1154A7-0B01-4FF6-89F3-9A601676D895}' : GTIParams,
	'{93E5E52B-181E-46B8-96CB-1C066AC04DCA}' : ISerialNumbers,
	'{31341DF9-0A1F-4B75-BBAB-50B96478E579}' : ChecksforPayment,
	'{741AA803-AB33-4FD7-B664-63116291D6CE}' : IBillOfExchange,
	'{3F0B1146-0F25-4198-A84C-BBA0CEB0FACF}' : BrazilNumericIndexersParams,
	'{EE480268-BD9E-4DD2-8BA2-BBB3C9665448}' : IAttachments2,
	'{3026EE2A-44C8-433C-AE19-0C9EBD1C6285}' : BPCode,
	'{457F56A9-7F85-4ABF-91A4-5384A0CED40C}' : WorkOrder_Lines,
	'{A7420F65-B537-47B4-870C-CE7E3D98CB29}' : ActivityParams,
	'{687B84CE-D196-49C9-A617-C6FC57BB2204}' : ICostCenterTypesService,
	'{D50B349A-0226-4D72-9FEC-B38D21C65FE0}' : IDimensionParams,
	'{65307EF1-BD5A-4297-B9F0-7F957D7CC0FC}' : HouseBankAccounts,
	'{6B52A2CD-C166-404E-9A92-A0D4B812488A}' : ISalesOpportunitySourceSetup,
	'{A64105B1-0FB5-47EA-852E-A9975E5A5722}' : PartnersSetupsParams,
	'{DF63C280-18C5-4444-BDAF-59318E9ED979}' : IGTIParamsCollection,
	'{4DC9AE34-8FF4-4900-8021-D641EF898358}' : IServiceCallProblemTypeParamsCollection,
	'{0362FE87-4255-455E-A6C8-A356C252767B}' : BatchNumberDetailParams,
	'{9C192F0B-809E-4115-B560-3D683C99D48E}' : ILegalDataParamsCollection,
	'{2A1B975B-3697-472C-A9AA-57B400510C93}' : SalesOpportunityCompetitorSetupParamsCollection,
	'{58FCDC2F-A0BF-4211-A2F9-D21C0E13AEDF}' : BrazilMultiIndexerParams,
	'{0C607D21-E148-42CE-AF58-E8C38EB26275}' : IUserObjectMD_FormColumns,
	'{A46D497B-B625-4043-B6E6-988E544336BE}' : CashDiscountsService,
	'{4B445959-4085-4FCE-8832-58AD489D81D1}' : BOEDocumentTypeParams,
	'{DFE5A4A8-345B-43B3-A77F-906F10F142EE}' : IFactoringIndicators,
	'{B9DE72FD-C04A-4585-9850-73B6E3E58ADB}' : ApprovalTemplateTerms,
	'{84119864-5879-482E-ADE4-D1C839F40BCE}' : JournalEntryDocumentTypeParamsCollection,
	'{C02B3449-252C-42AD-A6AA-05513188EA84}' : CurrencyRestrictions,
	'{B148F7EE-7416-4B22-B266-55321DF794D8}' : IApprovalRequestDecisions,
	'{ADFCD5D9-B501-4CB5-892C-61FE7FB225B3}' : ElectronicFileFormatsService,
	'{F31F3841-559A-4CF2-B26C-17AA566FA21F}' : CreditCards,
	'{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}' : IBPFiscalTaxID,
	'{C0E3FD16-7EC1-462F-BF9E-5524665C2E22}' : BOELinesService,
	'{24AD49CD-DD3F-42CB-B745-5D6329BD0EDA}' : Banks,
	'{360A35E4-0B22-4324-AA42-9DF442E64379}' : TaxReportGroup,
	'{EA19AA7D-6063-4C86-BC1C-27B0572209ED}' : IRetornoCodesService,
	'{EE5CC625-8EC4-42A3-B9A2-53B254F222DB}' : UserLicenseParams,
	'{7DCD3C0C-6B56-4572-8015-8E4CC744A095}' : IBankStatementsImportFile,
	'{32E2CAC3-EEFA-4C2B-B916-C43A8A39BEAE}' : IMessage,
	'{C4DCA924-9189-4969-8609-8564D6E5AFAA}' : IMessages,
	'{E1CFA100-9492-4B13-9AB1-4980DEC2DEB5}' : TargetGroupParams,
	'{4FE2A366-A423-4720-967D-4227EC04B8DE}' : FIFOLayers,
	'{B7DDAC79-1287-429E-B0C6-8D09A8F6A043}' : ServiceCallProblemTypeParamsCollection,
	'{62CDCF16-DA97-4440-AED9-3C1FB8C60D4B}' : OccurenceCodeParams,
	'{746B0E89-0625-4B20-BD67-029DB26D074D}' : IBOEDocumentType,
	'{5E6A92D1-9BAB-4BB4-A379-2428006247C3}' : IChecksforPayment,
	'{F41E89FB-D3D8-47BE-858C-332AC9DF8A86}' : IExtendedTranslationsService,
	'{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}' : IApprovalTemplateUser,
	'{91CC17DA-3F2C-464A-8060-8338ADD207DA}' : ItemProperties,
	'{C3B4DABB-A057-4D70-AE0C-7ABD7A4254B0}' : SalesOpportunitiesReasons,
	'{9D202A0D-3D49-47E0-AC0D-90333C553E85}' : ICompanyService,
	'{C397C564-B506-4649-9C12-E4B63BBD7711}' : Messages,
	'{38DFDAC8-1F86-4E1D-9CDE-00425A5143BA}' : EmployeeTransfer,
	'{494EAB50-0ED0-4773-8BCF-9F769A80B6BC}' : ItemWarehouseInfo,
	'{4735E037-68A6-474D-AEC5-F5D9BD3B09A6}' : IBrazilStringIndexersService,
	'{02F225DD-827F-4065-BC4A-14D5F4136D28}' : IBPAddresses,
	'{3D83A354-89D4-46AF-841A-D659A0C2678E}' : IColumnsPreferencesParams,
	'{A6D332DA-630B-44C7-AA91-69F2C1A2501D}' : IQueueMembers,
	'{3FE3132C-CA33-4338-A4C7-140952E59D31}' : PathAdmin,
	'{7E723574-58DD-46D4-9856-44426EE523AE}' : IJournalEntryDocumentTypeService,
	'{5077C7F7-E950-40A4-9A0E-71CF776AE79F}' : IDashboardPackagesService,
	'{9D3B180E-A24C-48C9-A742-093663FF1878}' : Fields,
	'{FA50FE8D-9DFF-44CD-A0D2-6FE8315B2393}' : ApprovalRequestsService,
	'{93CF87D1-95CB-459C-A906-729819461CA1}' : ICommandParams,
	'{7B677F06-BB36-462B-BABF-99676A90BC70}' : ICashFlowLineItemsParams,
	'{CE2AC3A6-339A-4F3B-9C70-600FC4A6F2DE}' : RecipientCollection,
	'{9AA8D14C-3AB3-44F0-BEDD-0AB156BD2A9D}' : ITaxDefinitions,
	'{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}' : ICampaignBusinessPartner,
	'{22DCA799-2F7B-4B31-ABB6-74F3C07CB367}' : ContactEmployees,
	'{54B31C27-C3D0-41DE-89BA-5E8800D0361D}' : IWizardPaymentMethods,
	'{20971C52-C8A9-4B34-B882-A2B3D0826E32}' : DashboardPackagesParams,
	'{3B62767B-45B8-4997-B249-F989A0C4AB8E}' : ApprovalTemplateQueries,
	'{C09C1DAE-49E3-43CF-AA54-D2EDDCAAE9DB}' : ICostCenterTypesParams,
	'{CB6D5BD6-878B-4966-9E6B-8599949B657F}' : ICallArgument,
	'{2FCB8823-03A3-47F9-BC0B-EEC815138967}' : EmployeeTransfersParams,
	'{53062C45-E05A-4717-909C-3C3073E10DDD}' : IBankChargesAllocationCodeParams,
	'{E8F14B2A-6381-4A84-8BF2-A4DA70A9F684}' : ReportLayout_TranslationLine,
	'{5EE41EF0-1319-400C-807D-7CAA21FBA466}' : ITaxReportGroups,
	'{F29A5E07-7C8B-4706-99D7-9BFB85180358}' : IProfitCenter,
	'{9B92292E-B9FD-4317-B7FA-5E1BD04C8697}' : Series,
	'{3DAD979D-9F98-4BBA-8566-7789FD6C8615}' : OriginalItem,
	'{51090998-B57D-4A0B-A634-4664FE76FA57}' : BusinessPartnerPropertyParams,
	'{BF84F083-2917-4B14-80E4-3333A08C7073}' : MultiplePayments,
	'{D154A6C0-19F8-46CE-B66D-FFC856FC0310}' : IApprovalStageApprovers,
	'{FEC77FB3-300B-4F11-9931-7BAA71C9EB9A}' : PredefinedTextParams,
	'{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}' : IBOEPortfolio,
	'{E9B749CA-045B-4BDD-A5BD-143458EBA752}' : Document_Lines,
	'{28C5094B-E595-4D16-BB84-07C23357EDA0}' : PartnersSetup,
	'{6D6214D8-5ABD-4DAD-9F9C-E2F69EFEBA8D}' : AlertManagementParams,
	'{E4B8D471-9672-41D7-B340-E8DF455FE90D}' : ApprovalTemplatesService,
	'{EE8E76CB-5ABF-4220-B5A9-DC11A34F042F}' : ApprovalTemplateUsers,
	'{B18C2498-6343-4620-87B9-6C298AE9BFD9}' : DashboardPackageParams,
	'{31DE5655-438F-420E-83D0-016C88203706}' : IGeneralService,
	'{308CD5F0-5908-47B2-BE56-A1104C45FCF7}' : ITaxReportSeries,
	'{2E43D661-7B70-4889-95E8-63B49DF0CDFE}' : NatureOfAssessee,
	'{EEDDBCFE-7934-4DE6-9B67-F43B454D3336}' : ReportTypesService,
	'{303AD037-92AA-4508-8FD3-08C4A6D4CFAF}' : BranchesParams,
	'{9A38EECB-D61C-469C-9425-C66BAAA0623E}' : NotaFiscalCFOP,
	'{D1DD9101-9264-450A-9FAC-C9D899078775}' : ITaxInvoice_Lines,
	'{1C59C249-B65E-472F-80BB-EE0A05F75666}' : UserObjectMD_FindColumns,
	'{E60CDE47-FBBE-4719-BCFF-022E70710702}' : ISalesOpportunityReasonSetupParams,
	'{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}' : IApprovalRequestParams,
	'{1569ABCE-0AFF-4A64-9558-9B23DE1B0512}' : LandedCostsParams,
	'{4D2FFFD1-12AF-439B-9E32-049F24A661D8}' : MessagesService,
	'{73042DE8-A510-4C53-B256-FD249BA13723}' : IDiscountLine,
	'{046161D0-6736-48A3-A619-805A9C68F5C1}' : IAccrualTypesParams,
	'{18B4A57B-206A-4CF7-B94B-7325AED96137}' : IAttachment,
	'{7615E097-E207-4E8D-A114-74031034136B}' : IWorkOrders,
	'{C1A276C6-FD68-4693-8D70-D9A7A3E69712}' : UserObjectMD_FormColumns,
	'{DF517030-9004-4965-96A3-CFE398A79DDC}' : IBusinessPartnersService,
	'{0C610415-1BAF-4B92-B485-23D9F3E5AA9E}' : WorkOrders,
	'{E962CD81-105C-4E61-91B8-A86AFE748209}' : IBOEInstructionsService,
	'{78A66A76-1B6F-44EC-B0FD-5C5CDC2752F4}' : CashFlowLineItemsParams,
	'{5923A153-B41F-4676-A5B6-1FAD645FDD7B}' : IDefaultCreditCards,
	'{8ED60CF1-3116-4C89-A77D-B67ED48F2F22}' : INCMCodeSetup,
	'{55ACC8CD-3412-452A-9AF8-304A0A56FD3B}' : IUserPermissionTree,
	'{EBCC9023-5BC9-4CA8-B28F-24E4E60F0965}' : ShowDifferenceParams,
	'{297C40ED-92B6-4DB9-9304-CF9350F3FE8C}' : ApprovalRequestDecisions,
	'{661FDCA5-1B1D-4EBA-8DC9-EB75F2E506AD}' : CommissionGroups,
	'{F574C00A-3CAE-4269-84D7-E77A6237CAE0}' : EmployeeIDTypeService,
	'{874D0559-C968-49F1-9562-E57E493A47AB}' : ICreditCardPayments,
	'{70DC39C1-4019-4618-9D1F-7D227A68491F}' : IAccrualTypeParams,
	'{89BD7B04-5C1F-41DC-8B8C-4F8CFFA716CD}' : StockTransfer_ApprovalRequests,
	'{1470A4FE-6338-4FC7-AD95-D6E2CB4DBB20}' : INCMCodesSetupService,
	'{E8DA612B-3A4E-4186-B127-DAF785480B47}' : BrazilStringIndexer,
	'{3932D717-09BF-4109-BDBB-CBF31DEF5E34}' : RetornoCodeParams,
	'{9E37320F-F058-462C-9483-AD67BC65191B}' : IState,
	'{E5EB0192-6BCF-43FF-94E7-8A17C7F6B566}' : IDistributionRulesParams,
	'{216D15B1-8639-435F-8C85-4967488AD161}' : IApprovalTemplateDocuments,
	'{1C7C966F-B713-42BF-9A74-0B15A649E63D}' : IProductionOrders,
	'{2DC3C9A3-A237-4DB3-A0BC-AB92D24ED68E}' : IReportTypesService,
	'{EC78D9AA-6CA6-427C-9D33-38A4EAD168AB}' : BOEInstructionsService,
	'{069837FF-A1F4-4442-92EF-DFEA56C23992}' : ILandedCost,
	'{C1F83FBE-3A3F-4A81-8B0B-B5485DC6ADF9}' : IBudget,
	'{6155B8DA-5812-48F9-8955-67CE75857600}' : Payments_Checks,
	'{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}' : ITaxJurisdictions,
	'{B9A56422-93A0-4480-BAF3-48907F403CB8}' : IJournalVouchers,
	'{A9FD63E5-C131-4554-975C-7D8C5C0A2A0A}' : InventoryCycles,
	'{A0B604D4-3D7B-427D-9EA1-15456A2329BD}' : ICertificateSeriesParams,
	'{400500D2-38E8-4EB9-9C7F-1843B8D2ED20}' : TargetGroupsDetails,
	'{1CBABC7A-347F-48EA-A6F6-FCA17C04A159}' : BankChargesAllocationCodesService,
	'{EC084090-ED29-4B85-BAF8-8058B245EA06}' : IUserBranchAssignment,
	'{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}' : IField,
	'{A0F06FB9-C420-4CA6-B1A5-D688A5322E8D}' : IJournalEntryDocumentTypeParamsCollection,
	'{35CD3214-7F63-4C98-8969-E1D83791B7BA}' : SalesOpportunitySourceSetupParamsCollection,
	'{163BF46A-64A8-4757-A11B-B7958797CC85}' : TaxCodeDetermination,
	'{80E28887-F468-4172-9043-D442BCAB1F55}' : IBrazilBeverageIndexersService,
	'{09C6E920-908C-4FD2-9CBF-21C3F4329A33}' : ITeamMembers,
	'{A9C6DFCF-1FFD-46AF-89FC-5618ECAF2441}' : BOEInstructionParams,
	'{120471FC-3B19-4A4B-89DB-8999A7439A3C}' : TaxReportFilter,
	'{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}' : INFModelParams,
	'{6F959012-2D32-4854-814C-4B0B89621EE0}' : KPIsParams,
	'{4B310591-7DB5-48EE-BB34-A2F954D41897}' : BankChargesAllocationCodesParams,
	'{12980E2B-036E-4D5D-90F9-44383341DF63}' : ICountriesService,
	'{D2BAB599-C7C6-4301-B925-B6BB51092A79}' : IBudget_Lines,
	'{E8632E10-873F-4EBF-8339-E57C985D4472}' : IGetChangeLogParams,
	'{E57AA648-0ADC-4146-A01E-19E0AB5C0A2D}' : RetornoCode,
	'{FACA7A4B-46DF-4875-8591-A5A0C3D9761F}' : ICostCenterTypes,
	'{481D2A59-9B17-4C56-B245-04F85EA1C74E}' : ISalesPersons,
	'{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}' : ITargetGroupParams,
	'{0207412D-F955-46BA-AE96-E749573B4106}' : IServiceCallActivities,
	'{DB836AB0-9F22-422C-BA3A-873208689C81}' : DashboardPackagesService,
	'{77C5B820-63C3-4825-9279-964224F7BE00}' : IReportLayout,
	'{FB0CD2F1-E744-4CC6-8D1C-9A9ED9F533F1}' : ApprovalRequestsParams,
	'{5FE3FCA3-E93E-4106-8190-F62CB9FBF137}' : IForms1099,
	'{B7BB4C0A-4CE3-494B-B928-AA94004B0866}' : TaxReportAccounts,
	'{4600E0D8-E8C5-4CC3-93CB-68DB78774B44}' : CashDiscountParams,
	'{94BACBC3-E916-4D1F-9469-F7F44F8E39F0}' : TaxExtension,
	'{41172218-C619-4E35-9D03-59EAF1E0F300}' : BatchNumbers,
	'{1D2BD23C-C2FC-447C-B63E-4D4A321ECEED}' : BankStatements,
	'{D7CA14AD-9A60-48D8-857B-441F3102B1AC}' : BankChargesAllocationCode,
	'{D6BF90B4-5DE1-4A71-8463-FEB7AB1A9AB4}' : IInvokeParams,
	'{598819B6-D5B0-4CF1-A533-D966C1D9267A}' : ILegalDataService,
	'{215A5610-7BBC-4D8A-B41F-33EF4BFBEF9F}' : CampaignsParams,
	'{E25C76F1-5CE3-4001-AAD4-525D50E4C294}' : RetornoCodeParamsCollection,
	'{74490BE7-8344-4F48-90C9-2A811E54AA49}' : IServiceGroupsParams,
	'{BED262F2-5DAF-4D1B-91C6-B5DCABE54A90}' : ISalesOpportunityCompetitorSetup,
	'{797B09FC-E40A-42FA-9045-30B351D937F1}' : IAccountCategoryParams,
	'{63F3E235-30B2-4C42-8A9A-5953779F0C4E}' : DiscountGroups,
	'{C29BB9BD-1EC7-4427-A484-E79EC58F7224}' : IFinancialYear,
	'{5016BA26-6D6D-47B7-9B13-558EC0B1B916}' : BOEPortfolioParams,
	'{4DB4395A-231C-4BE3-B582-F6C7C70D109E}' : IPartnersSetup,
	'{DF69751C-704D-47C1-87DC-0F7D074BC516}' : UserDefaultGroups,
	'{A93138D1-7360-49C9-8F1C-EC5239C494B0}' : ICampaignPartner,
	'{8DCD076F-BF30-45C6-822A-B23FDA1B37F5}' : BudgetScenarios,
	'{8FA3D085-7415-4301-8262-C977EB250400}' : ReportType,
	'{04305B71-95D2-4327-B7A5-ED12DFB5FB1B}' : IOccurenceCode,
	'{8C6FB6CA-693A-4647-9F88-B0427A245D60}' : DepartmentParams,
	'{6749C3DD-5643-464C-82AB-CEE67CC78C9C}' : OpenningBalanceAccount,
	'{5764FA3D-17B0-4CDC-80CD-6D6BB2ED446F}' : ProjectsParams,
	'{AFB12D1C-F0C3-4FA6-BF53-CA858C1BE796}' : ShippingTypes,
	'{0247151C-E23B-4C8A-B5BB-3BC1203A04EC}' : ExternalCall,
	'{27D88079-2713-4D2E-94D4-3C6F14D18140}' : INatureOfAssesseeParams,
	'{0ED256A5-4119-4245-A961-A01AD0134E4E}' : IBusinessPartnerPropertiesService,
	'{F510FF2B-D307-487F-9ECC-EE436A6EBF10}' : IStockTransfer_TaxExtension,
	'{A2120F6A-992A-4AAE-A98B-F573035921E8}' : UserKeysMD_Elements,
	'{2795C6A1-A943-411B-BE58-A062A0E4711A}' : BPAccountReceivablePayble,
	'{0C349981-9E5F-4814-910B-8995D5E9D32E}' : IDimension,
	'{B1D15948-E323-4C52-BA55-70E0678549CD}' : IElectronicFileFormatParams,
	'{E2AABE75-E867-4BE2-8E09-AD1EE61C62BC}' : EmployeeIDTypeParamsCollection,
	'{C083AAA6-1496-4E5F-82B0-201194FD8651}' : IBlanketAgreements_ItemsLine,
	'{68FA6F71-028F-434E-AAA4-32B8BBB67CC4}' : ITaxCodeDeterminationsService,
	'{24464254-073D-4148-A045-3CFDB71DE48C}' : IUserPermissionForms,
	'{97C9DB0B-4DBF-4EEA-98A9-04EE1F5B031E}' : SalesTaxCodes,
	'{2C6522F2-47AE-4707-B34C-A4973216808E}' : EmployeeIDTypeParams,
	'{161C44B9-9DAC-4D31-AB92-EED776B8C745}' : Contacts,
	'{94DA073B-4599-4BC9-A22B-87D912159247}' : BillOfExchangeTrans_Deposits,
	'{1F27E785-8D39-4E94-9022-6EAF45962D86}' : ServiceGroupsParams,
	'{0D5D4022-6FCC-49A4-AB69-7F4304B47EC9}' : DataBrowser,
	'{1CFBF8AA-ED92-4452-9DBE-4E8BCA68731C}' : AlternativeItemsService,
	'{877ACA0D-FA03-41F8-8B84-E4090B053532}' : BOEPortfoliosService,
	'{A912A61F-CCFA-450D-9B6C-CA22F88D1FE8}' : UserValidValues,
	'{5CCE45B6-F63F-4CEE-9FF8-F05F0943C696}' : SalesOpportunityCompetitorSetup,
	'{1678F2A9-8FBA-47E8-A678-FE06A7D22007}' : IEmployeeTransfersService,
	'{C7DF4768-56A6-45D9-9C2B-916008846E76}' : IProject,
	'{D48A6D0F-F063-4ED4-B1E1-59B6998EE91A}' : SalesOpportunitiesInterests,
	'{4E6D1836-16F8-4D8F-9BF8-0271F4856450}' : Industries,
	'{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}' : IWorkOrder_Lines,
	'{CB4596BC-49AF-40FF-AF45-DC92A9C75C97}' : IFeatureStatusCollection,
	'{AF74F44A-F8C1-4A3E-B390-01D61430ED8A}' : DeductionTaxSubGroupsParams,
	'{BD849811-3C0D-4850-8E56-26C12823E15C}' : ApprovalRequestParams,
	'{6C123256-BF67-4AA6-BE6B-4C085AB0731A}' : ISalesOpportunitySourceSetupParamsCollection,
	'{63A44BC7-2798-4F4A-B0C7-B407EA917702}' : ITransactionCodeParams,
	'{AE9073B1-59FF-423E-B562-BEFE747D2D5C}' : Attachments2_Lines,
	'{AC935452-7934-4093-810F-D66BD350A247}' : ISalesOpportunitySourceSetupParams,
	'{A22E33CF-C423-4581-8C7C-382E5D59B301}' : IPredefinedTextsParams,
	'{7424993D-6DC0-48E5-AEEF-B10A3177E175}' : IAlertManagementService,
	'{174DC159-9A9A-46AC-9A78-EAA35119F267}' : CountriesService,
	'{B4F1CCC6-85B4-48D1-9E4D-E068CE6D681B}' : AccountCategory,
	'{07E15DBA-2CB3-40D0-BE23-686EBE7F192D}' : DistributionRule,
	'{AE08D2F8-6EBB-42BA-9226-FD68AC457294}' : ChangeLogsParams,
	'{2704D884-C30C-42FF-8D33-D1D7E3FE039A}' : ApprovalRequestLine,
	'{C636E409-2B25-451B-90CE-B34F4C700180}' : ApprovalTemplateUser,
	'{BD51601F-CF1B-4F4E-A99A-A8642C241815}' : BrazilStringIndexersService,
	'{DFED3449-35B2-4A0A-B789-20EE627AE347}' : BOEPortfolio,
	'{2647D070-305A-43E8-89AE-B4D2C41E5168}' : IBankStatementRow,
	'{F0C0A764-0170-479E-BEA9-152989FB0E55}' : NFModel,
	'{AC21F36A-556F-4374-AAB0-96949C7469FF}' : IServiceCallOriginParams,
	'{8EDBEEE5-B0AB-4400-889A-851F0F74FFEF}' : LandedCost_CostLine,
	'{B11BE4C5-0512-4150-A932-336EBF71547F}' : ReportLayoutsService,
	'{8080167A-3150-4B5F-8108-9BE2FA9DC31B}' : IEmployeeTransferParams,
	'{0D446022-9A79-4535-9174-EEAE21DF924A}' : ISalesTaxAuthorities,
	'{B69F1DD8-E760-42A1-8E55-C7078C936DB5}' : TaxReportSeriesCollection,
	'{4AFE074D-4F31-4E7B-87DF-64D55098DA5E}' : Documents,
	'{33A595E0-A668-490E-8D9F-5BBD94927FDA}' : ServiceCallStatusParams,
	'{978E2893-F916-456D-B318-0BDE27B4246E}' : Section,
	'{6499CEB7-4CF2-48F6-93B7-93C949DBA246}' : PeriodCategory,
	'{B551C968-0DE9-48FA-B48D-385284294F16}' : IFeatureStatus,
	'{C38D34A0-DA36-4B9A-9211-21F9228EC20D}' : ISalesOpportunityInterestSetup,
	'{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}' : IExtendedTranslationParams,
	'{B8FFD2FD-01A8-404E-995F-B7C004675ADB}' : SalesOpportunitySourceSetupParams,
	'{FD7ECEE2-5FA5-4054-9769-B86A8096D9BA}' : BOEInstructions,
	'{AFFB904C-0D52-4359-B44B-FB594DC5618A}' : INotaFiscalCFOP,
	'{0561126D-01CD-453B-A5FB-6AC3C11E05D5}' : ElectronicSeriesCollection,
	'{F1E88ED4-1F91-4FE5-B4EB-13B48CB46F52}' : IBudgetCostAccounting_Lines,
	'{E0718E09-A6F5-4221-84C5-EB8A28F4F741}' : ApprovalTemplate,
	'{6CC3E1D1-D934-46CD-9DAD-33C30A06CA1C}' : FinancePeriodParams,
	'{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}' : IUserTable,
	'{8D158412-BA39-4046-8326-2E22EE49F8C1}' : EmployeeEducationInfo,
	'{17F42A0A-DF72-432D-9953-1993A831A197}' : IEmployeeIDType,
	'{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}' : IRetornoCodeParams,
	'{B7A80F7E-77C0-404E-A8B3-01D0F9136DCF}' : ILocalEra,
	'{AA5DB4F6-0C6C-4453-B5C5-EC21CBC719A7}' : ApprovalTemplates,
	'{7FD8CD14-6E6B-4B4F-801A-0155E5389896}' : TaxReportGroups,
	'{BC177C74-40FA-4140-8374-ED45F9FCFF87}' : ISalesOpportunityInterestSetupParamsCollection,
	'{D562FBDC-788B-4D80-B9EB-9238CC4EF91C}' : TeamMembers,
	'{77B8BCD1-46B3-41EF-92DD-F1F6680159DA}' : Deposit,
	'{DAB0264E-58F1-4024-BA03-EE55FE4BB12E}' : BankStatementParams,
	'{6EA82155-C282-4F2D-90C4-BF6F95269228}' : IBOEPortfoliosService,
	'{C8A713C7-A32D-46CC-87FC-EF65827B1E49}' : CallArguments,
	'{052A6BA1-A1AA-4A04-ABDE-23FE11833711}' : ILandedCost_ItemLine,
	'{11FA87EF-9F44-4528-AE1D-DAF92AEA3545}' : Recordset,
	'{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}' : IBankStatementParams,
	'{4A1DF035-9612-4CCC-B9B8-C58511D0D705}' : BusinessPartners,
	'{3E6CC39D-A5A5-43E7-856E-4A1D4D97A77D}' : SalesForecast,
	'{8018B387-2D98-40E1-9983-365221335839}' : SerialNumberDetail,
	'{C9379AB8-CDE2-4A35-99CE-DB1CE9D7950E}' : IDefaultElectronicSeriesParams,
	'{43885104-EC53-4FF2-965B-BA783636A33E}' : Layers,
	'{F7CB66FA-3F53-4B0F-818C-259C599CFE15}' : BOEDocumentTypesParams,
	'{82C83910-6247-4BFB-AAE2-C9AD27B1947D}' : IApprovalTemplate,
	'{FFDDAD10-AEC3-4717-B909-2C409EA9859E}' : AlternativeItems,
	'{16E2EB82-A981-4E4F-A378-6D4E53B17134}' : IServiceTaxPostingParamsCollection,
	'{A2EC2F58-8237-41EC-94A1-89BA109C8EB9}' : LandedCost_CostLines,
	'{B133843B-6DB2-4920-976F-1C7EB0AD60A2}' : MaterialRevaluation,
	'{AA803CCD-C262-45A7-B9C6-FC034D4938CE}' : ApprovalTemplateTerm,
	'{2C1751BA-5CFF-4E47-8C1E-13CAF241A13F}' : ISpecialPrices,
	'{458A15A5-B980-4543-A289-F6477A36EB24}' : IWithholdingTaxLines,
	'{5D29B8B0-A8BC-4905-B713-7DE4207A130A}' : IServiceCallStatusParams,
	'{44AB2C0B-390B-43A1-8BCD-529BA39C52C3}' : IProjectsParams,
	'{01EC1A1A-17D7-4A77-BCD5-2AE1B2FE4385}' : DistributionRuleLine,
	'{7FDEAE23-7D23-4F12-BA4A-02E65FD9C534}' : ProfitCenterParams,
	'{A0307CBF-64B1-49E8-B60D-38803E20D107}' : ICashFlowAssignments,
	'{8E861D67-6E55-4201-9AE5-F193127E6F67}' : IDocumentPackageItems,
	'{A574B4DA-F87A-414B-AC49-ED8C6BF84B2C}' : EmployeeAbsenceInfo,
	'{C81FD047-A4A2-4EF6-9538-65D9F381CB03}' : CostCenterTypeParams,
	'{2FC28FB9-7376-41BE-9CCE-50FCB69D8ECF}' : BOELinesParams,
	'{9A96D2E9-0308-433A-AE8B-417FE4AD66D3}' : ICertificateSeriesService,
	'{7178EF0A-1740-4B4C-89A2-779BB1E618D9}' : FactoringIndicators,
	'{AB7947CF-8191-498D-8B3C-8E04A00957E7}' : IPayments_Invoices,
	'{029D7691-D339-4790-9D8A-652C86A30458}' : IPathAdmin,
	'{3F5CE8F3-380C-4E97-A303-342EF66DE0DC}' : CheckLinesService,
	'{86A368F0-8603-466A-906F-9FC811B1B711}' : IReportLayout_TranslationLine,
	'{F68150E3-371A-4D4F-990C-16CDFF1A04FA}' : AdditionalExpenses,
	'{269D9A4D-1866-43A0-B5AB-B46035B1667F}' : IStatesService,
	'{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}' : IBrazilStringIndexerParams,
	'{F59180EC-0D39-40F6-894E-3444F552732D}' : AlertManagementRecipient,
	'{EC857C0B-EFEB-43D5-92CF-8EFAC1D138F7}' : CreditCardPayments,
	'{4A2F8C9A-04AD-4CBA-842B-54BCF3927A35}' : IServiceTaxPostingService,
	'{7A1326F7-9545-4AAC-B875-C317CF7D76B4}' : SpecialPricesDataAreas,
	'{35CF9AB5-A66B-46EC-805A-E5192414BD4A}' : AlternativeItem,
	'{BD9CCFD9-ABF6-4596-AD04-363D8046FAA2}' : TaxCodeDeterminationParams,
	'{60288E22-2FC1-402B-80FE-04D66413E1A0}' : ICashDiscountParams,
	'{BFFF366B-1B1C-4EF6-8546-27C9BFF735CE}' : IPredefinedText,
	'{F6964AD5-EB4F-4E38-824E-60026EA9F159}' : IPaymentBlock,
	'{A52ED4BA-1C19-4553-9A60-D69B653E8CB5}' : Payments,
	'{E944AF70-E7E5-4414-833E-A62BFCF9EA65}' : UserFieldsMD,
	'{38FD1577-2135-4D5F-A037-E5388B413F83}' : IMessageDataLines,
	'{0104D235-3B56-47AF-ADEE-352BA7538035}' : AccountsService,
	'{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}' : ISalesForecast_Lines,
	'{04C582B6-340A-4E71-B18B-460A37A04A62}' : Manufacturers,
	'{D4A7CE6F-B909-4273-8499-C210F94ED2D1}' : ISalesOpportunitiesReasons,
	'{16209A8A-D1E6-4820-A4B4-DB43EBEE8BFA}' : IReportLayoutsParams,
	'{12E82740-BADE-4630-8BDB-2C3073D27F45}' : ElectronicFileFormatsParams,
	'{FC2AB5F1-3242-42D2-985E-D23052C9834A}' : IDistributionRule,
	'{2254824E-D59D-4A5D-8817-2F49B620154E}' : ItemLocalizationInfos,
	'{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}' : IStockTransfer_Lines,
	'{74598C2A-7868-4A07-83CE-229328FD3A11}' : ProjectsService,
	'{68C60132-0DD3-4AD2-B4FF-DB358A6184BC}' : IIndustries,
	'{6815F02A-AC31-4264-93DF-A403569495AC}' : ServiceCallOriginParamsCollection,
	'{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}' : IBlobTableKeySegment,
	'{38B3A4C7-93BE-4A6C-A060-C54D34979E1C}' : ICashDiscountsParams,
	'{BC7EF5B4-EEA5-4C83-8478-FBC484133A79}' : IOriginalItemParams,
	'{82C004A0-40F6-460F-8581-E34747E9CF01}' : BOEInstructionsParams,
	'{1EFF6EB3-9368-4A68-B619-0B57A134F0CE}' : IItems,
	'{576DD096-1276-42C3-9BCA-25FBCEE2E3CD}' : TaxJurisdictions,
	'{3443DB6C-7014-4BC3-A860-F4934E449818}' : IStatesParams,
	'{2C08600E-B9F0-432D-9D95-F934DDC01165}' : IRetornoCode,
	'{71ECA915-CB27-41B1-9E9F-DF819F1C52D6}' : ServiceCallSolutions,
	'{B93946BC-D44E-4D81-8071-B56EF0830B51}' : IAlertManagementRecipient,
	'{A5CDC033-47D7-4019-801A-8443F14D52D0}' : ITaxReportFilterParams,
	'{5691EAF4-B571-4BDA-B908-F7596767830E}' : IApprovalTemplateTerm,
	'{5E9FC07C-E9A5-465A-A532-F12DC65304D4}' : DocumentsAdditionalExpenses,
	'{5128D2EC-8CF5-47BD-A12F-B53211A1CE54}' : ISalesOpportunityReasonSetup,
	'{A1A07E2A-270F-4C69-8D1A-68D5CEF00CD2}' : TaxInvoice_OperationCodes,
	'{3B27BECB-507C-43E6-8FDF-080EC3810C1E}' : CreditLinesParams,
	'{5433B477-761B-47F3-8F1B-12694ED7AE47}' : GeneralService,
	'{F3C8C06A-7D48-4B85-9BD6-12344F1CC72E}' : NCMCodeSetupParamsCollection,
	'{8D14FB10-4616-4AF3-B477-0B87C797AEBC}' : IDepositsService,
	'{0F314F27-D439-454B-9722-A1C1AE6A11A5}' : LandedCost_ItemLines,
	'{FFA101D6-62B7-4615-A050-5BEE79FBF640}' : IExtendedTranslation_ItemLine,
	'{C24AF27A-8F41-42CD-8881-98F964EDF2C1}' : ExtendedTranslationsParams,
	'{EBB0F6A6-D704-41FF-8D22-CC3B76407F5B}' : UserTable,
	'{A3029CAF-054C-4339-ADDD-87F60B113023}' : BOEInstruction,
	'{C057A0F5-A755-4C5E-A410-D4C4D1379487}' : BillOfExchangeTrans_BankPages,
	'{FF79D2D4-A79B-4DCF-A3BB-14A8B01A5FDC}' : IDecimalData,
	'{BBB45A32-F446-4ED3-915B-C811BBA6C2C7}' : IRelationships,
	'{9AF2EEA5-78E2-4CE5-A748-29C849AD9096}' : EmployeeSavingsPaymentInfo,
	'{83E2FD00-E8D3-40D0-91E7-59166A6309DC}' : IBOELinesService,
	'{0DAE1D7B-419B-4573-9315-8094285CD00A}' : IBOELinesParams,
	'{F7DE78D1-5738-4D41-8002-396D495E6483}' : GLAccounts,
	'{14AF3328-811A-4FE5-A55A-C17BECE10062}' : IBlanketAgreementsDocument,
	'{C7E88977-022A-494D-BC9D-09FA85E7AC15}' : PriceLists,
	'{4207538F-AAC0-4EDD-9002-6F710410D5C6}' : IMultiplePayments,
	'{C392F1DC-DD79-4692-8FBA-7CAD03877993}' : ISerialNumberDetailParams,
	'{44E44FE4-3855-4EEF-9854-D8FF22F4801E}' : TaxReportFilterParams,
	'{FDC4607A-1635-40A8-8519-A756C180FCFB}' : MultiplePayment,
	'{B14AF4AA-36E3-4C09-9BEF-6DCED4B5EBFB}' : INCMCodeSetupParamsCollection,
	'{CBC0A7DF-E458-45B8-B640-955215643708}' : StockTaking,
	'{323B7F1F-31D3-45CE-A325-B81187DA9C0C}' : IExtendedTranslation_ItemLines,
	'{AAC173E2-F851-4F94-AE33-00CC4F38FDCD}' : IServiceCallSolutionStatusService,
	'{2AC79865-8E0D-42CD-8A97-AA4ADF24B4EE}' : ITranslationsInUserLanguages,
	'{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}' : IBrazilBeverageIndexerParams,
	'{D1B282C5-C219-48C7-93E3-6BD01735EFD5}' : ITargetGroupsParams,
	'{0274D5B9-311A-4D13-A665-E981B9E43491}' : ActivitiesParams,
	'{013F0389-85E2-4B8B-9285-18843E4236F3}' : IValidValue,
	'{986A5D5D-8D68-40EF-B579-C5A4CBAC0CFE}' : DownPaymentsToDrawDetails,
	'{8DBC2FA6-D028-4CF6-9987-EE7EDFC91F71}' : ProfitCenter,
	'{2240A153-81F1-4335-8702-1EB085CB1056}' : GeneralData,
	'{D6B048C3-D52A-4627-B4CF-81D0B203C076}' : ServiceCallOriginsService,
	'{453C97AF-4491-4776-A6BA-52F8739A96D9}' : AlertManagementDocuments,
	'{5D02917C-8423-418A-8BC7-7D1631742444}' : BlanketAgreementsDocument,
	'{13792BEB-6BDC-46EC-A35F-F98DF2B98CD6}' : IBOEDocumentTypesService,
	'{3984330B-A277-496F-9926-EBAA43351154}' : ApprovalTemplatesParams,
	'{461F000F-9DB2-45D0-808D-FA552126FF16}' : IMaterialRevaluation,
	'{A8AB919D-856C-4883-959D-57D7CB9C51F2}' : ITaxCodeDeterminationsParams,
	'{457DC126-2E63-4241-9497-1A104E8AB550}' : IElectronicFileFormatsService,
	'{7D2E0C15-AC4A-4833-9567-F7167B71CA53}' : SeriesCollection,
	'{D30C3CFB-358F-45C2-9F62-9CE26AF80E13}' : DistributionRulesService,
	'{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}' : IItems_Prices,
	'{2FA94E31-95AE-4F97-BD68-90E1DCC414F5}' : ServiceTaxPostingService,
	'{5D48514C-4B40-4C2A-9FC9-8CC2518B0F8E}' : IBudgetScenarios,
	'{2C3D3B79-8BCD-4CF4-981D-1033A54CBF17}' : NotaFiscalUsage,
	'{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}' : ICommand,
	'{EE92D21D-B6D8-4BD2-B481-EF2FE7C6E731}' : CockpitsParams,
	'{7A042067-2E94-48B5-A7CB-3534F6223B35}' : KnowledgeBaseSolutions,
	'{66F66F95-FC79-49B3-8B71-F80CFC73EAD0}' : CampaignItem,
	'{3EFBE347-7427-4459-A969-37AE80D0AFEF}' : ISectionsParams,
	'{828E364E-A21E-452E-9733-C49A96051736}' : KPIParams,
	'{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}' : IBillOfExchangeTrans_Deposits,
	'{215D7856-947B-49AC-BE80-CF521824D692}' : ExternalCallsService,
	'{9992E219-AAB5-48C8-B749-9D13289B4111}' : CustomsDeclarationService,
	'{14BE1C8C-20CA-4E53-A55C-097AB57740B8}' : IActivityInstancesListParams,
	'{1E6899F1-7A1B-460A-B134-3A82F9083C77}' : ILandedCostsCodes,
	'{297DB996-8B05-4D4A-BD2D-333A643F7303}' : ICallMessage,
	'{14F49B88-4722-45AC-993A-AD7680142769}' : IBlanketAgreement,
	'{CFAA1E6C-53D8-4C8E-A7DE-78ABE1601F30}' : BillOfExchangeTransaction,
	'{C54F7212-C3DC-4E35-B61C-73E6297F1AD6}' : ValidValues,
	'{02B05079-F380-48A7-A573-0BB7307A52C0}' : IApprovalTemplateStages,
	'{6745AAF0-21A4-4999-B90F-0C5B8595DF18}' : TargetGroupsParams,
	'{BD54054F-D434-4DC7-8D84-8020C653432C}' : IItemProperties,
	'{36FA3872-B465-409C-8F70-24AC72D4D5CE}' : MessageDataColumns,
	'{4E0DC009-5AF1-4931-92D5-B5C051C11800}' : ServiceCallSolutionStatusParamsCollection,
	'{DB038EC5-97EC-4D04-8E6A-AF01A5C05900}' : IBillOfExchangeTransaction,
	'{E498C4B2-E919-48EA-B512-79DE65B1F5CE}' : IColumnPreferences,
	'{087B9C04-C8CF-4606-A7B4-8FEC6CB8AE1D}' : IKPI,
	'{5079035B-D0E5-4D0E-AFB1-6CB1FBAB11AE}' : IColumnsPreferences,
	'{FE305F7C-1D01-4B99-AB83-BBB8503B8A95}' : ISerialNumberDetailsService,
	'{D8FB6CAE-94FF-49EB-9B87-0FDDAAA8C165}' : BatchNumberDetail,
	'{6076F945-EB54-4BA8-B00C-891BB860356A}' : ITaxReportGroup,
	'{6C92660E-0507-4C90-8DDB-1C5B61AB41AA}' : IBusinessPlaces,
	'{BCB7B6F8-6750-499E-B446-BC080CAD82D1}' : GetChangeLogParams,
	'{6ECD0990-1D31-4DDF-AF93-494A9DD7A104}' : IDocument_SpecialLines,
	'{4F06C847-96F8-4421-B1C7-2FA41FCB0CFF}' : ISalesOpportunities,
	'{E4546110-84BF-46DE-9E5B-CB9CA610296E}' : FinancePeriods,
	'{95AF3307-477A-4189-A934-CC32F18264F7}' : WithholdingTaxLines,
	'{9A5FCF99-FC73-47E0-A68D-A8156EB864E5}' : IDocumentChangeMenuName,
	'{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}' : IMessageDataLine,
	'{596CFFFE-E95F-472D-8243-37094A850DCF}' : ICurrencies,
	'{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}' : IMessageHeader,
	'{A6E70E75-647C-48BF-A642-84841BD85B2C}' : IAlertManagementDocuments,
	'{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}' : IServiceTaxPostingParams,
	'{B1E97A7D-C850-4253-BF24-D946B20A13A3}' : AccrualTypeParams,
	'{B7546EA2-0DE7-4F28-8596-ACCD323F584E}' : IBusinessPartnerPropertyParams,
	'{317E97C8-89A1-45FB-BDD3-8AB420DDF340}' : ICampaignItems,
	'{92C049DE-4E6A-47E8-8910-1C4C83E91780}' : IServiceCallOriginsService,
	'{81735331-E9E5-4A93-9772-BA20A8027E7A}' : AcctSegmnt_Categories,
	'{C44BDF5B-E877-4183-AC97-76D9E4921BB3}' : IBOEPortfoliosParams,
	'{B3DEEBBD-3798-43CD-9A29-1432782507D3}' : LegalDataDetail,
	'{009BFAE6-2701-4E63-B9EA-1335C9658CC0}' : ITaxReportAccounts,
	'{0C9CE0A9-AA16-4C81-A474-9D960E735AA5}' : BPBankAccounts,
	'{842BE793-D5A4-4C52-B7C1-99E189D39B8D}' : BankPages,
	'{82F30FF0-185D-4F73-8ECD-7CE2E4E77FEE}' : TargetGroupsDetail,
	'{D70469B5-F299-4F3E-9417-527D9BFEF649}' : DepartmentsParams,
	'{DB78F75E-A7AB-4DEC-A2CF-62ACE2A3E27F}' : WithholdingTaxCodes,
	'{486F8D7E-FB6A-49BA-9333-ED25151631D8}' : LegalDataDetailCollection,
	'{625162C1-3894-460F-94EC-72D6AFEA34D2}' : IUserTables,
	'{F72514BA-4388-4D35-821A-CF58DA7F7C10}' : ApprovalTemplateStage,
	'{1322FD3F-D88B-4321-9AC1-D9423CFBF06A}' : Project,
	'{72274C66-4457-4D17-8F61-014F5520C434}' : IServiceCallTypeParams,
	'{9DF321C2-6A1D-446B-AE8A-F7C33987D792}' : IBusinessPartners,
	'{BFC32883-8D3F-49F9-A985-3F9B3B37260F}' : IRecipient,
	'{EF865450-BA41-490B-B580-3D566BA3681A}' : ICampaignsParams,
	'{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}' : ICreditLine,
	'{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}' : IPeriodCategoryParams,
	'{943EB4D4-ED2B-4815-B6D8-3CA50DF8D139}' : IServiceCallProblemType,
	'{4E7D63F0-1341-4517-8F19-2EBC03A2D875}' : Blob,
	'{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}' : IServiceContract_Lines,
	'{16BDDE57-AD9D-48FE-9E33-964239B3F414}' : GeneralDataCollection,
	'{63F814CA-BC06-4069-9B83-5A73B7BE911D}' : TaxDefinitions,
	'{D9DD7A40-DA9C-4ED0-A5B9-103650442A61}' : ServiceCallTypesService,
	'{7BFDBDE4-A073-448A-B89B-6300C5B8B8E5}' : TaxReportBusinessPartner,
	'{921DBA91-7B93-4AEB-859C-C4452CA0F739}' : Recipients,
	'{F7BC21C9-ACB8-4B44-8488-5BE5D15BADEA}' : IDashboardPackagesParams,
	'{AB9A1501-E84C-4EC2-9869-8A843FBCCBB6}' : ITaxWebSitesParams,
	'{F8E64A61-69DC-439B-82C9-0D7B1BD5E4B1}' : IDNFCodeSetup,
	'{1FA65DB2-F84E-4C7C-A48D-E4043BCF6557}' : ICashDiscountsService,
	'{9A49C2D7-CC5F-4CEE-95B9-6A8B16CA2031}' : IEmployeeRoleSetupParamsCollection,
	'{6228C442-C4B7-4841-9275-54B459F42BCB}' : IApprovalRequestLine,
	'{0B5DE094-FB49-4B4C-AA7C-F87F5E3A932F}' : IDistributionRuleLines,
	'{C131D463-24C3-424A-B734-589D0F452D2E}' : IGeneralData,
	'{6684E784-5C62-4636-B20E-8AAA5B20BBF2}' : TaxWebSiteParams,
	'{CB6DE5B7-50B1-4068-A778-CD08EEA34DC4}' : BPCodes,
	'{EB66D894-270C-4DF1-B76A-AB91ABE88D03}' : IBlanketAgreements_DetailsLines,
	'{43C8A942-73F5-40BE-9675-CC8946003F0A}' : IAccountsService,
	'{56AE7782-A205-4EBB-ADFD-FE4CE27B9201}' : ApprovalTemplateParams,
	'{99FB9754-BDAE-4C8D-BA96-4F2263A73A6A}' : IPriceLists,
	'{E04751E5-F944-4A94-B580-320744878FDA}' : CampaignParams,
	'{7D947F60-6017-44AA-AEAC-9721FF263D5E}' : IBPPaymentMethods,
	'{F72D84B1-6F70-44CD-8B91-2FC481ADFE2E}' : IPaymentBlocksService,
	'{9020ED56-6B7D-4FAC-8D93-B185D1E65A59}' : IPaymentRunExport,
	'{DFF94208-9A06-4594-992D-8D758D296BD4}' : IDownPaymentsToDraw,
	'{8276E7F7-9178-409D-88DB-5A8D41DED6E5}' : IPayments_ApprovalRequests,
	'{F0D891FD-5D68-466B-90C3-0EDE46E01241}' : LocalEra,
	'{07F27714-4BA9-42E3-8E93-3418F73C55E4}' : IDocumentPackages,
	'{33DDE1AB-5C1F-454E-840A-884CF62A6747}' : IDeductionTaxHierarchies,
	'{A9030345-42BE-4206-8236-DF97C0B60529}' : CountriesParams,
	'{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}' : IPayments_Checks,
	'{46CBA2F6-0319-4C81-8D08-407EB184F732}' : ApprovalTemplateQuery,
	'{DF752E29-B42C-4FB2-8634-AC2F74DC9DEE}' : SerialNumberDetailParams,
	'{420B8379-83B3-4AE9-B7B8-4DDF73D3085D}' : ICountriesParams,
	'{3288D1F6-6EA4-4FA3-82E5-53943D2DA511}' : CampaignsService,
	'{90F5B36A-4621-44F8-BB72-8FC83DC756F2}' : ActivityInstancesParams,
	'{DACFE08E-8A02-43ED-B762-5E664186FB0E}' : IStockTransfer_ApprovalRequests,
	'{FCB4B06C-8747-4678-85EB-4F28B51A88C8}' : IPartnersSetupsService,
	'{22219181-9047-4C89-BAC3-4BB311AE77E4}' : IServiceCallSolutionStatus,
	'{12A99320-EEE7-4398-90E2-74BC014F5CE2}' : ITransactionCodeParamsCollection,
	'{12BC616F-58C9-4281-8EF8-633FD300E827}' : JournalEntryDocumentTypeService,
	'{F56E791B-BAEE-49D5-9981-DB03FBFDFD47}' : KPI_ItemLine,
	'{AEDDBC24-5587-4895-A37D-E41F54A42A44}' : DunningTermLine,
	'{FC75103E-6EAA-4246-A097-B6F81E9DD4A3}' : JournalVouchers,
	'{6C589BC6-9ACE-4A99-8097-038E9AC52155}' : ILayers,
	'{B7334829-8658-48D1-9FF6-056E90AEB07D}' : ICostCenterType,
	'{D03750AE-84B3-4539-A931-36AAA98C4EBB}' : MessageHeaders,
	'{46BED4FA-A7F1-4067-8FC7-A6303F0F3A5C}' : DocumentPackages,
	'{36360587-E2A6-4BF4-BFED-92F2CEDDF03D}' : ChecksforPaymentLines,
	'{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}' : IEmployeePrevEmpoymentInfo,
	'{D0DD241B-FDFC-4D57-ACD0-CBCB01611BF9}' : CockpitsService,
	'{0219BFB4-6A47-47F5-942F-8B05389A05FB}' : ICreditLines,
	'{3D623D04-749A-46B6-B0A2-AAC17B3FAEC8}' : ChooseFromList,
	'{17432CFA-F59A-4F5E-B58D-A2948523C77F}' : ReportLayout,
	'{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}' : IUserPermission,
	'{D3259ECE-289F-4B9B-9C81-AD71D8EACE67}' : _GenArrObj,
	'{BC23E72E-CE89-4492-BEEC-6F5FE1D694A2}' : ITargetGroupsDetails,
	'{E47E4050-E7A6-4FD5-8F38-A8066213559A}' : ICampaignParams,
	'{99D4BEE7-9E10-4C05-885B-4BEA6BFB1983}' : SalesOpportunityInterestSetup,
	'{DC66A989-A072-41C9-959F-B9525E8AFC1B}' : BrazilStringIndexersParams,
	'{7BD692D0-D375-4754-AC78-310F1035CEF8}' : DunningTermParams,
	'{0383EE76-4325-42FE-8164-91C2E8FDE242}' : IActivityLocations,
	'{BF7FD103-23BD-401E-8A87-DBAFBBB7DB37}' : IProfitCentersParams,
	'{0CA3C6AF-091A-4C96-9F9D-F9B99F868AB7}' : ExtendedTranslationParams,
	'{A6DB2CDA-3A42-4A70-918C-53595D6091C9}' : IChecksforPaymentLines,
	'{41CE0964-B3EC-45D0-AB38-D1D70788750E}' : FinancialYearsParams,
	'{C868B9F4-6EC8-4A28-81AF-546DD81B1083}' : ValidValuesMD,
	'{7F146AF0-3304-4133-BC4F-48797C66B12F}' : SalesTaxAuthorities,
	'{180937C4-1314-4A9D-BFF2-27C3969681DC}' : SalesStages,
	'{0F2D8F44-9F7D-4290-8A2C-9B08EC782ECD}' : ImportProcesses,
	'{8C9A31B4-0BEA-4A72-8D4E-F4C00F683E6B}' : DunningLetters,
	'{EA80E8EC-0D43-4C8B-9F8C-BA5D71F12578}' : IKPIsService,
	'{F63FB1C7-CC5F-4FBD-AF7A-A1686D1BCD64}' : DimensionParams,
	'{9B732959-2A6C-46D0-B082-DF0FD03D7EE0}' : CostCenterTypes,
	'{79148B90-9790-418A-B904-DA8C72CCCDDF}' : QueueMembers,
	'{98F79F87-3825-465E-8E69-E7E416534B7B}' : IProfitCenterParams,
	'{9AC69118-AA6E-44B4-ACDC-176426BCBA1C}' : ProductionOrders_Lines,
	'{FB73DAFB-EA3A-4D1B-9EFC-57F68BF26A2E}' : DunningTermsParams,
	'{389082B5-04A7-4CB6-A0FB-EEC065715703}' : IDeductionTaxSubGroupsService,
	'{A31EC6FB-9B3A-439E-828D-C95CB0646555}' : IPeriodCategoryParamsCollection,
	'{5AB3CD70-9DFD-4904-A6FC-AE99578C58BF}' : CallMessageArguments,
	'{251C6447-671B-4ACB-9CB3-C8E072B5E60D}' : LandedCostParams,
	'{8DD14B84-6D7B-49E9-8137-A3E7F9A3642F}' : IStockTransfer,
	'{869F134B-E012-418A-B519-FC5CBAC4E5F4}' : ActivityInstanceParams,
	'{F25B1134-169D-4C7C-B46A-B90707621373}' : NCMCodesSetupService,
	'{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}' : IEmployeeRoleSetupParams,
	'{5E23BA23-D431-4212-BD7F-D5CB7E263494}' : ICommissionGroups,
	'{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}' : IDocument_LinesAdditionalExpenses,
	'{DF1B1704-3860-4602-914C-71D3A9789748}' : ExportProcesses,
	'{B63DD56F-5008-48E8-B7FF-DA56720F422D}' : IEmployeeTransfer,
	'{EBBCE4C7-AE00-46A4-A0BA-851F42E7CADF}' : ICallArguments,
	'{B4031DD0-97CA-4315-8ED6-211B8368E96F}' : FormattedSearches,
	'{00F3FE74-2DDE-4095-888D-A0E7D4BA83AC}' : PartnersSetupParams,
	'{1B0F044E-5955-4426-8CEE-885A8388A8F9}' : Users,
	'{C8D6687E-6A96-4458-AF54-B052F20C26B3}' : ICostCenterTypeParams,
	'{9BD8670D-B894-43A6-9CF7-F3C07E7DDCB6}' : Payments_ApprovalRequests,
	'{2B38E868-B135-40FE-9174-5C258F8638DB}' : CreditLine,
	'{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}' : IUserObjectMD_FindColumns,
	'{002ACD1C-A740-40C7-9927-33E4CB58536F}' : IMessageDataColumns,
	'{A24C6BD6-06BA-47B3-8B67-D628AEFAD721}' : IMessagesService,
	'{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}' : ILandedCostParams,
	'{6437CFC6-20AE-456A-8CD1-0F98D6F2CAF9}' : AccrualTypesParams,
	'{920385DA-2BF3-41E5-BB01-EFDE51C104E6}' : CashFlowAssignments,
	'{F4B554B0-CBF3-4258-89E5-F94FB08E463C}' : DNFCodeSetupParams,
	'{6162B662-5834-44EC-9A3A-6E36B4EB227F}' : ReportLayoutPrintParams,
	'{04A588AD-9FA8-4238-8044-D70C1988BFD2}' : CashDiscountsParams,
	'{CE69987E-8F99-4FC1-8C86-837E5246AFA2}' : IPackagesTypes,
	'{3CFFABA9-A29B-4D64-8344-17073542C395}' : BrazilNumericIndexer,
	'{D5B65908-18C4-493A-B1F3-BC7987AF01DD}' : ISeriesLines,
	'{FECE5DF5-E254-43C1-BDD9-5C82097B9B9D}' : IBlanketAgreements_ItemsLines,
	'{CC3579ED-1C61-4864-8E51-208A3DCDFC93}' : IPayments_CreditCards,
	'{2468326B-CAE1-42CA-8139-3D674F3E4875}' : SectionParams,
	'{B65E1962-E1A8-4BD0-83D6-6F159503C18E}' : BrazilNumericIndexersService,
	'{6B7F9C14-6E99-4405-8796-51F1EF735889}' : IEmployeeIDTypeService,
	'{C1BF990C-0774-48F2-901C-84E414D881C6}' : IBusinessPlaceTributaryInfos,
	'{7A4DE818-7DD3-4035-97F8-6696A65651BF}' : IBanks,
	'{646FEBEB-91D7-4517-8CB0-B550DCA64490}' : IGeneralDataCollection,
	'{43A684B0-5463-4FD9-9F52-A2E57909EAF2}' : ChangeLogDifferenceParams,
	'{669DAF62-7776-4DF5-AB51-B35DABFC4ACE}' : IEmployeeSavingsPaymentInfo,
	'{58E6063A-F616-4E44-AC69-8E40356F5830}' : IElectronicFileFormatsParams,
	'{7649AEBB-4217-4944-9DC2-1426C38113C7}' : ApprovalTemplateStages,
	'{EF61561B-2AB6-42DB-82EF-C440E4A4A71C}' : ILandedCostsService,
	'{E22659B2-7CEA-4351-96C4-80160CFAADE7}' : IBlanketAgreementsService,
	'{BBC625E2-17DA-4434-83D6-56FE0401D9A6}' : AlternateCatNum,
	'{2C841DE4-014D-44C4-9D48-6A9B7BCD789A}' : IBankStatementsParams,
	'{7DE64B38-CB91-46C2-B1F2-B016D3CBD61D}' : ICallMessageArguments,
	'{BBC9323D-F9D4-4087-A7E0-1768D5F64538}' : PeriodCategoryParamsCollection,
	'{3BA8DAED-5B33-4CE4-A4B8-B4308D86E524}' : ICompany,
	'{4821A00E-CC17-4B2F-99A7-61D49901AC89}' : DiscountLine,
	'{49593AE6-FB7B-4B31-9029-F84067559E54}' : ICreditCards,
	'{D178B341-234B-4CEC-AB38-5D2227C64DF3}' : OccurenceCodeParamsCollection,
	'{C2920491-21F1-4CB6-B7FF-C638324F1234}' : Country,
	'{6EF2D0B5-8580-41AD-B879-42738445BE03}' : CustomerEquipmentCards,
	'{52065704-057D-4B2B-A301-40F252371DA3}' : BlobTableKeySegment,
	'{19E6540E-4E64-48C1-9525-29D5710D1FFD}' : ISalesOpportunitiesCompetition,
	'{EF78E12B-50D7-424C-9314-1275E4EEAF23}' : BusinessPlaceIENumbers,
	'{DB4F4E62-87CD-4113-8EA9-4EAAC1555DBD}' : ISeriesParams,
	'{FD5860AF-4409-4BE0-87A2-51FB438E08BF}' : BrazilBeverageIndexersParams,
	'{E41626ED-6A4E-4C2A-8E60-7010C443F3F9}' : CampaignBusinessPartner,
	'{52E836D1-B708-41C5-850C-624B33BB2BE3}' : LandedCostsCodes,
	'{7E0EA2EC-9661-427C-B8EB-0C818F908F67}' : IBOEPortfolioParams,
	'{70443238-FECE-4E0B-8900-9C5D06C4E71C}' : IBOEInstruction,
	'{0AE67F4C-4636-4B39-AB14-B5C669FB2DF0}' : ReportTypesParams,
	'{D919D79B-2CE9-4A88-9C3D-59A67A334D81}' : I_GenArrObj,
	'{835F6104-3A36-4122-8AE8-C4E1D7B15453}' : ContractTemplates,
	'{6719EA66-D6B5-4509-ABC0-E16BDC730623}' : CheckLines,
	'{724DEACC-3DDF-46DC-A884-A69751E80603}' : ICashFlowLineItemsService,
	'{AAD58C85-8182-4A48-AC46-3D29F6E02F83}' : EmployeeTransferDetails,
	'{81D132DE-0549-460D-9BEC-2FEDEAB0A950}' : IUserFieldsMD,
	'{73B70E17-5D4B-4AD8-BF03-DBD596A6C4CC}' : TaxReportAccount,
	'{62F0798F-B9DB-43CB-B3BA-5C499E271143}' : ServiceCallTypeParamsCollection,
	'{9D2F3E85-AF82-4AF9-AB62-9B210FA52B46}' : ServiceCallStatusParamsCollection,
	'{2309689C-63EA-4D8E-B675-E6459533E27A}' : IElectronicSeries,
	'{475E4307-5C54-4449-BFCA-2CCCBBEB6448}' : IServiceCallTypeParamsCollection,
	'{2393BA89-A02B-4E4E-8703-0412A8B757C4}' : TaxInvoices,
	'{917BA077-4D88-46A8-B78A-E396315D7E59}' : IPaymentRunExport_Lines,
	'{9D5AE661-24A0-4F2A-AE75-714F3FF59B91}' : IKPI_ItemLines,
	'{EA66002F-549F-4B15-BD0E-7AB565D29B5F}' : CountryParams,
	'{8C5510F0-AA36-4CBD-A5AC-7DCF29EE0249}' : IQueue,
	'{411526CA-B3C4-489C-B4FB-6539B5BF09C2}' : TaxInvoice_Lines,
	'{47C12E2F-E1CA-41E8-A9FA-F8415E2B6125}' : GTIParamsCollection,
	'{88134489-A686-4E22-811B-40E0728F4497}' : ProjectParams,
	'{DE04D890-B86A-47EF-AEFD-562E6187C25F}' : SalesOpportunityInterestSetupParamsCollection,
	'{6D9D8D62-8831-45B0-814A-BF7EB5AA63DD}' : BrazilFuelIndexersParams,
	'{0038F785-2853-4267-9629-3444A3CCC2AD}' : IEmployeeTransferDetail,
	'{E0F9420B-02BE-490B-BE28-1216726EF3FD}' : Document_SpecialLines,
	'{3FF527E2-2FBB-4F74-BBF9-C0EDBF44E63C}' : EmployeeReviewsInfo,
	'{690E65AA-B309-41D2-9697-0B6CBB58C4AF}' : IApprovalTemplatesService,
	'{1445B394-DD5B-4542-9E3B-2B6E9CA92621}' : IApprovalTemplateParams,
	'{CF02E105-3575-467B-9AD6-5BF719C9BC8B}' : IBatchNumberDetailParams,
	'{85830213-6564-4BBA-95DD-246624D1A4D2}' : INFModelsParams,
	'{7F9581D3-34A6-4B9A-88E3-E518307C6FF6}' : ServiceCallStatusService,
	'{F69530F1-7AD5-4496-807B-6911ED2E5363}' : BrazilMultiIndexersParams,
	'{05F0D981-435B-46CE-B13D-25D4A87B8088}' : EmployeeTransferDetail,
	'{F5C29BC7-F643-4A93-9026-C045A11D564A}' : IMaterialRevaluationFIFO,
	'{EACF6445-6CE2-41DA-AB6E-681B6BB6BA11}' : TransactionCode,
	'{9E2A9072-D759-4FEB-AD91-90CCC8BC7D64}' : PickLists_Lines,
	'{788DDDE0-9FE1-4653-8F1A-DCBFF4DD0B49}' : IDunningTermsService,
	'{E3F9ACA7-17D5-4A5B-8AAF-91CB41E2896F}' : IExportProcesses,
	'{EB9E1080-A979-4BA0-895B-D424C68063BC}' : IExtendedTranslation,
	'{1AF6323B-193A-4A12-A001-67993DA9310E}' : TaxWebSitesService,
	'{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}' : IApprovalStageParams,
	'{EE825513-A21F-467A-AAC5-931A7939C954}' : IActivity,
	'{3CA31A48-0CEE-436B-9447-E14D8D27C546}' : IBranchesParams,
	'{3503F7F1-5A0C-4D08-A498-0D9619097C09}' : ITaxReportFilter,
	'{0B4E873F-65FD-4638-9339-84D197CF8109}' : IReportParams,
	'{2BDDDD4B-2399-48E0-A9E1-7BC3DE1324A0}' : CertificateSeries,
	'{022D793A-3706-459F-A7FE-4169894754D8}' : ISeriesLine,
	'{00C7246F-BD54-4E8B-8CE0-39F9C6568F68}' : IBusinessPartnerPropertiesParams,
	'{AB36A971-B92E-4C38-BA4B-2BE928C8C652}' : ServiceCallStatus,
	'{4838BBDC-5B48-44EF-A7F7-A705BB07B24F}' : ValidValue,
	'{A7FDC596-1604-4DE8-841C-DADBA34B32E0}' : ITaxWebSitesService,
	'{2CF2E472-CA6D-4D8E-8B80-046D28E75C40}' : IChartOfAccounts,
	'{F3801C93-51D8-48E9-9018-0CAB9A4FCBC2}' : NatureOfAssesseesService,
	'{6956AD8B-4137-40EE-8614-DBC251938619}' : MessageDataLines,
	'{8EBC49BF-EDA5-4B08-B93A-5B4A81045176}' : BankStatementsService,
	'{E644A5ED-C97E-4EE8-8191-E20EBC9508AB}' : EmployeeRolesInfo,
	'{505427E7-5F80-437F-A4DD-972DA3F1C9C9}' : IWeightMeasures,
	'{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}' : ICockpitParams,
	'{4162242D-4217-47FA-BDFF-5070B6D03F30}' : IBPAccountReceivablePayble,
	'{D89C1B1F-B7A1-4669-B80D-E3A041767ABE}' : QueryCategories,
	'{28DD7AE7-0602-49B2-80EB-827454AA99E7}' : ITaxReportDocument,
	'{142EBC48-A651-4AA5-831C-8A4DA3172194}' : RoundedData,
	'{E90FD334-9FC7-4E35-8E2D-43D338D63C1F}' : GTIsService,
	'{E07E71EA-0DEF-4990-A99D-C6B7407995C9}' : ApprovalStagesParams,
	'{ED256951-E65E-40BF-A2E9-2A21741D8720}' : IUsers,
	'{171C2811-0B09-46D2-B716-50A0FF4CB5AE}' : BranchParams,
	'{106B8134-EDB5-4417-BFAC-4A3A2A7B9419}' : IServiceCallStatusParamsCollection,
	'{3AFC5084-1838-4196-BAEF-7C16635E8068}' : Attachments2,
	'{08F4BA3C-A72A-4612-B5D4-F3E1C120004E}' : BusinessPlaceTributaryInfos,
	'{2C35D508-856B-43E0-A1A5-EC6BCA16E62A}' : IBPFiscalRegistryID,
	'{2691123A-50EC-4554-9180-490532131218}' : IReportLayoutItem,
	'{0FCFCE88-47F3-4F05-9803-3081D83C92DC}' : IAdditionalExpenses,
	'{6446D947-9BED-41FE-876C-B89334D5D85F}' : IUserMenuParams,
	'{2B7E88E6-AA4B-48A5-A462-AD771C618A44}' : LegalDataParamsCollection,
	'{740243E4-B946-4D50-94D9-7F7E3EC04FE9}' : BPWithholdingTax,
	'{D5F33B11-D467-4234-AE58-63E6D70E6E26}' : DefaultElectronicSeriesParams,
	'{6A174FBA-0ED4-4619-BC5F-2DF68BB53C89}' : ImportFileParam,
	'{EC280F9D-83C0-4324-9B19-18CB128A7021}' : IBusinessPlaceIENumbers,
	'{207685C7-0E68-4A17-AD6C-7C2635B60316}' : IBrazilMultiIndexersService,
	'{08F86A95-6E92-4287-AA3A-8B044183ED1F}' : FormPreferencesService,
	'{0E2CBAD1-1857-4E2F-8AE4-5246D1F6725E}' : IServiceCallStatus,
	'{DFFEC465-C3AA-45DD-ABBC-9D025A328335}' : IGLAccounts,
	'{292717A3-9E69-4C34-BE56-A61A52CA8AA2}' : IBrazilMultiIndexersParams,
	'{7CD6F364-32D1-4862-8470-E27D69A03F08}' : NotaFiscalCST,
	'{594B9D4F-6946-40E7-9E69-2DC0F506A823}' : Cockpit,
	'{C1751C9B-F39D-4401-87D9-2C0C6B2DD2D2}' : IBlanketAgreementsParams,
	'{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}' : IServiceCallInventoryExpenses,
	'{C9C6EE8B-66E6-4C3E-91ED-49482CF4B903}' : IInventoryCycles,
	'{E24C2504-36B4-4EE4-A990-0F487E774211}' : IDocumentSeriesParams,
	'{9091A78F-FCC8-4399-88F3-53E1631F100F}' : BPPaymentMethods,
	'{CD793E21-582C-4408-8AF7-1B256D29BF5A}' : UserTables,
	'{F1CD6BFD-F77D-4059-A4E7-016D298C5C4D}' : FinancePeriod,
	'{7590979F-CE5F-480B-AEA5-2B83A04BE64B}' : IApprovalStages,
	'{B2CFCDE5-3753-4A47-9199-38D08718B3AE}' : IEmployeesInfo,
	'{969F9241-8C84-4966-B0D9-EC89E15E43B8}' : SalesOpportunityReasonSetupParams,
	'{0C60C86B-3CB9-4E78-80D0-1AACB3C1C6F0}' : IActivityTypes,
	'{0E77E5DB-93A3-4FCF-BB4B-BE8323F27387}' : Payments_Accounts,
	'{C4397D01-E44E-4B76-80AB-4B888EEA10DD}' : IEmployeeReviewsInfo,
	'{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}' : IDistributionRuleLine,
	'{5C63DF2C-6C18-4447-A9BB-B6277EF0DAF2}' : Items_Prices,
	'{A0B0F43B-427F-4744-ABD3-0684090D3470}' : ApprovalStages,
	'{843B58CC-38C1-4C93-B5F6-533BFB3006BD}' : IMaterialGroupsService,
	'{02FD29A2-2B9E-4D9E-936C-5DE5A115C180}' : BankStatementsParams,
	'{F09D2D1D-1BB3-4D09-946B-71AE1263D6AC}' : IUserObjectMD_EnhancedFormColumns,
	'{3BCB6516-86EB-4170-91BD-7EE4E52D6172}' : IBOEDocumentTypes,
	'{B6D42A3B-BAEB-4A65-BA49-E5A89BC8EAFA}' : BankStatementsFilter,
	'{6DFC79D0-66CD-483F-AF0E-DBEA40C86AAC}' : NFModelsService,
	'{100612B7-46C2-4489-A406-504575577467}' : IApprovalRequestLines,
	'{0CFCFE82-D222-486A-9E49-0FBE58FDD534}' : IBudgetDistribution,
	'{686C8BDD-2405-4A47-AE0B-4E2E0C7C27FF}' : PredefinedTextsParams,
	'{17785C88-48FC-4D21-A790-81AC72C1D4CC}' : IPredefinedTextsService,
	'{62EC03F0-1AC2-40AA-B3B4-CB7D3964E0BF}' : TaxReportDocuments,
	'{FD65E5A4-2232-452B-8541-5BC1EC3FF9C6}' : ColumnsPreferencesParams,
	'{B9580913-6CE6-48EC-84CF-E22544326D60}' : ReportLayoutsParams,
	'{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}' : IApprovalStageApprover,
	'{1870838E-C4B4-4ACB-A0F8-FD98EE7673F6}' : FinancialYearsService,
	'{6BA3F221-1146-4650-AE35-03C139F04C02}' : SerialNumbers,
	'{FFA181B4-6482-45B5-901D-525B13F491EA}' : ICheckLinesParams,
	'{E6BBD705-997C-468F-924D-ABE0D1B96E8B}' : TaxReportDocument,
	'{D110EAAC-B59D-499D-9936-67F70B616026}' : CreditLinesService,
	'{9B4D2E09-CE62-49C7-BF5D-0D9BC6BD9F81}' : TaxReportSeries,
	'{4F6D3681-33BD-41F5-BFEA-DE2059E4ADF4}' : SpecialPrices,
	'{78A768C9-EDA6-4798-AFC3-114DEC3DE8E5}' : IQueryCategories,
	'{C5006530-1F40-4FD6-A525-6BCBF66DE58B}' : PredefinedTextsService,
	'{907E9130-6B06-4C32-91E2-453846193486}' : ICockpitsService,
	'{41776B28-16AF-4699-B4FC-475989790FB8}' : IReportType,
	'{842F5C3F-67A6-42B4-8181-98EFB9520A5F}' : ICustomsGroups,
	'{0ED9BFD6-A5ED-40D2-8645-BE4ED8AC9CE5}' : ServiceCallActivities,
	'{FCF196BC-2669-4A6D-92C8-33896FD2D3B1}' : ICampaignsService,
	'{C7678A96-E53C-402A-B298-8104D810EDE5}' : BrazilBeverageIndexerParams,
	'{341FC52D-5088-4DE4-8308-7085F8D950A1}' : IAlertManagementParamsCollection,
	'{701AB128-130F-4ECA-B477-EDAC4B7C875A}' : WeightMeasures,
	'{C9A336DC-4108-44D2-8161-5420E75E8475}' : IServiceGroupParams,
	'{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}' : ITaxReportBusinessPartner,
	'{8529DA4C-CD2E-4D6B-95F9-E4BE53D72883}' : DunningTermLines,
	'{D9D5A329-257D-45AE-8897-AFD53838C099}' : ISection,
	'{7918DE8E-296C-4D36-9BB5-AE66DC9A466D}' : Campaign,
	'{45D4B1C7-FB50-4628-94F5-78006AD1EFAC}' : CreditLineParams,
	'{BEB8ACDC-E50B-4DA3-8281-EF5228E55099}' : ITerritories,
	'{A04457CF-8DB7-477B-9298-374E7CDAA9D8}' : DocumentTypeParams,
	'{7C3BB8E9-B896-4556-859F-FCAC93473C04}' : IDeductionTaxGroups,
	'{3C447394-4D07-46E5-8ADE-0E5973F97CF7}' : Attachments,
	'{23BBD185-4EAB-45D4-950E-194CD4A96BE2}' : IPartnersSetupParams,
	'{40BEDE06-EB4F-4914-BCDF-71018C6FE98C}' : ICampaignPartners,
	'{268D6CC3-E244-4AD7-B009-16C8ED7F710A}' : ISBObob,
	'{DFBE6ED2-7510-49C9-8C39-35B939DB586D}' : IEmployeeTransfersParams,
	'{24D0CDB0-8592-4CD3-A247-9A51C55D060F}' : IBrazilFuelIndexerParams,
	'{C90D9F7D-14B6-465B-BE3B-48FABA68CF75}' : IBankStatementsService,
	'{416CFADF-9DA6-47BD-A490-09AC890FC530}' : IAlternativeItems,
	'{871BC4E7-9FB2-4847-8031-FF03A682F0D5}' : ServiceGroupParams,
	'{09BAC4F7-AA34-4417-8C7F-7451098A4D5D}' : SectionsService,
	'{A07F5790-711E-49FC-9843-935F7C8CDB85}' : ISalesTaxCodes,
	'{1E293D13-1EC1-4DF2-A5CC-7FE45030EEE5}' : IKnowledgeBaseSolutions,
	'{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}' : IReportLayoutParams,
	'{31BF39D4-A4A4-4FF6-A946-D7DFB4B37D5D}' : IOpenningBalanceAccount,
	'{C15B6D2B-EA40-48FC-990E-6CE5EB32B7E4}' : DiscountLines,
	'{57FF304C-3414-48FA-8059-4F3B10FB37C9}' : IExtendedTranslationsParams,
	'{8C66EF53-C778-466A-AC1C-6BEB8605425D}' : DimensionsParams,
	'{C48ABD4C-43C8-4776-87E7-337D661050C2}' : INCMCodeSetupParams,
	'{6DE9F2ED-C121-43F2-B922-CE373DC2EC17}' : MaterialRevaluationFIFOParams,
	'{C842A9F9-CB16-4E6A-A1DB-7D8964889C74}' : IDepartmentsService,
	'{135ACD20-6799-42E5-8ECC-4077CEF72812}' : IElectronicSeriesParams,
	'{5BCB48BA-A4A6-4087-B1FD-1E9F076EFD33}' : ITaxInvoice_OperationCodes,
	'{55053980-777B-44CF-8D76-84DD975171AA}' : IJournalEntries_Lines,
	'{3D7A2391-5E52-45DE-80DB-A09ECADBD5A3}' : ICustomsDeclarationParams,
	'{31A74034-7CDC-4A30-AE5A-2F237201F390}' : NatureOfAssesseeParams,
	'{692B8669-26B5-4D4F-A768-F92576E3EF85}' : ServiceCallInventoryExpenses,
	'{7276D73A-6B18-4F86-B517-6DB9363FC772}' : IServiceCallSolutionStatusParams,
	'{0B24F304-D586-4E29-8820-90E334D034D5}' : IServiceCallProblemTypeParams,
	'{403E32F9-EBDD-4528-89C2-FE8BE8F7F0A6}' : PaymentTermsTypes,
	'{635ED325-EEA5-4340-AA1A-5845D97CFCC1}' : DistributionRuleLines,
	'{FF87B29E-5D38-4901-A443-8672387A200A}' : IUserMenuService,
	'{9057028D-894C-4F75-877F-A856F36DDEA5}' : IUserQueries,
	'{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}' : IUserMenuItem,
	'{E14BAC45-1772-407F-B255-178FF23F91E3}' : IDiscountLines,
	'{5E789D08-DD00-438D-A3B0-91CAB1CEA247}' : SalesOpportunityReasonSetup,
	'{729A48C9-675C-4F2C-9A16-2C29D1825C05}' : IServiceGroupsService,
	'{F2A7926C-BDB1-4151-8FEC-5A58C2BCC600}' : IBrazilStringIndexersParams,
	'{B6F90D8C-7E5B-4EE0-8E60-D536FD4C3665}' : IElectronicSeriesCollection,
	'{1B73D91C-F2B5-4BF3-A772-0A95FBBA1128}' : NCMCodeSetupParams,
	'{CA9C97EF-439D-4040-B1A1-39F83CBC2CD5}' : DocumentSeriesUserParams,
	'{B3D0E8B3-C0C8-4CC2-9D0B-121D6384E95E}' : ISalesOpportunitySourcesSetupService,
	'{2E4A01AF-5881-4F33-8D91-A4EBBFADBADA}' : DocumentChangeMenuName,
	'{81BEC420-E567-4353-95BA-71F26FD54BCD}' : IApprovalTemplateDocument,
	'{9028E41B-53F3-4D7F-8A0E-FFD5F9923664}' : CallMessage,
	'{60469EFE-3F0E-4B28-B387-6F6ADFB367DF}' : BatchNumberDetailsService,
	'{57544A70-71BC-4A35-B018-BB43DD24941A}' : Warehouses,
	'{1BB46BE0-4ECB-44DB-B6ED-64356031568E}' : Document_ApprovalRequests,
	'{439BEC35-EDAA-4F54-8FEF-647658D06148}' : IAccrualType,
	'{AFC4F081-3100-4940-88E0-E614C717E8A7}' : RetornoCodesService,
	'{CDB52791-B0FC-4BE1-A712-06941AF91D52}' : IItemWarehouseInfo,
	'{F7E00222-C717-40BF-9DC0-A95200B0FEEB}' : ITaxWebSiteParams,
	'{954AC9A0-5402-436F-A20B-38E093F0A636}' : IPaymentBlocksParams,
	'{2D582F5D-2BE6-408A-A03A-ED37F5C30491}' : DeductionTaxGroups,
	'{3C3E8D7B-D724-4ED0-BBE3-955F8711B716}' : IReportFilterService,
	'{ABDA119B-E21C-44A5-8DA3-CA870D0D9486}' : ICheckLinesService,
	'{84AA649E-44F2-4988-8CDF-53FFD270933C}' : Branch,
	'{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}' : IEmployeeRolesInfo,
	'{F105494C-B48F-4E8A-B6E7-C1947194E835}' : Budget_Lines,
	'{8D12B6FF-AA47-441C-BA2F-C02A10890DCE}' : ActivityInstancesListParams,
	'{918EBBE1-6DBB-4B20-AF74-34A5CA1B5E21}' : SalesOpportunitySourcesSetupService,
	'{07C983CC-2615-4105-A114-AB0094DBD192}' : PaymentBlockParams,
	'{99E84704-3E04-40DD-BE1D-854068378E3A}' : IDepartmentParams,
	'{91B68A10-74AD-4FAC-98F5-746FDD45D957}' : IUserLicenseParams,
	'{302CB444-8F72-40F4-A8A7-457500892805}' : BOEDocumentTypesService,
	'{812BAA6F-715C-42E4-811F-287EF23E05A2}' : ICustomsDeclaration,
	'{49703681-AAAE-49B5-B2AA-402D622EE537}' : ITransactionCode,
	'{247CDE70-F00E-4033-8EC1-3E173AEA8596}' : ISalesOpportunityCompetitorsSetupService,
	'{50A5CCB1-6509-462A-8A81-B9A11DA1C4DA}' : CockpitParams,
	'{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}' : IBranchParams,
	'{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}' : IDNFCodeSetupParams,
	'{97B3DA37-698B-4ED4-84E8-B8A110AEC25E}' : Forms1099,
	'{6E3987D0-11D5-4A95-B5B7-E5BCFE88E060}' : JournalEntries,
	'{06ACC334-F4CD-4259-B2A8-149807E97E6C}' : State,
	'{ECE6964D-9F54-4552-9727-F31126FDE3F8}' : ServiceCallProblemTypeParams,
	'{96D7BBA9-27E7-4893-BC78-CC4313BE0DD1}' : IContacts,
	'{03826AF0-3BF7-4C97-B1F1-D5B2CCE19621}' : Items_PreferredVendors,
	'{DA0391B0-6748-4F2D-8FEC-A077DE54FED8}' : IApprovalStagesService,
	'{061D26BF-D1D2-4A8C-A29E-9ECB34E36AC4}' : IDistributionRulesService,
	'{69B00574-A904-4416-AC73-94E84B7882CA}' : IBrazilNumericIndexer,
	'{AC388829-78AF-4297-973E-CC26057B737D}' : ServiceCallOrigin,
	'{91155E58-DB6A-4817-ABA0-657B09C05471}' : CampaignPartners,
	'{1B107C12-CCB2-4F12-A67B-E1700F36570B}' : PredefinedText,
	'{9766B024-E4F6-4116-98AC-DE54D618BFFA}' : IDeductionTaxSubGroupsParams,
	'{2CE582CB-83A3-49C0-AF0B-5C7F6EA88B0B}' : IMultiLanguageTranslations,
	'{A91769F5-16B5-49A6-8305-A2DC6054206F}' : IDistributionRuleParams,
	'{3A1E1C0F-EEA6-43A5-893C-280A50D37410}' : BPPriorities,
	'{14E8A7AE-CC48-4793-B4C6-4942E83F92BD}' : IApprovalTemplatesParams,
	'{CD72781D-9EE9-4A21-8953-C5721F506955}' : DepositsParams,
	'{B9614205-7D1D-4EEC-9E2E-B1F6F1ACE50F}' : BlanketAgreementsService,
	'{0677DAD5-92DA-441E-A674-13DE601888FB}' : IAlternateCatNum,
	'{E0E5F6AB-18E3-45F8-A9DA-D2AB88B08A54}' : IDunningTermsParams,
	'{1D5336D5-065A-44D3-AFCC-D8BBEFB03234}' : EmployeeRoleSetup,
	'{450A7F0E-0D42-4720-907E-C672EE2F6382}' : ISalesTaxAuthoritiesTypes,
	'{5E97458D-A97E-4369-B747-9AFD1A04A0D9}' : ColumnPreferences,
	'{65C62A16-791E-4D58-A0F9-1ED312BE7ACB}' : IPartnersSetupsParams,
	'{001A7E87-FD95-421B-8F59-DBA53D45745B}' : ServiceTaxPostingParams,
	'{8289DE12-A145-459F-90F2-69A907294981}' : IActivitiesParams,
	'{6751B54D-0896-4E23-9511-D4BE79AB78B4}' : ColumnsPreferences,
	'{445CC71E-29FC-41F0-ACC6-049A2CC3CF36}' : ISalesOpportunityInterestsSetupService,
	'{1E3842BA-EAE5-4CAC-A134-0328B7986BBC}' : EmployeeRolesSetupService,
	'{BCA3F54F-34D2-4E1C-A700-AD1C35F0B415}' : ITeams,
	'{5BB202A1-E560-4E34-ACB3-2ECA52FFB274}' : IBankPages,
	'{AB946B33-0679-4E78-92EE-BAFFC4DAA9AE}' : BlobTableKeySegments,
	'{5BD31F83-42C4-4D73-95D3-53AA2E45A16B}' : TranslationsInUserLanguages,
	'{83EEB8EC-F354-45A8-A55B-4C2EF2511F9C}' : BrazilBeverageIndexersService,
	'{DC24341F-4CD3-4608-9ED4-745882053E6A}' : IBranch,
	'{F408B086-B6E4-4EE0-9B95-710C117E56F0}' : IRecipients,
	'{BDDB80DE-CB4A-44DC-8BAC-1F1169E23805}' : EmployeeTransferParams,
	'{2167C74B-B692-4B1C-AE1E-721CA61EA8A1}' : CampaignPartner,
	'{879F8B93-27BD-48D8-BFB9-34F47B572F48}' : EmployeeRoleSetupParamsCollection,
	'{24323C3C-1853-425E-96F9-1D441B2D462F}' : BankStatementsImportFile,
	'{A1CC204F-6BD1-417A-A6F8-9A3E7C96D28B}' : IPickLists,
	'{DEA042B3-1E27-4546-9F43-D78BD356E060}' : MessageDataLine,
	'{225FB23A-8178-4A0B-A9F4-88D1F33278DC}' : IBOELineParams,
	'{280836CC-E077-4487-8759-D06DC3E31076}' : IUserValidValues,
	'{11067A79-5484-43A2-945C-7408CDCF01E6}' : Budget,
	'{3B0A3979-DE99-4162-8B2F-A8D4C9737B71}' : IBatchNumberDetailsService,
	'{231A13D7-5DA8-4467-A263-FDE84A268AC9}' : IPayments_Accounts,
	'{9A4EDA67-F390-4901-80F3-0D85F73994B7}' : IBankStatementsFilter,
	'{10449DDE-FB95-4E0E-B699-D13949A808CF}' : ApprovalTemplateDocument,
	'{D2FE59A3-5DA7-403C-9EAB-EF2C8CD8EFEA}' : IChangeLogsParams,
	'{B9127E1F-9408-4957-B724-6A3A9AE42C74}' : IEmployeeRoleSetup,
	'{D9C8E19C-6F74-4457-BEC3-332EABE6D013}' : AccountCategoryService,
	'{21B9721D-5933-4547-A8F9-2AFB83B6735F}' : ISeries,
	'{3C0844B7-EFC9-4F84-99C7-EE736EDF6A89}' : BlobParams,
	'{64D39F13-2594-4AE9-A4C1-E32EA143C3C7}' : SalesOpportunityCompetitorsSetupService,
	'{819AD6EF-E5DB-4FBA-8387-17863BEFE018}' : BrazilFuelIndexerParams,
	'{23CD8BD9-08A1-469B-936F-6C468F37B31A}' : ExtendedTranslation_ResultLines,
	'{F6E76C2D-0F98-4358-B0F3-BE632E6CC9F7}' : BOELine,
	'{108C5978-B8B4-452F-9C4E-67ECDE1AA94E}' : SalesOpportunityInterestsSetupService,
	'{472B7A32-EB83-4D3A-9908-699D5C8DC33B}' : IBPBankAccounts,
	'{E6144A85-69CC-4178-A0B2-BDC8BED4930E}' : ICurrencyRestrictions,
	'{8F4727F1-1991-4F80-8363-F7E1ABD6AF5E}' : IVatGroups,
	'{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}' : ISpecialPricesDataAreas,
	'{A44871DD-1C9F-4CCA-B9F9-CF688753D4B2}' : FinancialYear,
	'{1B562911-6C93-4858-B003-D2586E02BA48}' : ICallMessages,
	'{930EBAD5-80E3-46B6-9DCB-BB6F73541C5D}' : CompanyInfo,
	'{036CFBA9-9D90-46D7-BCA2-5C1B028E56A4}' : ServiceGroup,
	'{C65DEE24-288A-43E4-9F93-93F384B157BB}' : IBPBranchAssignment,
	'{1442D59A-3803-4A00-B991-1652819C0E7E}' : CreditLines,
	'{F17A759E-0E4E-448D-BA57-E6EF3760A591}' : IBrazilBeverageIndexer,
	'{9147FC50-6FF2-40EC-B59B-2F9302B4A31D}' : IBusinessPartnerGroups,
	'{13CC4089-F2FA-4B28-9BD9-75F6DC0E44B3}' : CommandParam,
	'{67D827C6-26FA-43AD-84B9-38F2C233BEB8}' : IApprovalStage,
	'{1520690D-0D25-415A-B290-66DF277561FE}' : BPAddresses,
	'{FF4507B4-AF5E-4599-89D6-B24974CE248E}' : MessageHeader,
	'{A68554D5-F932-4B92-980E-6060777F59F4}' : IServiceCallType,
	'{6D9B2EFB-F9A8-4AE9-9C92-6C0DDF80EA56}' : MessageDataColumn,
	'{AC6E5992-362B-4007-8C90-1AA8DF3B3BA2}' : ReportLayoutParams,
	'{5421B2C4-A3D9-4965-9ED8-1A0BEEECCD5C}' : OriginalItemParams,
	'{054C0B23-FE27-46A4-990C-901A4906BEB5}' : Attachment,
	'{84920F8B-AB22-4ECF-997E-DDEDEDA235B3}' : DefaultDocuments,
	'{3BDD39A5-7A7A-4DD1-963A-5C3500A6B262}' : BrazilFuelIndexer,
	'{83C6551A-5E1D-4651-8272-88BA8B56E728}' : IFinancialYearParams,
	'{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}' : IDocumentsAdditionalExpenses,
	'{910FEA90-B652-4099-9817-3AA0CF635963}' : IClosingDateProcedure,
	'{57803F71-402E-40E7-94A1-A479207BD227}' : IBankStatements,
	'{C04822E7-C6E2-46D3-94FC-712AFB757912}' : EmployeeRoleSetupParams,
	'{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}' : IProductionOrders_Lines,
	'{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}' : IWithholdingTaxData,
	'{F4F504EC-6960-4064-BC79-BD395CB495B7}' : ProfitCentersService,
	'{07B255E1-6AF8-4615-BAC4-D258D316BF1B}' : ActivityStatus,
	'{8CA91808-D098-4416-8368-E426484BA8DB}' : ICommandParam,
	'{A5EC07B2-5898-4104-8015-F876A386D231}' : IEmployeeEducationInfo,
	'{8F1131E9-C31E-4F6D-BC3A-1F94AE2CEACF}' : ServiceContract_Lines,
	'{066F2531-FDDC-46CF-9795-BD09D7E3A4C9}' : BlanketAgreements_DetailsLines,
	'{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}' : IBillOfExchangeTrans_BankPages,
	'{E8289C17-9062-4232-A0B9-F82C67364B57}' : LegalDataService,
	'{BB817262-453B-4151-9F56-BFD987164133}' : IOccurrenceCodesService,
	'{40BA4F6D-54E1-41DD-A912-C9D3A4C5EA28}' : IBrazilFuelIndexersService,
	'{9A0BF629-D6FA-4CD8-A7E7-2C57E0677593}' : LegalDataParams,
	'{9BCDAE48-582B-4E76-BD8F-E8A77BC6CF6E}' : IProductTrees,
	'{F2BCB557-408E-4D6C-B46D-7E5517D939B2}' : BPFiscalRegistryID,
	'{5C730C88-3D5F-4C01-911A-56813AD89504}' : IApprovalTemplateQueries,
	'{42D4F1DC-5789-4594-A1D7-601CAFBBA6C9}' : ExternalCallParams,
	'{5BD5C9AB-52F6-411E-992F-1D507D70F6C1}' : BankStatementRow,
	'{9883D635-027D-472C-AAA6-AC346F3DF308}' : ServiceCallTypeParams,
	'{EA2133A7-F8D4-4444-834F-1129CE2081EB}' : Queue,
	'{2FE8BD34-3F78-4FE0-A577-EE9496E8F294}' : ILengthMeasures,
	'{9B7AB6DE-2A25-4329-9423-6B175EB8BCD3}' : IBPCodes,
	'{3D580E7A-74D7-48C1-854B-269EFC3B7F59}' : PaymentBlock,
	'{94A52D5C-D174-4B52-9A5B-2E9E936226DF}' : ReportLayoutItem,
	'{B476320F-636F-42C4-9BA9-2D6CE71D3CBC}' : CustomsDeclaration,
	'{87B9E57D-866B-4AE6-9C1D-571888134690}' : ICampaign,
	'{9A0F5F4B-EE27-4C5D-8BC0-09F916CF962C}' : OccurrenceCodesService,
	'{ABCF9B92-C676-4369-A84F-1A7B29838E4E}' : Layer,
	'{137AD94C-2F5B-42AB-9DB5-309BD89EF224}' : IGeneralDataParams,
	'{37C235F6-0465-4E85-80A0-776D4602B09B}' : ProductionOrders,
	'{384B70CF-CF41-42B7-8599-B65597837C3F}' : FeatureStatusCollection,
	'{15BD344C-48ED-4A6A-8A31-AFBD7A2ED57B}' : Command,
	'{04A02F02-1211-4507-87DB-DBE6A4807718}' : UserTablesMD,
	'{285E7F1A-1AB7-45F3-9A0A-2B1AD538954B}' : IApprovalRequestsService,
	'{16F466DA-6A22-46AE-A5B2-5934A0194D7A}' : BudgetDistribution,
	'{0A65D039-CEA5-4AA4-8F48-F5D6DA35737A}' : ServiceCallOriginParams,
	'{CA7F3C6F-4074-46E9-8B96-3CBDDFC9C320}' : ITaxReportBusinessPartners,
	'{60836D85-E0A0-435F-B237-4A1E79D7D670}' : ICreditLinesParams,
	'{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}' : IEmployeeIDTypeParams,
	'{7F873201-71DD-4678-AFEB-8EB4D0ED45A4}' : ApprovalRequest,
	'{93780531-1F63-4CD5-9F32-2A232E2679C5}' : TaxWebSitesParams,
	'{0D3C05B0-0EF2-4FB1-8A75-345E3893A995}' : IProfitCentersService,
	'{91D09078-1DA3-4320-BDAF-AFCD977F7E83}' : CashDiscount,
	'{632F4591-AA62-4219-8FB6-22BCF5F60088}' : Company,
	'{418E7FC7-70AC-4443-B526-E3C154E6DA4B}' : IOccurenceCodeParams,
	'{7C51D9D4-DDBA-4057-BC03-AEE13B22CD64}' : ChangeLogParams,
	'{2608CED7-EBD1-4F95-B41C-ECDF2CE685E4}' : IAccountSegmentationCategories,
	'{128C44F7-92DA-4BCB-B864-107D02E1ECFB}' : UserObjectMD_EnhancedFormColumns,
	'{248B28DD-1281-4C6C-9780-22D19BA13D1F}' : IDocument_Lines,
	'{216974E8-B66D-4022-9AB1-97BAA96084A3}' : IItemGroups,
	'{CCCB8B97-63C1-461E-957F-858EADAE1E04}' : ICreditLinesService,
	'{17865049-85ED-47FE-8CCF-C481E3373439}' : ItemCycleCount,
	'{7055A28F-3019-4826-A4CC-FC4E5D5E42C7}' : IDimensionsParams,
	'{1688D816-29DF-4BF3-89A8-D6312DF351AB}' : AccountSegmentations,
	'{6C40800B-AFDB-4B88-947B-128F32F24EC9}' : ActivitiesService,
	'{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}' : IBankStatement,
	'{18E244C5-2925-44E3-9DF7-3D8E38583DE0}' : IWarehouseLocations,
	'{81460BB2-567C-447B-9606-1C70FCF4F204}' : CheckLinesParams,
	'{C8D20CC8-E622-4D4A-8EE8-AE014B6271DF}' : VatGroups,
	'{A0324965-FF3F-43FA-BE6B-63DE64C9991F}' : CheckLineParams,
	'{4DEFA778-37C3-4F67-9EF9-2675EEE468F8}' : ApprovalStagesService,
	'{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}' : ISalesOpportunitiesPartners,
	'{DC399818-11FD-4FC3-A46C-B9A3F35E5CD1}' : ApprovalStageApprover,
	'{F1778F57-69E0-4FED-8EA1-D4921A239055}' : LengthMeasures,
	'{E7011745-D89C-48AA-AC84-93CFC315B5CC}' : ExtendedTranslationsService,
	'{50ACD964-9DDC-46E4-9719-56DB0EED92AB}' : IExtendedTranslation_ResultLine,
	'{4B0217F3-1748-4E90-B442-C83DF84BF4B5}' : BlanketAgreementsDocuments,
	'{BDD8F465-17AF-49ED-AA8D-50A52B849D4F}' : IEmployeeIDTypeParamsCollection,
	'{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}' : IChangeLogParams,
	'{F060E5FE-31B3-4480-8A4F-EB5BB0964C4B}' : TaxReportFiltersParams,
	'{9A19D585-D582-4079-BDDB-CA9F28F76603}' : KPI_ItemLines,
	'{1C485004-89C3-4E4F-A043-697986E0D571}' : BlanketAgreements_ItemsLine,
	'{19F3C51D-AE7A-4293-A027-CEA9C9C20B98}' : IUserActionRecord,
	'{58CF80CD-7170-4036-93FC-C43C324FE006}' : ExtendedTranslation_ItemLine,
	'{DBB3E886-60E7-4058-930A-1C7C07CADB2C}' : IManufacturers,
	'{F0DA88A7-72BE-4DF7-9A0A-05600C784DE8}' : CashFlowLineItemsService,
	'{3CE45D97-D58D-4011-812D-32D867DDA8A7}' : IFormattedSearches,
	'{1DC7EF54-44B5-4B53-90E9-EA337660D8F2}' : LandedCostsService,
	'{F44DCA1A-C2B4-4CD3-9536-1471ADBA10E0}' : ApprovalTemplateDocuments,
	'{49353779-B77E-4F0C-B8DE-499566F0A89A}' : InvokeParams,
	'{9C11E37D-538D-4819-85D1-00048E759E11}' : StockTransfer_Lines,
	'{9A92B21A-A70D-489C-86EC-47E379581650}' : StateParams,
	'{86767BCE-5E50-43DB-98D1-AB217A925BF9}' : ILegalDataDetail,
	'{A740D0B2-649F-40A6-AF5E-77FF340AEEFD}' : SBObob,
	'{892F8759-3131-447C-804C-73A754C51B42}' : ISalesOpportunityCompetitorSetupParamsCollection,
	'{743A4F30-AC7F-4606-9AA3-5139F07E08A2}' : IItemCycleCount,
	'{8490CA7E-FCC5-422B-8359-BC2B74FDCD44}' : JournalEntryDocumentTypeParams,
	'{4385C84B-AE8C-424F-9071-546FF9E1D503}' : SalesTaxCodes_Lines,
	'{1CDABF4D-2512-4C50-8387-3D5661526475}' : NatureOfAssesseesParams,
	'{8CA3AB92-1930-4511-4AA8-82D53C3150C3}' : IRecordset,
	'{2C728EFB-8BF9-4D0A-8135-E53AD4CDC064}' : IRecipientCollection,
	'{1C972937-3B53-45EE-9728-516996023C1A}' : Payments_CreditCards,
	'{69FA8A61-A978-4B0A-AF72-0419D377EDF2}' : ILegalDataParams,
	'{722D7EF1-D469-4168-B435-F4434F1502A0}' : UserMenuParams,
	'{2760F015-04C7-40D5-88DD-499BFD8B6CD1}' : BOEPortfoliosParams,
	'{4701FCE6-F62A-47EC-BF1A-FA9894901984}' : AlertManagementRecipients,
	'{ACAC0540-ACCA-4278-8EB8-2300D893ADD1}' : IGeneralCollectionParams,
	'{A8A658F8-0A8A-4CEF-B5F4-481C3D4652FA}' : BillOfExchangeTransaction_Lines,
	'{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}' : IApprovalTemplateStage,
	'{30EB7C61-BD42-4AAF-877E-DB6253066688}' : ICockpit,
	'{E53F69BA-CA7A-4D3D-86BF-B36CC42A3646}' : UserMenuItem,
	'{F8306AD8-D5B1-4CBE-A36B-ECF55FF2D3FE}' : ExtendedTranslation,
	'{00AC5F7B-92BD-4EB4-AF80-0673AB0B0B7D}' : LandedCost,
	'{84A6DF78-FF80-4131-9A1E-742801212279}' : TargetGroupsService,
	'{4AA87BC6-363C-4A35-9EB3-473BF6785478}' : IImportFileParam,
	'{B0C0628F-DBC1-48C8-9E88-ADB8D7E8758C}' : UserMenuService,
	'{4DBA16CD-1221-4A1F-90C3-E2472532E820}' : PaymentBlocksService,
	'{969FE83E-F0A8-47E9-811E-C8B03F67253A}' : BOELines,
	'{70BFE200-77E9-4D02-B0E6-49800F3E9AD2}' : JournalEntries_Lines,
	'{B6ED00E3-ECCF-40C1-A0EE-5B3C5C22BE8B}' : SalesOpportunityInterestSetupParams,
	'{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}' : IApprovalRequestsParams,
	'{85EBDF2E-252D-4489-9E2F-FE17C36ACE86}' : ChartOfAccounts,
	'{DD85FFF4-93C1-4673-9129-175B77C1CC4C}' : IUserDefaultGroups,
	'{F9FF31EB-6912-401D-91E5-ADDC459EBECA}' : SalesOpportunityReasonSetupParamsCollection,
	'{99074C83-3748-491D-AD31-7EDE65691225}' : CompanyService,
	'{97F84FDF-0E1F-4C2A-9FC2-B779411EC1EB}' : ICompanyInfo,
	'{C9C4DE1F-9409-446D-AC6A-0FAD12624939}' : IBrazilBeverageIndexersParams,
	'{65BDBFCE-903B-43E2-98FD-8B46471141BD}' : LegalData,
	'{C1DD2F9D-7198-47C3-936D-46E421503333}' : IMaterialRevaluationFIFOParams,
	'{E8E96048-6DF2-4DE2-8311-72582D7F4512}' : EmployeeTransfersService,
	'{3E16229E-BFD2-42F0-9044-85D8EB97865F}' : MaterialGroupsParams,
	'{B728546D-EA5F-4122-9FE0-759C89BF95D0}' : IAttachments,
	'{563777FD-DD54-40BC-BC70-3DF2EA78F859}' : IProjectParams,
	'{FC030AB5-B942-4D71-A5BF-1EAA5D9BC808}' : ITaxReportDocuments,
	'{0D31ADD3-85B1-40F1-979F-8612E10B8DD8}' : ISalesForecast,
	'{3329D652-8FFF-4076-B051-A4B503878986}' : BusinessPartnerProperty,
	'{61408D92-9E9A-4A1F-B5B0-A60332828007}' : ISalesOpportunityInterestSetupParams,
	'{13B1D6B4-A9ED-4787-8B8B-24AAE9525342}' : IServiceCallOriginParamsCollection,
	'{BCCBA528-E381-4559-90D2-A242DE43AD60}' : ServiceCallSolutionStatusService,
	'{87447CCD-DE87-4992-A2FD-2B0E26460BCB}' : IShowDifferenceParams,
	'{70CF9E47-2388-4A02-BC90-6F7CA6220DCB}' : ILegalDataDetailCollection,
	'{4CD3DB89-C622-42EF-BEBD-7BB1CF9F5E54}' : ExtendedTranslation_ResultLine,
	'{19A76A7C-7D0A-43FB-B70C-2338FCAA6453}' : BankStatementRows,
	'{B2BFF6DD-6309-40EB-BC59-75D1996BD77D}' : IExternalCall,
	'{17854208-BA31-4EAB-9481-C0806F815FA0}' : IDimensionsService,
	'{638D8662-F163-4574-B69D-11B5C6696733}' : BrazilStringIndexerParams,
	'{48B89C08-2AE9-435F-B7C4-D7219E938E46}' : IValidValues,
	'{DCC7C980-6F3B-4823-872C-5DAD0BBA3A42}' : CampaignItems,
	'{D8BCB8BC-6DD1-4D3A-ABBF-FA7A18396B2C}' : ICustomerEquipmentCards,
	'{DA13FA15-615B-4F4D-9E61-120A803D3F32}' : IBrazilNumericIndexersService,
	'{A3DFD03F-4F42-44A0-9EBD-ECA4370209DD}' : SalesPersons,
	'{831AB766-3423-4E64-8EB1-42614102CDC7}' : IDunningTermLines,
	'{ADCC23F1-37CE-4327-BE13-88D1E14F8877}' : Payments_Invoices,
	'{A86FB678-5037-4F08-AD65-6C281693C16F}' : IReportLayoutPrintParams,
	'{0DA4D491-BDE7-4126-81E1-BCDA814B5332}' : SalesOpportunitiesPartners,
	'{28F2FDF3-FCEC-4D90-983B-D4C805891EC0}' : UserObjectMD_ChildTables,
	'{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}' : ICheckLineParams,
	'{6C62EE4B-B4A6-4BD1-B0E3-D81EEB7888CA}' : IChangeLogsService,
	'{F63CDC3F-A87E-4BEF-99DD-8F1540BD524D}' : DeductionTaxSubGroupsService,
	'{B10E527A-7667-46CC-AA30-461F5D93FA99}' : ServiceTaxPostingParamsCollection,
	'{116B0B02-4096-48F9-A00C-E99E6EE7ADA1}' : IOccurenceCodeParamsCollection,
	'{F20289AA-1F5D-421F-A23A-0A50FE3BBEE7}' : AccountCategoriesParams,
	'{43A00E70-9D54-4A08-BE46-BD22286DF8EB}' : IDunningTerm,
	'{A55338A2-5402-41BB-9588-39EC814AB644}' : IServiceGroup,
	'{6A7BB82D-309D-4A45-818A-6FAB750C449C}' : DNFCodeSetupParamsCollection,
	'{051656EB-47C7-4435-B61D-D4135C235EA5}' : TaxWebSite,
	'{438F04FE-3A92-426F-BD6C-29807B132A19}' : LandedCost_ItemLine,
	'{6625CFCF-AADC-4D47-A83E-C1C786666117}' : IBlobParams,
	'{856AB71E-0D54-4BA5-95CA-7135D77040EC}' : PaymentRunExport,
	'{336661D7-9504-4915-9EAD-6DF66DBBA590}' : ISeriesService,
	'{8A1D0D45-C379-4714-87A6-F81EA6284EEB}' : ICountry,
	'{000DE7D3-9F70-4BA6-BDE0-F4FFFDD7813E}' : WarehouseLocations,
}
CLSIDToPackageMap = {}
win32com.client.CLSIDToClass.RegisterCLSIDsFromDict( CLSIDToClassMap )
VTablesToPackageMap = {}
VTablesToClassMap = {
	'{6EA82155-C282-4F2D-90C4-BF6F95269228}' : 'IBOEPortfoliosService',
	'{78A768C9-EDA6-4798-AFC3-114DEC3DE8E5}' : 'IQueryCategories',
	'{907E9130-6B06-4C32-91E2-453846193486}' : 'ICockpitsService',
	'{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}' : 'IEmployeeIDTypeParams',
	'{41776B28-16AF-4699-B4FC-475989790FB8}' : 'IReportType',
	'{948C7B32-1518-45ED-99A3-94AA328CD7FF}' : 'IApprovalTemplateUsers',
	'{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}' : 'IJournalEntryDocumentTypeParams',
	'{9AA94F66-6356-43C6-A77E-C638B796511B}' : 'IMaterialGroupsParams',
	'{FC2AB5F1-3242-42D2-985E-D23052C9834A}' : 'IDistributionRule',
	'{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}' : 'IDepositParams',
	'{842F5C3F-67A6-42B4-8181-98EFB9520A5F}' : 'ICustomsGroups',
	'{FCF196BC-2669-4A6D-92C8-33896FD2D3B1}' : 'ICampaignsService',
	'{13792BEB-6BDC-46EC-A35F-F98DF2B98CD6}' : 'IBOEDocumentTypesService',
	'{341FC52D-5088-4DE4-8308-7085F8D950A1}' : 'IAlertManagementParamsCollection',
	'{DF63C280-18C5-4444-BDAF-59318E9ED979}' : 'IGTIParamsCollection',
	'{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}' : 'IActivityParams',
	'{44F97BA6-22A5-4687-BFBF-863A346A414C}' : 'IKPIsParams',
	'{A6DA575B-E105-4585-9F4B-50CC4044EEDD}' : 'IDocuments',
	'{68C60132-0DD3-4AD2-B4FF-DB358A6184BC}' : 'IIndustries',
	'{BAEEDA1A-8CBE-4C07-B23A-CBC9BCE6AE37}' : 'IAlternativeItemsService',
	'{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}' : 'IBlobTableKeySegment',
	'{17F42A0A-DF72-432D-9953-1993A831A197}' : 'IEmployeeIDType',
	'{C9A336DC-4108-44D2-8161-5420E75E8475}' : 'IServiceGroupParams',
	'{67D0EFEB-7047-4726-98B7-C60B83F0F98D}' : 'ITargetGroupsService',
	'{F09A4CB0-F8CA-4342-A44D-82DE3395B011}' : 'IPaymentTermsTypes',
	'{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}' : 'ITaxReportBusinessPartner',
	'{38B3A4C7-93BE-4A6C-A060-C54D34979E1C}' : 'ICashDiscountsParams',
	'{D0D6E022-B36B-44E9-BD9A-24E3169AD532}' : 'IDashboardPackageImportParams',
	'{BC7EF5B4-EEA5-4C83-8478-FBC484133A79}' : 'IOriginalItemParams',
	'{F675D408-2207-4E44-AE93-3BFDA7DE7CA3}' : 'IAlertManagementRecipients',
	'{D9D5A329-257D-45AE-8897-AFD53838C099}' : 'ISection',
	'{259FA540-F962-4A5D-9BF5-E9772AF43A31}' : 'IBPCode',
	'{05167588-6D3A-4C0E-AEFA-284CFDA23B7E}' : 'ICampaignBusinessPartners',
	'{DD85FFF4-93C1-4673-9129-175B77C1CC4C}' : 'IUserDefaultGroups',
	'{1EFF6EB3-9368-4A68-B619-0B57A134F0CE}' : 'IItems',
	'{1C764D4F-63DA-46FE-BD81-56548EEDB2F6}' : 'IPeriodCategory',
	'{3443DB6C-7014-4BC3-A860-F4934E449818}' : 'IStatesParams',
	'{A8AB919D-856C-4883-959D-57D7CB9C51F2}' : 'ITaxCodeDeterminationsParams',
	'{2C08600E-B9F0-432D-9D95-F934DDC01165}' : 'IRetornoCode',
	'{B93946BC-D44E-4D81-8071-B56EF0830B51}' : 'IAlertManagementRecipient',
	'{D2D6E703-7339-4D1A-BC4B-6BFF83622871}' : 'ISalesStages',
	'{A60820F4-BCF8-4153-8E22-34DDF1E4F1E9}' : 'INatureOfAssesseesService',
	'{CC51470B-7859-4DC8-B636-E3856A52C02D}' : 'IAlertManagementParams',
	'{5691EAF4-B571-4BDA-B908-F7596767830E}' : 'IApprovalTemplateTerm',
	'{03664F1A-4FCF-401A-84E1-934D1F101EA4}' : 'IApprovalStagesParams',
	'{943EB4D4-ED2B-4815-B6D8-3CA50DF8D139}' : 'IServiceCallProblemType',
	'{EB892090-5B7A-48F1-849C-5F4A0048B2DA}' : 'IBrazilMultiIndexer',
	'{BEB8ACDC-E50B-4DA3-8281-EF5228E55099}' : 'ITerritories',
	'{5128D2EC-8CF5-47BD-A12F-B53211A1CE54}' : 'ISalesOpportunityReasonSetup',
	'{EE047C63-413F-4CEA-B8BC-A4223AA6B482}' : 'IShippingTypes',
	'{E21D5CB9-5B51-4598-8989-75A702DFC29E}' : 'IBlanketAgreements_DetailsLine',
	'{7C3BB8E9-B896-4556-859F-FCAC93473C04}' : 'IDeductionTaxGroups',
	'{23BBD185-4EAB-45D4-950E-194CD4A96BE2}' : 'IPartnersSetupParams',
	'{F2353C93-5EBC-4DDC-B750-717E97F41CF2}' : 'IAccountCategoryService',
	'{EFA05C0F-B878-48E4-AA66-4E266FA5CC1A}' : 'IBlanketAgreementsDocuments',
	'{9048203E-CE84-4B53-B4C7-61632BD2DEAC}' : 'IItems_PreferredVendors',
	'{268D6CC3-E244-4AD7-B009-16C8ED7F710A}' : 'ISBObob',
	'{FFA101D6-62B7-4615-A050-5BEE79FBF640}' : 'IExtendedTranslation_ItemLine',
	'{DFBE6ED2-7510-49C9-8C39-35B939DB586D}' : 'IEmployeeTransfersParams',
	'{414D11BE-00FC-4AF1-BEDF-C0B3308E1A40}' : 'IAcctSegmnt_Categories',
	'{24D0CDB0-8592-4CD3-A247-9A51C55D060F}' : 'IBrazilFuelIndexerParams',
	'{910C52B1-ABDC-409F-80EE-D6219E33497E}' : 'IDynamicSystemStrings',
	'{34995651-4568-4AAE-B831-60693B932A35}' : 'ISpecialPricesQuantityAreas',
	'{416CFADF-9DA6-47BD-A490-09AC890FC530}' : 'IAlternativeItems',
	'{BC55E0FC-ADC0-4DF6-9F2A-5CD35E4F5A75}' : 'INFModelsService',
	'{9E52D02D-16FC-4E2C-87FC-CD070F5D646A}' : 'IAlertManagement',
	'{FF79D2D4-A79B-4DCF-A3BB-14A8B01A5FDC}' : 'IDecimalData',
	'{BBB45A32-F446-4ED3-915B-C811BBA6C2C7}' : 'IRelationships',
	'{1E293D13-1EC1-4DF2-A5CC-7FE45030EEE5}' : 'IKnowledgeBaseSolutions',
	'{2165070A-0BA0-4409-AC85-52A47508F236}' : 'IDeductionTaxSubGroupParams',
	'{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}' : 'IReportLayoutParams',
	'{83E2FD00-E8D3-40D0-91E7-59166A6309DC}' : 'IBOELinesService',
	'{0DAE1D7B-419B-4573-9315-8094285CD00A}' : 'IBOELinesParams',
	'{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}' : 'IApprovalTemplateQuery',
	'{14AF3328-811A-4FE5-A55A-C17BECE10062}' : 'IBlanketAgreementsDocument',
	'{31BF39D4-A4A4-4FF6-A946-D7DFB4B37D5D}' : 'IOpenningBalanceAccount',
	'{3EFBE347-7427-4459-A969-37AE80D0AFEF}' : 'ISectionsParams',
	'{46BCE59C-FCA9-4AC3-8A3D-07090C41E5F2}' : 'IBankChargesAllocationCodesParams',
	'{4207538F-AAC0-4EDD-9002-6F710410D5C6}' : 'IMultiplePayments',
	'{D48F490F-CB1F-46B9-A941-D1A84FCE1DB2}' : 'ISeriesCollection',
	'{49836643-1102-4273-B5DC-F4ADEC94D843}' : 'IExtendedTranslation_ResultLines',
	'{C392F1DC-DD79-4692-8FBA-7CAD03877993}' : 'ISerialNumberDetailParams',
	'{B83BBBFA-E5AF-48B4-B147-2DE092BF1E64}' : 'IHouseBankAccounts',
	'{57FF304C-3414-48FA-8059-4F3B10FB37C9}' : 'IExtendedTranslationsParams',
	'{FACA7A4B-46DF-4875-8591-A5A0C3D9761F}' : 'ICostCenterTypes',
	'{A6EE3F95-9556-4409-9BCB-9DC06E009E22}' : 'ICashFlowLineItemParams',
	'{F183C834-5321-46B5-96B6-0BC50D1726E8}' : 'IChooseFromList',
	'{2C4B93F4-860D-481D-85C5-020876095197}' : 'IFIFOLayers',
	'{B25EF557-1E57-4CA8-BDD3-B2AF96815278}' : 'IBOEDocumentTypesParams',
	'{690E65AA-B309-41D2-9697-0B6CBB58C4AF}' : 'IApprovalTemplatesService',
	'{6AAAB602-C1E1-4988-BF5D-ECE369936FC0}' : 'IExtendedAdminInfo',
	'{26767B5A-7011-4E58-A9FE-D6D1F8568B0F}' : 'IEmployeeRolesSetupService',
	'{475F9BBF-F860-48CE-8FD7-71E461BD7D95}' : 'ISalesOpportunityReasonSetupParamsCollection',
	'{C842A9F9-CB16-4E6A-A1DB-7D8964889C74}' : 'IDepartmentsService',
	'{135ACD20-6799-42E5-8ECC-4077CEF72812}' : 'IElectronicSeriesParams',
	'{5BCB48BA-A4A6-4087-B1FD-1E9F076EFD33}' : 'ITaxInvoice_OperationCodes',
	'{A0F06FB9-C420-4CA6-B1A5-D688A5322E8D}' : 'IJournalEntryDocumentTypeParamsCollection',
	'{323B7F1F-31D3-45CE-A325-B81187DA9C0C}' : 'IExtendedTranslation_ItemLines',
	'{9EB0E81A-9442-4C9A-B096-93C6134E684D}' : 'IContractTemplates',
	'{E7838784-BDDC-4EC2-A812-C96B19D169C5}' : 'IBlob',
	'{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}' : 'IBrazilBeverageIndexerParams',
	'{CC279FBE-7088-42E9-A579-EB2E3E971076}' : 'IUserFields',
	'{45CD0988-1275-4D2C-BF2C-5D04CB984489}' : 'IBrazilFuelIndexer',
	'{3D7A2391-5E52-45DE-80DB-A09ECADBD5A3}' : 'ICustomsDeclarationParams',
	'{CD0EAC7A-0E3F-4ED3-A9BF-42D4100A3FBB}' : 'INatureOfAssesseesParams',
	'{D1B282C5-C219-48C7-93E3-6BD01735EFD5}' : 'ITargetGroupsParams',
	'{2C35D508-856B-43E0-A1A5-EC6BCA16E62A}' : 'IBPFiscalRegistryID',
	'{013F0389-85E2-4B8B-9285-18843E4236F3}' : 'IValidValue',
	'{7276D73A-6B18-4F86-B517-6DB9363FC772}' : 'IServiceCallSolutionStatusParams',
	'{7AF930C1-1211-4953-BD69-5F64B3743316}' : 'ILandedCost_CostLine',
	'{95968C8C-6866-4B59-BB03-E08A96684591}' : 'IBankChargesAllocationCode',
	'{F8DE7AAE-13BF-46BD-A4B0-CD9535AAED63}' : 'IDunningLetters',
	'{93E5E52B-181E-46B8-96CB-1C066AC04DCA}' : 'ISerialNumbers',
	'{741AA803-AB33-4FD7-B664-63116291D6CE}' : 'IBillOfExchange',
	'{5C87125B-3FCE-4FC7-9AD9-430D8E555426}' : 'ITargetGroup',
	'{9057028D-894C-4F75-877F-A856F36DDEA5}' : 'IUserQueries',
	'{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}' : 'IUserMenuItem',
	'{6228C442-C4B7-4841-9275-54B459F42BCB}' : 'IApprovalRequestLine',
	'{EE480268-BD9E-4DD2-8BA2-BBB3C9665448}' : 'IAttachments2',
	'{E14BAC45-1772-407F-B255-178FF23F91E3}' : 'IDiscountLines',
	'{27A32FF4-4CC4-4D4A-860F-83E81EC52F3A}' : 'IDeductionTaxHierarchies_Lines',
	'{C7037B05-9DF8-47CA-8819-4D9460F03794}' : 'IBrazilFuelIndexersParams',
	'{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}' : 'IAlternativeItem',
	'{461F000F-9DB2-45D0-808D-FA552126FF16}' : 'IMaterialRevaluation',
	'{33201180-255B-46DF-A8C4-E8A7E2855353}' : 'IReportLayout_TranslationLines',
	'{DF33FA96-E656-4AF6-A877-AAC7D5A8D586}' : 'IUserLanguages',
	'{457DC126-2E63-4241-9497-1A104E8AB550}' : 'IElectronicFileFormatsService',
	'{4735E037-68A6-474D-AEC5-F5D9BD3B09A6}' : 'IBrazilStringIndexersService',
	'{F2A7926C-BDB1-4151-8FEC-5A58C2BCC600}' : 'IBrazilStringIndexersParams',
	'{B6F90D8C-7E5B-4EE0-8E60-D536FD4C3665}' : 'IElectronicSeriesCollection',
	'{881C8CF2-FDB4-43ED-866F-4F6A4827E02C}' : 'IBOEPortfolios',
	'{C1DD2F9D-7198-47C3-936D-46E421503333}' : 'IMaterialRevaluationFIFOParams',
	'{B3D0E8B3-C0C8-4CC2-9D0B-121D6384E95E}' : 'ISalesOpportunitySourcesSetupService',
	'{5D48514C-4B40-4C2A-9FC9-8CC2518B0F8E}' : 'IBudgetScenarios',
	'{681D8515-EF90-42C7-9463-3CE0B14E72C5}' : 'IActivityInstancesParams',
	'{D50B349A-0226-4D72-9FEC-B38D21C65FE0}' : 'IDimensionParams',
	'{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}' : 'ICommand',
	'{6B52A2CD-C166-404E-9A92-A0D4B812488A}' : 'ISalesOpportunitySourceSetup',
	'{7E9C6F20-F9A1-470C-B50D-D1EA112B030A}' : 'IBankStatementRows',
	'{81BEC420-E567-4353-95BA-71F26FD54BCD}' : 'IApprovalTemplateDocument',
	'{729A48C9-675C-4F2C-9A16-2C29D1825C05}' : 'IServiceGroupsService',
	'{DA6203BB-DE30-4AC7-9567-5822C3463335}' : 'IFinancePeriodParams',
	'{CF683F67-7A73-4D71-9C10-821A1E7715DC}' : 'IMaterialGroup',
	'{4DC9AE34-8FF4-4900-8021-D641EF898358}' : 'IServiceCallProblemTypeParamsCollection',
	'{9C192F0B-809E-4115-B560-3D683C99D48E}' : 'ILegalDataParamsCollection',
	'{A93138D1-7360-49C9-8F1C-EC5239C494B0}' : 'ICampaignPartner',
	'{CCCB8B97-63C1-461E-957F-858EADAE1E04}' : 'ICreditLinesService',
	'{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}' : 'IBillOfExchangeTrans_Deposits',
	'{0C607D21-E148-42CE-AF58-E8C38EB26275}' : 'IUserObjectMD_FormColumns',
	'{7DCD3C0C-6B56-4572-8015-8E4CC744A095}' : 'IBankStatementsImportFile',
	'{475E4307-5C54-4449-BFCA-2CCCBBEB6448}' : 'IServiceCallTypeParamsCollection',
	'{14BE1C8C-20CA-4E53-A55C-097AB57740B8}' : 'IActivityInstancesListParams',
	'{1E6899F1-7A1B-460A-B134-3A82F9083C77}' : 'ILandedCostsCodes',
	'{DFE5A4A8-345B-43B3-A77F-906F10F142EE}' : 'IFactoringIndicators',
	'{297DB996-8B05-4D4A-BD2D-333A643F7303}' : 'ICallMessage',
	'{38DA089C-BF1E-457E-B486-F1E35293F5F1}' : 'IBusinessPartnerProperty',
	'{2E2720A5-8F7C-45D3-BF5A-DD5BE3769F84}' : 'IUserObjectsMD',
	'{439BEC35-EDAA-4F54-8FEF-647658D06148}' : 'IAccrualType',
	'{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}' : 'IBOEPortfolio',
	'{02B05079-F380-48A7-A573-0BB7307A52C0}' : 'IApprovalTemplateStages',
	'{B148F7EE-7416-4B22-B266-55321DF794D8}' : 'IApprovalRequestDecisions',
	'{BD54054F-D434-4DC7-8D84-8020C653432C}' : 'IItemProperties',
	'{954AC9A0-5402-436F-A20B-38E093F0A636}' : 'IPaymentBlocksParams',
	'{D2EDF723-F433-4A0A-A4A9-5D8E628CC3E3}' : 'ICashFlowLineItem',
	'{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}' : 'IProductTrees_Lines',
	'{4631570A-DAE1-43BB-9E4A-BA9957E593E1}' : 'IOriginalItem',
	'{3C3E8D7B-D724-4ED0-BBE3-955F8711B716}' : 'IReportFilterService',
	'{DB038EC5-97EC-4D04-8E6A-AF01A5C05900}' : 'IBillOfExchangeTransaction',
	'{E498C4B2-E919-48EA-B512-79DE65B1F5CE}' : 'IColumnPreferences',
	'{087B9C04-C8CF-4606-A7B4-8FEC6CB8AE1D}' : 'IKPI',
	'{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}' : 'IBPFiscalTaxID',
	'{0D31ADD3-85B1-40F1-979F-8612E10B8DD8}' : 'ISalesForecast',
	'{5079035B-D0E5-4D0E-AFB1-6CB1FBAB11AE}' : 'IColumnsPreferences',
	'{52C8673B-CA79-4476-9F2E-28109AE17545}' : 'IContactEmployees',
	'{0577F672-2A66-452A-9597-5008904A3940}' : 'IBranchesService',
	'{70DC39C1-4019-4618-9D1F-7D227A68491F}' : 'IAccrualTypeParams',
	'{EA19AA7D-6063-4C86-BC1C-27B0572209ED}' : 'IRetornoCodesService',
	'{03111771-050A-41FF-A2EA-A17B8C7E99FE}' : 'ITaxCodeDetermination',
	'{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}' : 'IEmployeeRolesInfo',
	'{32E2CAC3-EEFA-4C2B-B916-C43A8A39BEAE}' : 'IMessage',
	'{6076F945-EB54-4BA8-B00C-891BB860356A}' : 'ITaxReportGroup',
	'{6C92660E-0507-4C90-8DDB-1C5B61AB41AA}' : 'IBusinessPlaces',
	'{EFFD365E-5096-4B19-9187-986F83D337E0}' : 'IApprovalTemplateTerms',
	'{C4DCA924-9189-4969-8609-8564D6E5AFAA}' : 'IMessages',
	'{6ECD0990-1D31-4DDF-AF93-494A9DD7A104}' : 'IDocument_SpecialLines',
	'{4F06C847-96F8-4421-B1C7-2FA41FCB0CFF}' : 'ISalesOpportunities',
	'{5FE3FCA3-E93E-4106-8190-F62CB9FBF137}' : 'IForms1099',
	'{746B0E89-0625-4B20-BD67-029DB26D074D}' : 'IBOEDocumentType',
	'{5E6A92D1-9BAB-4BB4-A379-2428006247C3}' : 'IChecksforPayment',
	'{9A5FCF99-FC73-47E0-A68D-A8156EB864E5}' : 'IDocumentChangeMenuName',
	'{F41E89FB-D3D8-47BE-858C-332AC9DF8A86}' : 'IExtendedTranslationsService',
	'{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}' : 'IMessageDataLine',
	'{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}' : 'IApprovalTemplateUser',
	'{596CFFFE-E95F-472D-8243-37094A850DCF}' : 'ICurrencies',
	'{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}' : 'IMessageHeader',
	'{FF87B29E-5D38-4901-A443-8672387A200A}' : 'IUserMenuService',
	'{99E84704-3E04-40DD-BE1D-854068378E3A}' : 'IDepartmentParams',
	'{F5221870-4600-47CC-AFA3-779B11403820}' : 'ILandedCostsParams',
	'{91B68A10-74AD-4FAC-98F5-746FDD45D957}' : 'IUserLicenseParams',
	'{48D8151E-BF85-4760-B7F8-B5E7E1B47937}' : 'IKPI_ItemLine',
	'{9D202A0D-3D49-47E0-AC0D-90333C553E85}' : 'ICompanyService',
	'{B7546EA2-0DE7-4F28-8596-ACCD323F584E}' : 'IBusinessPartnerPropertyParams',
	'{060F033E-2FC9-4266-90AE-3271AC203A59}' : 'IJournalEntries',
	'{AADAC0AA-6CBA-47EC-B923-05B029715123}' : 'IDocumentSeriesUserParams',
	'{4B03F542-E836-450B-89AC-04E7609E6B35}' : 'IBOEInstructions',
	'{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}' : 'IBranchParams',
	'{900A8956-ACED-4E66-B254-78EB55F7089F}' : 'ICheckLine',
	'{56B7FEB9-ECC9-4A64-BDDF-0AB70C3746D0}' : 'IJournalEntryDocumentType',
	'{3D83A354-89D4-46AF-841A-D659A0C2678E}' : 'IColumnsPreferencesParams',
	'{A6D332DA-630B-44C7-AA91-69F2C1A2501D}' : 'IQueueMembers',
	'{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}' : 'IDNFCodeSetupParams',
	'{B7334829-8658-48D1-9FF6-056E90AEB07D}' : 'ICostCenterType',
	'{92C049DE-4E6A-47E8-8910-1C4C83E91780}' : 'IServiceCallOriginsService',
	'{7E723574-58DD-46D4-9856-44426EE523AE}' : 'IJournalEntryDocumentTypeService',
	'{5077C7F7-E950-40A4-9A0E-71CF776AE79F}' : 'IDashboardPackagesService',
	'{9FEF81F9-9C21-4B0B-9EDA-0EF9A5C98739}' : 'IServiceCallOrigin',
	'{93CF87D1-95CB-459C-A906-729819461CA1}' : 'ICommandParams',
	'{96D7BBA9-27E7-4893-BC78-CC4313BE0DD1}' : 'IContacts',
	'{7B677F06-BB36-462B-BABF-99676A90BC70}' : 'ICashFlowLineItemsParams',
	'{389082B5-04A7-4CB6-A0FB-EEC065715703}' : 'IDeductionTaxSubGroupsService',
	'{C44BDF5B-E877-4183-AC97-76D9E4921BB3}' : 'IBOEPortfoliosParams',
	'{DA0391B0-6748-4F2D-8FEC-A077DE54FED8}' : 'IApprovalStagesService',
	'{061D26BF-D1D2-4A8C-A29E-9ECB34E36AC4}' : 'IDistributionRulesService',
	'{009BFAE6-2701-4E63-B9EA-1335C9658CC0}' : 'ITaxReportAccounts',
	'{6C62EE4B-B4A6-4BD1-B0E3-D81EEB7888CA}' : 'IChangeLogsService',
	'{DC24341F-4CD3-4608-9ED4-745882053E6A}' : 'IBranch',
	'{FC571383-8375-4B7D-BDEF-4EF2B91B7751}' : 'IUserTablesMD',
	'{69B00574-A904-4416-AC73-94E84B7882CA}' : 'IBrazilNumericIndexer',
	'{7B45A310-CED5-4D41-9A54-BED0F11B6950}' : 'IBOEDocumentTypeParams',
	'{61408D92-9E9A-4A1F-B5B0-A60332828007}' : 'ISalesOpportunityInterestSetupParams',
	'{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}' : 'ICampaignBusinessPartner',
	'{90E9CFE3-0440-4E26-B8E7-975A9A4638B4}' : 'IDefaultReportParams',
	'{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}' : 'IWorkOrder_Lines',
	'{54B31C27-C3D0-41DE-89BA-5E8800D0361D}' : 'IWizardPaymentMethods',
	'{813B8F2A-F8BC-4C70-A043-CF099057F3B8}' : 'ITaxReportFiltersParams',
	'{9766B024-E4F6-4116-98AC-DE54D618BFFA}' : 'IDeductionTaxSubGroupsParams',
	'{2CE582CB-83A3-49C0-AF0B-5C7F6EA88B0B}' : 'IMultiLanguageTranslations',
	'{A91769F5-16B5-49A6-8305-A2DC6054206F}' : 'IDistributionRuleParams',
	'{DA13FA15-615B-4F4D-9E61-120A803D3F32}' : 'IBrazilNumericIndexersService',
	'{14E8A7AE-CC48-4793-B4C6-4942E83F92BD}' : 'IApprovalTemplatesParams',
	'{CB6D5BD6-878B-4966-9E6B-8599949B657F}' : 'ICallArgument',
	'{625162C1-3894-460F-94EC-72D6AFEA34D2}' : 'IUserTables',
	'{72274C66-4457-4D17-8F61-014F5520C434}' : 'IServiceCallTypeParams',
	'{53062C45-E05A-4717-909C-3C3073E10DDD}' : 'IBankChargesAllocationCodeParams',
	'{BFC32883-8D3F-49F9-A985-3F9B3B37260F}' : 'IRecipient',
	'{CD47A725-AEA8-4224-93D3-F31848990C42}' : 'IEmployeeAbsenceInfo',
	'{87447CCD-DE87-4992-A2FD-2B0E26460BCB}' : 'IShowDifferenceParams',
	'{5EE41EF0-1319-400C-807D-7CAA21FBA466}' : 'ITaxReportGroups',
	'{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}' : 'ISalesOpportunitiesLines',
	'{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}' : 'IPredefinedTextParams',
	'{687B84CE-D196-49C9-A617-C6FC57BB2204}' : 'ICostCenterTypesService',
	'{F29A5E07-7C8B-4706-99D7-9BFB85180358}' : 'IProfitCenter',
	'{EF865450-BA41-490B-B580-3D566BA3681A}' : 'ICampaignsParams',
	'{5C594028-D730-4298-952E-4616C5047BC6}' : 'IServiceContracts',
	'{0677DAD5-92DA-441E-A674-13DE601888FB}' : 'IAlternateCatNum',
	'{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}' : 'ICreditLine',
	'{738D011A-EA2A-4205-B009-53C7C64D73DD}' : 'IMultiplePayment',
	'{731625D2-901C-40C1-A06C-C6A72FC00D8C}' : 'ICertificateSeriesParamsCollection',
	'{E0E5F6AB-18E3-45F8-A9DA-D2AB88B08A54}' : 'IDunningTermsParams',
	'{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}' : 'IPeriodCategoryParams',
	'{2DBFED56-4DB4-455A-9C22-E2C01C052D39}' : 'IBillOfExchangeTransaction_Lines',
	'{D154A6C0-19F8-46CE-B66D-FFC856FC0310}' : 'IApprovalStageApprovers',
	'{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}' : 'IServiceContract_Lines',
	'{E78A5751-F0F7-4A5A-BDE0-B59BC461F57C}' : 'IAccrualTypesService',
	'{D7B39E88-0C6D-4B8A-A083-AEC336746884}' : 'IDunningTermLine',
	'{317E97C8-89A1-45FB-BDD3-8AB420DDF340}' : 'ICampaignItems',
	'{450A7F0E-0D42-4720-907E-C672EE2F6382}' : 'ISalesTaxAuthoritiesTypes',
	'{FA8FD318-6971-4E8B-B6E9-959A938455C6}' : 'IServiceCallSolutions',
	'{AB9A1501-E84C-4EC2-9869-8A843FBCCBB6}' : 'ITaxWebSitesParams',
	'{F7BC21C9-ACB8-4B44-8488-5BE5D15BADEA}' : 'IDashboardPackagesParams',
	'{3E64E5EC-70CA-4129-BC06-0CE9B2058843}' : 'IDocument_Installments',
	'{F8E64A61-69DC-439B-82C9-0D7B1BD5E4B1}' : 'IDNFCodeSetup',
	'{2AC79865-8E0D-42CD-8A97-AA4ADF24B4EE}' : 'ITranslationsInUserLanguages',
	'{32ABB501-14BB-4467-8D98-597A9420D8C6}' : 'ITaxReportAccount',
	'{1FA65DB2-F84E-4C7C-A48D-E4043BCF6557}' : 'ICashDiscountsService',
	'{9A49C2D7-CC5F-4CEE-95B9-6A8B16CA2031}' : 'IEmployeeRoleSetupParamsCollection',
	'{36143269-AD6C-4AD9-9A2E-AE3273141D8C}' : 'ILandedCost_ItemLines',
	'{A5CDC033-47D7-4019-801A-8443F14D52D0}' : 'ITaxReportFilterParams',
	'{39DAE3AB-708D-4123-BC50-CC57F05D734E}' : 'IFinancePeriod',
	'{0B5DE094-FB49-4B4C-AA7C-F87F5E3A932F}' : 'IDistributionRuleLines',
	'{65C62A16-791E-4D58-A0F9-1ED312BE7ACB}' : 'IPartnersSetupsParams',
	'{301718D4-11C9-4C5F-88DD-3609C5FA21FF}' : 'IStockTaking',
	'{C131D463-24C3-424A-B734-589D0F452D2E}' : 'IGeneralData',
	'{8289DE12-A145-459F-90F2-69A907294981}' : 'IActivitiesParams',
	'{31DE5655-438F-420E-83D0-016C88203706}' : 'IGeneralService',
	'{445CC71E-29FC-41F0-ACC6-049A2CC3CF36}' : 'ISalesOpportunityInterestsSetupService',
	'{AAC173E2-F851-4F94-AE33-00CC4F38FDCD}' : 'IServiceCallSolutionStatusService',
	'{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}' : 'IBrazilMultiIndexerParams',
	'{BCA3F54F-34D2-4E1C-A700-AD1C35F0B415}' : 'ITeams',
	'{5BB202A1-E560-4E34-ACB3-2ECA52FFB274}' : 'IBankPages',
	'{1AD8B5F7-8076-488A-8493-1E430FF9EEAA}' : 'IExternalCallsService',
	'{308CD5F0-5908-47B2-BE56-A1104C45FCF7}' : 'ITaxReportSeries',
	'{F7E00222-C717-40BF-9DC0-A95200B0FEEB}' : 'ITaxWebSiteParams',
	'{9316E5DC-6A1E-4D66-A31D-40576A355AB9}' : 'IServiceCallSolutionStatusParamsCollection',
	'{B743C51D-0E51-400E-8245-91331C0A6762}' : 'IMaterialRevaluationFIFOService',
	'{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}' : 'IActivityInstanceParams',
	'{E985FCDC-43E0-47C4-821D-7F60D4BC9009}' : 'IActivityStatus',
	'{43C8A942-73F5-40BE-9675-CC8946003F0A}' : 'IAccountsService',
	'{43AC045C-DCA2-4150-B937-AB205DCA22E6}' : 'IWarehouses',
	'{F408B086-B6E4-4EE0-9B95-710C117E56F0}' : 'IRecipients',
	'{99FB9754-BDAE-4C8D-BA96-4F2263A73A6A}' : 'IPriceLists',
	'{A22E33CF-C423-4581-8C7C-382E5D59B301}' : 'IPredefinedTextsParams',
	'{7D947F60-6017-44AA-AEAC-9721FF263D5E}' : 'IBPPaymentMethods',
	'{E60CDE47-FBBE-4719-BCFF-022E70710702}' : 'ISalesOpportunityReasonSetupParams',
	'{F72D84B1-6F70-44CD-8B91-2FC481ADFE2E}' : 'IPaymentBlocksService',
	'{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}' : 'IUserMenuItems',
	'{40BEDE06-EB4F-4914-BCDF-71018C6FE98C}' : 'ICampaignPartners',
	'{9020ED56-6B7D-4FAC-8D93-B185D1E65A59}' : 'IPaymentRunExport',
	'{FFA181B4-6482-45B5-901D-525B13F491EA}' : 'ICheckLinesParams',
	'{DFF94208-9A06-4594-992D-8D758D296BD4}' : 'IDownPaymentsToDraw',
	'{8276E7F7-9178-409D-88DB-5A8D41DED6E5}' : 'IPayments_ApprovalRequests',
	'{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}' : 'IApprovalRequestParams',
	'{07F27714-4BA9-42E3-8E93-3418F73C55E4}' : 'IDocumentPackages',
	'{33DDE1AB-5C1F-454E-840A-884CF62A6747}' : 'IDeductionTaxHierarchies',
	'{73042DE8-A510-4C53-B256-FD249BA13723}' : 'IDiscountLine',
	'{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}' : 'IPayments_Checks',
	'{046161D0-6736-48A3-A619-805A9C68F5C1}' : 'IAccrualTypesParams',
	'{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}' : 'ISectionParams',
	'{18B4A57B-206A-4CF7-B94B-7325AED96137}' : 'IAttachment',
	'{225FB23A-8178-4A0B-A9F4-88D1F33278DC}' : 'IBOELineParams',
	'{7615E097-E207-4E8D-A114-74031034136B}' : 'IWorkOrders',
	'{EE912DF0-9D0E-49BE-999D-B88AA59B305D}' : 'ITaxWebSite',
	'{420B8379-83B3-4AE9-B7B8-4DDF73D3085D}' : 'ICountriesParams',
	'{E053D931-2878-44FD-88A0-2E572EA10DB0}' : 'ISectionsService',
	'{DF517030-9004-4965-96A3-CFE398A79DDC}' : 'IBusinessPartnersService',
	'{CBAB706D-E5DE-4D36-BB28-C6705D247335}' : 'IMessageHeaders',
	'{3B0A3979-DE99-4162-8B2F-A8D4C9737B71}' : 'IBatchNumberDetailsService',
	'{231A13D7-5DA8-4467-A263-FDE84A268AC9}' : 'IPayments_Accounts',
	'{E962CD81-105C-4E61-91B8-A86AFE748209}' : 'IBOEInstructionsService',
	'{9A4EDA67-F390-4901-80F3-0D85F73994B7}' : 'IBankStatementsFilter',
	'{3FFD991B-9010-4832-89C6-903CBB33AD7D}' : 'IDepositsParams',
	'{D2FE59A3-5DA7-403C-9EAB-EF2C8CD8EFEA}' : 'IChangeLogsParams',
	'{BDD8F465-17AF-49ED-AA8D-50A52B849D4F}' : 'IEmployeeIDTypeParamsCollection',
	'{B9127E1F-9408-4957-B724-6A3A9AE42C74}' : 'IEmployeeRoleSetup',
	'{5923A153-B41F-4676-A5B6-1FAD645FDD7B}' : 'IDefaultCreditCards',
	'{8A8F6C7B-BD55-45C5-A28C-C81A786B0EB8}' : 'IImportProcesses',
	'{8ED60CF1-3116-4C89-A77D-B67ED48F2F22}' : 'INCMCodeSetup',
	'{55ACC8CD-3412-452A-9AF8-304A0A56FD3B}' : 'IUserPermissionTree',
	'{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}' : 'IBOEInstructionParams',
	'{A07F5790-711E-49FC-9843-935F7C8CDB85}' : 'ISalesTaxCodes',
	'{A1CC204F-6BD1-417A-A6F8-9A3E7C96D28B}' : 'IPickLists',
	'{22219181-9047-4C89-BAC3-4BB311AE77E4}' : 'IServiceCallSolutionStatus',
	'{77C5B820-63C3-4825-9279-964224F7BE00}' : 'IReportLayout',
	'{12A99320-EEE7-4398-90E2-74BC014F5CE2}' : 'ITransactionCodeParamsCollection',
	'{63A44BC7-2798-4F4A-B0C7-B407EA917702}' : 'ITransactionCodeParams',
	'{874D0559-C968-49F1-9562-E57E493A47AB}' : 'ICreditCardPayments',
	'{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}' : 'IStateParams',
	'{472B7A32-EB83-4D3A-9908-699D5C8DC33B}' : 'IBPBankAccounts',
	'{1470A4FE-6338-4FC7-AD95-D6E2CB4DBB20}' : 'INCMCodesSetupService',
	'{E6144A85-69CC-4178-A0B2-BDC8BED4930E}' : 'ICurrencyRestrictions',
	'{8F4727F1-1991-4F80-8363-F7E1ABD6AF5E}' : 'IVatGroups',
	'{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}' : 'ISpecialPricesDataAreas',
	'{3503F7F1-5A0C-4D08-A498-0D9619097C09}' : 'ITaxReportFilter',
	'{E5EB0192-6BCF-43FF-94E7-8A17C7F6B566}' : 'IDistributionRulesParams',
	'{216D15B1-8639-435F-8C85-4967488AD161}' : 'IApprovalTemplateDocuments',
	'{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}' : 'IEmployeePrevEmpoymentInfo',
	'{A7FDC596-1604-4DE8-841C-DADBA34B32E0}' : 'ITaxWebSitesService',
	'{1C7C966F-B713-42BF-9A74-0B15A649E63D}' : 'IProductionOrders',
	'{0219BFB4-6A47-47F5-942F-8B05389A05FB}' : 'ICreditLines',
	'{2DC3C9A3-A237-4DB3-A0BC-AB92D24ED68E}' : 'IReportTypesService',
	'{B4CCEAAF-2511-4E3A-916F-8F0F7B6479C5}' : 'IDepartment',
	'{59837FCB-2720-45D3-85BF-9F075D5D6560}' : 'ILegalData',
	'{13B5A261-F351-4DB5-8D4A-5A6C9083CF19}' : 'ICustomsDeclarationService',
	'{C65DEE24-288A-43E4-9F93-93F384B157BB}' : 'IBPBranchAssignment',
	'{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}' : 'IUserPermission',
	'{177775C1-0633-42DE-8711-AF5D5DD650D8}' : 'IFormPreferencesService',
	'{04305B71-95D2-4327-B7A5-ED12DFB5FB1B}' : 'IOccurenceCode',
	'{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}' : 'IReportTypeParams',
	'{F17A759E-0E4E-448D-BA57-E6EF3760A591}' : 'IBrazilBeverageIndexer',
	'{9370956A-E63B-4B62-9AA0-EA32A0673B8A}' : 'ITaxInvoices',
	'{B2CFCDE5-3753-4A47-9199-38D08718B3AE}' : 'IEmployeesInfo',
	'{BC23E72E-CE89-4492-BEEC-6F5FE1D694A2}' : 'ITargetGroupsDetails',
	'{C1F83FBE-3A3F-4A81-8B0B-B5485DC6ADF9}' : 'IBudget',
	'{E47E4050-E7A6-4FD5-8F38-A8066213559A}' : 'ICampaignParams',
	'{D0A0837D-25C5-4511-9C31-B749CA452C8F}' : 'IGTIsService',
	'{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}' : 'IApprovalStageApprover',
	'{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}' : 'ITaxJurisdictions',
	'{B9A56422-93A0-4480-BAF3-48907F403CB8}' : 'IJournalVouchers',
	'{19F3C51D-AE7A-4293-A027-CEA9C9C20B98}' : 'IUserActionRecord',
	'{86767BCE-5E50-43DB-98D1-AB217A925BF9}' : 'ILegalDataDetail',
	'{C90D9F7D-14B6-465B-BE3B-48FABA68CF75}' : 'IBankStatementsService',
	'{0383EE76-4325-42FE-8164-91C2E8FDE242}' : 'IActivityLocations',
	'{BF7FD103-23BD-401E-8A87-DBAFBBB7DB37}' : 'IProfitCentersParams',
	'{67D827C6-26FA-43AD-84B9-38F2C233BEB8}' : 'IApprovalStage',
	'{4DA92EEC-3781-4B5B-B466-4001E7B6F439}' : 'ICheckLines',
	'{A6DB2CDA-3A42-4A70-918C-53595D6091C9}' : 'IChecksforPaymentLines',
	'{910426DC-C7C4-4EBC-8FB3-97BC2805C81D}' : 'IBOEInstructionsParams',
	'{A68554D5-F932-4B92-980E-6060777F59F4}' : 'IServiceCallType',
	'{EC084090-ED29-4B85-BAF8-8058B245EA06}' : 'IUserBranchAssignment',
	'{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}' : 'IField',
	'{E7092C39-C3B3-4928-A5AB-B0FF9B885D5E}' : 'IReportLayoutItems',
	'{3302B4B4-1F71-4D62-8D6E-85DEAB64B4EB}' : 'IWithholdingTaxCodes_Lines',
	'{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}' : 'IEmployeeRoleSetupParams',
	'{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}' : 'ISalesOpportunityCompetitorSetupParams',
	'{EF86275D-924A-4AC9-9461-E9AAF80894B6}' : 'IRoundedData',
	'{9324B0F9-58FC-404D-81BB-5591BE9E6A27}' : 'IEmployeeTransferDetails',
	'{80E28887-F468-4172-9043-D442BCAB1F55}' : 'IBrazilBeverageIndexersService',
	'{09C6E920-908C-4FD2-9CBF-21C3F4329A33}' : 'ITeamMembers',
	'{EA80E8EC-0D43-4C8B-9F8C-BA5D71F12578}' : 'IKPIsService',
	'{92196C1E-B89A-4F4E-8E37-A1F2FAC71C5C}' : 'IApprovalRequest',
	'{FA06709C-FEAA-4E4B-85F1-063578C32965}' : 'IChangeLogDifferencesParams',
	'{83C6551A-5E1D-4651-8272-88BA8B56E728}' : 'IFinancialYearParams',
	'{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}' : 'IDocumentsAdditionalExpenses',
	'{910FEA90-B652-4099-9817-3AA0CF635963}' : 'IClosingDateProcedure',
	'{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}' : 'INFModelParams',
	'{CDB52791-B0FC-4BE1-A712-06941AF91D52}' : 'IItemWarehouseInfo',
	'{4583DECC-E80D-46AE-B3C0-308FC33C58E9}' : 'IAdminInfo',
	'{98F79F87-3825-465E-8E69-E7E416534B7B}' : 'IProfitCenterParams',
	'{ABDA119B-E21C-44A5-8DA3-CA870D0D9486}' : 'ICheckLinesService',
	'{57803F71-402E-40E7-94A1-A479207BD227}' : 'IBankStatements',
	'{87B9E57D-866B-4AE6-9C1D-571888134690}' : 'ICampaign',
	'{E2C5A384-883B-4963-A4A4-30C6F553818F}' : 'INotaFiscalUsage',
	'{913C6394-89AD-47A9-9390-1B8686E65312}' : 'IUserKeysMD',
	'{12980E2B-036E-4D5D-90F9-44383341DF63}' : 'ICountriesService',
	'{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}' : 'IProductionOrders_Lines',
	'{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}' : 'IWithholdingTaxData',
	'{CE69987E-8F99-4FC1-8C86-837E5246AFA2}' : 'IPackagesTypes',
	'{A31EC6FB-9B3A-439E-828D-C95CB0646555}' : 'IPeriodCategoryParamsCollection',
	'{D2BAB599-C7C6-4301-B925-B6BB51092A79}' : 'IBudget_Lines',
	'{E8632E10-873F-4EBF-8339-E57C985D4472}' : 'IGetChangeLogParams',
	'{8CA91808-D098-4416-8368-E426484BA8DB}' : 'ICommandParam',
	'{A5EC07B2-5898-4104-8015-F876A386D231}' : 'IEmployeeEducationInfo',
	'{A0B604D4-3D7B-427D-9EA1-15456A2329BD}' : 'ICertificateSeriesParams',
	'{F788A8C7-F4E4-47BD-BBC8-79670F3EAE61}' : 'IElectronicFileFormat',
	'{1FEF5698-93E1-4167-AEA0-4BB151792623}' : 'IBatchNumbers',
	'{8DD14B84-6D7B-49E9-8137-A3E7F9A3642F}' : 'IStockTransfer',
	'{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}' : 'IBillOfExchangeTrans_BankPages',
	'{481D2A59-9B17-4C56-B245-04F85EA1C74E}' : 'ISalesPersons',
	'{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}' : 'ITargetGroupParams',
	'{0207412D-F955-46BA-AE96-E749573B4106}' : 'IServiceCallActivities',
	'{58A42D29-DF69-4C14-9467-656666D09CD5}' : 'IFinancialYearsService',
	'{280836CC-E077-4487-8759-D06DC3E31076}' : 'IUserValidValues',
	'{5E23BA23-D431-4212-BD7F-D5CB7E263494}' : 'ICommissionGroups',
	'{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}' : 'IDocument_LinesAdditionalExpenses',
	'{40BA4F6D-54E1-41DD-A912-C9D3A4C5EA28}' : 'IBrazilFuelIndexersService',
	'{B63DD56F-5008-48E8-B7FF-DA56720F422D}' : 'IEmployeeTransfer',
	'{EBBCE4C7-AE00-46A4-A0BA-851F42E7CADF}' : 'ICallArguments',
	'{87ED882F-80FA-487D-8DA1-058E42B6BFA8}' : 'IBOELines',
	'{9BCDAE48-582B-4E76-BD8F-E8A77BC6CF6E}' : 'IProductTrees',
	'{1C7661BB-2694-4ECF-94EF-588ECB0CB8AD}' : 'IBoxes1099',
	'{5C730C88-3D5F-4C01-911A-56813AD89504}' : 'IApprovalTemplateQueries',
	'{C8D6687E-6A96-4458-AF54-B052F20C26B3}' : 'ICostCenterTypeParams',
	'{F656351C-32B3-4FE5-9054-221B5988B7E7}' : 'IAccountCategory',
	'{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}' : 'IUserObjectMD_FindColumns',
	'{6692DB25-3CF4-44C4-932D-1F6D13DF6E7C}' : 'IRetornoCodeParamsCollection',
	'{002ACD1C-A740-40C7-9927-33E4CB58536F}' : 'IMessageDataColumns',
	'{BB817262-453B-4151-9F56-BFD987164133}' : 'IOccurrenceCodesService',
	'{D6BF90B4-5DE1-4A71-8463-FEB7AB1A9AB4}' : 'IInvokeParams',
	'{AABB98FA-CCB5-4F0D-A6B6-5684708886C9}' : 'IAccountCategoriesParams',
	'{36EA48A3-B828-45D8-B5E2-AE3584E54AE3}' : 'IBPPriorities',
	'{A24C6BD6-06BA-47B3-8B67-D628AEFAD721}' : 'IMessagesService',
	'{598819B6-D5B0-4CF1-A533-D966C1D9267A}' : 'ILegalDataService',
	'{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}' : 'IAlertManagementDocument',
	'{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}' : 'ILandedCostParams',
	'{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}' : 'IDunningTermParams',
	'{74490BE7-8344-4F48-90C9-2A811E54AA49}' : 'IServiceGroupsParams',
	'{EB66D894-270C-4DF1-B76A-AB91ABE88D03}' : 'IBlanketAgreements_DetailsLines',
	'{FB002972-8E0A-4819-AC30-B955B37C4772}' : 'IApprovalRequestDecision',
	'{BED262F2-5DAF-4D1B-91C6-B5DCABE54A90}' : 'ISalesOpportunityCompetitorSetup',
	'{6F49AA78-C540-44BD-B70F-050870C5BBF0}' : 'ITargetGroupsDetail',
	'{21B9721D-5933-4547-A8F9-2AFB83B6735F}' : 'ISeries',
	'{2FE8BD34-3F78-4FE0-A577-EE9496E8F294}' : 'ILengthMeasures',
	'{24464254-073D-4148-A045-3CFDB71DE48C}' : 'IUserPermissionForms',
	'{C29BB9BD-1EC7-4427-A484-E79EC58F7224}' : 'IFinancialYear',
	'{4DB4395A-231C-4BE3-B582-F6C7C70D109E}' : 'IPartnersSetup',
	'{9B7AB6DE-2A25-4329-9423-6B175EB8BCD3}' : 'IBPCodes',
	'{41A28682-1C73-4C77-ADC8-5F805700B244}' : 'IKPIParams',
	'{D5B65908-18C4-493A-B1F3-BC7987AF01DD}' : 'ISeriesLines',
	'{86FB8743-E265-47A1-BE6C-7A5E9FEEAAAB}' : 'IBlobTableKeySegments',
	'{1B31BF62-5F56-4A20-876D-1B7BC75824C9}' : 'IWithholdingTaxCodes',
	'{CEDAC9E2-A77F-4518-A524-1403050FFD3D}' : 'IDocument_ApprovalRequests',
	'{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}' : 'IBPPaymentDates',
	'{FECE5DF5-E254-43C1-BDD9-5C82097B9B9D}' : 'IBlanketAgreements_ItemsLines',
	'{9147FC50-6FF2-40EC-B59B-2F9302B4A31D}' : 'IBusinessPartnerGroups',
	'{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}' : 'IMessageDataColumn',
	'{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}' : 'IExtendedTranslationParams',
	'{CC3579ED-1C61-4864-8E51-208A3DCDFC93}' : 'IPayments_CreditCards',
	'{137AD94C-2F5B-42AB-9DB5-309BD89EF224}' : 'IGeneralDataParams',
	'{EF61561B-2AB6-42DB-82EF-C440E4A4A71C}' : 'ILandedCostsService',
	'{6B7F9C14-6E99-4405-8796-51F1EF735889}' : 'IEmployeeIDTypeService',
	'{C1BF990C-0774-48F2-901C-84E414D881C6}' : 'IBusinessPlaceTributaryInfos',
	'{7A4DE818-7DD3-4035-97F8-6696A65651BF}' : 'IBanks',
	'{646FEBEB-91D7-4517-8CB0-B550DCA64490}' : 'IGeneralDataCollection',
	'{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}' : 'IServiceTaxPostingParams',
	'{669DAF62-7776-4DF5-AB51-B35DABFC4ACE}' : 'IEmployeeSavingsPaymentInfo',
	'{DACFE08E-8A02-43ED-B762-5E664186FB0E}' : 'IStockTransfer_ApprovalRequests',
	'{27D88079-2713-4D2E-94D4-3C6F14D18140}' : 'INatureOfAssesseeParams',
	'{0ED256A5-4119-4245-A961-A01AD0134E4E}' : 'IBusinessPartnerPropertiesService',
	'{F510FF2B-D307-487F-9ECC-EE436A6EBF10}' : 'IStockTransfer_TaxExtension',
	'{E22659B2-7CEA-4351-96C4-80160CFAADE7}' : 'IBlanketAgreementsService',
	'{285E7F1A-1AB7-45F3-9A0A-2B1AD538954B}' : 'IApprovalRequestsService',
	'{0C349981-9E5F-4814-910B-8995D5E9D32E}' : 'IDimension',
	'{2C841DE4-014D-44C4-9D48-6A9B7BCD789A}' : 'IBankStatementsParams',
	'{CA7F3C6F-4074-46E9-8B96-3CBDDFC9C320}' : 'ITaxReportBusinessPartners',
	'{C7DF4768-56A6-45D9-9C2B-916008846E76}' : 'IProject',
	'{60836D85-E0A0-435F-B237-4A1E79D7D670}' : 'ICreditLinesParams',
	'{3BA8DAED-5B33-4CE4-A4B8-B4308D86E524}' : 'ICompany',
	'{C083AAA6-1496-4E5F-82B0-201194FD8651}' : 'IBlanketAgreements_ItemsLine',
	'{38EFFD46-32F0-4190-A769-E13A5CCC3F47}' : 'IDefaultDocuments',
	'{49593AE6-FB7B-4B31-9029-F84067559E54}' : 'ICreditCards',
	'{E79D3C41-BFE7-4C5A-B586-4F627E021A1C}' : 'IPayments',
	'{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}' : 'IStockTransfer_Lines',
	'{83CB8BC4-7FE1-4C02-81B4-35EE3C252DC8}' : 'ILandedCost_CostLines',
	'{0D3C05B0-0EF2-4FB1-8A75-345E3893A995}' : 'IProfitCentersService',
	'{68FA6F71-028F-434E-AAA4-32B8BBB67CC4}' : 'ITaxCodeDeterminationsService',
	'{8D14FB10-4616-4AF3-B477-0B87C797AEBC}' : 'IDepositsService',
	'{797B09FC-E40A-42FA-9045-30B351D937F1}' : 'IAccountCategoryParams',
	'{DF6C475B-AD8D-4E52-A412-9500E69DB54B}' : 'IProductionOrders_SalesOrderLines',
	'{812BAA6F-715C-42E4-811F-287EF23E05A2}' : 'ICustomsDeclaration',
	'{19E6540E-4E64-48C1-9525-29D5710D1FFD}' : 'ISalesOpportunitiesCompetition',
	'{418E7FC7-70AC-4443-B526-E3C154E6DA4B}' : 'IOccurenceCodeParams',
	'{DB4F4E62-87CD-4113-8EA9-4EAAC1555DBD}' : 'ISeriesParams',
	'{FE305F7C-1D01-4B99-AB83-BBB8503B8A95}' : 'ISerialNumberDetailsService',
	'{2608CED7-EBD1-4F95-B41C-ECDF2CE685E4}' : 'IAccountSegmentationCategories',
	'{DE680833-445E-4AF0-A7E3-377D5135268B}' : 'IFields',
	'{248B28DD-1281-4C6C-9780-22D19BA13D1F}' : 'IDocument_Lines',
	'{49703681-AAAE-49B5-B2AA-402D622EE537}' : 'ITransactionCode',
	'{7E0EA2EC-9661-427C-B8EB-0C818F908F67}' : 'IBOEPortfolioParams',
	'{70443238-FECE-4E0B-8900-9C5D06C4E71C}' : 'IBOEInstruction',
	'{216974E8-B66D-4022-9AB1-97BAA96084A3}' : 'IItemGroups',
	'{D919D79B-2CE9-4A88-9C3D-59A67A334D81}' : 'I_GenArrObj',
	'{724DEACC-3DDF-46DC-A884-A69751E80603}' : 'ICashFlowLineItemsService',
	'{247CDE70-F00E-4033-8EC1-3E173AEA8596}' : 'ISalesOpportunityCompetitorsSetupService',
	'{7055A28F-3019-4826-A4CC-FC4E5D5E42C7}' : 'IDimensionsParams',
	'{81D132DE-0549-460D-9BEC-2FEDEAB0A950}' : 'IUserFieldsMD',
	'{17785C88-48FC-4D21-A790-81AC72C1D4CC}' : 'IPredefinedTextsService',
	'{1678F2A9-8FBA-47E8-A678-FE06A7D22007}' : 'IEmployeeTransfersService',
	'{EB9E1080-A979-4BA0-895B-D424C68063BC}' : 'IExtendedTranslation',
	'{A6E70E75-647C-48BF-A642-84841BD85B2C}' : 'IAlertManagementDocuments',
	'{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}' : 'IBankStatement',
	'{18E244C5-2925-44E3-9DF7-3D8E38583DE0}' : 'IWarehouseLocations',
	'{7B78B94A-9F54-4A05-9A64-0A1E89484ECB}' : 'IDiscountGroups',
	'{CB4596BC-49AF-40FF-AF45-DC92A9C75C97}' : 'IFeatureStatusCollection',
	'{9DF321C2-6A1D-446B-AE8A-F7C33987D792}' : 'IBusinessPartners',
	'{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}' : 'ISalesOpportunitiesPartners',
	'{2309689C-63EA-4D8E-B675-E6459533E27A}' : 'IElectronicSeries',
	'{6C123256-BF67-4AA6-BE6B-4C085AB0731A}' : 'ISalesOpportunitySourceSetupParamsCollection',
	'{6AC1DA43-B01F-4E2E-8B5A-184BE9C05D80}' : 'IExternalCallParams',
	'{CFD28E0F-8394-4B7D-87A0-52D3AD73254E}' : 'IDNFCodeSetupService',
	'{AC935452-7934-4093-810F-D66BD350A247}' : 'ISalesOpportunitySourceSetupParams',
	'{98DF1BF3-2F28-46C7-8003-FB8D11276237}' : 'ISalesTaxCodes_Lines',
	'{7424993D-6DC0-48E5-AEEF-B10A3177E175}' : 'IAlertManagementService',
	'{A52E0922-634E-4827-9B4A-10D6D46ECE74}' : 'IDataBrowser',
	'{50ACD964-9DDC-46E4-9719-56DB0EED92AB}' : 'IExtendedTranslation_ResultLine',
	'{917BA077-4D88-46A8-B78A-E396315D7E59}' : 'IPaymentRunExport_Lines',
	'{8CC29ECE-02C3-4C7B-851B-5533D2C83627}' : 'ITaxExtension',
	'{B14AF4AA-36E3-4C09-9BEF-6DCED4B5EBFB}' : 'INCMCodeSetupParamsCollection',
	'{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}' : 'IChangeLogParams',
	'{9306DAC4-5FDE-4695-AF50-96349ABA5F74}' : 'IFinancialYearsParams',
	'{C48ABD4C-43C8-4776-87E7-337D661050C2}' : 'INCMCodeSetupParams',
	'{FCB4B06C-8747-4678-85EB-4F28B51A88C8}' : 'IPartnersSetupsService',
	'{9D5AE661-24A0-4F2A-AE75-714F3FF59B91}' : 'IKPI_ItemLines',
	'{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}' : 'IBrazilNumericIndexerParams',
	'{8C5510F0-AA36-4CBD-A5AC-7DCF29EE0249}' : 'IQueue',
	'{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}' : 'IGLAccount',
	'{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}' : 'IItems_Prices',
	'{DBB3E886-60E7-4058-930A-1C7C07CADB2C}' : 'IManufacturers',
	'{A7A2DCAC-BFE4-4CAA-B5D0-A337C4783C60}' : 'IDepartmentsParams',
	'{3CE45D97-D58D-4011-812D-32D867DDA8A7}' : 'IFormattedSearches',
	'{D435C006-B504-4847-B217-8AEA5439B779}' : 'IValidValuesMD',
	'{A177F24C-3E47-498B-9013-8CC3EEC13F78}' : 'IDownPaymentsToDrawDetails',
	'{F6964AD5-EB4F-4E38-824E-60026EA9F159}' : 'IPaymentBlock',
	'{6C589BC6-9ACE-4A99-8097-038E9AC52155}' : 'ILayers',
	'{2647D070-305A-43E8-89AE-B4D2C41E5168}' : 'IBankStatementRow',
	'{A302DDF1-F725-46B9-8CC4-19E5766CEAC0}' : 'IBatchNumberDetail',
	'{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}' : 'IBPWithholdingTax',
	'{71AE6937-9F02-409F-93D0-869D4E6DDE9A}' : 'ITaxReportSeriesCollection',
	'{AF0F5509-8F7B-402A-A7D5-2AC98461825F}' : 'IServiceCallStatusService',
	'{AC21F36A-556F-4374-AAB0-96949C7469FF}' : 'IServiceCallOriginParams',
	'{B0338FF7-542D-4AEA-A097-A51DECA7E671}' : 'ICreditLineParams',
	'{16E2EB82-A981-4E4F-A378-6D4E53B17134}' : 'IServiceTaxPostingParamsCollection',
	'{1445B394-DD5B-4542-9E3B-2B6E9CA92621}' : 'IApprovalTemplateParams',
	'{CF02E105-3575-467B-9AD6-5BF719C9BC8B}' : 'IBatchNumberDetailParams',
	'{85830213-6564-4BBA-95DD-246624D1A4D2}' : 'INFModelsParams',
	'{A3C28485-77EA-4396-9D1F-FAD7279A74A1}' : 'IBlanketAgreementParams',
	'{892F8759-3131-447C-804C-73A754C51B42}' : 'ISalesOpportunityCompetitorSetupParamsCollection',
	'{743A4F30-AC7F-4606-9AA3-5139F07E08A2}' : 'IItemCycleCount',
	'{F5C29BC7-F643-4A93-9026-C045A11D564A}' : 'IMaterialRevaluationFIFO',
	'{E5CFF30C-8D7D-4F36-A505-B2BA0EC0CB21}' : 'IReportLayoutsService',
	'{788DDDE0-9FE1-4653-8F1A-DCBFF4DD0B49}' : 'IDunningTermsService',
	'{8080167A-3150-4B5F-8108-9BE2FA9DC31B}' : 'IEmployeeTransferParams',
	'{E3F9ACA7-17D5-4A5B-8AAF-91CB41E2896F}' : 'IExportProcesses',
	'{8CA3AB92-1930-4511-4AA8-82D53C3150C3}' : 'IRecordset',
	'{2C728EFB-8BF9-4D0A-8135-E53AD4CDC064}' : 'IRecipientCollection',
	'{006B6314-B29C-407F-A8F8-11717E779A2A}' : 'IDashboardPackageParams',
	'{9E37320F-F058-462C-9483-AD67BC65191B}' : 'IState',
	'{0D446022-9A79-4535-9174-EEAE21DF924A}' : 'ISalesTaxAuthorities',
	'{BABAB22E-0679-48A4-B7BD-BB0BF14F927F}' : 'IActivitiesService',
	'{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}' : 'ICallMessageArgument',
	'{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}' : 'IApprovalStageParams',
	'{EE825513-A21F-467A-AAC5-931A7939C954}' : 'IActivity',
	'{3CA31A48-0CEE-436B-9447-E14D8D27C546}' : 'IBranchesParams',
	'{2E9D54CC-66FD-4688-9DA0-6AEE9C263D7E}' : 'IChooseFromList_Lines',
	'{69FA8A61-A978-4B0A-AF72-0419D377EDF2}' : 'ILegalDataParams',
	'{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}' : 'ICockpitsParams',
	'{0B4E873F-65FD-4638-9339-84D197CF8109}' : 'IReportParams',
	'{A46D71C0-8C65-4B7E-BBA7-F6228CA0FE76}' : 'ICashDiscount',
	'{14F49B88-4722-45AC-993A-AD7680142769}' : 'IBlanketAgreement',
	'{ACAC0540-ACCA-4278-8EB8-2300D893ADD1}' : 'IGeneralCollectionParams',
	'{35E59851-3F5C-40B3-9613-BCC32E3B97B8}' : 'INFModel',
	'{29A116DF-AE12-4A45-A5F0-3436E170B26B}' : 'IDeposit',
	'{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}' : 'IApprovalTemplateStage',
	'{30EB7C61-BD42-4AAF-877E-DB6253066688}' : 'ICockpit',
	'{00C7246F-BD54-4E8B-8CE0-39F9C6568F68}' : 'IBusinessPartnerPropertiesParams',
	'{0E2CBAD1-1857-4E2F-8AE4-5246D1F6725E}' : 'IServiceCallStatus',
	'{B551C968-0DE9-48FA-B48D-385284294F16}' : 'IFeatureStatus',
	'{C38D34A0-DA36-4B9A-9211-21F9228EC20D}' : 'ISalesOpportunityInterestSetup',
	'{1B562911-6C93-4858-B003-D2586E02BA48}' : 'ICallMessages',
	'{59DB637B-BF84-4D38-A0ED-1383F2556CA9}' : 'IPaymentBlockParams',
	'{2CF2E472-CA6D-4D8E-8B80-046D28E75C40}' : 'IChartOfAccounts',
	'{4AA87BC6-363C-4A35-9EB3-473BF6785478}' : 'IImportFileParam',
	'{A95C4C3D-71D5-475B-B6D9-BB75D22E1931}' : 'ISalesOpportunityReasonsSetupService',
	'{AFFB904C-0D52-4359-B44B-FB594DC5618A}' : 'INotaFiscalCFOP',
	'{022D793A-3706-459F-A7FE-4169894754D8}' : 'ISeriesLine',
	'{F1E88ED4-1F91-4FE5-B4EB-13B48CB46F52}' : 'IBudgetCostAccounting_Lines',
	'{F68C8591-8115-4DC6-B1EF-5071C5CEB367}' : 'ICampaignItem',
	'{505427E7-5F80-437F-A4DD-972DA3F1C9C9}' : 'IWeightMeasures',
	'{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}' : 'IUserTable',
	'{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}' : 'ICockpitParams',
	'{0038F785-2853-4267-9629-3444A3CCC2AD}' : 'IEmployeeTransferDetail',
	'{4162242D-4217-47FA-BDFF-5070B6D03F30}' : 'IBPAccountReceivablePayble',
	'{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}' : 'IApprovalRequestsParams',
	'{55053980-777B-44CF-8D76-84DD975171AA}' : 'IJournalEntries_Lines',
	'{28DD7AE7-0602-49B2-80EB-827454AA99E7}' : 'ITaxReportDocument',
	'{12696EFB-62EF-4BD0-9B7B-456F3999DAEF}' : 'IBrazilNumericIndexersParams',
	'{ED256951-E65E-40BF-A2E9-2A21741D8720}' : 'IUsers',
	'{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}' : 'IMaterialGroupParams',
	'{7A1600FC-7942-4604-8D55-1923FF369965}' : 'IAccountSegmentations',
	'{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}' : 'IRetornoCodeParams',
	'{269D9A4D-1866-43A0-B5AB-B46035B1667F}' : 'IStatesService',
	'{7B951C46-49D0-4E0C-8832-48B62F4EF0BD}' : 'ICreditPaymentMethods',
	'{106B8134-EDB5-4417-BFAC-4A3A2A7B9419}' : 'IServiceCallStatusParamsCollection',
	'{56F2B212-48C0-453C-9298-380C6F7350F2}' : 'ICertificateSeries',
	'{97F84FDF-0E1F-4C2A-9FC2-B779411EC1EB}' : 'ICompanyInfo',
	'{B7A80F7E-77C0-404E-A8B3-01D0F9136DCF}' : 'ILocalEra',
	'{BCE76DC7-889C-4A7A-B77F-842FC7D0684E}' : 'IBrazilStringIndexer',
	'{038A3F8E-2465-435E-8D05-F510620533C3}' : 'IMaterialRevaluation_lines',
	'{7CBD5DDC-C99C-4D73-9ECC-C8B6CDF2FB92}' : 'IAddressExtension',
	'{C9C4DE1F-9409-446D-AC6A-0FAD12624939}' : 'IBrazilBeverageIndexersParams',
	'{2691123A-50EC-4554-9180-490532131218}' : 'IReportLayoutItem',
	'{BC177C74-40FA-4140-8374-ED45F9FCFF87}' : 'ISalesOpportunityInterestSetupParamsCollection',
	'{0FCFCE88-47F3-4F05-9803-3081D83C92DC}' : 'IAdditionalExpenses',
	'{6446D947-9BED-41FE-876C-B89334D5D85F}' : 'IUserMenuParams',
	'{80B626C7-6F5E-4C42-BBD0-36A311400BAE}' : 'IDNFCodeSetupParamsCollection',
	'{B728546D-EA5F-4122-9FE0-759C89BF95D0}' : 'IAttachments',
	'{B9DC5AFA-1DC2-4BCB-B2D3-B84A889A9B0E}' : 'IServiceCallProblemTypesService',
	'{563777FD-DD54-40BC-BC70-3DF2EA78F859}' : 'IProjectParams',
	'{FC030AB5-B942-4D71-A5BF-1EAA5D9BC808}' : 'ITaxReportDocuments',
	'{F9D49CC8-76E7-4387-AA71-ED03A361F510}' : 'IAttachments2_Lines',
	'{ED79A1AF-2F5B-418E-A90C-1F504B49E364}' : 'IUserKeysMD_Elements',
	'{16403B63-EB90-4781-9C89-05EF77769731}' : 'IDeductionTaxSubGroup',
	'{052A6BA1-A1AA-4A04-ABDE-23FE11833711}' : 'ILandedCost_ItemLine',
	'{EC280F9D-83C0-4324-9B19-18CB128A7021}' : 'IBusinessPlaceIENumbers',
	'{02F225DD-827F-4065-BC4A-14D5F4136D28}' : 'IBPAddresses',
	'{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}' : 'IBankStatementParams',
	'{9739A029-5EB0-499A-9E72-967B98D55ECF}' : 'ILayer',
	'{207685C7-0E68-4A17-AD6C-7C2635B60316}' : 'IBrazilMultiIndexersService',
	'{9AA8D14C-3AB3-44F0-BEDD-0AB156BD2A9D}' : 'ITaxDefinitions',
	'{DFFEC465-C3AA-45DD-ABBC-9D025A328335}' : 'IGLAccounts',
	'{13B1D6B4-A9ED-4787-8B8B-24AAE9525342}' : 'IServiceCallOriginParamsCollection',
	'{E73F2CD8-14C2-4BDD-AEB2-7D7DCFF21571}' : 'IBankChargesAllocationCodesService',
	'{539EA80F-E53D-45C1-9610-C1D138699EFB}' : 'IAccrualTypes',
	'{C9379AB8-CDE2-4A35-99CE-DB1CE9D7950E}' : 'IDefaultElectronicSeriesParams',
	'{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}' : 'IGTIParams',
	'{069837FF-A1F4-4442-92EF-DFEA56C23992}' : 'ILandedCost',
	'{58E6063A-F616-4E44-AC69-8E40356F5830}' : 'IElectronicFileFormatsParams',
	'{82C83910-6247-4BFB-AAE2-C9AD27B1947D}' : 'IApprovalTemplate',
	'{C1751C9B-F39D-4401-87D9-2C0C6B2DD2D2}' : 'IBlanketAgreementsParams',
	'{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}' : 'IServiceCallInventoryExpenses',
	'{C9C6EE8B-66E6-4C3E-91ED-49482CF4B903}' : 'IInventoryCycles',
	'{B829E078-BAC8-4EC5-BFDD-7F4230AE8BF2}' : 'IServiceCallTypesService',
	'{2C1751BA-5CFF-4E47-8C1E-13CAF241A13F}' : 'ISpecialPrices',
	'{E24C2504-36B4-4EE4-A990-0F487E774211}' : 'IDocumentSeriesParams',
	'{17854208-BA31-4EAB-9481-C0806F815FA0}' : 'IDimensionsService',
	'{458A15A5-B980-4543-A289-F6477A36EB24}' : 'IWithholdingTaxLines',
	'{5D29B8B0-A8BC-4905-B713-7DE4207A130A}' : 'IServiceCallStatusParams',
	'{44AB2C0B-390B-43A1-8BCD-529BA39C52C3}' : 'IProjectsParams',
	'{48B89C08-2AE9-435F-B7C4-D7219E938E46}' : 'IValidValues',
	'{B1AB765A-A1F6-4365-BC25-D0C63B496C77}' : 'IProjectsService',
	'{A93CD1FA-F12F-47B0-8FAB-859692B8A653}' : 'IServiceCalls',
	'{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}' : 'IChangeLogDifferenceParams',
	'{7590979F-CE5F-480B-AEA5-2B83A04BE64B}' : 'IApprovalStages',
	'{D8BCB8BC-6DD1-4D3A-ABBF-FA7A18396B2C}' : 'ICustomerEquipmentCards',
	'{292717A3-9E69-4C34-BE56-A61A52CA8AA2}' : 'IBrazilMultiIndexersParams',
	'{0C60C86B-3CB9-4E78-80D0-1AACB3C1C6F0}' : 'IActivityTypes',
	'{831AB766-3423-4E64-8EB1-42614102CDC7}' : 'IDunningTermLines',
	'{343A6016-2B36-4522-B0E9-477A062EF6DB}' : 'IReportTypesParams',
	'{C4397D01-E44E-4B76-80AB-4B888EEA10DD}' : 'IEmployeeReviewsInfo',
	'{A0307CBF-64B1-49E8-B60D-38803E20D107}' : 'ICashFlowAssignments',
	'{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}' : 'IDistributionRuleLine',
	'{8E861D67-6E55-4201-9AE5-F193127E6F67}' : 'IDocumentPackageItems',
	'{70CF9E47-2388-4A02-BC90-6F7CA6220DCB}' : 'ILegalDataDetailCollection',
	'{843B58CC-38C1-4C93-B5F6-533BFB3006BD}' : 'IMaterialGroupsService',
	'{A86FB678-5037-4F08-AD65-6C281693C16F}' : 'IReportLayoutPrintParams',
	'{F09D2D1D-1BB3-4D09-946B-71AE1263D6AC}' : 'IUserObjectMD_EnhancedFormColumns',
	'{3BCB6516-86EB-4170-91BD-7EE4E52D6172}' : 'IBOEDocumentTypes',
	'{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}' : 'ICountryParams',
	'{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}' : 'ICheckLineParams',
	'{9A96D2E9-0308-433A-AE8B-417FE4AD66D3}' : 'ICertificateSeriesService',
	'{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}' : 'ISalesOpportunitiesInterests',
	'{8C5A86ED-4B60-46EB-A0D5-9F529DDF069E}' : 'IPickLists_Lines',
	'{AB7947CF-8191-498D-8B3C-8E04A00957E7}' : 'IPayments_Invoices',
	'{B1D15948-E323-4C52-BA55-70E0678549CD}' : 'IElectronicFileFormatParams',
	'{7DDA3A4A-07A5-43A7-885E-B34217076D17}' : 'IApprovalTemplates',
	'{100612B7-46C2-4489-A406-504575577467}' : 'IApprovalRequestLines',
	'{86A368F0-8603-466A-906F-9FC811B1B711}' : 'IReportLayout_TranslationLine',
	'{B2BFF6DD-6309-40EB-BC59-75D1996BD77D}' : 'IExternalCall',
	'{69A099F3-3B67-46A2-A4EB-6DC399C64078}' : 'INatureOfAssessee',
	'{0CFCFE82-D222-486A-9E49-0FBE58FDD534}' : 'IBudgetDistribution',
	'{D1DD9101-9264-450A-9FAC-C9D899078775}' : 'ITaxInvoice_Lines',
	'{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}' : 'IBrazilStringIndexerParams',
	'{0B24F304-D586-4E29-8820-90E334D034D5}' : 'IServiceCallProblemTypeParams',
	'{116B0B02-4096-48F9-A00C-E99E6EE7ADA1}' : 'IOccurenceCodeParamsCollection',
	'{43A00E70-9D54-4A08-BE46-BD22286DF8EB}' : 'IDunningTerm',
	'{54E2DDD8-87FE-415D-AA8E-2AC62C936C7A}' : 'INotaFiscalCST',
	'{6AA927D2-EF50-4064-AE3F-A65ADF1026B1}' : 'IVatGroups_Lines',
	'{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}' : 'IUserObjectMD_ChildTables',
	'{A55338A2-5402-41BB-9588-39EC814AB644}' : 'IServiceGroup',
	'{4A2F8C9A-04AD-4CBA-842B-54BCF3927A35}' : 'IServiceTaxPostingService',
	'{60288E22-2FC1-402B-80FE-04D66413E1A0}' : 'ICashDiscountParams',
	'{BFFF366B-1B1C-4EF6-8546-27C9BFF735CE}' : 'IPredefinedText',
	'{7A54452F-A767-4700-B3B5-880084053C0C}' : 'ITaxCodeDeterminationParams',
	'{7DE64B38-CB91-46C2-B1F2-B016D3CBD61D}' : 'ICallMessageArguments',
	'{38FD1577-2135-4D5F-A037-E5388B413F83}' : 'IMessageDataLines',
	'{6625CFCF-AADC-4D47-A83E-C1C786666117}' : 'IBlobParams',
	'{43CA4B0F-FF52-4C9A-9BB9-601CDFE3AD6D}' : 'ISerialNumberDetail',
	'{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}' : 'ISalesForecast_Lines',
	'{336661D7-9504-4915-9EAD-6DF66DBBA590}' : 'ISeriesService',
	'{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}' : 'IBOELine',
	'{8A1D0D45-C379-4714-87A6-F81EA6284EEB}' : 'ICountry',
	'{029D7691-D339-4790-9D8A-652C86A30458}' : 'IPathAdmin',
	'{C09C1DAE-49E3-43CF-AA54-D2EDDCAAE9DB}' : 'ICostCenterTypesParams',
	'{4CA3F302-7EC4-4514-9F07-CB688C56A2ED}' : 'IFinancePeriods',
	'{D4A7CE6F-B909-4273-8499-C210F94ED2D1}' : 'ISalesOpportunitiesReasons',
	'{B5196CD2-270C-42E8-81F5-735A99BECEA6}' : 'IDocumentTypeParams',
	'{04B4DCB9-A2CD-4C53-BD52-FA43B7754803}' : 'IItemLocalizationInfos',
	'{FE19123D-05AC-4D3F-8E3D-4A3155ECF43D}' : 'ITransactionCodesService',
	'{16209A8A-D1E6-4820-A4B4-DB43EBEE8BFA}' : 'IReportLayoutsParams',
}


NamesToIIDMap = {
	'IPredefinedText' : '{BFFF366B-1B1C-4EF6-8546-27C9BFF735CE}',
	'ITaxWebSiteParams' : '{F7E00222-C717-40BF-9DC0-A95200B0FEEB}',
	'ICashDiscount' : '{A46D71C0-8C65-4B7E-BBA7-F6228CA0FE76}',
	'IApprovalTemplateTerm' : '{5691EAF4-B571-4BDA-B908-F7596767830E}',
	'IFinancialYearsParams' : '{9306DAC4-5FDE-4695-AF50-96349ABA5F74}',
	'IInventoryCycles' : '{C9C6EE8B-66E6-4C3E-91ED-49482CF4B903}',
	'IShippingTypes' : '{EE047C63-413F-4CEA-B8BC-A4223AA6B482}',
	'IGetChangeLogParams' : '{E8632E10-873F-4EBF-8339-E57C985D4472}',
	'ITargetGroupsParams' : '{D1B282C5-C219-48C7-93E3-6BD01735EFD5}',
	'IDepositsParams' : '{3FFD991B-9010-4832-89C6-903CBB33AD7D}',
	'IAccountSegmentations' : '{7A1600FC-7942-4604-8D55-1923FF369965}',
	'IApprovalRequestDecision' : '{FB002972-8E0A-4819-AC30-B955B37C4772}',
	'IAcctSegmnt_Categories' : '{414D11BE-00FC-4AF1-BEDF-C0B3308E1A40}',
	'ISalesTaxAuthoritiesTypes' : '{450A7F0E-0D42-4720-907E-C672EE2F6382}',
	'IServiceCallTypesService' : '{B829E078-BAC8-4EC5-BFDD-7F4230AE8BF2}',
	'INotaFiscalCFOP' : '{AFFB904C-0D52-4359-B44B-FB594DC5618A}',
	'IExtendedTranslationParams' : '{8ACB6E74-88FF-4B55-BA1A-EA4AEAAAC23B}',
	'IEmployeeIDTypeService' : '{6B7F9C14-6E99-4405-8796-51F1EF735889}',
	'IBOEInstructionsService' : '{E962CD81-105C-4E61-91B8-A86AFE748209}',
	'IRetornoCodeParamsCollection' : '{6692DB25-3CF4-44C4-932D-1F6D13DF6E7C}',
	'ITaxReportDocument' : '{28DD7AE7-0602-49B2-80EB-827454AA99E7}',
	'ISeriesParams' : '{DB4F4E62-87CD-4113-8EA9-4EAAC1555DBD}',
	'IDownPaymentsToDrawDetails' : '{A177F24C-3E47-498B-9013-8CC3EEC13F78}',
	'IDepartmentsService' : '{C842A9F9-CB16-4E6A-A1DB-7D8964889C74}',
	'ICustomsGroups' : '{842F5C3F-67A6-42B4-8181-98EFB9520A5F}',
	'ICostCenterTypeParams' : '{C8D6687E-6A96-4458-AF54-B052F20C26B3}',
	'IIndustries' : '{68C60132-0DD3-4AD2-B4FF-DB358A6184BC}',
	'IPredefinedTextsParams' : '{A22E33CF-C423-4581-8C7C-382E5D59B301}',
	'IPredefinedTextsService' : '{17785C88-48FC-4D21-A790-81AC72C1D4CC}',
	'ICertificateSeries' : '{56F2B212-48C0-453C-9298-380C6F7350F2}',
	'IReportLayout_TranslationLines' : '{33201180-255B-46DF-A8C4-E8A7E2855353}',
	'ISalesOpportunities' : '{4F06C847-96F8-4421-B1C7-2FA41FCB0CFF}',
	'IEmployeeTransferDetail' : '{0038F785-2853-4267-9629-3444A3CCC2AD}',
	'IAlertManagementDocument' : '{0A8DACEE-9586-4CCD-86E1-4BA2D6C02EC2}',
	'IRecipients' : '{F408B086-B6E4-4EE0-9B95-710C117E56F0}',
	'IBOEInstructionParams' : '{F6B86D1A-4FD8-434C-B0B4-9E6B9FB54BFC}',
	'IDocument_SpecialLines' : '{6ECD0990-1D31-4DDF-AF93-494A9DD7A104}',
	'IServiceTaxPostingParams' : '{37B2AFF5-EB2F-440F-AB6D-751863E9D9C1}',
	'IBusinessPlaceTributaryInfos' : '{C1BF990C-0774-48F2-901C-84E414D881C6}',
	'IBankChargesAllocationCodesParams' : '{46BCE59C-FCA9-4AC3-8A3D-07090C41E5F2}',
	'IEmployeeRoleSetup' : '{B9127E1F-9408-4957-B724-6A3A9AE42C74}',
	'IBPPaymentDates' : '{DD12FBC9-290A-4A5A-84BF-5F27B5C0F124}',
	'IBPFiscalTaxID' : '{CC58BE3C-E272-40FC-97E5-3217A2C32FFE}',
	'INCMCodesSetupService' : '{1470A4FE-6338-4FC7-AD95-D6E2CB4DBB20}',
	'IOccurrenceCodesService' : '{BB817262-453B-4151-9F56-BFD987164133}',
	'IServiceCallSolutions' : '{FA8FD318-6971-4E8B-B6E9-959A938455C6}',
	'IDataBrowser' : '{A52E0922-634E-4827-9B4A-10D6D46ECE74}',
	'IItems_PreferredVendors' : '{9048203E-CE84-4B53-B4C7-61632BD2DEAC}',
	'IAdditionalExpenses' : '{0FCFCE88-47F3-4F05-9803-3081D83C92DC}',
	'IPeriodCategoryParamsCollection' : '{A31EC6FB-9B3A-439E-828D-C95CB0646555}',
	'IUserLicenseParams' : '{91B68A10-74AD-4FAC-98F5-746FDD45D957}',
	'IExtendedTranslation_ItemLines' : '{323B7F1F-31D3-45CE-A325-B81187DA9C0C}',
	'IPayments_Checks' : '{A2277D2E-0ECF-4C7A-941E-9CACB6A8D505}',
	'IFields' : '{DE680833-445E-4AF0-A7E3-377D5135268B}',
	'IBPBranchAssignment' : '{C65DEE24-288A-43E4-9F93-93F384B157BB}',
	'IActivitiesService' : '{BABAB22E-0679-48A4-B7BD-BB0BF14F927F}',
	'ISalesPersons' : '{481D2A59-9B17-4C56-B245-04F85EA1C74E}',
	'IApprovalStageApprover' : '{2F41209B-9C6D-4FC7-B6A2-B00F38C48C90}',
	'IBOEDocumentTypesService' : '{13792BEB-6BDC-46EC-A35F-F98DF2B98CD6}',
	'IBusinessPartnerPropertiesService' : '{0ED256A5-4119-4245-A961-A01AD0134E4E}',
	'ISalesOpportunitiesReasons' : '{D4A7CE6F-B909-4273-8499-C210F94ED2D1}',
	'ISalesOpportunityInterestSetup' : '{C38D34A0-DA36-4B9A-9211-21F9228EC20D}',
	'IServiceContract_Lines' : '{AFC9C52A-514C-43DC-A2FF-48D0B0FCD096}',
	'IDimensionParams' : '{D50B349A-0226-4D72-9FEC-B38D21C65FE0}',
	'ICallMessageArgument' : '{1A0EC41E-7EBB-4BB4-A72F-72CED033ADE3}',
	'IBankStatementsImportFile' : '{7DCD3C0C-6B56-4572-8015-8E4CC744A095}',
	'IWarehouses' : '{43AC045C-DCA2-4150-B937-AB205DCA22E6}',
	'IEmployeeIDTypeParams' : '{45FA8E45-6B39-4974-ACAB-7B6A2ED8FE5A}',
	'ISectionParams' : '{E3BE1834-7578-4487-AAD3-D5BCF3E1A8C6}',
	'IJournalEntries_Lines' : '{55053980-777B-44CF-8D76-84DD975171AA}',
	'ICashFlowLineItemsParams' : '{7B677F06-BB36-462B-BABF-99676A90BC70}',
	'ILandedCostsService' : '{EF61561B-2AB6-42DB-82EF-C440E4A4A71C}',
	'IFinancePeriodParams' : '{DA6203BB-DE30-4AC7-9567-5822C3463335}',
	'IBatchNumberDetail' : '{A302DDF1-F725-46B9-8CC4-19E5766CEAC0}',
	'IReportLayoutsParams' : '{16209A8A-D1E6-4820-A4B4-DB43EBEE8BFA}',
	'ICampaignPartner' : '{A93138D1-7360-49C9-8F1C-EC5239C494B0}',
	'IBusinessPartnerPropertyParams' : '{B7546EA2-0DE7-4F28-8596-ACCD323F584E}',
	'IServiceCallOrigin' : '{9FEF81F9-9C21-4B0B-9EDA-0EF9A5C98739}',
	'IUserKeysMD_Elements' : '{ED79A1AF-2F5B-418E-A90C-1F504B49E364}',
	'IApprovalTemplateQueries' : '{5C730C88-3D5F-4C01-911A-56813AD89504}',
	'IGTIParamsCollection' : '{DF63C280-18C5-4444-BDAF-59318E9ED979}',
	'ICommandParams' : '{93CF87D1-95CB-459C-A906-729819461CA1}',
	'ILandedCostParams' : '{89EB6D8E-979A-470E-8E57-3D8E1BB8857F}',
	'IDiscountLine' : '{73042DE8-A510-4C53-B256-FD249BA13723}',
	'IApprovalStagesService' : '{DA0391B0-6748-4F2D-8FEC-A077DE54FED8}',
	'IServiceCalls' : '{A93CD1FA-F12F-47B0-8FAB-859692B8A653}',
	'IDownPaymentsToDraw' : '{DFF94208-9A06-4594-992D-8D758D296BD4}',
	'IBrazilFuelIndexerParams' : '{24D0CDB0-8592-4CD3-A247-9A51C55D060F}',
	'ILegalDataParamsCollection' : '{9C192F0B-809E-4115-B560-3D683C99D48E}',
	'IItems' : '{1EFF6EB3-9368-4A68-B619-0B57A134F0CE}',
	'IValidValuesMD' : '{D435C006-B504-4847-B217-8AEA5439B779}',
	'IAlertManagementDocuments' : '{A6E70E75-647C-48BF-A642-84841BD85B2C}',
	'IBankChargesAllocationCodeParams' : '{53062C45-E05A-4717-909C-3C3073E10DDD}',
	'ITeamMembers' : '{09C6E920-908C-4FD2-9CBF-21C3F4329A33}',
	'ISeriesService' : '{336661D7-9504-4915-9EAD-6DF66DBBA590}',
	'ISerialNumberDetailParams' : '{C392F1DC-DD79-4692-8FBA-7CAD03877993}',
	'IUserFieldsMD' : '{81D132DE-0549-460D-9BEC-2FEDEAB0A950}',
	'IStatesService' : '{269D9A4D-1866-43A0-B5AB-B46035B1667F}',
	'IUserFields' : '{CC279FBE-7088-42E9-A579-EB2E3E971076}',
	'ICampaignItem' : '{F68C8591-8115-4DC6-B1EF-5071C5CEB367}',
	'IActivityInstancesParams' : '{681D8515-EF90-42C7-9463-3CE0B14E72C5}',
	'IExtendedAdminInfo' : '{6AAAB602-C1E1-4988-BF5D-ECE369936FC0}',
	'ICompanyInfo' : '{97F84FDF-0E1F-4C2A-9FC2-B779411EC1EB}',
	'ILegalDataDetail' : '{86767BCE-5E50-43DB-98D1-AB217A925BF9}',
	'IBrazilStringIndexerParams' : '{BC757F92-D4B9-4FCC-8D29-B3FDC9D1A773}',
	'IApprovalTemplateDocuments' : '{216D15B1-8639-435F-8C85-4967488AD161}',
	'IBlobTableKeySegment' : '{C50E5D37-A9C6-465C-ADCA-FFC09D3E483B}',
	'ITargetGroup' : '{5C87125B-3FCE-4FC7-9AD9-430D8E555426}',
	'IApprovalStageApprovers' : '{D154A6C0-19F8-46CE-B66D-FFC856FC0310}',
	'ITargetGroupsDetails' : '{BC23E72E-CE89-4492-BEEC-6F5FE1D694A2}',
	'IStockTaking' : '{301718D4-11C9-4C5F-88DD-3609C5FA21FF}',
	'IDiscountLines' : '{E14BAC45-1772-407F-B255-178FF23F91E3}',
	'ICheckLines' : '{4DA92EEC-3781-4B5B-B466-4001E7B6F439}',
	'IServiceGroupParams' : '{C9A336DC-4108-44D2-8161-5420E75E8475}',
	'INatureOfAssessee' : '{69A099F3-3B67-46A2-A4EB-6DC399C64078}',
	'IPaymentTermsTypes' : '{F09A4CB0-F8CA-4342-A44D-82DE3395B011}',
	'IApprovalStage' : '{67D827C6-26FA-43AD-84B9-38F2C233BEB8}',
	'IBudgetCostAccounting_Lines' : '{F1E88ED4-1F91-4FE5-B4EB-13B48CB46F52}',
	'IDimensionsParams' : '{7055A28F-3019-4826-A4CC-FC4E5D5E42C7}',
	'ICostCenterTypesService' : '{687B84CE-D196-49C9-A617-C6FC57BB2204}',
	'ITargetGroupsDetail' : '{6F49AA78-C540-44BD-B70F-050870C5BBF0}',
	'IDepositParams' : '{163F1DF1-B468-4E1D-BEA3-0BAEE94C6733}',
	'IDocument_Installments' : '{3E64E5EC-70CA-4129-BC06-0CE9B2058843}',
	'IBlob' : '{E7838784-BDDC-4EC2-A812-C96B19D169C5}',
	'ICallMessage' : '{297DB996-8B05-4D4A-BD2D-333A643F7303}',
	'ICreditLinesService' : '{CCCB8B97-63C1-461E-957F-858EADAE1E04}',
	'IPredefinedTextParams' : '{19E0EAD7-A9AF-41A7-84A8-3089A425A5B2}',
	'IProfitCentersService' : '{0D3C05B0-0EF2-4FB1-8A75-345E3893A995}',
	'ICustomsDeclarationService' : '{13B5A261-F351-4DB5-8D4A-5A6C9083CF19}',
	'IItemLocalizationInfos' : '{04B4DCB9-A2CD-4C53-BD52-FA43B7754803}',
	'ISalesOpportunityInterestsSetupService' : '{445CC71E-29FC-41F0-ACC6-049A2CC3CF36}',
	'ITaxReportSeriesCollection' : '{71AE6937-9F02-409F-93D0-869D4E6DDE9A}',
	'IKPI_ItemLine' : '{48D8151E-BF85-4760-B7F8-B5E7E1B47937}',
	'IAlternateCatNum' : '{0677DAD5-92DA-441E-A674-13DE601888FB}',
	'IExtendedTranslation_ResultLine' : '{50ACD964-9DDC-46E4-9719-56DB0EED92AB}',
	'IDocumentPackageItems' : '{8E861D67-6E55-4201-9AE5-F193127E6F67}',
	'IUserMenuItem' : '{3FF28329-D3E0-4DB0-AFA3-38409E9E8BD2}',
	'IJournalVouchers' : '{B9A56422-93A0-4480-BAF3-48907F403CB8}',
	'IReportTypesService' : '{2DC3C9A3-A237-4DB3-A0BC-AB92D24ED68E}',
	'IDefaultCreditCards' : '{5923A153-B41F-4676-A5B6-1FAD645FDD7B}',
	'IMessage' : '{32E2CAC3-EEFA-4C2B-B916-C43A8A39BEAE}',
	'IServiceCallProblemTypeParamsCollection' : '{4DC9AE34-8FF4-4900-8021-D641EF898358}',
	'IDNFCodeSetup' : '{F8E64A61-69DC-439B-82C9-0D7B1BD5E4B1}',
	'IBankStatementRow' : '{2647D070-305A-43E8-89AE-B4D2C41E5168}',
	'IApprovalTemplateDocument' : '{81BEC420-E567-4353-95BA-71F26FD54BCD}',
	'IProfitCentersParams' : '{BF7FD103-23BD-401E-8A87-DBAFBBB7DB37}',
	'IJournalEntryDocumentTypeParamsCollection' : '{A0F06FB9-C420-4CA6-B1A5-D688A5322E8D}',
	'IElectronicSeriesCollection' : '{B6F90D8C-7E5B-4EE0-8E60-D536FD4C3665}',
	'IKPIsService' : '{EA80E8EC-0D43-4C8B-9F8C-BA5D71F12578}',
	'IDeductionTaxSubGroupsService' : '{389082B5-04A7-4CB6-A0FB-EEC065715703}',
	'IBOEDocumentTypes' : '{3BCB6516-86EB-4170-91BD-7EE4E52D6172}',
	'IApprovalStages' : '{7590979F-CE5F-480B-AEA5-2B83A04BE64B}',
	'IField' : '{6B2A877D-56A5-4DB4-A2DB-D0D46292B0A1}',
	'IFIFOLayers' : '{2C4B93F4-860D-481D-85C5-020876095197}',
	'IRelationships' : '{BBB45A32-F446-4ED3-915B-C811BBA6C2C7}',
	'IOpenningBalanceAccount' : '{31BF39D4-A4A4-4FF6-A946-D7DFB4B37D5D}',
	'IProductionOrders' : '{1C7C966F-B713-42BF-9A74-0B15A649E63D}',
	'ISalesOpportunityCompetitorSetup' : '{BED262F2-5DAF-4D1B-91C6-B5DCABE54A90}',
	'ICertificateSeriesService' : '{9A96D2E9-0308-433A-AE8B-417FE4AD66D3}',
	'IWarehouseLocations' : '{18E244C5-2925-44E3-9DF7-3D8E38583DE0}',
	'IUserTables' : '{625162C1-3894-460F-94EC-72D6AFEA34D2}',
	'IBrazilFuelIndexersParams' : '{C7037B05-9DF8-47CA-8819-4D9460F03794}',
	'IKPIParams' : '{41A28682-1C73-4C77-ADC8-5F805700B244}',
	'IEmployeeTransferParams' : '{8080167A-3150-4B5F-8108-9BE2FA9DC31B}',
	'IMessageHeader' : '{A2080CCB-4B9F-4C76-BAE5-0C700814E3C7}',
	'IReportLayoutItem' : '{2691123A-50EC-4554-9180-490532131218}',
	'IEmployeeTransferDetails' : '{9324B0F9-58FC-404D-81BB-5591BE9E6A27}',
	'ICallMessages' : '{1B562911-6C93-4858-B003-D2586E02BA48}',
	'IUserDefaultGroups' : '{DD85FFF4-93C1-4673-9129-175B77C1CC4C}',
	'IBlobTableKeySegments' : '{86FB8743-E265-47A1-BE6C-7A5E9FEEAAAB}',
	'IBatchNumberDetailParams' : '{CF02E105-3575-467B-9AD6-5BF719C9BC8B}',
	'IDeductionTaxSubGroupsParams' : '{9766B024-E4F6-4116-98AC-DE54D618BFFA}',
	'IBrazilNumericIndexersService' : '{DA13FA15-615B-4F4D-9E61-120A803D3F32}',
	'ICheckLinesService' : '{ABDA119B-E21C-44A5-8DA3-CA870D0D9486}',
	'ICommand' : '{AA94CF0B-1F76-4227-8549-35BA7ED96AF0}',
	'IElectronicFileFormatsParams' : '{58E6063A-F616-4E44-AC69-8E40356F5830}',
	'IBillOfExchange' : '{741AA803-AB33-4FD7-B664-63116291D6CE}',
	'IVatGroups_Lines' : '{6AA927D2-EF50-4064-AE3F-A65ADF1026B1}',
	'IMessageHeaders' : '{CBAB706D-E5DE-4D36-BB28-C6705D247335}',
	'ISpecialPricesQuantityAreas' : '{34995651-4568-4AAE-B831-60693B932A35}',
	'IServiceTaxPostingParamsCollection' : '{16E2EB82-A981-4E4F-A378-6D4E53B17134}',
	'IState' : '{9E37320F-F058-462C-9483-AD67BC65191B}',
	'ICountriesParams' : '{420B8379-83B3-4AE9-B7B8-4DDF73D3085D}',
	'IDimensionsService' : '{17854208-BA31-4EAB-9481-C0806F815FA0}',
	'IFeatureStatusCollection' : '{CB4596BC-49AF-40FF-AF45-DC92A9C75C97}',
	'IServiceCallTypeParamsCollection' : '{475E4307-5C54-4449-BFCA-2CCCBBEB6448}',
	'IServiceCallStatusService' : '{AF0F5509-8F7B-402A-A7D5-2AC98461825F}',
	'ICommandParam' : '{8CA91808-D098-4416-8368-E426484BA8DB}',
	'IBOEDocumentTypesParams' : '{B25EF557-1E57-4CA8-BDD3-B2AF96815278}',
	'IUserPermissionTree' : '{55ACC8CD-3412-452A-9AF8-304A0A56FD3B}',
	'IItemWarehouseInfo' : '{CDB52791-B0FC-4BE1-A712-06941AF91D52}',
	'IDocument_Lines' : '{248B28DD-1281-4C6C-9780-22D19BA13D1F}',
	'ISalesTaxCodes_Lines' : '{98DF1BF3-2F28-46C7-8003-FB8D11276237}',
	'IEmployeeTransfersParams' : '{DFBE6ED2-7510-49C9-8C39-35B939DB586D}',
	'ITaxReportGroups' : '{5EE41EF0-1319-400C-807D-7CAA21FBA466}',
	'ICashFlowLineItem' : '{D2EDF723-F433-4A0A-A4A9-5D8E628CC3E3}',
	'IProductTrees' : '{9BCDAE48-582B-4E76-BD8F-E8A77BC6CF6E}',
	'ISectionsParams' : '{3EFBE347-7427-4459-A969-37AE80D0AFEF}',
	'ISerialNumbers' : '{93E5E52B-181E-46B8-96CB-1C066AC04DCA}',
	'IFinancialYearsService' : '{58A42D29-DF69-4C14-9467-656666D09CD5}',
	'IAttachment' : '{18B4A57B-206A-4CF7-B94B-7325AED96137}',
	'IPaymentRunExport' : '{9020ED56-6B7D-4FAC-8D93-B185D1E65A59}',
	'IGLAccount' : '{0BE721D9-EBA1-48A4-9C6A-75FF948BBD4D}',
	'IServiceCallProblemTypesService' : '{B9DC5AFA-1DC2-4BCB-B2D3-B84A889A9B0E}',
	'ICountry' : '{8A1D0D45-C379-4714-87A6-F81EA6284EEB}',
	'INFModelsParams' : '{85830213-6564-4BBA-95DD-246624D1A4D2}',
	'ICockpitsParams' : '{44AA8DA3-AA22-46F3-8EA5-CE3C670AA3A0}',
	'IProductionOrders_Lines' : '{BEACEF84-4C88-45BE-ADC8-C866A8B755C6}',
	'ICustomerEquipmentCards' : '{D8BCB8BC-6DD1-4D3A-ABBF-FA7A18396B2C}',
	'IReportTypeParams' : '{CF724A90-EFB8-41EB-A2C6-A8EDF1C258CE}',
	'ILegalDataParams' : '{69FA8A61-A978-4B0A-AF72-0419D377EDF2}',
	'IEmployeeEducationInfo' : '{A5EC07B2-5898-4104-8015-F876A386D231}',
	'IPayments' : '{E79D3C41-BFE7-4C5A-B586-4F627E021A1C}',
	'IValidValues' : '{48B89C08-2AE9-435F-B7C4-D7219E938E46}',
	'IImportFileParam' : '{4AA87BC6-363C-4A35-9EB3-473BF6785478}',
	'IEmployeeTransfer' : '{B63DD56F-5008-48E8-B7FF-DA56720F422D}',
	'IBrazilFuelIndexersService' : '{40BA4F6D-54E1-41DD-A912-C9D3A4C5EA28}',
	'ICheckLinesParams' : '{FFA181B4-6482-45B5-901D-525B13F491EA}',
	'IBankStatementParams' : '{2B6AB89A-9C77-45B7-A2D0-17BE5AC94886}',
	'IContractTemplates' : '{9EB0E81A-9442-4C9A-B096-93C6134E684D}',
	'IDepartment' : '{B4CCEAAF-2511-4E3A-916F-8F0F7B6479C5}',
	'IFinancePeriods' : '{4CA3F302-7EC4-4514-9F07-CB688C56A2ED}',
	'IGeneralService' : '{31DE5655-438F-420E-83D0-016C88203706}',
	'IProjectsService' : '{B1AB765A-A1F6-4365-BC25-D0C63B496C77}',
	'IGTIParams' : '{753CAF4F-2D96-4E5A-92BE-409CA76BDF5F}',
	'ISalesOpportunityCompetitorsSetupService' : '{247CDE70-F00E-4033-8EC1-3E173AEA8596}',
	'ILandedCost_ItemLine' : '{052A6BA1-A1AA-4A04-ABDE-23FE11833711}',
	'IMessages' : '{C4DCA924-9189-4969-8609-8564D6E5AFAA}',
	'IWizardPaymentMethods' : '{54B31C27-C3D0-41DE-89BA-5E8800D0361D}',
	'ITransactionCodesService' : '{FE19123D-05AC-4D3F-8E3D-4A3155ECF43D}',
	'ISalesTaxCodes' : '{A07F5790-711E-49FC-9843-935F7C8CDB85}',
	'ICurrencies' : '{596CFFFE-E95F-472D-8243-37094A850DCF}',
	'IAccountCategoryParams' : '{797B09FC-E40A-42FA-9045-30B351D937F1}',
	'IRecipientCollection' : '{2C728EFB-8BF9-4D0A-8135-E53AD4CDC064}',
	'IDunningTerm' : '{43A00E70-9D54-4A08-BE46-BD22286DF8EB}',
	'IDocumentsAdditionalExpenses' : '{FF458A30-213D-4BAC-BA26-F06E1F4A7E4E}',
	'IDistributionRulesService' : '{061D26BF-D1D2-4A8C-A29E-9ECB34E36AC4}',
	'IKPI_ItemLines' : '{9D5AE661-24A0-4F2A-AE75-714F3FF59B91}',
	'ICreditLines' : '{0219BFB4-6A47-47F5-942F-8B05389A05FB}',
	'ISalesForecast_Lines' : '{79C2A7F4-D7EB-4FD1-8F2B-D21577C4F422}',
	'IUserObjectMD_ChildTables' : '{9ED8B1B4-4E9D-4518-9A4B-A1E1CE1BBA3E}',
	'IUserMenuParams' : '{6446D947-9BED-41FE-876C-B89334D5D85F}',
	'IMaterialRevaluationFIFOService' : '{B743C51D-0E51-400E-8245-91331C0A6762}',
	'IReportLayoutPrintParams' : '{A86FB678-5037-4F08-AD65-6C281693C16F}',
	'ITranslationsInUserLanguages' : '{2AC79865-8E0D-42CD-8A97-AA4ADF24B4EE}',
	'IDistributionRuleParams' : '{A91769F5-16B5-49A6-8305-A2DC6054206F}',
	'IChecksforPaymentLines' : '{A6DB2CDA-3A42-4A70-918C-53595D6091C9}',
	'IBudgetScenarios' : '{5D48514C-4B40-4C2A-9FC9-8CC2518B0F8E}',
	'IOriginalItemParams' : '{BC7EF5B4-EEA5-4C83-8478-FBC484133A79}',
	'IApprovalRequestLines' : '{100612B7-46C2-4489-A406-504575577467}',
	'IFinancialYear' : '{C29BB9BD-1EC7-4427-A484-E79EC58F7224}',
	'IDistributionRule' : '{FC2AB5F1-3242-42D2-985E-D23052C9834A}',
	'IBlanketAgreements_ItemsLine' : '{C083AAA6-1496-4E5F-82B0-201194FD8651}',
	'IAddressExtension' : '{7CBD5DDC-C99C-4D73-9ECC-C8B6CDF2FB92}',
	'IBankStatementsService' : '{C90D9F7D-14B6-465B-BE3B-48FABA68CF75}',
	'ILandedCostsParams' : '{F5221870-4600-47CC-AFA3-779B11403820}',
	'ICreditCardPayments' : '{874D0559-C968-49F1-9562-E57E493A47AB}',
	'IOriginalItem' : '{4631570A-DAE1-43BB-9E4A-BA9957E593E1}',
	'ITaxInvoice_OperationCodes' : '{5BCB48BA-A4A6-4087-B1FD-1E9F076EFD33}',
	'IBOELines' : '{87ED882F-80FA-487D-8DA1-058E42B6BFA8}',
	'IBatchNumberDetailsService' : '{3B0A3979-DE99-4162-8B2F-A8D4C9737B71}',
	'ITaxReportFiltersParams' : '{813B8F2A-F8BC-4C70-A043-CF099057F3B8}',
	'IBatchNumbers' : '{1FEF5698-93E1-4167-AEA0-4BB151792623}',
	'IDocuments' : '{A6DA575B-E105-4585-9F4B-50CC4044EEDD}',
	'IManufacturers' : '{DBB3E886-60E7-4058-930A-1C7C07CADB2C}',
	'IBlanketAgreementsDocument' : '{14AF3328-811A-4FE5-A55A-C17BECE10062}',
	'IRecordset' : '{8CA3AB92-1930-4511-4AA8-82D53C3150C3}',
	'IBusinessPartnerPropertiesParams' : '{00C7246F-BD54-4E8B-8CE0-39F9C6568F68}',
	'IAlternativeItemsService' : '{BAEEDA1A-8CBE-4C07-B23A-CBC9BCE6AE37}',
	'IDocumentChangeMenuName' : '{9A5FCF99-FC73-47E0-A68D-A8156EB864E5}',
	'IExtendedTranslation_ResultLines' : '{49836643-1102-4273-B5DC-F4ADEC94D843}',
	'ICashDiscountParams' : '{60288E22-2FC1-402B-80FE-04D66413E1A0}',
	'IChartOfAccounts' : '{2CF2E472-CA6D-4D8E-8B80-046D28E75C40}',
	'IReportLayout_TranslationLine' : '{86A368F0-8603-466A-906F-9FC811B1B711}',
	'I_GenArrObj' : '{D919D79B-2CE9-4A88-9C3D-59A67A334D81}',
	'ICostCenterType' : '{B7334829-8658-48D1-9FF6-056E90AEB07D}',
	'ISalesOpportunitySourceSetupParams' : '{AC935452-7934-4093-810F-D66BD350A247}',
	'IOccurenceCodeParamsCollection' : '{116B0B02-4096-48F9-A00C-E99E6EE7ADA1}',
	'IDocument_ApprovalRequests' : '{CEDAC9E2-A77F-4518-A524-1403050FFD3D}',
	'IEmployeesInfo' : '{B2CFCDE5-3753-4A47-9199-38D08718B3AE}',
	'IProjectParams' : '{563777FD-DD54-40BC-BC70-3DF2EA78F859}',
	'INotaFiscalCST' : '{54E2DDD8-87FE-415D-AA8E-2AC62C936C7A}',
	'IStockTransfer_TaxExtension' : '{F510FF2B-D307-487F-9ECC-EE436A6EBF10}',
	'ICockpitParams' : '{6B1F665B-5A5E-4FD3-A253-3BEF58026E7E}',
	'IServiceCallSolutionStatusParamsCollection' : '{9316E5DC-6A1E-4D66-A31D-40576A355AB9}',
	'ISectionsService' : '{E053D931-2878-44FD-88A0-2E572EA10DB0}',
	'INFModelsService' : '{BC55E0FC-ADC0-4DF6-9F2A-5CD35E4F5A75}',
	'IBlanketAgreementsParams' : '{C1751C9B-F39D-4401-87D9-2C0C6B2DD2D2}',
	'IExternalCallsService' : '{1AD8B5F7-8076-488A-8493-1E430FF9EEAA}',
	'IBankStatementsParams' : '{2C841DE4-014D-44C4-9D48-6A9B7BCD789A}',
	'IHouseBankAccounts' : '{B83BBBFA-E5AF-48B4-B147-2DE092BF1E64}',
	'IBlobParams' : '{6625CFCF-AADC-4D47-A83E-C1C786666117}',
	'IApprovalRequestsService' : '{285E7F1A-1AB7-45F3-9A0A-2B1AD538954B}',
	'IPartnersSetupParams' : '{23BBD185-4EAB-45D4-950E-194CD4A96BE2}',
	'ICreditLinesParams' : '{60836D85-E0A0-435F-B237-4A1E79D7D670}',
	'IKPI' : '{087B9C04-C8CF-4606-A7B4-8FEC6CB8AE1D}',
	'IStockTransfer_ApprovalRequests' : '{DACFE08E-8A02-43ED-B762-5E664186FB0E}',
	'IPartnersSetup' : '{4DB4395A-231C-4BE3-B582-F6C7C70D109E}',
	'IServiceCallStatusParams' : '{5D29B8B0-A8BC-4905-B713-7DE4207A130A}',
	'IDeductionTaxHierarchies' : '{33DDE1AB-5C1F-454E-840A-884CF62A6747}',
	'IApprovalRequestDecisions' : '{B148F7EE-7416-4B22-B266-55321DF794D8}',
	'IReportFilterService' : '{3C3E8D7B-D724-4ED0-BBE3-955F8711B716}',
	'IBillOfExchangeTrans_BankPages' : '{B5BDAFD8-D5E8-4867-8E3C-9E0F2E7A139F}',
	'IAccountCategory' : '{F656351C-32B3-4FE5-9054-221B5988B7E7}',
	'IApprovalTemplatesParams' : '{14E8A7AE-CC48-4793-B4C6-4942E83F92BD}',
	'ILandedCostsCodes' : '{1E6899F1-7A1B-460A-B134-3A82F9083C77}',
	'IWithholdingTaxData' : '{CD9E3DF4-9AA5-4C4B-A0F6-BE36298D5701}',
	'IFormattedSearches' : '{3CE45D97-D58D-4011-812D-32D867DDA8A7}',
	'IBOEInstruction' : '{70443238-FECE-4E0B-8900-9C5D06C4E71C}',
	'ICampaignPartners' : '{40BEDE06-EB4F-4914-BCDF-71018C6FE98C}',
	'IDunningTermParams' : '{FD8BF391-0B78-4E71-80BF-6CA34CE66BED}',
	'INCMCodeSetup' : '{8ED60CF1-3116-4C89-A77D-B67ED48F2F22}',
	'IActivityLocations' : '{0383EE76-4325-42FE-8164-91C2E8FDE242}',
	'ISection' : '{D9D5A329-257D-45AE-8897-AFD53838C099}',
	'IMaterialGroupParams' : '{0E24FCD5-AE39-43FB-8DF1-04492DCA2745}',
	'ICheckLine' : '{900A8956-ACED-4E66-B254-78EB55F7089F}',
	'IAlertManagementRecipients' : '{F675D408-2207-4E44-AE93-3BFDA7DE7CA3}',
	'IPathAdmin' : '{029D7691-D339-4790-9D8A-652C86A30458}',
	'IReportType' : '{41776B28-16AF-4699-B4FC-475989790FB8}',
	'IMaterialGroupsParams' : '{9AA94F66-6356-43C6-A77E-C638B796511B}',
	'IBlanketAgreementsDocuments' : '{EFA05C0F-B878-48E4-AA66-4E266FA5CC1A}',
	'IGeneralDataCollection' : '{646FEBEB-91D7-4517-8CB0-B550DCA64490}',
	'IBranchesParams' : '{3CA31A48-0CEE-436B-9447-E14D8D27C546}',
	'ICompany' : '{3BA8DAED-5B33-4CE4-A4B8-B4308D86E524}',
	'IRetornoCode' : '{2C08600E-B9F0-432D-9D95-F934DDC01165}',
	'ISeries' : '{21B9721D-5933-4547-A8F9-2AFB83B6735F}',
	'ICampaignsService' : '{FCF196BC-2669-4A6D-92C8-33896FD2D3B1}',
	'ICampaignParams' : '{E47E4050-E7A6-4FD5-8F38-A8066213559A}',
	'IShowDifferenceParams' : '{87447CCD-DE87-4992-A2FD-2B0E26460BCB}',
	'IDashboardPackageImportParams' : '{D0D6E022-B36B-44E9-BD9A-24E3169AD532}',
	'IBankStatementRows' : '{7E9C6F20-F9A1-470C-B50D-D1EA112B030A}',
	'IAlertManagementRecipient' : '{B93946BC-D44E-4D81-8071-B56EF0830B51}',
	'ISBObob' : '{268D6CC3-E244-4AD7-B009-16C8ED7F710A}',
	'IBOELinesParams' : '{0DAE1D7B-419B-4573-9315-8094285CD00A}',
	'ILegalDataDetailCollection' : '{70CF9E47-2388-4A02-BC90-6F7CA6220DCB}',
	'IBOEPortfolios' : '{881C8CF2-FDB4-43ED-866F-4F6A4827E02C}',
	'IElectronicFileFormat' : '{F788A8C7-F4E4-47BD-BBC8-79670F3EAE61}',
	'IBranchParams' : '{BB6A6DF6-29BA-4B78-ADFC-29C3EBE54313}',
	'IBlanketAgreements_DetailsLines' : '{EB66D894-270C-4DF1-B76A-AB91ABE88D03}',
	'IDeductionTaxSubGroupParams' : '{2165070A-0BA0-4409-AC85-52A47508F236}',
	'ITaxCodeDeterminationParams' : '{7A54452F-A767-4700-B3B5-880084053C0C}',
	'IBillOfExchangeTrans_Deposits' : '{FD5F3C7D-0AB2-47B0-8EF5-F590E734B776}',
	'ICallMessageArguments' : '{7DE64B38-CB91-46C2-B1F2-B016D3CBD61D}',
	'IDashboardPackageParams' : '{006B6314-B29C-407F-A8F8-11717E779A2A}',
	'ISalesStages' : '{D2D6E703-7339-4D1A-BC4B-6BFF83622871}',
	'IApprovalTemplate' : '{82C83910-6247-4BFB-AAE2-C9AD27B1947D}',
	'IPartnersSetupsParams' : '{65C62A16-791E-4D58-A0F9-1ED312BE7ACB}',
	'IBranch' : '{DC24341F-4CD3-4608-9ED4-745882053E6A}',
	'IEmployeeRolesSetupService' : '{26767B5A-7011-4E58-A9FE-D6D1F8568B0F}',
	'INotaFiscalUsage' : '{E2C5A384-883B-4963-A4A4-30C6F553818F}',
	'ISalesOpportunitiesCompetition' : '{19E6540E-4E64-48C1-9525-29D5710D1FFD}',
	'ITaxExtension' : '{8CC29ECE-02C3-4C7B-851B-5533D2C83627}',
	'IGLAccounts' : '{DFFEC465-C3AA-45DD-ABBC-9D025A328335}',
	'IBankStatementsFilter' : '{9A4EDA67-F390-4901-80F3-0D85F73994B7}',
	'IBPBankAccounts' : '{472B7A32-EB83-4D3A-9908-699D5C8DC33B}',
	'IBrazilStringIndexersParams' : '{F2A7926C-BDB1-4151-8FEC-5A58C2BCC600}',
	'IBusinessPlaces' : '{6C92660E-0507-4C90-8DDB-1C5B61AB41AA}',
	'ICompanyService' : '{9D202A0D-3D49-47E0-AC0D-90333C553E85}',
	'IChooseFromList' : '{F183C834-5321-46B5-96B6-0BC50D1726E8}',
	'IDiscountGroups' : '{7B78B94A-9F54-4A05-9A64-0A1E89484ECB}',
	'IBlanketAgreements_ItemsLines' : '{FECE5DF5-E254-43C1-BDD9-5C82097B9B9D}',
	'IUserTable' : '{DAFE7156-D1A5-4B41-B9CE-599AFD5C6964}',
	'IProject' : '{C7DF4768-56A6-45D9-9C2B-916008846E76}',
	'IDepartmentParams' : '{99E84704-3E04-40DD-BE1D-854068378E3A}',
	'IDashboardPackagesParams' : '{F7BC21C9-ACB8-4B44-8488-5BE5D15BADEA}',
	'ITaxJurisdictions' : '{1E7372E2-C931-4A07-9A74-4A054C1BAE7C}',
	'IDNFCodeSetupParams' : '{1C8C439D-3079-4C94-AF38-097D8CCD6AD2}',
	'IReportLayoutItems' : '{E7092C39-C3B3-4928-A5AB-B0FF9B885D5E}',
	'ITaxReportGroup' : '{6076F945-EB54-4BA8-B00C-891BB860356A}',
	'IUserMenuService' : '{FF87B29E-5D38-4901-A443-8672387A200A}',
	'IDefaultElectronicSeriesParams' : '{C9379AB8-CDE2-4A35-99CE-DB1CE9D7950E}',
	'IActivityInstancesListParams' : '{14BE1C8C-20CA-4E53-A55C-097AB57740B8}',
	'IApprovalTemplateStage' : '{51E040B4-AC44-4474-86E0-DA7CFCD0AD96}',
	'IRoundedData' : '{EF86275D-924A-4AC9-9461-E9AAF80894B6}',
	'IEmployeeIDType' : '{17F42A0A-DF72-432D-9953-1993A831A197}',
	'IBudget_Lines' : '{D2BAB599-C7C6-4301-B925-B6BB51092A79}',
	'IAttachments2_Lines' : '{F9D49CC8-76E7-4387-AA71-ED03A361F510}',
	'ISalesTaxAuthorities' : '{0D446022-9A79-4535-9174-EEAE21DF924A}',
	'IReportParams' : '{0B4E873F-65FD-4638-9339-84D197CF8109}',
	'ITaxCodeDetermination' : '{03111771-050A-41FF-A2EA-A17B8C7E99FE}',
	'IAccountsService' : '{43C8A942-73F5-40BE-9675-CC8946003F0A}',
	'IServiceCallOriginParamsCollection' : '{13B1D6B4-A9ED-4787-8B8B-24AAE9525342}',
	'IAccountCategoryService' : '{F2353C93-5EBC-4DDC-B750-717E97F41CF2}',
	'ICurrencyRestrictions' : '{E6144A85-69CC-4178-A0B2-BDC8BED4930E}',
	'IBusinessPartnerGroups' : '{9147FC50-6FF2-40EC-B59B-2F9302B4A31D}',
	'IApprovalTemplateParams' : '{1445B394-DD5B-4542-9E3B-2B6E9CA92621}',
	'IBranchesService' : '{0577F672-2A66-452A-9597-5008904A3940}',
	'ILandedCost_ItemLines' : '{36143269-AD6C-4AD9-9A2E-AE3273141D8C}',
	'IPaymentBlocksParams' : '{954AC9A0-5402-436F-A20B-38E093F0A636}',
	'IPaymentBlock' : '{F6964AD5-EB4F-4E38-824E-60026EA9F159}',
	'IBrazilBeverageIndexersParams' : '{C9C4DE1F-9409-446D-AC6A-0FAD12624939}',
	'IBPAccountReceivablePayble' : '{4162242D-4217-47FA-BDFF-5070B6D03F30}',
	'ICreditPaymentMethods' : '{7B951C46-49D0-4E0C-8832-48B62F4EF0BD}',
	'IDunningTermLine' : '{D7B39E88-0C6D-4B8A-A083-AEC336746884}',
	'IElectronicFileFormatsService' : '{457DC126-2E63-4241-9497-1A104E8AB550}',
	'IServiceContracts' : '{5C594028-D730-4298-952E-4616C5047BC6}',
	'ILegalData' : '{59837FCB-2720-45D3-85BF-9F075D5D6560}',
	'IPackagesTypes' : '{CE69987E-8F99-4FC1-8C86-837E5246AFA2}',
	'IMaterialGroupsService' : '{843B58CC-38C1-4C93-B5F6-533BFB3006BD}',
	'ITaxCodeDeterminationsParams' : '{A8AB919D-856C-4883-959D-57D7CB9C51F2}',
	'ITaxReportBusinessPartners' : '{CA7F3C6F-4074-46E9-8B96-3CBDDFC9C320}',
	'IReportLayoutParams' : '{7C2CB2D6-5C52-47A5-AFCD-0DF8F5BB4F84}',
	'IBPPriorities' : '{36EA48A3-B828-45D8-B5E2-AE3584E54AE3}',
	'IServiceCallInventoryExpenses' : '{7D2E44A0-ED32-4404-A186-EB64B8BEE3A4}',
	'IApprovalTemplateTerms' : '{EFFD365E-5096-4B19-9187-986F83D337E0}',
	'IBrazilMultiIndexerParams' : '{A87B0CFB-B0A7-49E7-AF5A-2B77AA6AB227}',
	'IColumnPreferences' : '{E498C4B2-E919-48EA-B512-79DE65B1F5CE}',
	'IUserPermission' : '{2CDE8AC0-68D7-4C58-AAA4-D9C1947B2FBF}',
	'IEmployeeTransfersService' : '{1678F2A9-8FBA-47E8-A678-FE06A7D22007}',
	'IJournalEntryDocumentType' : '{56B7FEB9-ECC9-4A64-BDDF-0AB70C3746D0}',
	'IDistributionRuleLine' : '{BAA78C65-59B2-419C-82A7-0BE5CCA96EA2}',
	'IItems_Prices' : '{E343AA97-4BC8-4E0F-BE71-1B3BE345F702}',
	'IBOEInstructions' : '{4B03F542-E836-450B-89AC-04E7609E6B35}',
	'IServiceTaxPostingService' : '{4A2F8C9A-04AD-4CBA-842B-54BCF3927A35}',
	'ICommissionGroups' : '{5E23BA23-D431-4212-BD7F-D5CB7E263494}',
	'IActivityInstanceParams' : '{CF05D1A7-0FD4-4800-9643-E9631CDE2D49}',
	'IUserObjectsMD' : '{2E2720A5-8F7C-45D3-BF5A-DD5BE3769F84}',
	'IMaterialRevaluation' : '{461F000F-9DB2-45D0-808D-FA552126FF16}',
	'IServiceCallSolutionStatus' : '{22219181-9047-4C89-BAC3-4BB311AE77E4}',
	'ISeriesCollection' : '{D48F490F-CB1F-46B9-A941-D1A84FCE1DB2}',
	'IClosingDateProcedure' : '{910FEA90-B652-4099-9817-3AA0CF635963}',
	'IServiceCallActivities' : '{0207412D-F955-46BA-AE96-E749573B4106}',
	'IExportProcesses' : '{E3F9ACA7-17D5-4A5B-8AAF-91CB41E2896F}',
	'IApprovalTemplatesService' : '{690E65AA-B309-41D2-9697-0B6CBB58C4AF}',
	'IColumnsPreferences' : '{5079035B-D0E5-4D0E-AFB1-6CB1FBAB11AE}',
	'ISalesOpportunityReasonsSetupService' : '{A95C4C3D-71D5-475B-B6D9-BB75D22E1931}',
	'IDynamicSystemStrings' : '{910C52B1-ABDC-409F-80EE-D6219E33497E}',
	'ITaxWebSitesService' : '{A7FDC596-1604-4DE8-841C-DADBA34B32E0}',
	'ICertificateSeriesParamsCollection' : '{731625D2-901C-40C1-A06C-C6A72FC00D8C}',
	'ISalesOpportunitiesPartners' : '{435ACA34-F69A-4BD7-8BD3-D8CF72E99070}',
	'IDeductionTaxGroups' : '{7C3BB8E9-B896-4556-859F-FCAC93473C04}',
	'IDocument_LinesAdditionalExpenses' : '{4ED8248F-4104-4397-BC2B-1DE54AA35E3A}',
	'IBanks' : '{7A4DE818-7DD3-4035-97F8-6696A65651BF}',
	'ICallArgument' : '{CB6D5BD6-878B-4966-9E6B-8599949B657F}',
	'IUserTablesMD' : '{FC571383-8375-4B7D-BDEF-4EF2B91B7751}',
	'ICreditCards' : '{49593AE6-FB7B-4B31-9029-F84067559E54}',
	'IAccrualTypeParams' : '{70DC39C1-4019-4618-9D1F-7D227A68491F}',
	'IFinancialYearParams' : '{83C6551A-5E1D-4651-8272-88BA8B56E728}',
	'IRecipient' : '{BFC32883-8D3F-49F9-A985-3F9B3B37260F}',
	'IBOEPortfoliosService' : '{6EA82155-C282-4F2D-90C4-BF6F95269228}',
	'ISeriesLine' : '{022D793A-3706-459F-A7FE-4169894754D8}',
	'ITaxCodeDeterminationsService' : '{68FA6F71-028F-434E-AAA4-32B8BBB67CC4}',
	'INatureOfAssesseeParams' : '{27D88079-2713-4D2E-94D4-3C6F14D18140}',
	'IAlternativeItem' : '{7A83E2DD-0AF9-4C69-9076-A6CF2A414B30}',
	'IBrazilStringIndexersService' : '{4735E037-68A6-474D-AEC5-F5D9BD3B09A6}',
	'IWithholdingTaxCodes_Lines' : '{3302B4B4-1F71-4D62-8D6E-85DEAB64B4EB}',
	'IGeneralDataParams' : '{137AD94C-2F5B-42AB-9DB5-309BD89EF224}',
	'ICostCenterTypesParams' : '{C09C1DAE-49E3-43CF-AA54-D2EDDCAAE9DB}',
	'ITaxReportBusinessPartner' : '{D82AD3C0-5E31-4B8A-AECC-7602B8393E29}',
	'ITransactionCodeParams' : '{63A44BC7-2798-4F4A-B0C7-B407EA917702}',
	'IActivityStatus' : '{E985FCDC-43E0-47C4-821D-7F60D4BC9009}',
	'IPeriodCategory' : '{1C764D4F-63DA-46FE-BD81-56548EEDB2F6}',
	'IProjectsParams' : '{44AB2C0B-390B-43A1-8BCD-529BA39C52C3}',
	'IApprovalTemplateQuery' : '{ED24FEA6-637A-40C1-BE17-14E5F4EE68C3}',
	'IPayments_Invoices' : '{AB7947CF-8191-498D-8B3C-8E04A00957E7}',
	'IWorkOrders' : '{7615E097-E207-4E8D-A114-74031034136B}',
	'ISalesOpportunitySourceSetup' : '{6B52A2CD-C166-404E-9A92-A0D4B812488A}',
	'IExternalCallParams' : '{6AC1DA43-B01F-4E2E-8B5A-184BE9C05D80}',
	'IOccurenceCode' : '{04305B71-95D2-4327-B7A5-ED12DFB5FB1B}',
	'IBusinessPartnerProperty' : '{38DA089C-BF1E-457E-B486-F1E35293F5F1}',
	'INFModelParams' : '{14B86DBB-49A3-4893-B5E8-5B0B396CFF04}',
	'INCMCodeSetupParams' : '{C48ABD4C-43C8-4776-87E7-337D661050C2}',
	'IApprovalRequestLine' : '{6228C442-C4B7-4841-9275-54B459F42BCB}',
	'ICustomsDeclarationParams' : '{3D7A2391-5E52-45DE-80DB-A09ECADBD5A3}',
	'IMultiplePayment' : '{738D011A-EA2A-4205-B009-53C7C64D73DD}',
	'IBusinessPlaceIENumbers' : '{EC280F9D-83C0-4324-9B19-18CB128A7021}',
	'IBOEDocumentType' : '{746B0E89-0625-4B20-BD67-029DB26D074D}',
	'IBillOfExchangeTransaction_Lines' : '{2DBFED56-4DB4-455A-9C22-E2C01C052D39}',
	'IMultiplePayments' : '{4207538F-AAC0-4EDD-9002-6F710410D5C6}',
	'ISalesForecast' : '{0D31ADD3-85B1-40F1-979F-8612E10B8DD8}',
	'IWithholdingTaxLines' : '{458A15A5-B980-4543-A289-F6477A36EB24}',
	'IElectronicSeries' : '{2309689C-63EA-4D8E-B675-E6459533E27A}',
	'ICallArguments' : '{EBBCE4C7-AE00-46A4-A0BA-851F42E7CADF}',
	'ITaxReportDocuments' : '{FC030AB5-B942-4D71-A5BF-1EAA5D9BC808}',
	'ITaxReportSeries' : '{308CD5F0-5908-47B2-BE56-A1104C45FCF7}',
	'IServiceCallType' : '{A68554D5-F932-4B92-980E-6060777F59F4}',
	'IChooseFromList_Lines' : '{2E9D54CC-66FD-4688-9DA0-6AEE9C263D7E}',
	'IDecimalData' : '{FF79D2D4-A79B-4DCF-A3BB-14A8B01A5FDC}',
	'ICampaign' : '{87B9E57D-866B-4AE6-9C1D-571888134690}',
	'IUserBranchAssignment' : '{EC084090-ED29-4B85-BAF8-8058B245EA06}',
	'ILegalDataService' : '{598819B6-D5B0-4CF1-A533-D966C1D9267A}',
	'IDNFCodeSetupService' : '{CFD28E0F-8394-4B7D-87A0-52D3AD73254E}',
	'_ICompanyEvents' : '{57B97799-106E-4EA3-8203-1B30B6B7D463}',
	'IEmployeeReviewsInfo' : '{C4397D01-E44E-4B76-80AB-4B888EEA10DD}',
	'IBPCodes' : '{9B7AB6DE-2A25-4329-9423-6B175EB8BCD3}',
	'ILengthMeasures' : '{2FE8BD34-3F78-4FE0-A577-EE9496E8F294}',
	'ISerialNumberDetailsService' : '{FE305F7C-1D01-4B99-AB83-BBB8503B8A95}',
	'IDefaultReportParams' : '{90E9CFE3-0440-4E26-B8E7-975A9A4638B4}',
	'IExternalCall' : '{B2BFF6DD-6309-40EB-BC59-75D1996BD77D}',
	'IPaymentBlocksService' : '{F72D84B1-6F70-44CD-8B91-2FC481ADFE2E}',
	'ITaxWebSite' : '{EE912DF0-9D0E-49BE-999D-B88AA59B305D}',
	'ITerritories' : '{BEB8ACDC-E50B-4DA3-8281-EF5228E55099}',
	'IServiceCallOriginsService' : '{92C049DE-4E6A-47E8-8910-1C4C83E91780}',
	'IReportLayoutsService' : '{E5CFF30C-8D7D-4F36-A505-B2BA0EC0CB21}',
	'IEmployeeRoleSetupParams' : '{E5957BB1-8C90-4AC2-BF74-4EC28DF7BCDD}',
	'IJournalEntryDocumentTypeService' : '{7E723574-58DD-46D4-9856-44426EE523AE}',
	'IApprovalTemplateUsers' : '{948C7B32-1518-45ED-99A3-94AA328CD7FF}',
	'IValidValue' : '{013F0389-85E2-4B8B-9285-18843E4236F3}',
	'IBPFiscalRegistryID' : '{2C35D508-856B-43E0-A1A5-EC6BCA16E62A}',
	'ICashFlowAssignments' : '{A0307CBF-64B1-49E8-B60D-38803E20D107}',
	'IDistributionRuleLines' : '{0B5DE094-FB49-4B4C-AA7C-F87F5E3A932F}',
	'IMaterialRevaluationFIFOParams' : '{C1DD2F9D-7198-47C3-936D-46E421503333}',
	'ILayers' : '{6C589BC6-9ACE-4A99-8097-038E9AC52155}',
	'IEmployeeAbsenceInfo' : '{CD47A725-AEA8-4224-93D3-F31848990C42}',
	'IAlertManagementParamsCollection' : '{341FC52D-5088-4DE4-8308-7085F8D950A1}',
	'IServiceCallSolutionStatusParams' : '{7276D73A-6B18-4F86-B517-6DB9363FC772}',
	'IDeductionTaxSubGroup' : '{16403B63-EB90-4781-9C89-05EF77769731}',
	'IMessageDataColumn' : '{C2CD5E2C-D6CE-4D01-8EF0-3EB48E7F3974}',
	'IBankChargesAllocationCodesService' : '{E73F2CD8-14C2-4BDD-AEB2-7D7DCFF21571}',
	'IStockTransfer_Lines' : '{CAF06BB7-9E71-4EB7-BD56-2A79781C3855}',
	'IBOEPortfolioParams' : '{7E0EA2EC-9661-427C-B8EB-0C818F908F67}',
	'IChangeLogDifferenceParams' : '{626BE3A8-0FC8-4C86-8B8C-FABB5047B747}',
	'IPayments_CreditCards' : '{CC3579ED-1C61-4864-8E51-208A3DCDFC93}',
	'IElectronicSeriesParams' : '{135ACD20-6799-42E5-8ECC-4077CEF72812}',
	'IBlanketAgreements_DetailsLine' : '{E21D5CB9-5B51-4598-8989-75A702DFC29E}',
	'ISpecialPricesDataAreas' : '{10DBC97D-D42A-4C0E-99F0-08A577AD83C2}',
	'IWorkOrder_Lines' : '{8A7B7302-F7B1-4E68-91FF-3F407B63A6BB}',
	'IPaymentRunExport_Lines' : '{917BA077-4D88-46A8-B78A-E396315D7E59}',
	'IMessagesService' : '{A24C6BD6-06BA-47B3-8B67-D628AEFAD721}',
	'IBusinessPartners' : '{9DF321C2-6A1D-446B-AE8A-F7C33987D792}',
	'IBillOfExchangeTransaction' : '{DB038EC5-97EC-4D04-8E6A-AF01A5C05900}',
	'IColumnsPreferencesParams' : '{3D83A354-89D4-46AF-841A-D659A0C2678E}',
	'IAlertManagementService' : '{7424993D-6DC0-48E5-AEEF-B10A3177E175}',
	'IActivityParams' : '{E7F10DDC-8DAE-4B03-990C-3FA513E0FC9A}',
	'INCMCodeSetupParamsCollection' : '{B14AF4AA-36E3-4C09-9BEF-6DCED4B5EBFB}',
	'IBrazilBeverageIndexersService' : '{80E28887-F468-4172-9043-D442BCAB1F55}',
	'IApprovalRequestsParams' : '{D14EF57C-1B15-49DB-9BFE-C9238CEF1BF9}',
	'IUserObjectMD_FindColumns' : '{069A0AEA-9F3F-458F-BE26-0543D7A3EEFD}',
	'IFinancePeriod' : '{39DAE3AB-708D-4123-BC50-CC57F05D734E}',
	'IChangeLogParams' : '{A564B0B0-8547-4D95-9AF6-7CAE59D1EA23}',
	'IUserValidValues' : '{280836CC-E077-4487-8759-D06DC3E31076}',
	'IReportTypesParams' : '{343A6016-2B36-4522-B0E9-477A062EF6DB}',
	'IOccurenceCodeParams' : '{418E7FC7-70AC-4443-B526-E3C154E6DA4B}',
	'ICashDiscountsService' : '{1FA65DB2-F84E-4C7C-A48D-E4043BCF6557}',
	'IServiceCallOriginParams' : '{AC21F36A-556F-4374-AAB0-96949C7469FF}',
	'IChangeLogsService' : '{6C62EE4B-B4A6-4BD1-B0E3-D81EEB7888CA}',
	'IDashboardPackagesService' : '{5077C7F7-E950-40A4-9A0E-71CF776AE79F}',
	'IPaymentBlockParams' : '{59DB637B-BF84-4D38-A0ED-1383F2556CA9}',
	'IMultiLanguageTranslations' : '{2CE582CB-83A3-49C0-AF0B-5C7F6EA88B0B}',
	'IServiceCallProblemType' : '{943EB4D4-ED2B-4815-B6D8-3CA50DF8D139}',
	'IDimension' : '{0C349981-9E5F-4814-910B-8995D5E9D32E}',
	'IServiceCallTypeParams' : '{72274C66-4457-4D17-8F61-014F5520C434}',
	'ICustomsDeclaration' : '{812BAA6F-715C-42E4-811F-287EF23E05A2}',
	'ICertificateSeriesParams' : '{A0B604D4-3D7B-427D-9EA1-15456A2329BD}',
	'IServiceGroupsParams' : '{74490BE7-8344-4F48-90C9-2A811E54AA49}',
	'IProfitCenterParams' : '{98F79F87-3825-465E-8E69-E7E416534B7B}',
	'ISalesOpportunityInterestSetupParamsCollection' : '{BC177C74-40FA-4140-8374-ED45F9FCFF87}',
	'ISerialNumberDetail' : '{43CA4B0F-FF52-4C9A-9BB9-601CDFE3AD6D}',
	'ISalesOpportunityInterestSetupParams' : '{61408D92-9E9A-4A1F-B5B0-A60332828007}',
	'IEmployeePrevEmpoymentInfo' : '{C6BF8D81-6C25-471C-AD3F-B1376C1AA25B}',
	'IServiceCallSolutionStatusService' : '{AAC173E2-F851-4F94-AE33-00CC4F38FDCD}',
	'IAlertManagement' : '{9E52D02D-16FC-4E2C-87FC-CD070F5D646A}',
	'ITransactionCode' : '{49703681-AAAE-49B5-B2AA-402D622EE537}',
	'IExtendedTranslation' : '{EB9E1080-A979-4BA0-895B-D424C68063BC}',
	'IUserObjectMD_EnhancedFormColumns' : '{F09D2D1D-1BB3-4D09-946B-71AE1263D6AC}',
	'ISalesOpportunityReasonSetup' : '{5128D2EC-8CF5-47BD-A12F-B53211A1CE54}',
	'IPeriodCategoryParams' : '{7E8F7FB2-8FA8-4366-8AFA-565CDCC827CF}',
	'IBOEInstructionsParams' : '{910426DC-C7C4-4EBC-8FB3-97BC2805C81D}',
	'IAccountSegmentationCategories' : '{2608CED7-EBD1-4F95-B41C-ECDF2CE685E4}',
	'IPartnersSetupsService' : '{FCB4B06C-8747-4678-85EB-4F28B51A88C8}',
	'IMessageDataLine' : '{83848F7F-7E5C-4EEE-82C8-374CCA5BB644}',
	'IAttachments2' : '{EE480268-BD9E-4DD2-8BA2-BBB3C9665448}',
	'IForms1099' : '{5FE3FCA3-E93E-4106-8190-F62CB9FBF137}',
	'ITransactionCodeParamsCollection' : '{12A99320-EEE7-4398-90E2-74BC014F5CE2}',
	'IUsers' : '{ED256951-E65E-40BF-A2E9-2A21741D8720}',
	'ITargetGroupsService' : '{67D0EFEB-7047-4726-98B7-C60B83F0F98D}',
	'IDunningLetters' : '{F8DE7AAE-13BF-46BD-A4B0-CD9535AAED63}',
	'IBPAddresses' : '{02F225DD-827F-4065-BC4A-14D5F4136D28}',
	'IApprovalStagesParams' : '{03664F1A-4FCF-401A-84E1-934D1F101EA4}',
	'ISalesOpportunitySourcesSetupService' : '{B3D0E8B3-C0C8-4CC2-9D0B-121D6384E95E}',
	'IBankStatements' : '{57803F71-402E-40E7-94A1-A479207BD227}',
	'IUserActionRecord' : '{19F3C51D-AE7A-4293-A027-CEA9C9C20B98}',
	'IBankStatement' : '{3E2080DD-AD4B-41E6-A55F-7758EBCF6922}',
	'IProductionOrders_SalesOrderLines' : '{DF6C475B-AD8D-4E52-A412-9500E69DB54B}',
	'IChangeLogsParams' : '{D2FE59A3-5DA7-403C-9EAB-EF2C8CD8EFEA}',
	'IMaterialGroup' : '{CF683F67-7A73-4D71-9C10-821A1E7715DC}',
	'ISeriesLines' : '{D5B65908-18C4-493A-B1F3-BC7987AF01DD}',
	'IDocumentPackages' : '{07F27714-4BA9-42E3-8E93-3418F73C55E4}',
	'IFormPreferencesService' : '{177775C1-0633-42DE-8711-AF5D5DD650D8}',
	'IBrazilMultiIndexersParams' : '{292717A3-9E69-4C34-BE56-A61A52CA8AA2}',
	'IEmployeeIDTypeParamsCollection' : '{BDD8F465-17AF-49ED-AA8D-50A52B849D4F}',
	'IUserKeysMD' : '{913C6394-89AD-47A9-9390-1B8686E65312}',
	'IDepositsService' : '{8D14FB10-4616-4AF3-B477-0B87C797AEBC}',
	'ICheckLineParams' : '{9FD052AE-94FD-41B9-996B-D5AF3DCC5C33}',
	'IBPCode' : '{259FA540-F962-4A5D-9BF5-E9772AF43A31}',
	'ILandedCost' : '{069837FF-A1F4-4442-92EF-DFEA56C23992}',
	'IRetornoCodesService' : '{EA19AA7D-6063-4C86-BC1C-27B0572209ED}',
	'IPayments_ApprovalRequests' : '{8276E7F7-9178-409D-88DB-5A8D41DED6E5}',
	'IApprovalTemplateUser' : '{41E9016A-6784-4B6C-8CFB-AF7AAE459A37}',
	'IKPIsParams' : '{44F97BA6-22A5-4687-BFBF-863A346A414C}',
	'IBudget' : '{C1F83FBE-3A3F-4A81-8B0B-B5485DC6ADF9}',
	'IServiceCallStatusParamsCollection' : '{106B8134-EDB5-4417-BFAC-4A3A2A7B9419}',
	'IBankPages' : '{5BB202A1-E560-4E34-ACB3-2ECA52FFB274}',
	'IExtendedTranslation_ItemLine' : '{FFA101D6-62B7-4615-A050-5BEE79FBF640}',
	'IBOEDocumentTypeParams' : '{7B45A310-CED5-4D41-9A54-BED0F11B6950}',
	'ITargetGroupParams' : '{EC2449D7-87D4-4A5C-BBFD-49711B5D6953}',
	'IPickLists_Lines' : '{8C5A86ED-4B60-46EB-A0D5-9F529DDF069E}',
	'IDocumentTypeParams' : '{B5196CD2-270C-42E8-81F5-735A99BECEA6}',
	'IApprovalTemplateStages' : '{02B05079-F380-48A7-A573-0BB7307A52C0}',
	'IDunningTermsParams' : '{E0E5F6AB-18E3-45F8-A9DA-D2AB88B08A54}',
	'ISalesOpportunityCompetitorSetupParams' : '{3B6193EC-52FD-404D-985B-16F6B0A1A5B4}',
	'ISalesOpportunitySourceSetupParamsCollection' : '{6C123256-BF67-4AA6-BE6B-4C085AB0731A}',
	'IQueryCategories' : '{78A768C9-EDA6-4798-AFC3-114DEC3DE8E5}',
	'IItemProperties' : '{BD54054F-D434-4DC7-8D84-8020C653432C}',
	'IServiceCallStatus' : '{0E2CBAD1-1857-4E2F-8AE4-5246D1F6725E}',
	'IContactEmployees' : '{52C8673B-CA79-4476-9F2E-28109AE17545}',
	'IItemCycleCount' : '{743A4F30-AC7F-4606-9AA3-5139F07E08A2}',
	'ISalesOpportunityReasonSetupParams' : '{E60CDE47-FBBE-4719-BCFF-022E70710702}',
	'IDocumentSeriesUserParams' : '{AADAC0AA-6CBA-47EC-B923-05B029715123}',
	'ICreditLineParams' : '{B0338FF7-542D-4AEA-A097-A51DECA7E671}',
	'ITaxReportFilterParams' : '{A5CDC033-47D7-4019-801A-8443F14D52D0}',
	'IAttachments' : '{B728546D-EA5F-4122-9FE0-759C89BF95D0}',
	'IDunningTermsService' : '{788DDDE0-9FE1-4653-8F1A-DCBFF4DD0B49}',
	'IApprovalStageParams' : '{32C99937-0DD9-4E8F-90C3-AB2CB3CB1BA6}',
	'IFeatureStatus' : '{B551C968-0DE9-48FA-B48D-385284294F16}',
	'IBrazilBeverageIndexerParams' : '{9FCE9DA7-9D0A-4973-86DC-37F6ED59AD35}',
	'IDeposit' : '{29A116DF-AE12-4A45-A5F0-3436E170B26B}',
	'ISalesOpportunitiesInterests' : '{9E74C830-FE72-4241-A2B3-BAE642EDFBF2}',
	'IBrazilFuelIndexer' : '{45CD0988-1275-4D2C-BF2C-5D04CB984489}',
	'IGeneralData' : '{C131D463-24C3-424A-B734-589D0F452D2E}',
	'IReportLayout' : '{77C5B820-63C3-4825-9279-964224F7BE00}',
	'IStockTransfer' : '{8DD14B84-6D7B-49E9-8137-A3E7F9A3642F}',
	'IApprovalTemplates' : '{7DDA3A4A-07A5-43A7-885E-B34217076D17}',
	'IAccountCategoriesParams' : '{AABB98FA-CCB5-4F0D-A6B6-5684708886C9}',
	'IUserMenuItems' : '{E47A46CE-64EC-439A-B3C3-EFDDC23393F0}',
	'ITeams' : '{BCA3F54F-34D2-4E1C-A700-AD1C35F0B415}',
	'IRetornoCodeParams' : '{8B7B4062-1A48-4DF3-9DFA-6E3684B9D0E5}',
	'IBPWithholdingTax' : '{D9A67DC0-2B5F-4540-AA79-5A7750C3AF77}',
	'ICampaignsParams' : '{EF865450-BA41-490B-B580-3D566BA3681A}',
	'IMessageDataLines' : '{38FD1577-2135-4D5F-A037-E5388B413F83}',
	'IPickLists' : '{A1CC204F-6BD1-417A-A6F8-9A3E7C96D28B}',
	'IPriceLists' : '{99FB9754-BDAE-4C8D-BA96-4F2263A73A6A}',
	'ICampaignBusinessPartner' : '{1F6F5A95-EFF6-432F-B882-3A4931DDA95E}',
	'ITaxReportAccount' : '{32ABB501-14BB-4467-8D98-597A9420D8C6}',
	'IAdminInfo' : '{4583DECC-E80D-46AE-B3C0-308FC33C58E9}',
	'ICashFlowLineItemsService' : '{724DEACC-3DDF-46DC-A884-A69751E80603}',
	'IUserLanguages' : '{DF33FA96-E656-4AF6-A877-AAC7D5A8D586}',
	'ICountryParams' : '{C28C5E76-815C-4BCC-B822-5EBAF6A47ACD}',
	'IActivity' : '{EE825513-A21F-467A-AAC5-931A7939C954}',
	'IElectronicFileFormatParams' : '{B1D15948-E323-4C52-BA55-70E0678549CD}',
	'IEmployeeSavingsPaymentInfo' : '{669DAF62-7776-4DF5-AB51-B35DABFC4ACE}',
	'ICockpit' : '{30EB7C61-BD42-4AAF-877E-DB6253066688}',
	'IUserObjectMD_FormColumns' : '{0C607D21-E148-42CE-AF58-E8C38EB26275}',
	'IDeductionTaxHierarchies_Lines' : '{27A32FF4-4CC4-4D4A-860F-83E81EC52F3A}',
	'IImportProcesses' : '{8A8F6C7B-BD55-45C5-A28C-C81A786B0EB8}',
	'ISalesOpportunityCompetitorSetupParamsCollection' : '{892F8759-3131-447C-804C-73A754C51B42}',
	'IGeneralCollectionParams' : '{ACAC0540-ACCA-4278-8EB8-2300D893ADD1}',
	'ISalesOpportunitiesLines' : '{F5791EF2-E6CE-43CE-8A9C-59C628EEE419}',
	'IQueueMembers' : '{A6D332DA-630B-44C7-AA91-69F2C1A2501D}',
	'ICashDiscountsParams' : '{38B3A4C7-93BE-4A6C-A060-C54D34979E1C}',
	'IBrazilMultiIndexer' : '{EB892090-5B7A-48F1-849C-5F4A0048B2DA}',
	'IItemGroups' : '{216974E8-B66D-4022-9AB1-97BAA96084A3}',
	'ITaxInvoice_Lines' : '{D1DD9101-9264-450A-9FAC-C9D899078775}',
	'IWeightMeasures' : '{505427E7-5F80-437F-A4DD-972DA3F1C9C9}',
	'ICreditLine' : '{AFFBD91B-08A8-4972-B8B1-2E923B3F989A}',
	'IBrazilNumericIndexerParams' : '{7CF1BCB1-7449-4C23-BDC5-72313CAF5175}',
	'IChangeLogDifferencesParams' : '{FA06709C-FEAA-4E4B-85F1-063578C32965}',
	'ITaxReportFilter' : '{3503F7F1-5A0C-4D08-A498-0D9619097C09}',
	'IPayments_Accounts' : '{231A13D7-5DA8-4467-A263-FDE84A268AC9}',
	'ICashFlowLineItemParams' : '{A6EE3F95-9556-4409-9BCB-9DC06E009E22}',
	'IBOELine' : '{C9E6FA58-C5B3-469C-9F0C-45C63F3B057C}',
	'IServiceGroup' : '{A55338A2-5402-41BB-9588-39EC814AB644}',
	'IEmployeeRolesInfo' : '{3D698BD3-DA75-4CC7-97A9-AE151B6ADE3F}',
	'ILandedCost_CostLine' : '{7AF930C1-1211-4953-BD69-5F64B3743316}',
	'ITaxDefinitions' : '{9AA8D14C-3AB3-44F0-BEDD-0AB156BD2A9D}',
	'IDepartmentsParams' : '{A7A2DCAC-BFE4-4CAA-B5D0-A337C4783C60}',
	'IStatesParams' : '{3443DB6C-7014-4BC3-A860-F4934E449818}',
	'IAccrualTypesParams' : '{046161D0-6736-48A3-A619-805A9C68F5C1}',
	'IQueue' : '{8C5510F0-AA36-4CBD-A5AC-7DCF29EE0249}',
	'IWithholdingTaxCodes' : '{1B31BF62-5F56-4A20-876D-1B7BC75824C9}',
	'IBoxes1099' : '{1C7661BB-2694-4ECF-94EF-588ECB0CB8AD}',
	'IAccrualType' : '{439BEC35-EDAA-4F54-8FEF-647658D06148}',
	'IProfitCenter' : '{F29A5E07-7C8B-4706-99D7-9BFB85180358}',
	'ITaxInvoices' : '{9370956A-E63B-4B62-9AA0-EA32A0673B8A}',
	'IBrazilNumericIndexersParams' : '{12696EFB-62EF-4BD0-9B7B-456F3999DAEF}',
	'IBlanketAgreement' : '{14F49B88-4722-45AC-993A-AD7680142769}',
	'IVatGroups' : '{8F4727F1-1991-4F80-8363-F7E1ABD6AF5E}',
	'IBlanketAgreementsService' : '{E22659B2-7CEA-4351-96C4-80160CFAADE7}',
	'IMessageDataColumns' : '{002ACD1C-A740-40C7-9927-33E4CB58536F}',
	'ICampaignBusinessPartners' : '{05167588-6D3A-4C0E-AEFA-284CFDA23B7E}',
	'IExtendedTranslationsService' : '{F41E89FB-D3D8-47BE-858C-332AC9DF8A86}',
	'IFactoringIndicators' : '{DFE5A4A8-345B-43B3-A77F-906F10F142EE}',
	'IActivityTypes' : '{0C60C86B-3CB9-4E78-80D0-1AACB3C1C6F0}',
	'IBOEPortfoliosParams' : '{C44BDF5B-E877-4183-AC97-76D9E4921BB3}',
	'IDocumentSeriesParams' : '{E24C2504-36B4-4EE4-A990-0F487E774211}',
	'IInvokeParams' : '{D6BF90B4-5DE1-4A71-8463-FEB7AB1A9AB4}',
	'IBusinessPartnersService' : '{DF517030-9004-4965-96A3-CFE398A79DDC}',
	'ITaxReportAccounts' : '{009BFAE6-2701-4E63-B9EA-1335C9658CC0}',
	'IBrazilStringIndexer' : '{BCE76DC7-889C-4A7A-B77F-842FC7D0684E}',
	'IServiceGroupsService' : '{729A48C9-675C-4F2C-9A16-2C29D1825C05}',
	'INatureOfAssesseesService' : '{A60820F4-BCF8-4153-8E22-34DDF1E4F1E9}',
	'ISalesOpportunityReasonSetupParamsCollection' : '{475F9BBF-F860-48CE-8FD7-71E461BD7D95}',
	'IContacts' : '{96D7BBA9-27E7-4893-BC78-CC4313BE0DD1}',
	'ICountriesService' : '{12980E2B-036E-4D5D-90F9-44383341DF63}',
	'IMaterialRevaluationFIFO' : '{F5C29BC7-F643-4A93-9026-C045A11D564A}',
	'IAlternativeItems' : '{416CFADF-9DA6-47BD-A490-09AC890FC530}',
	'IMaterialRevaluation_lines' : '{038A3F8E-2465-435E-8D05-F510620533C3}',
	'IAccrualTypes' : '{539EA80F-E53D-45C1-9610-C1D138699EFB}',
	'IAlertManagementParams' : '{CC51470B-7859-4DC8-B636-E3856A52C02D}',
	'IBrazilMultiIndexersService' : '{207685C7-0E68-4A17-AD6C-7C2635B60316}',
	'IBPPaymentMethods' : '{7D947F60-6017-44AA-AEAC-9721FF263D5E}',
	'INatureOfAssesseesParams' : '{CD0EAC7A-0E3F-4ED3-A9BF-42D4100A3FBB}',
	'IBOEPortfolio' : '{EA561B2E-AEF0-4CFB-A2F4-4C450C33ADBE}',
	'IDNFCodeSetupParamsCollection' : '{80B626C7-6F5E-4C42-BBD0-36A311400BAE}',
	'ILayer' : '{9739A029-5EB0-499A-9E72-967B98D55ECF}',
	'IBOELinesService' : '{83E2FD00-E8D3-40D0-91E7-59166A6309DC}',
	'ILandedCost_CostLines' : '{83CB8BC4-7FE1-4C02-81B4-35EE3C252DC8}',
	'IKnowledgeBaseSolutions' : '{1E293D13-1EC1-4DF2-A5CC-7FE45030EEE5}',
	'IUserQueries' : '{9057028D-894C-4F75-877F-A856F36DDEA5}',
	'IGTIsService' : '{D0A0837D-25C5-4511-9C31-B749CA452C8F}',
	'IJournalEntryDocumentTypeParams' : '{16EC75C0-F804-4EC4-8BC3-9B70C74E014A}',
	'IBudgetDistribution' : '{0CFCFE82-D222-486A-9E49-0FBE58FDD534}',
	'IUserPermissionForms' : '{24464254-073D-4148-A045-3CFDB71DE48C}',
	'IDefaultDocuments' : '{38EFFD46-32F0-4190-A769-E13A5CCC3F47}',
	'IEmployeeRoleSetupParamsCollection' : '{9A49C2D7-CC5F-4CEE-95B9-6A8B16CA2031}',
	'IExtendedTranslationsParams' : '{57FF304C-3414-48FA-8059-4F3B10FB37C9}',
	'IJournalEntries' : '{060F033E-2FC9-4266-90AE-3271AC203A59}',
	'IApprovalRequestParams' : '{D12CB06B-CC0F-4C90-AB23-966C158B2DC2}',
	'ICostCenterTypes' : '{FACA7A4B-46DF-4875-8591-A5A0C3D9761F}',
	'IBlanketAgreementParams' : '{A3C28485-77EA-4396-9D1F-FAD7279A74A1}',
	'INFModel' : '{35E59851-3F5C-40B3-9613-BCC32E3B97B8}',
	'IProductTrees_Lines' : '{4F14B45D-CEA3-4D0C-A13A-DC670324AF81}',
	'ICampaignItems' : '{317E97C8-89A1-45FB-BDD3-8AB420DDF340}',
	'IDunningTermLines' : '{831AB766-3423-4E64-8EB1-42614102CDC7}',
	'IBrazilBeverageIndexer' : '{F17A759E-0E4E-448D-BA57-E6EF3760A591}',
	'IBrazilNumericIndexer' : '{69B00574-A904-4416-AC73-94E84B7882CA}',
	'IAccrualTypesService' : '{E78A5751-F0F7-4A5A-BDE0-B59BC461F57C}',
	'IDistributionRulesParams' : '{E5EB0192-6BCF-43FF-94E7-8A17C7F6B566}',
	'IBankChargesAllocationCode' : '{95968C8C-6866-4B59-BB03-E08A96684591}',
	'IActivitiesParams' : '{8289DE12-A145-459F-90F2-69A907294981}',
	'IStateParams' : '{E20B5B68-1106-4951-8C3C-1C44AB7A6B6F}',
	'IBOELineParams' : '{225FB23A-8178-4A0B-A9F4-88D1F33278DC}',
	'ISpecialPrices' : '{2C1751BA-5CFF-4E47-8C1E-13CAF241A13F}',
	'ITaxWebSitesParams' : '{AB9A1501-E84C-4EC2-9869-8A843FBCCBB6}',
	'IServiceCallProblemTypeParams' : '{0B24F304-D586-4E29-8820-90E334D034D5}',
	'IApprovalRequest' : '{92196C1E-B89A-4F4E-8E37-A1F2FAC71C5C}',
	'ICockpitsService' : '{907E9130-6B06-4C32-91E2-453846193486}',
	'IChecksforPayment' : '{5E6A92D1-9BAB-4BB4-A379-2428006247C3}',
	'ILocalEra' : '{B7A80F7E-77C0-404E-A8B3-01D0F9136DCF}',
}

win32com.client.constants.__dicts__.append(constants.__dict__)

